# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: otg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\totg.proto\x12\x03otg\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xeb\x02\n\x06\x43onfig\x12\x18\n\x05ports\x18\x01 \x03(\x0b\x32\t.otg.Port\x12\x16\n\x04lags\x18\x02 \x03(\x0b\x32\x08.otg.Lag\x12\x1b\n\x06layer1\x18\x03 \x03(\x0b\x32\x0b.otg.Layer1\x12\x1e\n\x08\x63\x61ptures\x18\x04 \x03(\x0b\x32\x0c.otg.Capture\x12\x1c\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x0b.otg.Device\x12\x18\n\x05\x66lows\x18\x06 \x03(\x0b\x32\t.otg.Flow\x12\x1a\n\x06\x65vents\x18\x07 \x01(\x0b\x32\n.otg.Event\x12#\n\x07options\x18\x08 \x01(\x0b\x32\x12.otg.ConfigOptions\x12\x17\n\x04lldp\x18\t \x03(\x0b\x32\t.otg.Lldp\x12)\n\x0estateful_flows\x18\n \x01(\x0b\x32\x11.otg.StatefulFlow\x12\x35\n\x14\x65gress_only_tracking\x18\x0b \x03(\x0b\x32\x17.otg.EgressOnlyTracking\"\x96\x01\n\rConfigOptions\x12&\n\x0cport_options\x18\x01 \x01(\x0b\x32\x10.otg.PortOptions\x12.\n\x10protocol_options\x18\x02 \x01(\x0b\x32\x14.otg.ProtocolOptions\x12-\n\x10per_port_options\x18\x03 \x03(\x0b\x32\x13.otg.PerPortOptions\"F\n\x04Port\x12\x15\n\x08location\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_locationB\x07\n\x05_name\"G\n\x0bPortOptions\x12 \n\x13location_preemption\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_location_preemption\"\x88\x01\n\x03Lag\x12\x1b\n\x05ports\x18\x01 \x03(\x0b\x32\x0c.otg.LagPort\x12\"\n\x08protocol\x18\x02 \x01(\x0b\x32\x10.otg.LagProtocol\x12\x16\n\tmin_links\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_min_linksB\x07\n\x05_name\"z\n\x07LagPort\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x04lacp\x18\x02 \x01(\x0b\x32\x10.otg.LagPortLacp\x12)\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x17.otg.DeviceEthernetBaseB\x0c\n\n_port_name\"\xd0\x01\n\x0bLagProtocol\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.LagProtocol.Choice.EnumH\x00\x88\x01\x01\x12\"\n\x04lacp\x18\x02 \x01(\x0b\x32\x14.otg.LagProtocolLacp\x12&\n\x06static\x18\x03 \x01(\x0b\x32\x16.otg.LagProtocolStatic\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04lacp\x10\x01\x12\n\n\x06static\x10\x02\x42\t\n\x07_choice\"3\n\x11LagProtocolStatic\x12\x13\n\x06lag_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_lag_id\"\xa7\x01\n\x0fLagProtocolLacp\x12\x1c\n\x0f\x61\x63tor_system_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x61\x63tor_system_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tactor_key\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x12\n\x10_actor_system_idB\x18\n\x16_actor_system_priorityB\x0c\n\n_actor_key\"\x93\x03\n\x0bLagPortLacp\x12\x1e\n\x11\x61\x63tor_port_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13\x61\x63tor_port_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12@\n\x0e\x61\x63tor_activity\x18\x03 \x01(\x0e\x32#.otg.LagPortLacp.ActorActivity.EnumH\x02\x88\x01\x01\x12*\n\x1dlacpdu_periodic_time_interval\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1b\n\x0elacpdu_timeout\x18\x05 \x01(\rH\x04\x88\x01\x01\x1a\x41\n\rActorActivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07passive\x10\x01\x12\n\n\x06\x61\x63tive\x10\x02\x42\x14\n\x12_actor_port_numberB\x16\n\x14_actor_port_priorityB\x11\n\x0f_actor_activityB \n\x1e_lacpdu_periodic_time_intervalB\x11\n\x0f_lacpdu_timeout\"\x84\x01\n\x12\x44\x65viceEthernetBase\x12\x10\n\x03mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03mtu\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x05vlans\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x11\n\x04name\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x06\n\x04_macB\x06\n\x04_mtuB\x07\n\x05_name\"\xe7\x02\n\x0e\x44\x65viceEthernet\x12+\n\nconnection\x18\x02 \x01(\x0b\x32\x17.otg.EthernetConnection\x12\'\n\x0eipv4_addresses\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceIpv4\x12\'\n\x0eipv6_addresses\x18\x04 \x03(\x0b\x32\x0f.otg.DeviceIpv6\x12\x10\n\x03mac\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03mtu\x18\x06 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x05vlans\x18\x07 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x11\n\x04name\x18\x08 \x01(\tH\x02\x88\x01\x01\x12\x32\n\x11\x64hcpv4_interfaces\x18\t \x03(\x0b\x32\x17.otg.DeviceDhcpv4client\x12\x32\n\x11\x64hcpv6_interfaces\x18\n \x03(\x0b\x32\x17.otg.DeviceDhcpv6clientB\x06\n\x04_macB\x06\n\x04_mtuB\x07\n\x05_name\"\xe3\x02\n\x12\x45thernetConnection\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.EthernetConnection.Choice.EnumH\x00\x88\x01\x01\x12\x16\n\tport_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08lag_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nvxlan_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x32\n\x0esimulated_link\x18\x05 \x01(\x0b\x32\x1a.otg.EthernetSimulatedLink\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tport_name\x10\x01\x12\x0c\n\x08lag_name\x10\x02\x12\x0e\n\nvxlan_name\x10\x03\x12\x12\n\x0esimulated_link\x10\x04\x42\t\n\x07_choiceB\x0c\n\n_port_nameB\x0b\n\t_lag_nameB\r\n\x0b_vxlan_name\"\xe6\x01\n\x15\x45thernetSimulatedLink\x12\"\n\x15remote_simulated_link\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\tlink_type\x18\x02 \x01(\x0e\x32(.otg.EthernetSimulatedLink.LinkType.EnumH\x01\x88\x01\x01\x1a?\n\x08LinkType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07primary\x10\x01\x12\r\n\tsecondary\x10\x02\x42\x18\n\x16_remote_simulated_linkB\x0c\n\n_link_type\"\xf3\x01\n\nDeviceVlan\x12,\n\x04tpid\x18\x01 \x01(\x0e\x32\x19.otg.DeviceVlan.Tpid.EnumH\x00\x88\x01\x01\x12\x15\n\x08priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x1aV\n\x04Tpid\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05x8100\x10\x01\x12\t\n\x05x88A8\x10\x02\x12\t\n\x05x9100\x10\x03\x12\t\n\x05x9200\x10\x04\x12\t\n\x05x9300\x10\x05\x42\x07\n\x05_tpidB\x0b\n\t_priorityB\x05\n\x03_idB\x07\n\x05_name\"\xbc\x01\n\nDeviceIpv4\x12\x14\n\x07gateway\x18\x01 \x01(\tH\x00\x88\x01\x01\x12.\n\x0bgateway_mac\x18\x02 \x01(\x0b\x32\x19.otg.DeviceIpv4GatewayMAC\x12\x14\n\x07\x61\x64\x64ress\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prefix\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\n\n\x08_gatewayB\n\n\x08_addressB\t\n\x07_prefixB\x07\n\x05_name\"v\n\x12\x44\x65viceIpv4Loopback\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_eth_nameB\n\n\x08_addressB\x07\n\x05_name\"\xcf\x01\n\x14\x44\x65viceIpv4GatewayMAC\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.DeviceIpv4GatewayMAC.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xbc\x01\n\nDeviceIpv6\x12\x14\n\x07gateway\x18\x01 \x01(\tH\x00\x88\x01\x01\x12.\n\x0bgateway_mac\x18\x02 \x01(\x0b\x32\x19.otg.DeviceIpv6GatewayMAC\x12\x14\n\x07\x61\x64\x64ress\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prefix\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\n\n\x08_gatewayB\n\n\x08_addressB\t\n\x07_prefixB\x07\n\x05_name\"v\n\x12\x44\x65viceIpv6Loopback\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_eth_nameB\n\n\x08_addressB\x07\n\x05_name\"\xcf\x01\n\x14\x44\x65viceIpv6GatewayMAC\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.DeviceIpv6GatewayMAC.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xce\x02\n\x12\x44\x65viceDhcpv4client\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x06\x63hoice\x18\x02 \x01(\x0e\x32#.otg.DeviceDhcpv4client.Choice.EnumH\x01\x88\x01\x01\x12\x1b\n\x0eserver_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tbroadcast\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12\x38\n\x17parameters_request_list\x18\x06 \x01(\x0b\x32\x17.otg.Dhcpv4ClientParams\x1aG\n\x06\x43hoice\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66irst_server\x10\x01\x12\x12\n\x0eserver_address\x10\x02\x42\x07\n\x05_nameB\t\n\x07_choiceB\x11\n\x0f_server_addressB\x0c\n\n_broadcast\"\xbe\x01\n\x12\x44hcpv4ClientParams\x12\x18\n\x0bsubnet_mask\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06router\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1a\n\rrenewal_timer\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1c\n\x0frebinding_timer\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x0e\n\x0c_subnet_maskB\t\n\x07_routerB\x10\n\x0e_renewal_timerB\x12\n\x10_rebinding_timer\"\xb1\x02\n\x12\x44\x65viceDhcpv6client\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0crapid_commit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12.\n\x07ia_type\x18\x03 \x01(\x0b\x32\x1d.otg.DeviceDhcpv6clientIaType\x12\x32\n\tduid_type\x18\x04 \x01(\x0b\x32\x1f.otg.DeviceDhcpv6clientDuidType\x12>\n\x0foptions_request\x18\x05 \x01(\x0b\x32%.otg.DeviceDhcpv6ClientOptionsRequest\x12/\n\x07options\x18\x06 \x01(\x0b\x32\x1e.otg.DeviceDhcpv6ClientOptionsB\x07\n\x05_nameB\x0f\n\r_rapid_commit\"\xa7\x01\n DeviceDhcpv6ClientOptionsRequest\x12\x37\n\x07request\x18\x01 \x03(\x0b\x32&.otg.Dhcpv6ClientOptionsOptionsRequest\x12J\n\x18\x61ssociated_dhcp_messages\x18\x02 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessages\"\x80\x02\n\x19\x44\x65viceDhcpv6ClientOptions\x12\x43\n\x11server_identifier\x18\x01 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsServerIdentifier\x12\x39\n\x0cvendor_class\x18\x02 \x01(\x0b\x32#.otg.Dhcpv6ClientOptionsVendorClass\x12\x37\n\x0bvendor_info\x18\x03 \x01(\x0b\x32\".otg.Dhcpv6ClientOptionsVendorInfo\x12*\n\x04\x66qdn\x18\x04 \x01(\x0b\x32\x1c.otg.Dhcpv6ClientOptionsFqdn\"\xca\x02\n\x18\x44\x65viceDhcpv6clientIaType\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.DeviceDhcpv6clientIaType.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x04iana\x18\x02 \x01(\x0b\x32\".otg.DeviceDhcpv6clientIaTimeValue\x12\x30\n\x04iapd\x18\x03 \x01(\x0b\x32\".otg.DeviceDhcpv6clientIaTimeValue\x12\x32\n\x06ianapd\x18\x04 \x01(\x0b\x32\".otg.DeviceDhcpv6clientIaTimeValue\x1aK\n\x06\x43hoice\"A\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04iana\x10\x01\x12\x08\n\x04iata\x10\x02\x12\x08\n\x04iapd\x10\x03\x12\n\n\x06ianapd\x10\x04\x42\t\n\x07_choice\"O\n\x1d\x44\x65viceDhcpv6clientIaTimeValue\x12\x0f\n\x02t1\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02t2\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x05\n\x03_t1B\x05\n\x03_t2\"\xaa\x02\n\x1a\x44\x65viceDhcpv6clientDuidType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.DeviceDhcpv6clientDuidType.Choice.EnumH\x00\x88\x01\x01\x12*\n\x03llt\x18\x02 \x01(\x0b\x32\x1d.otg.DeviceDhcpv6clientNoDuid\x12,\n\x02\x65n\x18\x03 \x01(\x0b\x32 .otg.DeviceDhcpv6clientDuidValue\x12)\n\x02ll\x18\x04 \x01(\x0b\x32\x1d.otg.DeviceDhcpv6clientNoDuid\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03llt\x10\x01\x12\x06\n\x02\x65n\x10\x02\x12\x06\n\x02ll\x10\x03\x42\t\n\x07_choice\"q\n\x1b\x44\x65viceDhcpv6clientDuidValue\x12\x1a\n\renterprise_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tvendor_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x10\n\x0e_enterprise_idB\x0c\n\n_vendor_id\"\x1a\n\x18\x44\x65viceDhcpv6clientNoDuid\"\x9f\x03\n#Dhcpv6ClientOptionsServerIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.Dhcpv6ClientOptionsServerIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x08\x64uid_llt\x18\x02 \x01(\x0b\x32\x1f.otg.Dhcpv6ClientOptionsDuidLlt\x12/\n\x07\x64uid_en\x18\x03 \x01(\x0b\x32\x1e.otg.Dhcpv6ClientOptionsDuidEn\x12/\n\x07\x64uid_ll\x18\x04 \x01(\x0b\x32\x1e.otg.Dhcpv6ClientOptionsDuidLl\x12\x33\n\tduid_uuid\x18\x05 \x01(\x0b\x32 .otg.Dhcpv6ClientOptionsDuidUuid\x1aX\n\x06\x43hoice\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08\x64uid_llt\x10\x01\x12\x0b\n\x07\x64uid_en\x10\x02\x12\x0b\n\x07\x64uid_ll\x10\x03\x12\r\n\tduid_uuid\x10\x04\x42\t\n\x07_choice\"~\n\x1a\x44hcpv6ClientOptionsDuidLlt\x12\x11\n\x04time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x44\n\x12link_layer_address\x18\x02 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsLinkLayerAddressB\x07\n\x05_time\"y\n\x19\x44hcpv6ClientOptionsDuidEn\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x17\n\nidentifier\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x14\n\x12_enterprise_numberB\r\n\x0b_identifier\"a\n\x19\x44hcpv6ClientOptionsDuidLl\x12\x44\n\x12link_layer_address\x18\x01 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsLinkLayerAddress\"\xa3\x03\n\x1b\x44hcpv6ClientOptionsDuidUuid\x12\x38\n\x07version\x18\x01 \x01(\x0b\x32\'.otg.Dhcpv6ClientOptionsDuidUuidVersion\x12\x38\n\x07variant\x18\x02 \x01(\x0b\x32\'.otg.Dhcpv6ClientOptionsDuidUuidVariant\x12\x15\n\x08time_low\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08time_mid\x18\x04 \x01(\rH\x01\x88\x01\x01\x12 \n\x13time_hi_and_version\x18\x05 \x01(\rH\x02\x88\x01\x01\x12&\n\x19\x63lock_seq_hi_and_reserved\x18\x06 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\rclock_seq_low\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x11\n\x04node\x18\x08 \x01(\tH\x05\x88\x01\x01\x42\x0b\n\t_time_lowB\x0b\n\t_time_midB\x16\n\x14_time_hi_and_versionB\x1c\n\x1a_clock_seq_hi_and_reservedB\x10\n\x0e_clock_seq_lowB\x07\n\x05_node\"\xc9\x01\n\"Dhcpv6ClientOptionsDuidUuidVersion\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.Dhcpv6ClientOptionsDuidUuidVersion.Choice.EnumH\x00\x88\x01\x01\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03v_1\x10\x01\x12\x07\n\x03v_2\x10\x02\x12\x07\n\x03v_3\x10\x03\x12\x07\n\x03v_4\x10\x04\x12\x07\n\x03v_5\x10\x05\x42\t\n\x07_choice\"\xca\x01\n\"Dhcpv6ClientOptionsDuidUuidVariant\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.Dhcpv6ClientOptionsDuidUuidVariant.Choice.EnumH\x00\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03ncs\x10\x01\x12\x07\n\x03\x64\x63\x65\x10\x02\x12\x08\n\x04guid\x10\x03\x12\x10\n\x0cvar_reserved\x10\x04\x42\t\n\x07_choice\"C\n#Dhcpv6ClientOptionsLinkLayerAddress\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xa6\x02\n!Dhcpv6ClientOptionsOptionsRequest\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.Dhcpv6ClientOptionsOptionsRequest.Choice.EnumH\x00\x88\x01\x01\x12.\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x1e.otg.Dhcpv6ClientOptionsCustom\x1a}\n\x06\x43hoice\"s\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12vendor_information\x10\x01\x12\x10\n\x0cname_servers\x10\x02\x12\x08\n\x04\x66qdn\x10\x03\x12\x10\n\x0c\x62ootfile_url\x10\x04\x12\x08\n\x04sztp\x10\x05\x12\n\n\x06\x63ustom\x10\x06\x42\t\n\x07_choice\"7\n\x19\x44hcpv6ClientOptionsCustom\x12\x11\n\x04type\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x07\n\x05_type\"\xb6\x01\n\x1e\x44hcpv6ClientOptionsVendorClass\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\nclass_data\x18\x02 \x03(\t\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessagesB\x14\n\x12_enterprise_number\"\xee\x01\n#Dhcpv6ClientOptionsIncludedMessages\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.Dhcpv6ClientOptionsIncludedMessages.Choice.EnumH\x00\x88\x01\x01\x12\x36\n\tmsg_types\x18\x02 \x03(\x0b\x32#.otg.Dhcpv6ClientOptionsMessageType\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\r\n\tmsg_types\x10\x02\x42\t\n\x07_choice\"\xe6\x01\n\x1e\x44hcpv6ClientOptionsMessageType\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.Dhcpv6ClientOptionsMessageType.Choice.EnumH\x00\x88\x01\x01\x1as\n\x06\x43hoice\"i\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07solicit\x10\x01\x12\x0b\n\x07request\x10\x02\x12\x12\n\x0einform_request\x10\x03\x12\x0b\n\x07release\x10\x04\x12\t\n\x05renew\x10\x05\x12\n\n\x06rebind\x10\x06\x42\t\n\x07_choice\"\xdf\x01\n\x1d\x44hcpv6ClientOptionsVendorInfo\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12<\n\x0boption_data\x18\x02 \x03(\x0b\x32\'.otg.Dhcpv6OptionsVendorSpecificOptions\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessagesB\x14\n\x12_enterprise_number\"\xdf\x01\n\x1d\x44hcpv6ServerOptionsVendorInfo\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12<\n\x0boption_data\x18\x02 \x03(\x0b\x32\'.otg.Dhcpv6OptionsVendorSpecificOptions\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ServerOptionsIncludedMessagesB\x14\n\x12_enterprise_number\"\xee\x01\n#Dhcpv6ServerOptionsIncludedMessages\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.Dhcpv6ServerOptionsIncludedMessages.Choice.EnumH\x00\x88\x01\x01\x12\x36\n\tmsg_types\x18\x02 \x03(\x0b\x32#.otg.Dhcpv6ServerOptionsMessageType\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\r\n\tmsg_types\x10\x02\x42\t\n\x07_choice\"\xc0\x01\n\x1e\x44hcpv6ServerOptionsMessageType\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.Dhcpv6ServerOptionsMessageType.Choice.EnumH\x00\x88\x01\x01\x1aM\n\x06\x43hoice\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tadvertise\x10\x01\x12\t\n\x05reply\x10\x02\x12\x10\n\x0cre_configure\x10\x03\x42\t\n\x07_choice\"\\\n\"Dhcpv6OptionsVendorSpecificOptions\x12\x11\n\x04\x63ode\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04\x64\x61ta\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\x07\n\x05_data\"\xef\x01\n\x17\x44hcpv6ClientOptionsFqdn\x12\x13\n\x06\x66lag_s\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x66lag_o\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06\x66lag_n\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x18\n\x0b\x64omain_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12J\n\x18\x61ssociated_dhcp_messages\x18\x05 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessagesB\t\n\x07_flag_sB\t\n\x07_flag_oB\t\n\x07_flag_nB\x0e\n\x0c_domain_name\"\xc7\x01\n\x1e\x44hcpv6ServerOptionsBootfileUrl\x12\x10\n\x03url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\x0f\x62ootfile_params\x18\x02 \x03(\x0b\x32&.otg.Dhcpv6ServerOptionsBootFileParams\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ServerOptionsIncludedMessagesB\x06\n\x04_url\"I\n!Dhcpv6ServerOptionsBootFileParams\x12\x16\n\tparameter\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_parameter\"\xa6\x06\n\x06Layer1\x12\x12\n\nport_names\x18\x01 \x03(\t\x12*\n\x05speed\x18\x02 \x01(\x0e\x32\x16.otg.Layer1.Speed.EnumH\x00\x88\x01\x01\x12*\n\x05media\x18\x03 \x01(\x0e\x32\x16.otg.Layer1.Media.EnumH\x01\x88\x01\x01\x12\x18\n\x0bpromiscuous\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03mtu\x18\x05 \x01(\rH\x03\x88\x01\x01\x12 \n\x13ieee_media_defaults\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x1b\n\x0e\x61uto_negotiate\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x34\n\x10\x61uto_negotiation\x18\x08 \x01(\x0b\x32\x1a.otg.Layer1AutoNegotiation\x12,\n\x0c\x66low_control\x18\t \x01(\x0b\x32\x16.otg.Layer1FlowControl\x12\x11\n\x04name\x18\n \x01(\tH\x06\x88\x01\x01\x1a\xa9\x02\n\x05Speed\"\x9f\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10speed_10_fd_mbps\x10\x01\x12\x14\n\x10speed_10_hd_mbps\x10\x02\x12\x15\n\x11speed_100_fd_mbps\x10\x03\x12\x15\n\x11speed_100_hd_mbps\x10\x04\x12\x10\n\x0cspeed_1_gbps\x10\x05\x12\x11\n\rspeed_10_gbps\x10\x06\x12\x11\n\rspeed_25_gbps\x10\x07\x12\x11\n\rspeed_40_gbps\x10\x08\x12\x11\n\rspeed_50_gbps\x10\t\x12\x12\n\x0espeed_100_gbps\x10\n\x12\x12\n\x0espeed_200_gbps\x10\x0b\x12\x12\n\x0espeed_400_gbps\x10\x0c\x12\x12\n\x0espeed_800_gbps\x10\r\x1a\x42\n\x05Media\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63opper\x10\x01\x12\t\n\x05\x66iber\x10\x02\x12\t\n\x05sgmii\x10\x03\x42\x08\n\x06_speedB\x08\n\x06_mediaB\x0e\n\x0c_promiscuousB\x06\n\x04_mtuB\x16\n\x14_ieee_media_defaultsB\x11\n\x0f_auto_negotiateB\x07\n\x05_name\"\x93\x03\n\x15Layer1AutoNegotiation\x12 \n\x13\x61\x64vertise_1000_mbps\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_fd_mbps\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_hd_mbps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_fd_mbps\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_hd_mbps\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rlink_training\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06rs_fec\x18\x07 \x01(\x08H\x06\x88\x01\x01\x42\x16\n\x14_advertise_1000_mbpsB\x18\n\x16_advertise_100_fd_mbpsB\x18\n\x16_advertise_100_hd_mbpsB\x17\n\x15_advertise_10_fd_mbpsB\x17\n\x15_advertise_10_hd_mbpsB\x10\n\x0e_link_trainingB\t\n\x07_rs_fec\"\xac\x02\n\x11Layer1FlowControl\x12\x1d\n\x10\x64irected_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\".otg.Layer1FlowControl.Choice.EnumH\x01\x88\x01\x01\x12-\n\rieee_802_1qbb\x18\x03 \x01(\x0b\x32\x16.otg.Layer1Ieee8021qbb\x12)\n\x0bieee_802_3x\x18\x04 \x01(\x0b\x32\x14.otg.Layer1Ieee8023x\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rieee_802_1qbb\x10\x01\x12\x0f\n\x0bieee_802_3x\x10\x02\x42\x13\n\x11_directed_addressB\t\n\x07_choice\"\x11\n\x0fLayer1Ieee8023x\"\x89\x03\n\x11Layer1Ieee8021qbb\x12\x16\n\tpfc_delay\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0bpfc_class_0\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bpfc_class_1\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0bpfc_class_2\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0bpfc_class_3\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x18\n\x0bpfc_class_4\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0bpfc_class_5\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x18\n\x0bpfc_class_6\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x18\n\x0bpfc_class_7\x18\t \x01(\rH\x08\x88\x01\x01\x42\x0c\n\n_pfc_delayB\x0e\n\x0c_pfc_class_0B\x0e\n\x0c_pfc_class_1B\x0e\n\x0c_pfc_class_2B\x0e\n\x0c_pfc_class_3B\x0e\n\x0c_pfc_class_4B\x0e\n\x0c_pfc_class_5B\x0e\n\x0c_pfc_class_6B\x0e\n\x0c_pfc_class_7\"\xa1\x02\n\x07\x43\x61pture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.otg.CaptureFilter\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bpacket_size\x18\x04 \x01(\rH\x01\x88\x01\x01\x12-\n\x06\x66ormat\x18\x05 \x01(\x0e\x32\x18.otg.Capture.Format.EnumH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x06 \x01(\tH\x03\x88\x01\x01\x1a\x37\n\x06\x46ormat\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04pcap\x10\x01\x12\n\n\x06pcapng\x10\x02\x42\x0c\n\n_overwriteB\x0e\n\x0c_packet_sizeB\t\n\x07_formatB\x07\n\x05_name\"\xd6\x02\n\rCaptureFilter\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.CaptureFilter.Choice.EnumH\x00\x88\x01\x01\x12\"\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x12.otg.CaptureCustom\x12&\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x14.otg.CaptureEthernet\x12\x1e\n\x04vlan\x18\x04 \x01(\x0b\x32\x10.otg.CaptureVlan\x12\x1e\n\x04ipv4\x18\x05 \x01(\x0b\x32\x10.otg.CaptureIpv4\x12\x1e\n\x04ipv6\x18\x06 \x01(\x0b\x32\x10.otg.CaptureIpv6\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\x08\n\x04ipv4\x10\x04\x12\x08\n\x04ipv6\x10\x05\x42\t\n\x07_choice\"\xb1\x01\n\rCaptureCustom\x12\x13\n\x06offset\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x17\n\nbit_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04mask\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06negate\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_offsetB\r\n\x0b_bit_lengthB\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"h\n\x0c\x43\x61ptureField\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04mask\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06negate\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"\x9e\x01\n\x0f\x43\x61ptureEthernet\x12\x1e\n\x03src\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x64st\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12%\n\nether_type\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12$\n\tpfc_queue\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\"\x96\x01\n\x0b\x43\x61ptureVlan\x12#\n\x08priority\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1d\n\x02id\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08protocol\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\"\xb4\x04\n\x0b\x43\x61ptureIpv4\x12\"\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12(\n\rheader_length\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08priority\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12\'\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\x12)\n\x0eidentification\x18\x05 \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08reserved\x18\x06 \x01(\x0b\x32\x11.otg.CaptureField\x12(\n\rdont_fragment\x18\x07 \x01(\x0b\x32\x11.otg.CaptureField\x12)\n\x0emore_fragments\x18\x08 \x01(\x0b\x32\x11.otg.CaptureField\x12*\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\x11.otg.CaptureField\x12\'\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08protocol\x18\x0b \x01(\x0b\x32\x11.otg.CaptureField\x12*\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03src\x18\r \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x64st\x18\x0e \x01(\x0b\x32\x11.otg.CaptureField\"\xbb\x02\n\x0b\x43\x61ptureIpv6\x12\"\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12(\n\rtraffic_class\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12%\n\nflow_label\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12)\n\x0epayload_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\x12&\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x11.otg.CaptureField\x12$\n\thop_limit\x18\x06 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03src\x18\x07 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x64st\x18\x08 \x01(\x0b\x32\x11.otg.CaptureField\"\xfe\x03\n\x06\x44\x65vice\x12&\n\tethernets\x18\x01 \x03(\x0b\x32\x13.otg.DeviceEthernet\x12/\n\x0eipv4_loopbacks\x18\x02 \x03(\x0b\x32\x17.otg.DeviceIpv4Loopback\x12/\n\x0eipv6_loopbacks\x18\x03 \x03(\x0b\x32\x17.otg.DeviceIpv6Loopback\x12#\n\x04isis\x18\x04 \x01(\x0b\x32\x15.otg.DeviceIsisRouter\x12!\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x14.otg.DeviceBgpRouter\x12\x1f\n\x05vxlan\x18\x06 \x01(\x0b\x32\x10.otg.DeviceVxlan\x12\x11\n\x04name\x18\x07 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x04rsvp\x18\x08 \x01(\x0b\x32\x0f.otg.DeviceRsvp\x12*\n\x0b\x64hcp_server\x18\t \x01(\x0b\x32\x15.otg.DeviceDhcpServer\x12\'\n\x06ospfv2\x18\n \x01(\x0b\x32\x17.otg.DeviceOspfv2Router\x12!\n\x06macsec\x18\x0b \x01(\x0b\x32\x11.otg.DeviceMacsec\x12\'\n\x06ospfv3\x18\x0c \x01(\x0b\x32\x17.otg.DeviceOspfv3Router\x12%\n\x06rocev2\x18\r \x01(\x0b\x32\x15.otg.DeviceRocev2PeerB\x07\n\x05_name\"A\n\x0fProtocolOptions\x12\x1b\n\x0e\x61uto_start_all\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x11\n\x0f_auto_start_all\"\xd8\x03\n\x10\x44\x65viceIsisRouter\x12.\n\x08instance\x18\x01 \x01(\x0b\x32\x1c.otg.DeviceIsisMultiInstance\x12\x16\n\tsystem_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12&\n\ninterfaces\x18\x03 \x03(\x0b\x32\x12.otg.IsisInterface\x12\x1d\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32\x0e.otg.IsisBasic\x12#\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x11.otg.IsisAdvanced\x12,\n\x0brouter_auth\x18\x06 \x01(\x0b\x32\x17.otg.IsisAuthentication\x12(\n\tv4_routes\x18\x07 \x03(\x0b\x32\x15.otg.IsisV4RouteRange\x12(\n\tv6_routes\x18\x08 \x03(\x0b\x32\x15.otg.IsisV6RouteRange\x12\x11\n\x04name\x18\t \x01(\tH\x01\x88\x01\x01\x12\x30\n\x0fsegment_routing\x18\n \x01(\x0b\x32\x17.otg.IsisSegmentRouting\x12\x32\n\x10graceful_restart\x18\x0b \x01(\x0b\x32\x18.otg.IsisGracefulRestartB\x0c\n\n_system_idB\x07\n\x05_name\"B\n\x17\x44\x65viceIsisMultiInstance\x12\x10\n\x03iid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\r\n\x05itids\x18\x02 \x03(\rB\x06\n\x04_iid\"\xc9\x06\n\rIsisInterface\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x02 \x01(\rH\x01\x88\x01\x01\x12>\n\x0cnetwork_type\x18\x03 \x01(\x0e\x32#.otg.IsisInterface.NetworkType.EnumH\x02\x88\x01\x01\x12:\n\nlevel_type\x18\x04 \x01(\x0e\x32!.otg.IsisInterface.LevelType.EnumH\x03\x88\x01\x01\x12,\n\x0bl1_settings\x18\x05 \x01(\x0b\x32\x17.otg.IsisInterfaceLevel\x12,\n\x0bl2_settings\x18\x06 \x01(\x0b\x32\x17.otg.IsisInterfaceLevel\x12\'\n\x12multi_topology_ids\x18\x07 \x03(\x0b\x32\x0b.otg.IsisMT\x12-\n\x13traffic_engineering\x18\x08 \x03(\x0b\x32\x10.otg.LinkStateTE\x12\x38\n\x0e\x61uthentication\x18\t \x01(\x0b\x32 .otg.IsisInterfaceAuthentication\x12,\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x1a.otg.IsisInterfaceAdvanced\x12\x39\n\x0flink_protection\x18\x0b \x01(\x0b\x32 .otg.IsisInterfaceLinkProtection\x12\x13\n\x0bsrlg_values\x18\x0c \x03(\r\x12\x11\n\x04name\x18\r \x01(\tH\x04\x88\x01\x01\x12\x36\n\x0e\x61\x64jacency_sids\x18\x0e \x03(\x0b\x32\x1e.otg.IsisInterfaceAdjacencySid\x1aI\n\x0bNetworkType\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\x0b\n\t_eth_nameB\t\n\x07_metricB\x0f\n\r_network_typeB\r\n\x0b_level_typeB\x07\n\x05_name\"\x96\x01\n\x12IsisInterfaceLevel\x12\x15\n\x08priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x0b\n\t_priorityB\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_interval\"P\n\x06IsisMT\x12\x12\n\x05mt_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0blink_metric\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_mt_idB\x0e\n\x0c_link_metric\"\xa4\x02\n\x0bLinkStateTE\x12!\n\x14\x61\x64ministrative_group\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cmetric_level\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0cmax_bandwith\x18\x03 \x01(\rH\x02\x88\x01\x01\x12%\n\x18max_reservable_bandwidth\x18\x04 \x01(\rH\x03\x88\x01\x01\x12=\n\x13priority_bandwidths\x18\x05 \x01(\x0b\x32 .otg.LinkStatepriorityBandwidthsB\x17\n\x15_administrative_groupB\x0f\n\r_metric_levelB\x0f\n\r_max_bandwithB\x1b\n\x19_max_reservable_bandwidth\"\xed\x01\n\x1bLinkStatepriorityBandwidths\x12\x10\n\x03pb0\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03pb1\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x10\n\x03pb2\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x10\n\x03pb3\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x10\n\x03pb4\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x10\n\x03pb5\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x10\n\x03pb6\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x10\n\x03pb7\x18\x08 \x01(\rH\x07\x88\x01\x01\x42\x06\n\x04_pb0B\x06\n\x04_pb1B\x06\n\x04_pb2B\x06\n\x04_pb3B\x06\n\x04_pb4B\x06\n\x04_pb5B\x06\n\x04_pb6B\x06\n\x04_pb7\"\xed\x01\n\x1bIsisInterfaceAuthentication\x12\x46\n\tauth_type\x18\x01 \x01(\x0e\x32..otg.IsisInterfaceAuthentication.AuthType.EnumH\x00\x88\x01\x01\x12\x10\n\x03md5\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x0c\n\n_auth_typeB\x06\n\x04_md5B\x0b\n\t_password\"\xd3\x02\n\x15IsisInterfaceAdvanced\x12\x1c\n\x0f\x61uto_adjust_mtu\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1d\n\x10\x61uto_adjust_area\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12,\n\x1f\x61uto_adjust_supported_protocols\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\"\n\x15\x65nable_3way_handshake\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12&\n\x19p2p_hellos_to_unicast_mac\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x12\n\x10_auto_adjust_mtuB\x13\n\x11_auto_adjust_areaB\"\n _auto_adjust_supported_protocolsB\x18\n\x16_enable_3way_handshakeB\x1c\n\x1a_p2p_hellos_to_unicast_mac\"\xf9\x02\n\x1bIsisInterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\x94\x03\n\x19IsisInterfaceAdjacencySid\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.IsisInterfaceAdjacencySid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\nsid_values\x18\x02 \x03(\r\x12\x13\n\x0bsid_indices\x18\x03 \x03(\r\x12\x13\n\x06\x66_flag\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06\x62_flag\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06l_flag\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06s_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06p_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06weight\x18\t \x01(\rH\x06\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nsid_values\x10\x01\x12\x0f\n\x0bsid_indices\x10\x02\x42\t\n\x07_choiceB\t\n\x07_f_flagB\t\n\x07_b_flagB\t\n\x07_l_flagB\t\n\x07_s_flagB\t\n\x07_p_flagB\t\n\x07_weight\"\xd5\x01\n\tIsisBasic\x12\x1e\n\x11ipv4_te_router_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08hostname\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x65nable_wide_metric\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1f\n\x12learned_lsp_filter\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x14\n\x12_ipv4_te_router_idB\x0b\n\t_hostnameB\x15\n\x13_enable_wide_metricB\x15\n\x13_learned_lsp_filter\"\x8a\x04\n\x0cIsisAdvanced\x12!\n\x14\x65nable_hello_padding\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12max_area_addresses\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\x0e\x61rea_addresses\x18\x03 \x03(\t\x12\x1d\n\x10lsp_refresh_rate\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x19\n\x0clsp_lifetime\x18\x05 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\rpsnp_interval\x18\x06 \x01(\rH\x04\x88\x01\x01\x12\x1a\n\rcsnp_interval\x18\x07 \x01(\rH\x05\x88\x01\x01\x12\x19\n\x0cmax_lsp_size\x18\x08 \x01(\rH\x06\x88\x01\x01\x12*\n\x1dlsp_mgroup_min_trans_interval\x18\t \x01(\rH\x07\x88\x01\x01\x12 \n\x13\x65nable_attached_bit\x18\n \x01(\x08H\x08\x88\x01\x01\x42\x17\n\x15_enable_hello_paddingB\x15\n\x13_max_area_addressesB\x13\n\x11_lsp_refresh_rateB\x0f\n\r_lsp_lifetimeB\x10\n\x0e_psnp_intervalB\x10\n\x0e_csnp_intervalB\x0f\n\r_max_lsp_sizeB \n\x1e_lsp_mgroup_min_trans_intervalB\x16\n\x14_enable_attached_bit\"\xae\x01\n\x12IsisAuthentication\x12\x1f\n\x12ignore_receive_md5\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12.\n\tarea_auth\x18\x02 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBase\x12\x30\n\x0b\x64omain_auth\x18\x03 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseB\x15\n\x13_ignore_receive_md5\"\xe3\x01\n\x16IsisAuthenticationBase\x12\x41\n\tauth_type\x18\x01 \x01(\x0e\x32).otg.IsisAuthenticationBase.AuthType.EnumH\x00\x88\x01\x01\x12\x10\n\x03md5\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x0c\n\n_auth_typeB\x06\n\x04_md5B\x0b\n\t_password\"\x83\x05\n\x10IsisV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\rH\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV4RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV4RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x07\x88\x01\x01\x12)\n\x0bprefix_sids\x18\n \x03(\x0b\x32\x14.otg.IsisSRPrefixSid\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x07\n\x05_nameB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"\x8c\x01\n\x0eV4RouteAddress\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\n\n\x08_addressB\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\x8c\x01\n\x0eV6RouteAddress\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\n\n\x08_addressB\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\x8d\x01\n\x0fMACRouteAddress\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\n\n\x08_addressB\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\x86\x03\n\x0fIsisSRPrefixSid\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.IsisSRPrefixSid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\nsid_values\x18\x02 \x03(\r\x12\x13\n\x0bsid_indices\x18\x03 \x03(\r\x12\x13\n\x06r_flag\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06n_flag\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06p_flag\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06\x65_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06l_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x16\n\talgorithm\x18\t \x01(\rH\x06\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nsid_values\x10\x01\x12\x0f\n\x0bsid_indices\x10\x02\x42\t\n\x07_choiceB\t\n\x07_r_flagB\t\n\x07_n_flagB\t\n\x07_p_flagB\t\n\x07_e_flagB\t\n\x07_l_flagB\x0c\n\n_algorithm\"\x83\x05\n\x10IsisV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\rH\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV6RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV6RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x07\x88\x01\x01\x12)\n\x0bprefix_sids\x18\n \x03(\x0b\x32\x14.otg.IsisSRPrefixSid\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x07\n\x05_nameB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"J\n\x12IsisSegmentRouting\x12\x34\n\x11router_capability\x18\x01 \x01(\x0b\x32\x19.otg.IsisRouterCapability\"\xe1\x04\n\x14IsisRouterCapability\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.IsisRouterCapability.Choice.EnumH\x00\x88\x01\x01\x12!\n\x14\x63ustom_router_cap_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x37\n\x05s_bit\x18\x03 \x01(\x0e\x32#.otg.IsisRouterCapability.SBit.EnumH\x02\x88\x01\x01\x12\x37\n\x05\x64_bit\x18\x04 \x01(\x0e\x32#.otg.IsisRouterCapability.DBit.EnumH\x03\x88\x01\x01\x12,\n\rsr_capability\x18\x05 \x01(\x0b\x32\x15.otg.IsisSRCapability\x12\x12\n\nalgorithms\x18\x06 \x03(\r\x12$\n\x0bsrlb_ranges\x18\x07 \x03(\x0b\x32\x0f.otg.IsisSRSrlb\x1a\x64\n\x06\x43hoice\"Z\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11ipv4_te_router_id\x10\x01\x12\x10\n\x0cinterface_ip\x10\x02\x12\x18\n\x14\x63ustom_router_cap_id\x10\x03\x1a\x39\n\x04SBit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lood\x10\x01\x12\r\n\tnot_flood\x10\x02\x1a\x37\n\x04\x44\x42it\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64own\x10\x01\x12\x0c\n\x08not_down\x10\x02\x42\t\n\x07_choiceB\x17\n\x15_custom_router_cap_idB\x08\n\x06_s_bitB\x08\n\x06_d_bit\"c\n\x10IsisSRCapability\x12)\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.IsisSRCapabilityFlags\x12$\n\x0bsrgb_ranges\x18\x02 \x03(\x0b\x32\x0f.otg.IsisSRSrgb\"c\n\x15IsisSRCapabilityFlags\x12\x16\n\tipv4_mpls\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tipv6_mpls\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0c\n\n_ipv4_mplsB\x0c\n\n_ipv6_mpls\"V\n\nIsisSRSrgb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"V\n\nIsisSRSrlb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"?\n\x13IsisGracefulRestart\x12\x18\n\x0bhelper_mode\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x0e\n\x0c_helper_mode\"\x93\x01\n\x0f\x44\x65viceBgpRouter\x12\x16\n\trouter_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12,\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x13.otg.BgpV4Interface\x12,\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x13.otg.BgpV6InterfaceB\x0c\n\n_router_id\"\x90\x02\n\x1b\x44\x65viceBgpMessageHeaderError\x12\x43\n\x07subcode\x18\x01 \x01(\x0e\x32-.otg.DeviceBgpMessageHeaderError.Subcode.EnumH\x00\x88\x01\x01\x1a\x9f\x01\n\x07Subcode\"\x93\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12.\n*connection_not_synchronized_code1_subcode1\x10\x01\x12%\n!bad_message_length_code1_subcode2\x10\x02\x12#\n\x1f\x62\x61\x64_message_type_code1_subcode3\x10\x03\x42\n\n\x08_subcode\"\xaa\x03\n\x19\x44\x65viceBgpOpenMessageError\x12\x41\n\x07subcode\x18\x01 \x01(\x0e\x32+.otg.DeviceBgpOpenMessageError.Subcode.EnumH\x00\x88\x01\x01\x1a\xbd\x02\n\x07Subcode\"\xb1\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12-\n)unsupported_version_number_code2_subcode1\x10\x01\x12 \n\x1c\x65rror_peer_as_code2_subcode2\x10\x02\x12\x1f\n\x1b\x65rror_bgp_id_code2_subcode3\x10\x03\x12\x31\n-unsupported_optional_parameter_code2_subcode4\x10\x04\x12\x1e\n\x1a\x61uth_failed_code2_subcode5\x10\x05\x12(\n$unsupported_hold_time_code2_subcode6\x10\x06\x12)\n%unsupported_capability_code2_subcode7\x10\x07\x42\n\n\x08_subcode\"\xdc\x04\n\x1b\x44\x65viceBgpUpdateMessageError\x12\x43\n\x07subcode\x18\x01 \x01(\x0e\x32-.otg.DeviceBgpUpdateMessageError.Subcode.EnumH\x00\x88\x01\x01\x1a\xeb\x03\n\x07Subcode\"\xdf\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12(\n$malformed_attrib_list_code3_subcode1\x10\x01\x12\x30\n,unrecognized_wellknown_attrib_code3_subcode2\x10\x02\x12+\n\'wellknown_attrib_missing_code3_subcode3\x10\x03\x12%\n!attrib_flags_error_code3_subcode4\x10\x04\x12&\n\"attrib_length_error_code3_subcode5\x10\x05\x12(\n$invalid_origin_attrib_code3_subcode6\x10\x06\x12\"\n\x1e\x61s_routing_loop_code3_subcode7\x10\x07\x12&\n\"invalid_nhop_attrib_code3_subcode8\x10\x08\x12(\n$error_optional_attrib_code3_subcode9\x10\t\x12)\n%invalid_network_field_code3_subcode10\x10\n\x12#\n\x1f\x61\x62normal_aspath_code3_subcode11\x10\x0b\x42\n\n\x08_subcode\"\x1b\n\x19\x44\x65viceBgpHoldTimerExpired\"\"\n DeviceBgpFiniteStateMachineError\"\x83\x04\n\x13\x44\x65viceBgpCeaseError\x12;\n\x07subcode\x18\x01 \x01(\x0e\x32%.otg.DeviceBgpCeaseError.Subcode.EnumH\x00\x88\x01\x01\x1a\xa2\x03\n\x07Subcode\"\x96\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12,\n(max_number_prefix_reached_code6_subcode1\x10\x01\x12!\n\x1d\x61\x64min_shutdown_code6_subcode2\x10\x02\x12\x1f\n\x1bpeer_deleted_code6_subcode3\x10\x03\x12\x1e\n\x1a\x61\x64min_reset_code6_subcode4\x10\x04\x12$\n connection_reject_code6_subcode5\x10\x05\x12\'\n#other_config_changes_code6_subcode6\x10\x06\x12\x32\n.connection_collision_resolution_code6_subcode7\x10\x07\x12#\n\x1fout_of_resources_code6_subcode8\x10\x08\x12$\n bfd_session_down_code6_subcode10\x10\t\x12\x1d\n\x19hard_reset_code6_subcode9\x10\nB\n\n\x08_subcode\"T\n\x14\x44\x65viceBgpCustomError\x12\x11\n\x04\x63ode\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x14\n\x07subcode\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_subcode\"\xe0\x06\n\tBgpV4Peer\x12\x19\n\x0cpeer_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x39\n\x16\x65vpn_ethernet_segments\x18\x02 \x03(\x0b\x32\x19.otg.BgpV4EthernetSegment\x12\x30\n\x07\x61s_type\x18\x03 \x01(\x0e\x32\x1a.otg.BgpV4Peer.AsType.EnumH\x01\x88\x01\x01\x12\x16\n\tas_number\x18\x04 \x01(\rH\x02\x88\x01\x01\x12?\n\x0f\x61s_number_width\x18\x05 \x01(\x0e\x32!.otg.BgpV4Peer.AsNumberWidth.EnumH\x03\x88\x01\x01\x12\"\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x10.otg.BgpAdvanced\x12&\n\ncapability\x18\x07 \x01(\x0b\x32\x12.otg.BgpCapability\x12\x44\n\x1alearned_information_filter\x18\x08 \x01(\x0b\x32 .otg.BgpLearnedInformationFilter\x12\'\n\tv4_routes\x18\t \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\n \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\x0b \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\x0c \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x11\n\x04name\x18\r \x01(\tH\x04\x88\x01\x01\x12\x31\n\x10graceful_restart\x18\x0e \x01(\x0b\x32\x17.otg.BgpGracefulRestart\x12,\n\x0ereplay_updates\x18\x0f \x01(\x0b\x32\x14.otg.BgpUpdateReplay\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x0f\n\r_peer_addressB\n\n\x08_as_typeB\x0c\n\n_as_numberB\x12\n\x10_as_number_widthB\x07\n\x05_name\"U\n\x0e\x42gpV4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV4PeerB\x0c\n\n_ipv4_name\"\xf0\x03\n\x14\x42gpV4EthernetSegment\x12\x36\n\x0b\x64\x66_election\x18\x01 \x01(\x0b\x32!.otg.BgpEthernetSegmentDfElection\x12 \n\x04\x65vis\x18\x02 \x03(\x0b\x32\x12.otg.BgpV4EvpnEvis\x12\x10\n\x03\x65si\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x43\n\x0b\x61\x63tive_mode\x18\x04 \x01(\x0e\x32).otg.BgpV4EthernetSegment.ActiveMode.EnumH\x01\x88\x01\x01\x12\x16\n\tesi_label\x18\x05 \x01(\rH\x02\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x08 \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\t \x01(\x0b\x32\x0e.otg.BgpAsPath\x1aH\n\nActiveMode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsingle_active\x10\x01\x12\x0e\n\nall_active\x10\x02\x42\x06\n\x04_esiB\x0e\n\x0c_active_modeB\x0c\n\n_esi_label\"N\n\x1c\x42gpEthernetSegmentDfElection\x12\x1b\n\x0e\x65lection_timer\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x11\n\x0f_election_timer\"\xda\x03\n\x10\x42gpRouteAdvanced\x12-\n include_multi_exit_discriminator\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\x01 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0einclude_origin\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x36\n\x06origin\x18\x02 \x01(\x0e\x32!.otg.BgpRouteAdvanced.Origin.EnumH\x03\x88\x01\x01\x12%\n\x18include_local_preference\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1d\n\x10local_preference\x18\x06 \x01(\rH\x05\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42#\n!_include_multi_exit_discriminatorB\x1b\n\x19_multi_exit_discriminatorB\x11\n\x0f_include_originB\t\n\x07_originB\x1b\n\x19_include_local_preferenceB\x13\n\x11_local_preference\"\xa4\x02\n\x0c\x42gpCommunity\x12.\n\x04type\x18\x01 \x01(\x0e\x32\x1b.otg.BgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"\xf9\x03\n\x0f\x42gpExtCommunity\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\x1e.otg.BgpExtCommunity.Type.EnumH\x00\x88\x01\x01\x12\x37\n\x07subtype\x18\x02 \x01(\x0e\x32!.otg.BgpExtCommunity.Subtype.EnumH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\xbc\x01\n\x04Type\"\xb3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x61\x64ministrator_as_2octet\x10\x01\x12\x1e\n\x1a\x61\x64ministrator_ipv4_address\x10\x02\x12\x1b\n\x17\x61\x64ministrator_as_4octet\x10\x03\x12\n\n\x06opaque\x10\x04\x12\x08\n\x04\x65vpn\x10\x05\x12*\n&administrator_as_2octet_link_bandwidth\x10\x06\x1a\x87\x01\n\x07Subtype\"|\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0croute_target\x10\x01\x12\n\n\x06origin\x10\x02\x12\x16\n\x12\x65xtended_bandwidth\x10\x03\x12\t\n\x05\x63olor\x10\x04\x12\x11\n\rencapsulation\x10\x05\x12\x0f\n\x0bmac_address\x10\x06\x42\x07\n\x05_typeB\n\n\x08_subtypeB\x08\n\x06_value\"\xbe\x02\n\tBgpAsPath\x12\x37\n\x0b\x61s_set_mode\x18\x01 \x01(\x0e\x32\x1d.otg.BgpAsPath.AsSetMode.EnumH\x00\x88\x01\x01\x12\'\n\x08segments\x18\x02 \x03(\x0b\x32\x15.otg.BgpAsPathSegment\x1a\xbe\x01\n\tAsSetMode\"\xb0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x64o_not_include_local_as\x10\x01\x12\x12\n\x0einclude_as_seq\x10\x02\x12\x12\n\x0einclude_as_set\x10\x03\x12\x19\n\x15include_as_confed_seq\x10\x04\x12\x19\n\x15include_as_confed_set\x10\x05\x12\x1c\n\x18prepend_to_first_segment\x10\x06\x42\x0e\n\x0c_as_set_mode\"\xc2\x01\n\x10\x42gpAsPathSegment\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"\xa8\x01\n\rBgpV4EvpnEvis\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.BgpV4EvpnEvis.Choice.EnumH\x00\x88\x01\x01\x12%\n\tevi_vxlan\x18\x02 \x01(\x0b\x32\x12.otg.BgpV4EviVxlan\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tevi_vxlan\x10\x01\x42\t\n\x07_choice\"\xe3\x05\n\rBgpV4EviVxlan\x12<\n\x11\x62roadcast_domains\x18\x01 \x03(\x0b\x32!.otg.BgpV4EviVxlanBroadcastDomain\x12\x46\n\x10replication_type\x18\x02 \x01(\x0e\x32\'.otg.BgpV4EviVxlan.ReplicationType.EnumH\x00\x88\x01\x01\x12\x17\n\npmsi_label\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x61\x64_label\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x37\n\x13route_distinguisher\x18\x05 \x01(\x0b\x32\x1a.otg.BgpRouteDistinguisher\x12\x30\n\x13route_target_export\x18\x06 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x30\n\x13route_target_import\x18\x07 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_export\x18\x08 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_import\x18\t \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\'\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\r \x01(\x0b\x32\x0e.otg.BgpAsPath\x1a\x43\n\x0fReplicationType\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13ingress_replication\x10\x01\x42\x13\n\x11_replication_typeB\r\n\x0b_pmsi_labelB\x0b\n\t_ad_label\"\xb4\x01\n\x1c\x42gpV4EviVxlanBroadcastDomain\x12*\n\rcmac_ip_range\x18\x01 \x03(\x0b\x32\x13.otg.BgpCMacIpRange\x12\x1c\n\x0f\x65thernet_tag_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12vlan_aware_service\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_ethernet_tag_idB\x15\n\x13_vlan_aware_service\"\xd2\x03\n\x0e\x42gpCMacIpRange\x12+\n\rmac_addresses\x18\x01 \x01(\x0b\x32\x14.otg.MACRouteAddress\x12\x12\n\x05l2vni\x18\x02 \x01(\rH\x00\x88\x01\x01\x12+\n\x0eipv4_addresses\x18\x03 \x01(\x0b\x32\x13.otg.V4RouteAddress\x12+\n\x0eipv6_addresses\x18\x04 \x01(\x0b\x32\x13.otg.V6RouteAddress\x12\x12\n\x05l3vni\x18\x05 \x01(\rH\x01\x88\x01\x01\x12$\n\x17include_default_gateway\x18\x06 \x01(\x08H\x02\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x08 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\t \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPath\x12\x11\n\x04name\x18\x0b \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_l2vniB\x08\n\x06_l3vniB\x1a\n\x18_include_default_gatewayB\x07\n\x05_name\"\x98\x02\n\x15\x42gpRouteDistinguisher\x12<\n\x07rd_type\x18\x01 \x01(\x0e\x32&.otg.BgpRouteDistinguisher.RdType.EnumH\x00\x88\x01\x01\x12#\n\x16\x61uto_config_rd_ip_addr\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x15\n\x08rd_value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1aQ\n\x06RdType\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tas_2octet\x10\x01\x12\x10\n\x0cipv4_address\x10\x02\x12\r\n\tas_4octet\x10\x03\x42\n\n\x08_rd_typeB\x19\n\x17_auto_config_rd_ip_addrB\x0b\n\t_rd_value\"\xca\x01\n\x0e\x42gpRouteTarget\x12\x35\n\x07rt_type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpRouteTarget.RtType.EnumH\x00\x88\x01\x01\x12\x15\n\x08rt_value\x18\x02 \x01(\tH\x01\x88\x01\x01\x1aQ\n\x06RtType\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tas_2octet\x10\x01\x12\x10\n\x0cipv4_address\x10\x02\x12\r\n\tas_4octet\x10\x03\x42\n\n\x08_rt_typeB\x0b\n\t_rt_value\"\x83\x03\n\x0b\x42gpAdvanced\x12\x1f\n\x12hold_time_interval\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13keep_alive_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1c\n\x0fupdate_interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x14\n\x07md5_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0cpassive_mode\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0blisten_port\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x1a\n\rneighbor_port\x18\x08 \x01(\rH\x07\x88\x01\x01\x42\x15\n\x13_hold_time_intervalB\x16\n\x14_keep_alive_intervalB\x12\n\x10_update_intervalB\x0f\n\r_time_to_liveB\n\n\x08_md5_keyB\x0f\n\r_passive_modeB\x0e\n\x0c_listen_portB\x10\n\x0e_neighbor_port\"\x91\n\n\rBgpCapability\x12\x19\n\x0cipv4_unicast\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0eipv4_multicast\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0cipv6_unicast\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0eipv6_multicast\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04vpls\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rroute_refresh\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10route_constraint\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12link_state_non_vpn\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x1b\n\x0elink_state_vpn\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x11\n\x04\x65vpn\x18\n \x01(\x08H\t\x88\x01\x01\x12\'\n\x1a\x65xtended_next_hop_encoding\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x1f\n\x12ipv4_multicast_vpn\x18\x0c \x01(\x08H\x0b\x88\x01\x01\x12\x1a\n\ripv4_mpls_vpn\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\x15\n\x08ipv4_mdt\x18\x0e \x01(\x08H\r\x88\x01\x01\x12$\n\x17ipv4_multicast_mpls_vpn\x18\x0f \x01(\x08H\x0e\x88\x01\x01\x12#\n\x16ipv4_unicast_flow_spec\x18\x10 \x01(\x08H\x0f\x88\x01\x01\x12\x1e\n\x11ipv4_sr_te_policy\x18\x11 \x01(\x08H\x10\x88\x01\x01\x12\"\n\x15ipv4_unicast_add_path\x18\x12 \x01(\x08H\x11\x88\x01\x01\x12\x1f\n\x12ipv6_multicast_vpn\x18\x13 \x01(\x08H\x12\x88\x01\x01\x12\x1a\n\ripv6_mpls_vpn\x18\x14 \x01(\x08H\x13\x88\x01\x01\x12\x15\n\x08ipv6_mdt\x18\x15 \x01(\x08H\x14\x88\x01\x01\x12$\n\x17ipv6_multicast_mpls_vpn\x18\x16 \x01(\x08H\x15\x88\x01\x01\x12#\n\x16ipv6_unicast_flow_spec\x18\x17 \x01(\x08H\x16\x88\x01\x01\x12\x1e\n\x11ipv6_sr_te_policy\x18\x18 \x01(\x08H\x17\x88\x01\x01\x12\"\n\x15ipv6_unicast_add_path\x18\x19 \x01(\x08H\x18\x88\x01\x01\x42\x0f\n\r_ipv4_unicastB\x11\n\x0f_ipv4_multicastB\x0f\n\r_ipv6_unicastB\x11\n\x0f_ipv6_multicastB\x07\n\x05_vplsB\x10\n\x0e_route_refreshB\x13\n\x11_route_constraintB\x15\n\x13_link_state_non_vpnB\x11\n\x0f_link_state_vpnB\x07\n\x05_evpnB\x1d\n\x1b_extended_next_hop_encodingB\x15\n\x13_ipv4_multicast_vpnB\x10\n\x0e_ipv4_mpls_vpnB\x0b\n\t_ipv4_mdtB\x1a\n\x18_ipv4_multicast_mpls_vpnB\x19\n\x17_ipv4_unicast_flow_specB\x14\n\x12_ipv4_sr_te_policyB\x18\n\x16_ipv4_unicast_add_pathB\x15\n\x13_ipv6_multicast_vpnB\x10\n\x0e_ipv6_mpls_vpnB\x0b\n\t_ipv6_mdtB\x1a\n\x18_ipv6_multicast_mpls_vpnB\x19\n\x17_ipv6_unicast_flow_specB\x14\n\x12_ipv6_sr_te_policyB\x18\n\x16_ipv6_unicast_add_path\"\x91\x01\n\x1b\x42gpLearnedInformationFilter\x12 \n\x13unicast_ipv4_prefix\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12 \n\x13unicast_ipv6_prefix\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x16\n\x14_unicast_ipv4_prefixB\x16\n\x14_unicast_ipv6_prefix\"\x94\x06\n\x0f\x42gpV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV4RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV4RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12\x1f\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPath\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x11\n\x04name\x18\n \x01(\tH\x04\x88\x01\x01\x12-\n\x0f\x65xt_communities\x18\x0b \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x37\n\x14\x65xtended_communities\x18\x0c \x03(\x0b\x32\x19.otg.BgpExtendedCommunity\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_name\".\n\nBgpAddPath\x12\x14\n\x07path_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\n\n\x08_path_id\"\xf3\x06\n\x14\x42gpExtendedCommunity\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.BgpExtendedCommunity.Choice.EnumH\x00\x88\x01\x01\x12R\n\x19transitive_2octet_as_type\x18\x02 \x01(\x0b\x32/.otg.BgpExtendedCommunityTransitive2OctetAsType\x12X\n\x1ctransitive_ipv4_address_type\x18\x03 \x01(\x0b\x32\x32.otg.BgpExtendedCommunityTransitiveIpv4AddressType\x12R\n\x19transitive_4octet_as_type\x18\x04 \x01(\x0b\x32/.otg.BgpExtendedCommunityTransitive4OctetAsType\x12M\n\x16transitive_opaque_type\x18\x05 \x01(\x0b\x32-.otg.BgpExtendedCommunityTransitiveOpaqueType\x12I\n\x14transitive_evpn_type\x18\x06 \x01(\x0b\x32+.otg.BgpExtendedCommunityTransitiveEvpnType\x12Y\n\x1dnon_transitive_2octet_as_type\x18\x07 \x01(\x0b\x32\x32.otg.BgpExtendedCommunityNonTransitive2OctetAsType\x12\x33\n\x06\x63ustom\x18\x08 \x01(\x0b\x32#.otg.BgpExtendedCommunityCustomType\x1a\xe7\x01\n\x06\x43hoice\"\xdc\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1d\n\x19transitive_2octet_as_type\x10\x01\x12 \n\x1ctransitive_ipv4_address_type\x10\x02\x12\x1d\n\x19transitive_4octet_as_type\x10\x03\x12\x1a\n\x16transitive_opaque_type\x10\x04\x12\x18\n\x14transitive_evpn_type\x10\x05\x12!\n\x1dnon_transitive_2octet_as_type\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choice\"\x9f\x01\n5BgpExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\x9f\x01\n5BgpExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\x94\x03\n*BgpExtendedCommunityTransitive2OctetAsType\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.BgpExtendedCommunityTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12X\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12X\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\xa6\x01\n8BgpExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xa6\x01\n8BgpExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xa0\x03\n-BgpExtendedCommunityTransitiveIpv4AddressType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.BgpExtendedCommunityTransitiveIpv4AddressType.Choice.EnumH\x00\x88\x01\x01\x12[\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32=.otg.BgpExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12[\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32=.otg.BgpExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\x9f\x01\n5BgpExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\x9f\x01\n5BgpExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\x94\x03\n*BgpExtendedCommunityTransitive4OctetAsType\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.BgpExtendedCommunityTransitive4OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12X\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12X\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"k\n-BgpExtendedCommunityTransitiveOpaqueTypeColor\x12\x12\n\x05\x66lags\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_color\"\x85\x01\n5BgpExtendedCommunityTransitiveOpaqueTypeEncapsulation\x12\x15\n\x08reserved\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0btunnel_type\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0b\n\t_reservedB\x0e\n\x0c_tunnel_type\"\xfc\x02\n(BgpExtendedCommunityTransitiveOpaqueType\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.BgpExtendedCommunityTransitiveOpaqueType.Choice.EnumH\x00\x88\x01\x01\x12I\n\rcolor_subtype\x18\x02 \x01(\x0b\x32\x32.otg.BgpExtendedCommunityTransitiveOpaqueTypeColor\x12Y\n\x15\x65ncapsulation_subtype\x18\x03 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitiveOpaqueTypeEncapsulation\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rcolor_subtype\x10\x01\x12\x19\n\x15\x65ncapsulation_subtype\x10\x02\x42\t\n\x07_choice\"Y\n/BgpExtendedCommunityTransitiveEvpnTypeRouterMac\x12\x17\n\nrouter_mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_router_mac\"\x8e\x02\n&BgpExtendedCommunityTransitiveEvpnType\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.BgpExtendedCommunityTransitiveEvpnType.Choice.EnumH\x00\x88\x01\x01\x12P\n\x12router_mac_subtype\x18\x02 \x01(\x0b\x32\x34.otg.BgpExtendedCommunityTransitiveEvpnTypeRouterMac\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12router_mac_subtype\x10\x01\x42\t\n\x07_choice\"\x94\x01\n:BgpExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tbandwidth\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x0c\n\n_bandwidth\"\xaf\x02\n-BgpExtendedCommunityNonTransitive2OctetAsType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.BgpExtendedCommunityNonTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12_\n\x16link_bandwidth_subtype\x18\x02 \x01(\x0b\x32?.otg.BgpExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1a\n\x16link_bandwidth_subtype\x10\x01\x42\t\n\x07_choice\"\xa4\x01\n\x1e\x42gpExtendedCommunityCustomType\x12\x1b\n\x0e\x63ommunity_type\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11\x63ommunity_subtype\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x11\n\x0f_community_typeB\x14\n\x12_community_subtypeB\x08\n\x06_value\"\x94\x06\n\x0f\x42gpV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV6RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV6RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12\x1f\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPath\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x11\n\x04name\x18\n \x01(\tH\x04\x88\x01\x01\x12-\n\x0f\x65xt_communities\x18\x0b \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x37\n\x14\x65xtended_communities\x18\x0c \x03(\x0b\x32\x19.otg.BgpExtendedCommunity\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_name\"\xfb\x06\n\x0f\x42gpSrteV4Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\ripv4_endpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV4Policy.NextHopMode.EnumH\x03\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV4Policy.NextHopAddressType.EnumH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x1f\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPath\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV4TunnelTlv\x12\x11\n\x04name\x18\x0e \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\x08\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_ipv4_endpointB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_nameB\t\n\x07_active\"\xb6\x04\n\x12\x42gpSrteV4TunnelTlv\x12\x41\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlv\x12.\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlv\x12\x32\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlv\x12\x38\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlv\x12\x41\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlv\x12\x39\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlv\x12U\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlv\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x11\n\x04name\x18\t \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_active\"\xbe\x02\n\x1b\x42gpSrteRemoteEndpointSubTlv\x12\x16\n\tas_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12P\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32\x33.otg.BgpSrteRemoteEndpointSubTlv.AddressFamily.EnumH\x01\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a<\n\rAddressFamily\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x0c\n\n_as_numberB\x11\n\x0f_address_familyB\x0f\n\r_ipv4_addressB\x0f\n\r_ipv6_address\"2\n\x12\x42gpSrteColorSubTlv\x12\x12\n\x05\x63olor\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_color\"\xea\x02\n\x14\x42gpSrteBindingSubTlv\x12L\n\x10\x62inding_sid_type\x18\x01 \x01(\x0e\x32-.otg.BgpSrteBindingSubTlv.BindingSidType.EnumH\x00\x88\x01\x01\x12\x1b\n\x0e\x66our_octet_sid\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08ipv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06s_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06i_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x1a[\n\x0e\x42indingSidType\"I\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nno_binding\x10\x01\x12\x12\n\x0e\x66our_octet_sid\x10\x02\x12\x0c\n\x08ipv6_sid\x10\x03\x42\x13\n\x11_binding_sid_typeB\x11\n\x0f_four_octet_sidB\x0b\n\t_ipv6_sidB\t\n\x07_s_flagB\t\n\x07_i_flag\"A\n\x17\x42gpSrtePreferenceSubTlv\x12\x17\n\npreference\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\r\n\x0b_preference\"O\n\x1b\x42gpSrtePolicyPrioritySubTlv\x12\x1c\n\x0fpolicy_priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x12\n\x10_policy_priority\"C\n\x17\x42gpSrtePolicyNameSubTlv\x12\x18\n\x0bpolicy_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_policy_name\"\xd6\x02\n$BgpSrteExplicitNullLabelPolicySubTlv\x12o\n\x1a\x65xplicit_null_label_policy\x18\x01 \x01(\x0e\x32\x46.otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy.EnumH\x00\x88\x01\x01\x1a\x9d\x01\n\x17\x45xplicitNullLabelPolicy\"\x81\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rreserved_enlp\x10\x01\x12\x12\n\x0epush_ipv4_enlp\x10\x02\x12\x12\n\x0epush_ipv6_enlp\x10\x03\x12\x17\n\x13push_ipv4_ipv6_enlp\x10\x04\x12\x14\n\x10\x64o_not_push_enlp\x10\x05\x42\x1d\n\x1b_explicit_null_label_policy\"\x97\x01\n\x12\x42gpSrteSegmentList\x12\x13\n\x06weight\x18\x01 \x01(\rH\x00\x88\x01\x01\x12%\n\x08segments\x18\x02 \x03(\x0b\x32\x13.otg.BgpSrteSegment\x12\x11\n\x04name\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_weightB\x07\n\x05_nameB\t\n\x07_active\"\xdc\x06\n\x0e\x42gpSrteSegment\x12?\n\x0csegment_type\x18\x01 \x01(\x0e\x32$.otg.BgpSrteSegment.SegmentType.EnumH\x00\x88\x01\x01\x12.\n\x06type_a\x18\x02 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentATypeSubTlv\x12.\n\x06type_b\x18\x03 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentBTypeSubTlv\x12.\n\x06type_c\x18\x04 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentCTypeSubTlv\x12.\n\x06type_d\x18\x05 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentDTypeSubTlv\x12.\n\x06type_e\x18\x06 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentETypeSubTlv\x12.\n\x06type_f\x18\x07 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentFTypeSubTlv\x12.\n\x06type_g\x18\x08 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentGTypeSubTlv\x12.\n\x06type_h\x18\t \x01(\x0b\x32\x1e.otg.BgpSrteSegmentHTypeSubTlv\x12.\n\x06type_i\x18\n \x01(\x0b\x32\x1e.otg.BgpSrteSegmentITypeSubTlv\x12.\n\x06type_j\x18\x0b \x01(\x0b\x32\x1e.otg.BgpSrteSegmentJTypeSubTlv\x12.\n\x06type_k\x18\x0c \x01(\x0b\x32\x1e.otg.BgpSrteSegmentKTypeSubTlv\x12\x11\n\x04name\x18\r \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x0e \x01(\x08H\x02\x88\x01\x01\x1a\xab\x01\n\x0bSegmentType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\x0f\n\r_segment_typeB\x07\n\x05_nameB\t\n\x07_active\"\x80\x01\n\x10\x42gpSrteSrMplsSid\x12\x12\n\x05label\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02tc\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05s_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xca\x01\n*BgpSrteSRv6SIDEndpointBehaviorAndStructure\x12\x16\n\tlb_length\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tln_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\narg_length\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"\xa7\x01\n\x19\x42gpSrteSegmentATypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05label\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02tc\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05s_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x10\n\x03ttl\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xb2\x01\n\x19\x42gpSrteSegmentBTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x02 \x01(\tH\x01\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x03 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x0b\n\t_srv6_sid\"\xc7\x01\n\x19\x42gpSrteSegmentCTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv4_node_address\"\xc7\x01\n\x19\x42gpSrteSegmentDTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv6_node_address\"\xd3\x01\n\x19\x42gpSrteSegmentETypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x14\n\x12_ipv4_node_address\"\xd7\x01\n\x19\x42gpSrteSegmentFTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_ipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_ipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_ipv4_addressB\x16\n\x14_remote_ipv4_address\"\xdd\x02\n\x19\x42gpSrteSegmentGTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x05 \x01(\tH\x04\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_address\"\xd7\x01\n\x19\x42gpSrteSegmentHTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_ipv6_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_address\"\xe8\x01\n\x19\x42gpSrteSegmentITypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x04 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x14\n\x12_ipv6_node_addressB\x0b\n\t_srv6_sid\"\xd6\x03\n\x19\x42gpSrteSegmentJTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x05 \x01(\rH\x04\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x07 \x01(\tH\x06\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x08 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_addressB\x0b\n\t_srv6_sid\"\xd0\x02\n\x19\x42gpSrteSegmentKTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12local_ipv6_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x05 \x01(\tH\x04\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x06 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_addressB\x0b\n\t_srv6_sid\"\xfa\x06\n\x0f\x42gpSrteV6Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\ripv6_endpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV6Policy.NextHopMode.EnumH\x03\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV6Policy.NextHopAddressType.EnumH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x1f\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPath\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12,\n\x0e\x65xtcommunities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV6TunnelTlv\x12\x11\n\x04name\x18\x0e \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\x08\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_ipv6_endpointB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_nameB\t\n\x07_active\"\xb6\x04\n\x12\x42gpSrteV6TunnelTlv\x12\x41\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlv\x12.\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlv\x12\x32\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlv\x12\x38\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlv\x12\x41\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlv\x12\x39\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlv\x12U\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlv\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x11\n\x04name\x18\t \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_active\"\xf2\x01\n\x12\x42gpGracefulRestart\x12\x16\n\tenable_gr\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0crestart_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x65nable_llgr\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nstale_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x12 \n\x13\x65nable_notification\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x0c\n\n_enable_grB\x0f\n\r_restart_timeB\x0e\n\x0c_enable_llgrB\r\n\x0b_stale_timeB\x16\n\x14_enable_notification\"\xf0\x01\n\x0f\x42gpUpdateReplay\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.BgpUpdateReplay.Choice.EnumH\x00\x88\x01\x01\x12/\n\x0fstructured_pdus\x18\x02 \x01(\x0b\x32\x16.otg.BgpStructuredPdus\x12#\n\traw_bytes\x18\x03 \x01(\x0b\x32\x10.otg.BgpRawBytes\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fstructured_pdus\x10\x01\x12\r\n\traw_bytes\x10\x02\x42\t\n\x07_choice\"7\n\x0b\x42gpRawBytes\x12(\n\x07updates\x18\x01 \x03(\x0b\x32\x17.otg.BgpOneUpdateReplay\"d\n\x12\x42gpOneUpdateReplay\x12\x15\n\x08time_gap\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x19\n\x0cupdate_bytes\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_time_gapB\x0f\n\r_update_bytes\"G\n\x11\x42gpStructuredPdus\x12\x32\n\x07updates\x18\x01 \x03(\x0b\x32!.otg.BgpOneStructuredUpdateReplay\"\xf7\x01\n\x1c\x42gpOneStructuredUpdateReplay\x12\x15\n\x08time_gap\x18\x01 \x01(\rH\x00\x88\x01\x01\x12+\n\x0fpath_attributes\x18\x02 \x01(\x0b\x32\x12.otg.BgpAttributes\x12\x43\n\x19traditional_unreach_nlris\x18\x03 \x03(\x0b\x32 .otg.BgpOneTraditionalNlriPrefix\x12\x41\n\x17traditional_reach_nlris\x18\x04 \x03(\x0b\x32 .otg.BgpOneTraditionalNlriPrefixB\x0b\n\t_time_gap\"\x8a\x01\n\x1b\x42gpOneTraditionalNlriPrefix\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x07path_id\x18\x03 \x01(\x0b\x32\x18.otg.BgpNLRIPrefixPathIdB\n\n\x08_addressB\t\n\x07_prefix\"\x83\x01\n\x14\x42gpOneIpv4NLRIPrefix\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x07path_id\x18\x03 \x01(\x0b\x32\x18.otg.BgpNLRIPrefixPathIdB\n\n\x08_addressB\t\n\x07_prefix\"\x83\x01\n\x14\x42gpOneIpv6NLRIPrefix\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x07path_id\x18\x03 \x01(\x0b\x32\x18.otg.BgpNLRIPrefixPathIdB\n\n\x08_addressB\t\n\x07_prefix\"3\n\x13\x42gpNLRIPrefixPathId\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\x8b\x01\n\x19\x42gpIpv4SrPolicyNLRIPrefix\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x65ndpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x0b\n\t_endpoint\"\x8b\x01\n\x19\x42gpIpv6SrPolicyNLRIPrefix\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x65ndpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x0b\n\t_endpoint\"\xef\x07\n\rBgpAttributes\x12:\n\x10other_attributes\x18\x01 \x03(\x0b\x32 .otg.BgpAttributesOtherAttribute\x12\x33\n\x06origin\x18\x02 \x01(\x0e\x32\x1e.otg.BgpAttributes.Origin.EnumH\x00\x88\x01\x01\x12)\n\x07\x61s_path\x18\x03 \x01(\x0b\x32\x18.otg.BgpAttributesAsPath\x12+\n\x08\x61s4_path\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesAs4Path\x12+\n\x08next_hop\x18\x05 \x01(\x0b\x32\x19.otg.BgpAttributesNextHop\x12J\n\x18multi_exit_discriminator\x18\x06 \x01(\x0b\x32(.otg.BgpAttributesMultiExitDiscriminator\x12;\n\x10local_preference\x18\x07 \x01(\x0b\x32!.otg.BgpAttributesLocalPreference\x12&\n\x19include_atomic_aggregator\x18\x08 \x01(\x08H\x01\x88\x01\x01\x12\x30\n\naggregator\x18\t \x01(\x0b\x32\x1c.otg.BgpAttributesAggregator\x12\x37\n\x0e\x61s4_aggregator\x18\n \x01(\x0b\x32\x1f.otg.BgpAttributesAs4Aggregator\x12.\n\tcommunity\x18\x0b \x03(\x0b\x32\x1b.otg.BgpAttributesCommunity\x12\x35\n\roriginator_id\x18\x0c \x01(\x0b\x32\x1e.otg.BgpAttributesOriginatorId\x12\x13\n\x0b\x63luster_ids\x18\r \x03(\t\x12\x37\n\x14\x65xtended_communities\x18\x0e \x03(\x0b\x32\x19.otg.BgpExtendedCommunity\x12\x43\n\x14tunnel_encapsulation\x18\x0f \x01(\x0b\x32%.otg.BgpAttributesTunnelEncapsulation\x12/\n\x08mp_reach\x18\x10 \x01(\x0b\x32\x1d.otg.BgpAttributesMpReachNlri\x12\x33\n\nmp_unreach\x18\x11 \x01(\x0b\x32\x1f.otg.BgpAttributesMpUnreachNlri\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\t\n\x07_originB\x1c\n\x1a_include_atomic_aggregator\"\xa7\x02\n\x1b\x42gpAttributesOtherAttribute\x12\x1a\n\rflag_optional\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1c\n\x0f\x66lag_transitive\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0c\x66lag_partial\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x66lag_extended_length\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x16\n\traw_value\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x10\n\x0e_flag_optionalB\x12\n\x10_flag_transitiveB\x0f\n\r_flag_partialB\x17\n\x15_flag_extended_lengthB\x07\n\x05_typeB\x0c\n\n_raw_value\"\xaf\x02\n\x13\x42gpAttributesAsPath\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.BgpAttributesAsPath.Choice.EnumH\x00\x88\x01\x01\x12\x41\n\x11\x66our_byte_as_path\x18\x02 \x01(\x0b\x32&.otg.BgpAttributesAsPathFourByteAsPath\x12?\n\x10two_byte_as_path\x18\x03 \x01(\x0b\x32%.otg.BgpAttributesAsPathTwoByteAsPath\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11\x66our_byte_as_path\x10\x01\x12\x14\n\x10two_byte_as_path\x10\x02\x42\t\n\x07_choice\"^\n!BgpAttributesAsPathFourByteAsPath\x12\x39\n\x08segments\x18\x01 \x03(\x0b\x32\'.otg.BgpAttributesFourByteAsPathSegment\"\xe6\x01\n\"BgpAttributesFourByteAsPathSegment\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x31.otg.BgpAttributesFourByteAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"\\\n BgpAttributesAsPathTwoByteAsPath\x12\x38\n\x08segments\x18\x01 \x03(\x0b\x32&.otg.BgpAttributesTwoByteAsPathSegment\"\xe4\x01\n!BgpAttributesTwoByteAsPathSegment\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x30.otg.BgpAttributesTwoByteAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"Q\n\x14\x42gpAttributesAs4Path\x12\x39\n\x08segments\x18\x01 \x03(\x0b\x32\'.otg.BgpAttributesFourByteAsPathSegment\"\xab\x02\n\x17\x42gpAttributesAggregator\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.BgpAttributesAggregator.Choice.EnumH\x00\x88\x01\x01\x12\x19\n\x0c\x66our_byte_as\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0btwo_byte_as\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66our_byte_as\x10\x01\x12\x0f\n\x0btwo_byte_as\x10\x02\x42\t\n\x07_choiceB\x0f\n\r_four_byte_asB\x0e\n\x0c_two_byte_asB\x0f\n\r_ipv4_address\"h\n\x1a\x42gpAttributesAs4Aggregator\x12\x13\n\x06\x61s_num\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_as_numB\x0f\n\r_ipv4_address\"\xb1\x02\n\x16\x42gpAttributesCommunity\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.BgpAttributesCommunity.Choice.EnumH\x00\x88\x01\x01\x12;\n\x10\x63ustom_community\x18\x02 \x01(\x0b\x32!.otg.BgpAttributesCustomCommunity\x1a\x90\x01\n\x06\x43hoice\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10\x63ustom_community\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\t\n\x07_choice\"d\n\x1c\x42gpAttributesCustomCommunity\x12\x16\n\tas_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_as_numberB\t\n\x07_custom\"\xab\x02\n\x14\x42gpAttributesNextHop\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.BgpAttributesNextHop.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04ipv4\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04ipv6\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x45\n\x12ipv6_two_addresses\x18\x04 \x01(\x0b\x32).otg.BgpAttributesNextHopIpv6TwoAddresses\x1aM\n\x06\x43hoice\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x16\n\x12ipv6_two_addresses\x10\x03\x42\t\n\x07_choiceB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"d\n$BgpAttributesNextHopIpv6TwoAddresses\x12\x12\n\x05\x66irst\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06second\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_firstB\t\n\x07_second\"\xcf\x03\n\x18\x42gpAttributesMpReachNlri\x12+\n\x08next_hop\x18\x01 \x01(\x0b\x32\x19.otg.BgpAttributesNextHop\x12>\n\x06\x63hoice\x18\x02 \x01(\x0e\x32).otg.BgpAttributesMpReachNlri.Choice.EnumH\x00\x88\x01\x01\x12/\n\x0cipv4_unicast\x18\x03 \x03(\x0b\x32\x19.otg.BgpOneIpv4NLRIPrefix\x12/\n\x0cipv6_unicast\x18\x04 \x03(\x0b\x32\x19.otg.BgpOneIpv6NLRIPrefix\x12\x35\n\ripv4_srpolicy\x18\x05 \x01(\x0b\x32\x1e.otg.BgpIpv4SrPolicyNLRIPrefix\x12\x35\n\ripv6_srpolicy\x18\x06 \x01(\x0b\x32\x1e.otg.BgpIpv6SrPolicyNLRIPrefix\x1ak\n\x06\x43hoice\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\x12\x11\n\ripv4_srpolicy\x10\x03\x12\x11\n\ripv6_srpolicy\x10\x04\x42\t\n\x07_choice\"\xa6\x03\n\x1a\x42gpAttributesMpUnreachNlri\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.BgpAttributesMpUnreachNlri.Choice.EnumH\x00\x88\x01\x01\x12/\n\x0cipv4_unicast\x18\x02 \x03(\x0b\x32\x19.otg.BgpOneIpv4NLRIPrefix\x12/\n\x0cipv6_unicast\x18\x03 \x03(\x0b\x32\x19.otg.BgpOneIpv6NLRIPrefix\x12\x35\n\ripv4_srpolicy\x18\x04 \x01(\x0b\x32\x1e.otg.BgpIpv4SrPolicyNLRIPrefix\x12\x35\n\ripv6_srpolicy\x18\x05 \x01(\x0b\x32\x1e.otg.BgpIpv6SrPolicyNLRIPrefix\x1ak\n\x06\x43hoice\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\x12\x11\n\ripv4_srpolicy\x10\x03\x12\x11\n\ripv6_srpolicy\x10\x04\x42\t\n\x07_choice\"C\n#BgpAttributesMultiExitDiscriminator\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"<\n\x1c\x42gpAttributesLocalPreference\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"9\n\x19\x42gpAttributesOriginatorId\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xe2\x01\n BgpAttributesTunnelEncapsulation\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.BgpAttributesTunnelEncapsulation.Choice.EnumH\x00\x88\x01\x01\x12\x39\n\tsr_policy\x18\x02 \x01(\x0b\x32&.otg.BgpAttributesSegmentRoutingPolicy\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsr_policy\x10\x01\x42\t\n\x07_choice\"\xac\x04\n!BgpAttributesSegmentRoutingPolicy\x12:\n\x1a\x62inding_segment_identifier\x18\x01 \x01(\x0b\x32\x16.otg.BgpAttributesBsid\x12\x43\n\x1fsrv6_binding_segment_identifier\x18\x02 \x03(\x0b\x32\x1a.otg.BgpAttributesSrv6Bsid\x12\x38\n\npreference\x18\x03 \x01(\x0b\x32$.otg.BgpAttributesSrPolicyPreference\x12\x34\n\x08priority\x18\x04 \x01(\x0b\x32\".otg.BgpAttributesSrPolicyPriority\x12\x39\n\x0bpolicy_name\x18\x05 \x01(\x0b\x32$.otg.BgpAttributesSrPolicyPolicyName\x12L\n\x15policy_candidate_name\x18\x06 \x01(\x0b\x32-.otg.BgpAttributesSrPolicyPolicyCandidateName\x12P\n\x1a\x65xplicit_null_label_policy\x18\x07 \x01(\x0b\x32,.otg.BgpAttributesSrPolicyExplicitNullPolicy\x12;\n\x0csegment_list\x18\x08 \x03(\x0b\x32%.otg.BgpAttributesSrPolicySegmentList\"\xe2\x01\n\x11\x42gpAttributesBsid\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.BgpAttributesBsid.Choice.EnumH\x00\x88\x01\x01\x12(\n\x04mpls\x18\x02 \x01(\x0b\x32\x1a.otg.BgpAttributesBsidMpls\x12(\n\x04srv6\x18\x03 \x01(\x0b\x32\x1a.otg.BgpAttributesBsidSrv6\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mpls\x10\x01\x12\x08\n\x04srv6\x10\x02\x42\t\n\x07_choice\"\xc8\x01\n\x15\x42gpAttributesBsidMpls\x12%\n\x18\x66lag_specified_bsid_only\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16\x66lag_drop_upon_invalid\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12+\n\x08mpls_sid\x18\x03 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x1b\n\x19_flag_specified_bsid_onlyB\x19\n\x17_flag_drop_upon_invalid\"\xc1\x01\n\x15\x42gpAttributesBsidSrv6\x12%\n\x18\x66lag_specified_bsid_only\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16\x66lag_drop_upon_invalid\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x16\n\tipv6_addr\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x1b\n\x19_flag_specified_bsid_onlyB\x19\n\x17_flag_drop_upon_invalidB\x0c\n\n_ipv6_addr\"\xf6\x02\n\x15\x42gpAttributesSrv6Bsid\x12%\n\x18\x66lag_specified_bsid_only\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16\x66lag_drop_upon_invalid\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12(\n\x1b\x66lag_srv6_endpoint_behavior\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x16\n\tipv6_addr\x18\x04 \x01(\tH\x03\x88\x01\x01\x12i\n\x16srv6_endpoint_behavior\x18\x05 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x1b\n\x19_flag_specified_bsid_onlyB\x19\n\x17_flag_drop_upon_invalidB\x1e\n\x1c_flag_srv6_endpoint_behaviorB\x0c\n\n_ipv6_addr\"\xa0\x01\n\x14\x42gpAttributesSidMpls\x12\x12\n\x05label\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rtraffic_class\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x66lag_bos\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x10\n\x0e_traffic_classB\x0b\n\t_flag_bosB\x06\n\x04_ttl\".\n\x14\x42gpAttributesSidSrv6\x12\x0f\n\x02ip\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_ip\"?\n\x1f\x42gpAttributesSrPolicyPreference\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"=\n\x1d\x42gpAttributesSrPolicyPriority\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"H\n(BgpAttributesSrPolicyPolicyCandidateName\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"?\n\x1f\x42gpAttributesSrPolicyPolicyName\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xf9\x01\n\'BgpAttributesSrPolicyExplicitNullPolicy\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.BgpAttributesSrPolicyExplicitNullPolicy.Choice.EnumH\x00\x88\x01\x01\x1at\n\x06\x43hoice\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unknown\x10\x01\x12\r\n\tpush_ipv4\x10\x02\x12\r\n\tpush_ipv6\x10\x03\x12\x16\n\x12push_ipv4_and_ipv6\x10\x04\x12\x0e\n\ndonot_push\x10\x05\x42\t\n\x07_choice\"\xb7\x01\n BgpAttributesSrPolicySegmentList\x12G\n\x06weight\x18\x01 \x01(\x0b\x32\x37.otg.BgpAttributesSegmentRoutingPolicySegmentListWeight\x12J\n\x08segments\x18\x02 \x03(\x0b\x32\x38.otg.BgpAttributesSegmentRoutingPolicySegmentListSegment\"R\n2BgpAttributesSegmentRoutingPolicySegmentListWeight\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xe3\x07\n3BgpAttributesSegmentRoutingPolicySegmentListSegment\x12Y\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x44.otg.BgpAttributesSegmentRoutingPolicySegmentListSegment.Choice.EnumH\x00\x88\x01\x01\x12;\n\x06type_a\x18\x02 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeA\x12;\n\x06type_b\x18\x03 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeB\x12;\n\x06type_c\x18\x04 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeC\x12;\n\x06type_d\x18\x05 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeD\x12;\n\x06type_e\x18\x06 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeE\x12;\n\x06type_f\x18\x07 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeF\x12;\n\x06type_g\x18\x08 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeG\x12;\n\x06type_h\x18\t \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeH\x12;\n\x06type_i\x18\n \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeI\x12;\n\x06type_j\x18\x0b \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeJ\x12;\n\x06type_k\x18\x0c \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeK\x1a\xa6\x01\n\x06\x43hoice\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\t\n\x07_choice\"\x95\x01\n&BgpAttributesSegmentRoutingPolicyTypeA\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12+\n\x08mpls_sid\x18\x02 \x01(\x0b\x32\x19.otg.BgpAttributesSidMpls\"\xf7\x01\n&BgpAttributesSegmentRoutingPolicyTypeB\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x15\n\x08srv6_sid\x18\x02 \x01(\tH\x00\x88\x01\x01\x12i\n\x16srv6_endpoint_behavior\x18\x03 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0b\n\t_srv6_sid\"\xfa\x01\n&BgpAttributesSegmentRoutingPolicyTypeC\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv4_node_address\"\xfa\x01\n&BgpAttributesSegmentRoutingPolicyTypeD\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv6_node_address\"\x86\x02\n&BgpAttributesSegmentRoutingPolicyTypeE\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_interface_idB\x14\n\x12_ipv4_node_address\"\x8a\x02\n&BgpAttributesSegmentRoutingPolicyTypeF\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_ipv4_address\x18\x02 \x01(\tH\x00\x88\x01\x01\x12 \n\x13remote_ipv4_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_ipv4_addressB\x16\n\x14_remote_ipv4_address\"\x90\x03\n&BgpAttributesSegmentRoutingPolicyTypeG\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x04 \x01(\rH\x02\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_address\"\x8a\x02\n&BgpAttributesSegmentRoutingPolicyTypeH\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_ipv6_address\x18\x02 \x01(\tH\x00\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_address\"\xe2\x02\n&BgpAttributesSegmentRoutingPolicyTypeI\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\x08srv6_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidSrv6\x12i\n\x16srv6_endpoint_behavior\x18\x05 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv6_node_address\"\xa4\x04\n&BgpAttributesSegmentRoutingPolicyTypeJ\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\rH\x01\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x05 \x01(\rH\x03\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12+\n\x08srv6_sid\x18\x07 \x01(\x0b\x32\x19.otg.BgpAttributesSidSrv6\x12i\n\x16srv6_endpoint_behavior\x18\x08 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_address\"\x9e\x03\n&BgpAttributesSegmentRoutingPolicyTypeK\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12local_ipv6_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12+\n\x08srv6_sid\x18\x05 \x01(\x0b\x32\x19.otg.BgpAttributesSidSrv6\x12i\n\x16srv6_endpoint_behavior\x18\x06 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0f\n\r_sr_algorithmB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_address\"\xac\x01\n*BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x13\n\x06v_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x61_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06s_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06\x62_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\t\n\x07_v_flagB\t\n\x07_a_flagB\t\n\x07_s_flagB\t\n\x07_b_flag\"\x9c\x02\nDBgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructure\x12\x1f\n\x12\x65ndpoint_behaviour\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tlb_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tln_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x17\n\narg_length\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x15\n\x13_endpoint_behaviourB\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"H\n(BgpNLRIPrefixSegmentRoutingDistinguisher\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\x93\x07\n\tBgpV6Peer\x12\x19\n\x0cpeer_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x31\n\x0fsegment_routing\x18\x02 \x01(\x0b\x32\x18.otg.BgpV6SegmentRouting\x12\x39\n\x16\x65vpn_ethernet_segments\x18\x03 \x03(\x0b\x32\x19.otg.BgpV6EthernetSegment\x12\x30\n\x07\x61s_type\x18\x04 \x01(\x0e\x32\x1a.otg.BgpV6Peer.AsType.EnumH\x01\x88\x01\x01\x12\x16\n\tas_number\x18\x05 \x01(\rH\x02\x88\x01\x01\x12?\n\x0f\x61s_number_width\x18\x06 \x01(\x0e\x32!.otg.BgpV6Peer.AsNumberWidth.EnumH\x03\x88\x01\x01\x12\"\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x10.otg.BgpAdvanced\x12&\n\ncapability\x18\x08 \x01(\x0b\x32\x12.otg.BgpCapability\x12\x44\n\x1alearned_information_filter\x18\t \x01(\x0b\x32 .otg.BgpLearnedInformationFilter\x12\'\n\tv4_routes\x18\n \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\x0b \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\x0c \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\r \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x11\n\x04name\x18\x0e \x01(\tH\x04\x88\x01\x01\x12\x31\n\x10graceful_restart\x18\x0f \x01(\x0b\x32\x17.otg.BgpGracefulRestart\x12,\n\x0ereplay_updates\x18\x10 \x01(\x0b\x32\x14.otg.BgpUpdateReplay\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x0f\n\r_peer_addressB\n\n\x08_as_typeB\x0c\n\n_as_numberB\x12\n\x10_as_number_widthB\x07\n\x05_name\"U\n\x0e\x42gpV6Interface\x12\x16\n\tipv6_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV6PeerB\x0c\n\n_ipv6_name\"\xf1\x03\n\x13\x42gpV6SegmentRouting\x12!\n\x14ingress_supports_vpn\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15reduced_encapsulation\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1e\n\x11\x63opy_time_to_live\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10max_sids_per_srh\x18\x05 \x01(\rH\x04\x88\x01\x01\x12-\n auto_generate_segment_left_value\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1f\n\x12segment_left_value\x18\x07 \x01(\rH\x06\x88\x01\x01\x12#\n\x16\x61\x64vertise_sr_te_policy\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x17\n\x15_ingress_supports_vpnB\x18\n\x16_reduced_encapsulationB\x14\n\x12_copy_time_to_liveB\x0f\n\r_time_to_liveB\x13\n\x11_max_sids_per_srhB#\n!_auto_generate_segment_left_valueB\x15\n\x13_segment_left_valueB\x19\n\x17_advertise_sr_te_policy\"\xf0\x03\n\x14\x42gpV6EthernetSegment\x12\x36\n\x0b\x64\x66_election\x18\x01 \x01(\x0b\x32!.otg.BgpEthernetSegmentDfElection\x12 \n\x04\x65vis\x18\x02 \x03(\x0b\x32\x12.otg.BgpV6EvpnEvis\x12\x10\n\x03\x65si\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x43\n\x0b\x61\x63tive_mode\x18\x04 \x01(\x0e\x32).otg.BgpV6EthernetSegment.ActiveMode.EnumH\x01\x88\x01\x01\x12\x16\n\tesi_label\x18\x05 \x01(\rH\x02\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x08 \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\t \x01(\x0b\x32\x0e.otg.BgpAsPath\x1aH\n\nActiveMode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsingle_active\x10\x01\x12\x0e\n\nall_active\x10\x02\x42\x06\n\x04_esiB\x0e\n\x0c_active_modeB\x0c\n\n_esi_label\"\xa8\x01\n\rBgpV6EvpnEvis\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.BgpV6EvpnEvis.Choice.EnumH\x00\x88\x01\x01\x12%\n\tevi_vxlan\x18\x02 \x01(\x0b\x32\x12.otg.BgpV6EviVxlan\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tevi_vxlan\x10\x01\x42\t\n\x07_choice\"\xe3\x05\n\rBgpV6EviVxlan\x12<\n\x11\x62roadcast_domains\x18\x01 \x03(\x0b\x32!.otg.BgpV6EviVxlanBroadcastDomain\x12\x46\n\x10replication_type\x18\x02 \x01(\x0e\x32\'.otg.BgpV6EviVxlan.ReplicationType.EnumH\x00\x88\x01\x01\x12\x17\n\npmsi_label\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x61\x64_label\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x37\n\x13route_distinguisher\x18\x05 \x01(\x0b\x32\x1a.otg.BgpRouteDistinguisher\x12\x30\n\x13route_target_export\x18\x06 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x30\n\x13route_target_import\x18\x07 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_export\x18\x08 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_import\x18\t \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\'\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\r \x01(\x0b\x32\x0e.otg.BgpAsPath\x1a\x43\n\x0fReplicationType\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13ingress_replication\x10\x01\x42\x13\n\x11_replication_typeB\r\n\x0b_pmsi_labelB\x0b\n\t_ad_label\"\xb4\x01\n\x1c\x42gpV6EviVxlanBroadcastDomain\x12*\n\rcmac_ip_range\x18\x01 \x03(\x0b\x32\x13.otg.BgpCMacIpRange\x12\x1c\n\x0f\x65thernet_tag_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12vlan_aware_service\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_ethernet_tag_idB\x15\n\x13_vlan_aware_service\"]\n\x0b\x44\x65viceVxlan\x12&\n\nv4_tunnels\x18\x01 \x03(\x0b\x32\x12.otg.VxlanV4Tunnel\x12&\n\nv6_tunnels\x18\x02 \x03(\x0b\x32\x12.otg.VxlanV6Tunnel\"\xbb\x01\n\rVxlanV4Tunnel\x12\x1d\n\x10source_interface\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\x13\x64\x65stination_ip_mode\x18\x02 \x01(\x0b\x32#.otg.VxlanV4TunnelDestinationIPMode\x12\x10\n\x03vni\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_source_interfaceB\x06\n\x04_vniB\x07\n\x05_name\"\xbb\x01\n\rVxlanV6Tunnel\x12\x1d\n\x10source_interface\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\x13\x64\x65stination_ip_mode\x18\x02 \x01(\x0b\x32#.otg.VxlanV6TunnelDestinationIPMode\x12\x10\n\x03vni\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_source_interfaceB\x06\n\x04_vniB\x07\n\x05_name\"\xae\x02\n\x1eVxlanV4TunnelDestinationIPMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.VxlanV4TunnelDestinationIPMode.Choice.EnumH\x00\x88\x01\x01\x12;\n\x07unicast\x18\x02 \x01(\x0b\x32*.otg.VxlanV4TunnelDestinationIPModeUnicast\x12?\n\tmulticast\x18\x03 \x01(\x0b\x32,.otg.VxlanV4TunnelDestinationIPModeMulticast\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unicast\x10\x01\x12\r\n\tmulticast\x10\x02\x42\t\n\x07_choice\"\xae\x02\n\x1eVxlanV6TunnelDestinationIPMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.VxlanV6TunnelDestinationIPMode.Choice.EnumH\x00\x88\x01\x01\x12;\n\x07unicast\x18\x02 \x01(\x0b\x32*.otg.VxlanV6TunnelDestinationIPModeUnicast\x12?\n\tmulticast\x18\x03 \x01(\x0b\x32,.otg.VxlanV6TunnelDestinationIPModeMulticast\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unicast\x10\x01\x12\r\n\tmulticast\x10\x02\x42\t\n\x07_choice\"f\n%VxlanV4TunnelDestinationIPModeUnicast\x12=\n\x05vteps\x18\x01 \x03(\x0b\x32..otg.VxlanV4TunnelDestinationIPModeUnicastVtep\"f\n%VxlanV6TunnelDestinationIPModeUnicast\x12=\n\x05vteps\x18\x01 \x03(\x0b\x32..otg.VxlanV6TunnelDestinationIPModeUnicastVtep\"\x96\x01\n6VxlanTunnelDestinationIPModeUnicastArpSuppressionCache\x12\x1a\n\rremote_vm_mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eremote_vm_ipv4\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_remote_vm_macB\x11\n\x0f_remote_vm_ipv4\"\xc1\x01\n)VxlanV4TunnelDestinationIPModeUnicastVtep\x12 \n\x13remote_vtep_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12Z\n\x15\x61rp_suppression_cache\x18\x02 \x03(\x0b\x32;.otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheB\x16\n\x14_remote_vtep_address\"\xc1\x01\n)VxlanV6TunnelDestinationIPModeUnicastVtep\x12 \n\x13remote_vtep_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12Z\n\x15\x61rp_suppression_cache\x18\x02 \x03(\x0b\x32;.otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheB\x16\n\x14_remote_vtep_address\"K\n\'VxlanV4TunnelDestinationIPModeMulticast\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_address\"K\n\'VxlanV6TunnelDestinationIPModeMulticast\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_address\"\x91\x01\n\nDeviceRsvp\x12/\n\x0fipv4_interfaces\x18\x01 \x03(\x0b\x32\x16.otg.RsvpIpv4Interface\x12\x36\n\x13lsp_ipv4_interfaces\x18\x02 \x03(\x0b\x32\x19.otg.RsvpLspIpv4Interface\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\xc5\x04\n\x11RsvpIpv4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bneighbor_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x11label_space_start\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1c\n\x0flabel_space_end\x18\x04 \x01(\rH\x03\x88\x01\x01\x12%\n\x18\x65nable_refresh_reduction\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12%\n\x18summary_refresh_interval\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0bsend_bundle\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1d\n\x10\x62undle_threshold\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x19\n\x0c\x65nable_hello\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\n \x01(\rH\t\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x0b \x01(\rH\n\x88\x01\x01\x42\x0c\n\n_ipv4_nameB\x0e\n\x0c_neighbor_ipB\x14\n\x12_label_space_startB\x12\n\x10_label_space_endB\x1b\n\x19_enable_refresh_reductionB\x1b\n\x19_summary_refresh_intervalB\x0e\n\x0c_send_bundleB\x13\n\x11_bundle_thresholdB\x0f\n\r_enable_helloB\x11\n\x0f_hello_intervalB\x15\n\x13_timeout_multiplier\"\xd0\x01\n\x14RsvpLspIpv4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12G\n\x14p2p_egress_ipv4_lsps\x18\x02 \x01(\x0b\x32).otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp\x12I\n\x15p2p_ingress_ipv4_lsps\x18\x03 \x03(\x0b\x32*.otg.RsvpLspIpv4InterfaceP2PIngressIpv4LspB\x0c\n\n_ipv4_name\"\xf1\x03\n$RsvpLspIpv4InterfaceP2PEgressIpv4Lsp\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x10refresh_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x03 \x01(\rH\x02\x88\x01\x01\x12_\n\x11reservation_style\x18\x04 \x01(\x0e\x32?.otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp.ReservationStyle.EnumH\x03\x88\x01\x01\x12\x1f\n\x12\x65nable_fixed_label\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1e\n\x11\x66ixed_label_value\x18\x06 \x01(\rH\x05\x88\x01\x01\x1a\\\n\x10ReservationStyle\"H\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fshared_explicit\x10\x01\x12\x10\n\x0c\x66ixed_filter\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x42\x07\n\x05_nameB\x13\n\x11_refresh_intervalB\x15\n\x13_timeout_multiplierB\x14\n\x12_reservation_styleB\x15\n\x13_enable_fixed_labelB\x14\n\x12_fixed_label_value\"\xab\x04\n%RsvpLspIpv4InterfaceP2PIngressIpv4Lsp\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eremote_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\ttunnel_id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x13\n\x06lsp_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10refresh_interval\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x1a\n\rbackup_lsp_id\x18\x07 \x01(\rH\x06\x88\x01\x01\x12!\n\x14lsp_switchover_delay\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x34\n\x11session_attribute\x18\t \x01(\x0b\x32\x19.otg.RsvpSessionAttribute\x12\x1d\n\x05tspec\x18\n \x01(\x0b\x32\x0e.otg.RsvpTspec\x12*\n\x0c\x66\x61st_reroute\x18\x0b \x01(\x0b\x32\x14.otg.RsvpFastReroute\x12\x19\n\x03\x65ro\x18\x0c \x01(\x0b\x32\x0c.otg.RsvpEroB\x07\n\x05_nameB\x11\n\x0f_remote_addressB\x0c\n\n_tunnel_idB\t\n\x07_lsp_idB\x13\n\x11_refresh_intervalB\x15\n\x13_timeout_multiplierB\x10\n\x0e_backup_lsp_idB\x17\n\x15_lsp_switchover_delay\"\xf0\x04\n\x14RsvpSessionAttribute\x12\'\n\x1a\x61uto_generate_session_name\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0csession_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0esetup_priority\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x04 \x01(\rH\x03\x88\x01\x01\x12%\n\x18local_protection_desired\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12$\n\x17label_recording_desired\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10se_style_desired\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12)\n\x1c\x62\x61ndwidth_protection_desired\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12$\n\x17node_protection_desired\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x38\n\x13resource_affinities\x18\n \x01(\x0b\x32\x1b.otg.RsvpResourceAffinitiesB\x1d\n\x1b_auto_generate_session_nameB\x0f\n\r_session_nameB\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x1b\n\x19_local_protection_desiredB\x1a\n\x18_label_recording_desiredB\x13\n\x11_se_style_desiredB\x1f\n\x1d_bandwidth_protection_desiredB\x1a\n\x18_node_protection_desired\"\x96\x01\n\x16RsvpResourceAffinities\x12\x18\n\x0b\x65xclude_any\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_all\"\x9f\x02\n\tRsvpTspec\x12\x1e\n\x11token_bucket_rate\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1e\n\x11token_bucket_size\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x1b\n\x0epeak_data_rate\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12!\n\x14minimum_policed_unit\x18\x04 \x01(\rH\x03\x88\x01\x01\x12!\n\x14maximum_policed_unit\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x14\n\x12_token_bucket_rateB\x14\n\x12_token_bucket_sizeB\x11\n\x0f_peak_data_rateB\x17\n\x15_minimum_policed_unitB\x17\n\x15_maximum_policed_unit\"\xc7\x03\n\x0fRsvpFastReroute\x12\x1b\n\x0esetup_priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\thop_limit\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x16\n\tbandwidth\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x18\n\x0b\x65xclude_any\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x07 \x01(\tH\x06\x88\x01\x01\x12&\n\x19one_to_one_backup_desired\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12$\n\x17\x66\x61\x63ility_backup_desired\x18\t \x01(\x08H\x08\x88\x01\x01\x42\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0c\n\n_hop_limitB\x0c\n\n_bandwidthB\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_allB\x1c\n\x1a_one_to_one_backup_desiredB\x1a\n\x18_facility_backup_desired\"\xa8\x02\n\x07RsvpEro\x12\x45\n\x13prepend_neighbor_ip\x18\x01 \x01(\x0e\x32#.otg.RsvpEro.PrependNeighborIp.EnumH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\nsubobjects\x18\x03 \x03(\x0b\x32\x15.otg.RsvpEroSubobject\x1a\x65\n\x11PrependNeighborIp\"P\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x64ont_prepend\x10\x01\x12\x11\n\rprepend_loose\x10\x02\x12\x12\n\x0eprepend_strict\x10\x03\x42\x16\n\x14_prepend_neighbor_ipB\x10\n\x0e_prefix_length\"\x8c\x03\n\x10RsvpEroSubobject\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.RsvpEroSubobject.Type.EnumH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x16\n\tas_number\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x39\n\x08hop_type\x18\x05 \x01(\x0e\x32\".otg.RsvpEroSubobject.HopType.EnumH\x04\x88\x01\x01\x1a\x38\n\x04Type\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\r\n\tas_number\x10\x02\x1a\x39\n\x07HopType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06strict\x10\x01\x12\t\n\x05loose\x10\x02\x42\x07\n\x05_typeB\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x0c\n\n_as_numberB\x0b\n\t_hop_type\"j\n\x10\x44\x65viceDhcpServer\x12*\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x11.otg.DhcpServerV4\x12*\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x11.otg.DhcpServerV6\"~\n\x0c\x44hcpServerV4\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv4_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\raddress_pools\x18\x03 \x03(\x0b\x32\x15.otg.DhcpServerV4PoolB\x07\n\x05_nameB\x0c\n\n_ipv4_name\"\x9a\x02\n\x10\x44hcpServerV4Pool\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nlease_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\rstart_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x11\n\x04step\x18\x06 \x01(\rH\x05\x88\x01\x01\x12,\n\x07options\x18\x07 \x01(\x0b\x32\x1b.otg.DhcpServerV4PoolOptionB\x07\n\x05_nameB\r\n\x0b_lease_timeB\x10\n\x0e_start_addressB\x10\n\x0e_prefix_lengthB\x08\n\x06_countB\x07\n\x05_step\"\xfc\x01\n\x16\x44hcpServerV4PoolOption\x12\x1b\n\x0erouter_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12primary_dns_server\x18\x02 \x01(\tH\x01\x88\x01\x01\x12!\n\x14secondary_dns_server\x18\x03 \x01(\tH\x02\x88\x01\x01\x12#\n\x16\x65\x63ho_relay_with_tlv_82\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x11\n\x0f_router_addressB\x15\n\x13_primary_dns_serverB\x17\n\x15_secondary_dns_serverB\x19\n\x17_echo_relay_with_tlv_82\"\x99\x02\n\x0c\x44hcpServerV6\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv6_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x0crapid_commit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12(\n\x1breconfigure_via_relay_agent\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12&\n\x06leases\x18\x05 \x03(\x0b\x32\x16.otg.DhcpV6ServerLease\x12)\n\x07options\x18\x06 \x01(\x0b\x32\x18.otg.Dhcpv6ServerOptionsB\x07\n\x05_nameB\x0c\n\n_ipv6_nameB\x0f\n\r_rapid_commitB\x1e\n\x1c_reconfigure_via_relay_agent\"\xac\x01\n\x13\x44hcpv6ServerOptions\x12!\n\x03\x64ns\x18\x01 \x01(\x0b\x32\x14.otg.DhcpV6ServerDns\x12\x37\n\x0bvendor_info\x18\x02 \x01(\x0b\x32\".otg.Dhcpv6ServerOptionsVendorInfo\x12\x39\n\x0c\x62ootfile_url\x18\x03 \x01(\x0b\x32#.otg.Dhcpv6ServerOptionsBootfileUrl\"e\n\x11\x44hcpV6ServerLease\x12\x17\n\nlease_time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12(\n\x07ia_type\x18\x05 \x01(\x0b\x32\x17.otg.Dhcpv6ServerIaTypeB\r\n\x0b_lease_time\"\xd6\x02\n\x12\x44hcpv6ServerIaType\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.Dhcpv6ServerIaType.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x04iana\x18\x02 \x01(\x0b\x32\x19.otg.Dhcpv6ServerPoolInfo\x12\'\n\x04iata\x18\x03 \x01(\x0b\x32\x19.otg.Dhcpv6ServerPoolInfo\x12+\n\x04iapd\x18\x04 \x01(\x0b\x32\x1d.otg.Dhcpv6ServerIapdPoolInfo\x12/\n\x06ianapd\x18\x05 \x01(\x0b\x32\x1f.otg.Dhcpv6ServerIanapdPoolInfo\x1aK\n\x06\x43hoice\"A\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04iana\x10\x01\x12\x08\n\x04iata\x10\x02\x12\x08\n\x04iapd\x10\x03\x12\n\n\x06ianapd\x10\x04\x42\t\n\x07_choice\"\xa4\x01\n\x14\x44hcpv6ServerPoolInfo\x12\x1a\n\rstart_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nprefix_len\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x10\n\x0e_start_addressB\r\n\x0b_prefix_lenB\x07\n\x05_sizeB\x07\n\x05_step\"\xa6\x02\n\x18\x44hcpv6ServerIapdPoolInfo\x12!\n\x14start_prefix_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x63onfigured_prefix_len\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bprefix_size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0bprefix_step\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\"\n\x15\x61\x64vertised_prefix_len\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x17\n\x15_start_prefix_addressB\x18\n\x16_configured_prefix_lenB\x0e\n\x0c_prefix_sizeB\x0e\n\x0c_prefix_stepB\x18\n\x16_advertised_prefix_len\"r\n\x1a\x44hcpv6ServerIanapdPoolInfo\x12\'\n\x04iana\x18\x01 \x01(\x0b\x32\x19.otg.Dhcpv6ServerPoolInfo\x12+\n\x04iapd\x18\x02 \x01(\x0b\x32\x1d.otg.Dhcpv6ServerIapdPoolInfo\"i\n\x0f\x44hcpV6ServerDns\x12\x14\n\x07primary\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x34\n\rsecondary_dns\x18\x02 \x03(\x0b\x32\x1d.otg.DhcpV6ServerSecondaryDnsB\n\n\x08_primary\"2\n\x18\x44hcpV6ServerSecondaryDns\x12\x0f\n\x02ip\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_ip\"\xa8\x04\n\x12\x44\x65viceOspfv2Router\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\trouter_id\x18\x02 \x01(\x0b\x32\x13.otg.Ospfv2RouterId\x12 \n\x13lsa_retransmit_time\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x10lsa_refresh_time\x18\x04 \x01(\rH\x02\x88\x01\x01\x12%\n\x18inter_burst_lsu_interval\x18\x05 \x01(\rH\x03\x88\x01\x01\x12$\n\x17max_flood_lsu_per_burst\x18\x06 \x01(\rH\x04\x88\x01\x01\x12\x34\n\x10graceful_restart\x18\x07 \x01(\x0b\x32\x1a.otg.Ospfv2GracefulRestart\x12\x16\n\tstore_lsa\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12(\n\x0c\x63\x61pabilities\x18\t \x01(\x0b\x32\x12.otg.Ospfv2Options\x12(\n\ninterfaces\x18\n \x03(\x0b\x32\x14.otg.Ospfv2Interface\x12*\n\tv4_routes\x18\x0b \x03(\x0b\x32\x17.otg.Ospfv2V4RouteRangeB\x07\n\x05_nameB\x16\n\x14_lsa_retransmit_timeB\x13\n\x11_lsa_refresh_timeB\x1b\n\x19_inter_burst_lsu_intervalB\x1a\n\x18_max_flood_lsu_per_burstB\x0c\n\n_store_lsa\"\xb2\x01\n\x0eOspfv2RouterId\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.Ospfv2RouterId.Choice.EnumH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cinterface_ip\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choiceB\t\n\x07_custom\"\xdd\x02\n\rOspfv2Options\x12\x12\n\x05t_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x12\n\x05\x65_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06mc_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06np_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06\x65\x61_bit\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06\x64\x63_bit\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x12\n\x05o_bit\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nunused_bit\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x16\n\tlsa_b_bit\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x16\n\tlsa_e_bit\x18\n \x01(\x08H\t\x88\x01\x01\x42\x08\n\x06_t_bitB\x08\n\x06_e_bitB\t\n\x07_mc_bitB\t\n\x07_np_bitB\t\n\x07_ea_bitB\t\n\x07_dc_bitB\x08\n\x06_o_bitB\r\n\x0b_unused_bitB\x0c\n\n_lsa_b_bitB\x0c\n\n_lsa_e_bit\"A\n\x15Ospfv2GracefulRestart\x12\x18\n\x0bhelper_mode\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x0e\n\x0c_helper_mode\"\x9f\x03\n\x0fOspfv2Interface\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv4_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x04\x61rea\x18\x03 \x01(\x0b\x32\x18.otg.Ospfv2InterfaceArea\x12\x35\n\x0cnetwork_type\x18\x04 \x01(\x0b\x32\x1f.otg.Ospfv2InterfaceNetworkType\x12-\n\x13traffic_engineering\x18\x05 \x03(\x0b\x32\x10.otg.LinkStateTE\x12:\n\x0e\x61uthentication\x18\x06 \x01(\x0b\x32\".otg.Ospfv2InterfaceAuthentication\x12.\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x1c.otg.Ospfv2InterfaceAdvanced\x12;\n\x0flink_protection\x18\x08 \x01(\x0b\x32\".otg.Ospfv2InterfaceLinkProtection\x12\x13\n\x0bsrlg_values\x18\t \x03(\rB\x07\n\x05_nameB\x0c\n\n_ipv4_name\"\xbe\x01\n\x13Ospfv2InterfaceArea\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.Ospfv2InterfaceArea.Choice.EnumH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02ip\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x31\n\x06\x43hoice\"\'\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02id\x10\x01\x12\x06\n\x02ip\x10\x02\x42\t\n\x07_choiceB\x05\n\x03_idB\x05\n\x03_ip\"\x83\x02\n\x1aOspfv2InterfaceNetworkType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.Ospfv2InterfaceNetworkType.Choice.EnumH\x00\x88\x01\x01\x12\x39\n\x13point_to_multipoint\x18\x02 \x03(\x0b\x32\x1c.otg.Ospfv2InterfaceNeighbor\x1a]\n\x06\x43hoice\"S\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x12\x17\n\x13point_to_multipoint\x10\x03\x42\t\n\x07_choice\"C\n\x17Ospfv2InterfaceNeighbor\x12\x18\n\x0bneighbor_ip\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_neighbor_ip\"\x89\x02\n\x17Ospfv2InterfaceAdvanced\x12\x1b\n\x0ehello_interval\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0erouting_metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x15\n\x08priority\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\"\n\x15validate_received_mtu\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_intervalB\x11\n\x0f_routing_metricB\x0b\n\t_priorityB\x18\n\x16_validate_received_mtu\"\x9a\x02\n\x16Ospfv2InterfaceOptions\x12\x12\n\x05t_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x12\n\x05\x65_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06mc_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06np_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06\x65\x61_bit\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06\x64\x63_bit\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x12\n\x05o_bit\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nunused_bit\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x08\n\x06_t_bitB\x08\n\x06_e_bitB\t\n\x07_mc_bitB\t\n\x07_np_bitB\t\n\x07_ea_bitB\t\n\x07_dc_bitB\x08\n\x06_o_bitB\r\n\x0b_unused_bit\"\x80\x02\n\x1dOspfv2InterfaceAuthentication\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.Ospfv2InterfaceAuthentication.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04md5s\x18\x02 \x03(\x0b\x32\x1c.otg.Ospfv2AuthenticationMd5\x12\x17\n\nclear_text\x18\x04 \x01(\tH\x01\x88\x01\x01\x1a;\n\x06\x43hoice\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04md5s\x10\x01\x12\x0e\n\nclear_text\x10\x02\x42\t\n\x07_choiceB\r\n\x0b_clear_text\"S\n\x17Ospfv2AuthenticationMd5\x12\x13\n\x06key_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03key\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_key_idB\x06\n\x04_key\"\xfb\x02\n\x1dOspfv2InterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\xaa\x01\n\x12Ospfv2V4RouteRange\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\taddresses\x18\x02 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x30\n\x0croute_origin\x18\x04 \x01(\x0b\x32\x1a.otg.Ospfv2V4RRRouteOriginB\x07\n\x05_nameB\t\n\x07_metric\"\xdd\x03\n\x15Ospfv2V4RRRouteOrigin\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.Ospfv2V4RRRouteOrigin.Choice.EnumH\x00\x88\x01\x01\x12,\n\nintra_area\x18\x02 \x01(\x0b\x32\x18.otg.Ospfv2V4RRIntraArea\x12,\n\ninter_area\x18\x03 \x01(\x0b\x32\x18.otg.Ospfv2V4RRInterArea\x12\x35\n\x0f\x65xternal_type_1\x18\x04 \x01(\x0b\x32\x1c.otg.Ospfv2V4RRExternalType1\x12\x35\n\x0f\x65xternal_type_2\x18\x05 \x01(\x0b\x32\x1c.otg.Ospfv2V4RRExternalType2\x12\x32\n\rnssa_external\x18\x06 \x01(\x0b\x32\x1b.otg.Ospfv2V4RRNssaExternal\x1a~\n\x06\x43hoice\"t\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nintra_area\x10\x01\x12\x0e\n\ninter_area\x10\x02\x12\x13\n\x0f\x65xternal_type_1\x10\x03\x12\x13\n\x0f\x65xternal_type_2\x10\x04\x12\x11\n\rnssa_external\x10\x05\x42\t\n\x07_choice\"D\n\x13Ospfv2V4RRIntraArea\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"D\n\x13Ospfv2V4RRInterArea\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"H\n\x17Ospfv2V4RRExternalType1\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"H\n\x17Ospfv2V4RRExternalType2\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"q\n\x16Ospfv2V4RRNssaExternal\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\x12\x18\n\x0bpropagation\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x0e\n\x0c_propagation\"[\n\x19Ospfv2V4RRExtdPrefixFlags\x12\x13\n\x06\x61_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06n_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\t\n\x07_a_flagB\t\n\x07_n_flag\"O\n\x0c\x44\x65viceMacsec\x12?\n\x13\x65thernet_interfaces\x18\x01 \x03(\x0b\x32\".otg.DeviceMacsecEthernetInterface\"m\n\x1d\x44\x65viceMacsecEthernetInterface\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\rsecure_entity\x18\x02 \x01(\x0b\x32\x11.otg.SecureEntityB\x0b\n\t_eth_name\"\xa3\x01\n\x0cSecureEntity\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12G\n\x17key_generation_protocol\x18\x02 \x01(\x0b\x32&.otg.SecureEntityKeyGenerationProtocol\x12.\n\ndata_plane\x18\x03 \x01(\x0b\x32\x1a.otg.SecureEntityDataPlaneB\x07\n\x05_name\"\xfa\x01\n!SecureEntityKeyGenerationProtocol\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.SecureEntityKeyGenerationProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x15\n\x03mka\x18\x02 \x01(\x0b\x32\x08.otg.Mka\x12.\n\nstatic_key\x18\x03 \x01(\x0b\x32\x1a.otg.SecureEntityStaticKey\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03mka\x10\x01\x12\x0e\n\nstatic_key\x10\x02\x42\t\n\x07_choice\"\xeb\x01\n\x15SecureEntityDataPlane\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.SecureEntityDataPlane.Choice.EnumH\x00\x88\x01\x01\x12>\n\rencapsulation\x18\x02 \x01(\x0b\x32\'.otg.SecureEntityDataPlaneEncapsulation\x1aJ\n\x06\x43hoice\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rencapsulation\x10\x01\x12\x14\n\x10no_encapsulation\x10\x02\x42\t\n\x07_choice\"\xae\x01\n\"SecureEntityDataPlaneEncapsulation\x12(\n\x02tx\x18\x01 \x01(\x0b\x32\x1c.otg.SecureEntityDataPlaneTx\x12(\n\x02rx\x18\x02 \x01(\x0b\x32\x1c.otg.SecureEntityDataPlaneRx\x12\x34\n\rcrypto_engine\x18\x03 \x01(\x0b\x32\x1d.otg.SecureEntityCryptoEngine\"m\n\x17SecureEntityDataPlaneTx\x12\x18\n\x0b\x65nd_station\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0binclude_sci\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0e\n\x0c_end_stationB\x0e\n\x0c_include_sci\"}\n\x17SecureEntityDataPlaneRx\x12\x1e\n\x11replay_protection\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rreplay_window\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_replay_protectionB\x10\n\x0e_replay_window\"\xda\x01\n\x18SecureEntityCryptoEngine\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.SecureEntityCryptoEngine.Choice.EnumH\x00\x88\x01\x01\x12>\n\x0c\x65ncrypt_only\x18\x02 \x01(\x0b\x32(.otg.SecureEntityCryptoEngineEncryptOnly\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x65ncrypt_only\x10\x01\x42\t\n\x07_choice\"\xbd\x01\n#SecureEntityCryptoEngineEncryptOnly\x12\x45\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32,.otg.SecureEntityCryptoEngineEncryptOnlyTxSc\x12O\n\x0ftraffic_options\x18\x02 \x01(\x0b\x32\x36.otg.SecureEntityCryptoEngineEncryptOnlyTrafficOptions\"j\n\'SecureEntityCryptoEngineEncryptOnlyTxSc\x12?\n\x05tx_pn\x18\x01 \x01(\x0b\x32\x30.otg.SecureEntityCryptoEngineEncryptOnlyTxScTxPn\"\xdf\x02\n+SecureEntityCryptoEngineEncryptOnlyTxScTxPn\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.SecureEntityCryptoEngineEncryptOnlyTxScTxPn.Choice.EnumH\x00\x88\x01\x01\x12>\n\x05\x66ixed\x18\x02 \x01(\x0b\x32/.otg.SecureEntityCryptoEngineEncryptOnlyFixedPn\x12L\n\x0cincrementing\x18\x03 \x01(\x0b\x32\x36.otg.SecureEntityCryptoEngineEncryptOnlyIncrementingPn\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08\x66ixed_pn\x10\x01\x12\x13\n\x0fincrementing_pn\x10\x02\x42\t\n\x07_choice\"^\n*SecureEntityCryptoEngineEncryptOnlyFixedPn\x12\x0f\n\x02pn\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03xpn\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_pnB\x06\n\x04_xpn\"\xa7\x01\n1SecureEntityCryptoEngineEncryptOnlyIncrementingPn\x12\x12\n\x05\x63ount\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0bstarting_pn\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0cstarting_xpn\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x08\n\x06_countB\x0e\n\x0c_starting_pnB\x0f\n\r_starting_xpn\"m\n1SecureEntityCryptoEngineEncryptOnlyTrafficOptions\x12 \n\x13send_gratuitous_arp\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_send_gratuitous_arp\"~\n\x03Mka\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\r.otg.MkaBasic\x12%\n\nkey_server\x18\x03 \x01(\x0b\x32\x11.otg.MkaKeyServer\x12\x16\n\x02tx\x18\x04 \x01(\x0b\x32\n.otg.MkaTxB\x07\n\x05_name\"\xfe\x08\n\x08MkaBasic\x12N\n\x17key_derivation_function\x18\x01 \x01(\x0e\x32(.otg.MkaBasic.KeyDerivationFunction.EnumH\x00\x88\x01\x01\x12*\n\nkey_source\x18\x02 \x01(\x0b\x32\x16.otg.MkaBasicKeySource\x12\x1b\n\x0e\x61\x63tor_priority\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0emacsec_desired\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x43\n\x11macsec_capability\x18\x05 \x01(\x0e\x32#.otg.MkaBasic.MacsecCapability.EnumH\x03\x88\x01\x01\x12\x43\n\x17supported_cipher_suites\x18\x06 \x01(\x0b\x32\".otg.MkaBasicSupportedCipherSuites\x12 \n\x13\x65\x61pol_ethernet_type\x18\x07 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bmka_version\x18\x08 \x01(\rH\x05\x88\x01\x01\x12\x1b\n\x0emka_hello_time\x18\t \x01(\rH\x06\x88\x01\x01\x12\x1a\n\rmka_life_time\x18\n \x01(\rH\x07\x88\x01\x01\x12)\n\x1csend_icv_indicatior_in_mkpdu\x18\x0b \x01(\x08H\x08\x88\x01\x01\x12\x1a\n\rdelay_protect\x18\x0c \x01(\x08H\t\x88\x01\x01\x12*\n\nrekey_mode\x18\r \x01(\x0b\x32\x16.otg.MkaBasicRekeyMode\x12<\n\x14psk_chain_start_time\x18\x0e \x01(\x0b\x32\x1e.otg.MkaBasicPskChainStartTime\x1aT\n\x15KeyDerivationFunction\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x61\x65s_cmac_128\x10\x01\x12\x10\n\x0c\x61\x65s_cmac_256\x10\x02\x1a\xdd\x01\n\x10MacsecCapability\"\xc8\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1a\n\x16macsec_not_implemented\x10\x01\x12,\n(macsec_integrity_without_confidentiality\x10\x02\x12\x33\n/macsec_integrity_with_no_confidentiality_offset\x10\x03\x12\x30\n,macsec_integrity_with_confidentiality_offset\x10\x04\x42\x1a\n\x18_key_derivation_functionB\x11\n\x0f_actor_priorityB\x11\n\x0f_macsec_desiredB\x14\n\x12_macsec_capabilityB\x16\n\x14_eapol_ethernet_typeB\x0e\n\x0c_mka_versionB\x11\n\x0f_mka_hello_timeB\x10\n\x0e_mka_life_timeB\x1f\n\x1d_send_icv_indicatior_in_mkpduB\x10\n\x0e_delay_protect\"\xd7\x01\n\x1dMkaBasicSupportedCipherSuites\x12\x18\n\x0bgcm_aes_128\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bgcm_aes_256\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1c\n\x0fgcm_aes_xpn_128\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1c\n\x0fgcm_aes_xpn_256\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x0e\n\x0c_gcm_aes_128B\x0e\n\x0c_gcm_aes_256B\x12\n\x10_gcm_aes_xpn_128B\x12\n\x10_gcm_aes_xpn_256\"\xb5\x01\n\x11MkaBasicKeySource\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.MkaBasicKeySource.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x04psks\x18\x02 \x03(\x0b\x32\x19.otg.MkaBasicKeySourcePsk\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03psk\x10\x01\x12\x07\n\x03msk\x10\x02\x42\t\n\x07_choice\"\xce\x01\n\x14MkaBasicKeySourcePsk\x12\x16\n\tcak_value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x63\x61k_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x37\n\x11start_offset_time\x18\x03 \x01(\x0b\x32\x1c.otg.MkaBasicStartOffsetTime\x12\x33\n\x0f\x65nd_offset_time\x18\x04 \x01(\x0b\x32\x1a.otg.MkaBasicEndOffsetTimeB\x0c\n\n_cak_valueB\x0b\n\t_cak_name\"I\n\x17MkaBasicStartOffsetTime\x12\x0f\n\x02hh\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02mm\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x05\n\x03_hhB\x05\n\x03_mm\"G\n\x15MkaBasicEndOffsetTime\x12\x0f\n\x02hh\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02mm\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x05\n\x03_hhB\x05\n\x03_mm\"\xb6\x01\n\x19MkaBasicPskChainStartTime\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.MkaBasicPskChainStartTime.Choice.EnumH\x00\x88\x01\x01\x12!\n\x03utc\x18\x02 \x01(\x0b\x32\x14.otg.MkaBasicTimeUtc\x1a*\n\x06\x43hoice\" \n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03utc\x10\x01\x42\t\n\x07_choice\"\xc1\x01\n\x0fMkaBasicTimeUtc\x12\x10\n\x03\x64\x61y\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05month\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04year\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04hour\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x13\n\x06minute\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x13\n\x06second\x18\x06 \x01(\rH\x05\x88\x01\x01\x42\x06\n\x04_dayB\x08\n\x06_monthB\x07\n\x05_yearB\x07\n\x05_hourB\t\n\x07_minuteB\t\n\x07_second\"\xe0\x01\n\x11MkaBasicRekeyMode\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.MkaBasicRekeyMode.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x0btimer_based\x18\x02 \x01(\x0b\x32 .otg.MkaBasicRekeyModeTimerBased\x1aP\n\x06\x43hoice\"F\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ndont_rekey\x10\x01\x12\x0f\n\x0btimer_based\x10\x02\x12\x0c\n\x08pn_based\x10\x03\x42\t\n\x07_choice\"\xfd\x01\n\x1bMkaBasicRekeyModeTimerBased\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.MkaBasicRekeyModeTimerBased.Choice.EnumH\x00\x88\x01\x01\x12\x18\n\x0b\x66ixed_count\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ncontinuous\x10\x01\x12\x0f\n\x0b\x66ixed_count\x10\x02\x42\t\n\x07_choiceB\x0e\n\x0c_fixed_countB\x0b\n\t_interval\"\xe1\x05\n\x0cMkaKeyServer\x12O\n\x15\x63onfidentialty_offset\x18\x01 \x01(\x0e\x32+.otg.MkaKeyServer.ConfidentialtyOffset.EnumH\x00\x88\x01\x01\x12=\n\x0c\x63ipher_suite\x18\x02 \x01(\x0e\x32\".otg.MkaKeyServer.CipherSuite.EnumH\x01\x88\x01\x01\x12 \n\x13starting_key_number\x18\x03 \x01(\rH\x02\x88\x01\x01\x12$\n\x17starting_distributed_an\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1f\n\x12rekey_threshold_pn\x18\x05 \x01(\tH\x04\x88\x01\x01\x12 \n\x13rekey_threshold_xpn\x18\x06 \x01(\tH\x05\x88\x01\x01\x1a\xb3\x01\n\x14\x43onfidentialtyOffset\"\x9a\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12no_confidentiality\x10\x01\x12\x1d\n\x19no_confidentiality_offset\x10\x02\x12$\n confidentiality_offset_30_octets\x10\x03\x12$\n confidentiality_offset_50_octets\x10\x04\x1ar\n\x0b\x43ipherSuite\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bgcm_aes_128\x10\x01\x12\x0f\n\x0bgcm_aes_256\x10\x02\x12\x13\n\x0fgcm_aes_xpn_128\x10\x03\x12\x13\n\x0fgcm_aes_xpn_256\x10\x04\x42\x18\n\x16_confidentialty_offsetB\x0f\n\r_cipher_suiteB\x16\n\x14_starting_key_numberB\x1a\n\x18_starting_distributed_anB\x15\n\x13_rekey_threshold_pnB\x16\n\x14_rekey_threshold_xpn\".\n\x05MkaTx\x12%\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32\x0c.otg.MkaTxSc\"\xaf\x01\n\x07MkaTxSc\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tsystem_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12$\n\x17starting_message_number\x18\x04 \x01(\x04H\x03\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_system_idB\n\n\x08_port_idB\x1a\n\x18_starting_message_number\"\xb4\x04\n\x15SecureEntityStaticKey\x12\x46\n\x0c\x63ipher_suite\x18\x01 \x01(\x0e\x32+.otg.SecureEntityStaticKey.CipherSuite.EnumH\x00\x88\x01\x01\x12\x1c\n\x0f\x63onfidentiality\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12Z\n\x16\x63onfidentiality_offset\x18\x03 \x01(\x0e\x32\x35.otg.SecureEntityStaticKey.ConfidentialityOffset.EnumH\x02\x88\x01\x01\x12(\n\x02tx\x18\x04 \x01(\x0b\x32\x1c.otg.SecureEntityStaticKeyTx\x12(\n\x02rx\x18\x05 \x01(\x0b\x32\x1c.otg.SecureEntityStaticKeyRx\x1ar\n\x0b\x43ipherSuite\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bgcm_aes_128\x10\x01\x12\x0f\n\x0bgcm_aes_256\x10\x02\x12\x13\n\x0fgcm_aes_xpn_128\x10\x03\x12\x13\n\x0fgcm_aes_xpn_256\x10\x04\x1aQ\n\x15\x43onfidentialityOffset\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04zero\x10\x01\x12\n\n\x06thirty\x10\x02\x12\t\n\x05\x66ifty\x10\x03\x42\x0f\n\r_cipher_suiteB\x12\n\x10_confidentialityB\x19\n\x17_confidentiality_offset\"\x87\x02\n\x1eSecureEntityStaticKeyRekeyMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.SecureEntityStaticKeyRekeyMode.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\x0btimer_based\x18\x02 \x01(\x0b\x32-.otg.SecureEntityStaticKeyRekeyModeTimerBased\x1aP\n\x06\x43hoice\"F\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ndont_rekey\x10\x01\x12\x0f\n\x0btimer_based\x10\x02\x12\x0c\n\x08pn_based\x10\x03\x42\t\n\x07_choice\"\x97\x02\n(SecureEntityStaticKeyRekeyModeTimerBased\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.SecureEntityStaticKeyRekeyModeTimerBased.Choice.EnumH\x00\x88\x01\x01\x12\x18\n\x0b\x66ixed_count\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ncontinuous\x10\x01\x12\x0f\n\x0b\x66ixed_count\x10\x02\x42\t\n\x07_choiceB\x0e\n\x0c_fixed_countB\x0b\n\t_interval\"l\n\x18SecureEntityStaticKeySak\x12\x10\n\x03sak\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04ssci\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04salt\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x06\n\x04_sakB\x07\n\x05_ssciB\x07\n\x05_salt\"\x8b\x01\n\x17SecureEntityStaticKeyTx\x12\x37\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32\x1e.otg.SecureEntityStaticKeyTxSc\x12\x37\n\nrekey_mode\x18\x02 \x01(\x0b\x32#.otg.SecureEntityStaticKeyRekeyMode\"\x90\x01\n\x19SecureEntityStaticKeyTxSc\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12+\n\x04saks\x18\x03 \x03(\x0b\x32\x1d.otg.SecureEntityStaticKeySakB\x0c\n\n_system_idB\n\n\x08_port_id\"R\n\x17SecureEntityStaticKeyRx\x12\x37\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32\x1e.otg.SecureEntityStaticKeyRxSc\"\xda\x01\n\x19SecureEntityStaticKeyRxSc\x12\x1e\n\x11\x64ut_sci_system_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0f\x64ut_sci_port_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x64ut_msb_xpn\x18\x03 \x01(\rH\x02\x88\x01\x01\x12+\n\x04saks\x18\x04 \x03(\x0b\x32\x1d.otg.SecureEntityStaticKeySakB\x14\n\x12_dut_sci_system_idB\x12\n\x10_dut_sci_port_idB\x0e\n\x0c_dut_msb_xpn\"j\n\x12\x44\x65viceOspfv3Router\x12&\n\trouter_id\x18\x01 \x01(\x0b\x32\x13.otg.Ospfv3RouterId\x12,\n\tinstances\x18\x02 \x03(\x0b\x32\x19.otg.Ospfv3RouterInstance\"\xc5\x03\n\x14Ospfv3RouterInstance\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13lsa_retransmit_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x10lsa_refresh_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x12%\n\x18inter_burst_lsu_interval\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x34\n\x10graceful_restart\x18\x05 \x01(\x0b\x32\x1a.otg.Ospfv3GracefulRestart\x12\x16\n\tstore_lsa\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12-\n\x0c\x63\x61pabilities\x18\x07 \x01(\x0b\x32\x17.otg.Ospfv3Capabilities\x12(\n\ninterfaces\x18\x08 \x03(\x0b\x32\x14.otg.Ospfv3Interface\x12*\n\tv6_routes\x18\t \x03(\x0b\x32\x17.otg.Ospfv3V6RouteRangeB\x07\n\x05_nameB\x16\n\x14_lsa_retransmit_timeB\x13\n\x11_lsa_refresh_timeB\x1b\n\x19_inter_burst_lsu_intervalB\x0c\n\n_store_lsa\"\xaa\x01\n\x0eOspfv3RouterId\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.Ospfv3RouterId.Choice.EnumH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choiceB\t\n\x07_custom\"`\n\x12Ospfv3Capabilities\x12\x16\n\tlsa_b_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tlsa_e_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0c\n\n_lsa_b_bitB\x0c\n\n_lsa_e_bit\"A\n\x15Ospfv3GracefulRestart\x12\x18\n\x0bhelper_mode\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x0e\n\x0c_helper_mode\"\xba\x02\n\x0fOspfv3Interface\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv6_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x04\x61rea\x18\x03 \x01(\x0b\x32\x18.otg.Ospfv3InterfaceArea\x12\x35\n\x0cnetwork_type\x18\x04 \x01(\x0b\x32\x1f.otg.Ospfv3InterfaceNetworkType\x12.\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x1c.otg.Ospfv3InterfaceAdvanced\x12,\n\x07options\x18\x06 \x01(\x0b\x32\x1b.otg.Ospfv3InterfaceOptions\x12\x18\n\x0binstance_id\x18\x07 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_ipv6_nameB\x0e\n\x0c_instance_id\"\xbe\x01\n\x13Ospfv3InterfaceArea\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.Ospfv3InterfaceArea.Choice.EnumH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02ip\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x31\n\x06\x43hoice\"\'\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02id\x10\x01\x12\x06\n\x02ip\x10\x02\x42\t\n\x07_choiceB\x05\n\x03_idB\x05\n\x03_ip\"\xe1\x01\n\x1aOspfv3InterfaceNetworkType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.Ospfv3InterfaceNetworkType.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\tbroadcast\x18\x02 \x01(\x0b\x32\x1d.otg.Ospfv3InterfaceBroadcast\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x42\t\n\x07_choice\"\xdf\x01\n\x17Ospfv3InterfaceAdvanced\x12\x1b\n\x0ehello_interval\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0blink_metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\"\n\x15validate_received_mtu\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_intervalB\x0e\n\x0c_link_metricB\x18\n\x16_validate_received_mtu\"\xb2\x01\n\x16Ospfv3InterfaceOptions\x12\x13\n\x06\x64\x63_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x12\n\x05r_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x12\n\x05n_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x12\n\x05\x65_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06v6_bit\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_dc_bitB\x08\n\x06_r_bitB\x08\n\x06_n_bitB\x08\n\x06_e_bitB\t\n\x07_v6_bit\">\n\x18Ospfv3InterfaceBroadcast\x12\x15\n\x08priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x0b\n\t_priority\"\xaa\x01\n\x12Ospfv3V6RouteRange\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\taddresses\x18\x02 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x30\n\x0croute_origin\x18\x04 \x01(\x0b\x32\x1a.otg.Ospfv3V6RRRouteOriginB\x07\n\x05_nameB\t\n\x07_metric\"\x93\x02\n\x15Ospfv3V6RRRouteOrigin\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.Ospfv3V6RRRouteOrigin.Choice.EnumH\x00\x88\x01\x01\x12\x32\n\rnssa_external\x18\x02 \x01(\x0b\x32\x1b.otg.Ospfv3V6RRNssaExternal\x1a~\n\x06\x43hoice\"t\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nintra_area\x10\x01\x12\x0e\n\ninter_area\x10\x02\x12\x13\n\x0f\x65xternal_type_1\x10\x03\x12\x13\n\x0f\x65xternal_type_2\x10\x04\x12\x11\n\rnssa_external\x10\x05\x42\t\n\x07_choice\"K\n\x16Ospfv3V6RRNssaExternal\x12\x31\n\x0c\x63\x61pabilities\x18\x01 \x01(\x0b\x32\x1b.otg.Ospfv3V6RRCapabilities\"\x80\x01\n\x16Ospfv3V6RRCapabilities\x12\x18\n\x0bpropagation\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12<\n\x12\x66orwarding_address\x18\x02 \x01(\x0b\x32 .otg.Ospfv3V6RRForwardingAddressB\x0e\n\x0c_propagation\"\xcc\x01\n\x1bOspfv3V6RRForwardingAddress\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.Ospfv3V6RRForwardingAddress.Choice.EnumH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cinterface_ip\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choiceB\t\n\x07_custom\"t\n\x10\x44\x65viceRocev2Peer\x12/\n\x0fipv4_interfaces\x18\x01 \x03(\x0b\x32\x16.otg.Rocev2V4Interface\x12/\n\x0fipv6_interfaces\x18\x02 \x03(\x0b\x32\x16.otg.Rocev2V6Interface\"{\n\x11Rocev2V4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06ib_mtu\x18\x02 \x01(\rH\x01\x88\x01\x01\x12 \n\x05peers\x18\x03 \x03(\x0b\x32\x11.otg.Rocev2V4PeerB\x0c\n\n_ipv4_nameB\t\n\x07_ib_mtu\"\x87\x01\n\x0cRocev2V4Peer\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12#\n\x16\x64\x65stination_ip_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x03qps\x18\x03 \x03(\x0b\x32\x0e.otg.Rocev2QPsB\x07\n\x05_nameB\x19\n\x17_destination_ip_address\"a\n\tRocev2QPs\x12\x14\n\x07qp_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x32\n\x0f\x63onnection_type\x18\x02 \x01(\x0b\x32\x19.otg.Rocev2ConnectionTypeB\n\n\x08_qp_name\"\xcf\x01\n\x14Rocev2ConnectionType\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.Rocev2ConnectionType.Choice.EnumH\x00\x88\x01\x01\x12\x34\n\x13reliable_connection\x18\x02 \x01(\x0b\x32\x17.otg.Rocev2QPParameters\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13reliable_connection\x10\x01\x42\t\n\x07_choice\"\xa1\x03\n\x12Rocev2QPParameters\x12\x1d\n\x10source_qp_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04\x64scp\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x32\n\x03\x65\x63n\x18\x03 \x01(\x0e\x32 .otg.Rocev2QPParameters.Ecn.EnumH\x02\x88\x01\x01\x12\x1c\n\x0fudp_source_port\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0binitial_psn\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fvirtual_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\nremote_key\x18\x07 \x01(\tH\x06\x88\x01\x01\x1aI\n\x03\x45\x63n\"B\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07non_ect\x10\x01\x12\t\n\x05\x65\x63t_1\x10\x02\x12\t\n\x05\x65\x63t_0\x10\x03\x12\x06\n\x02\x63\x65\x10\x04\x42\x13\n\x11_source_qp_numberB\x07\n\x05_dscpB\x06\n\x04_ecnB\x12\n\x10_udp_source_portB\x0e\n\x0c_initial_psnB\x12\n\x10_virtual_addressB\r\n\x0b_remote_key\"{\n\x11Rocev2V6Interface\x12\x16\n\tipv6_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06ib_mtu\x18\x02 \x01(\rH\x01\x88\x01\x01\x12 \n\x05peers\x18\x03 \x03(\x0b\x32\x11.otg.Rocev2V6PeerB\x0c\n\n_ipv6_nameB\t\n\x07_ib_mtu\"\x87\x01\n\x0cRocev2V6Peer\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12#\n\x16\x64\x65stination_ip_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x03qps\x18\x03 \x03(\x0b\x32\x0e.otg.Rocev2QPsB\x07\n\x05_nameB\x19\n\x17_destination_ip_address\"\xae\x02\n\x04\x46low\x12\x1c\n\x05tx_rx\x18\x01 \x01(\x0b\x32\r.otg.FlowTxRx\x12\x1f\n\x06packet\x18\x02 \x03(\x0b\x32\x0f.otg.FlowHeader\x12&\n\regress_packet\x18\t \x03(\x0b\x32\x0f.otg.FlowHeader\x12\x1b\n\x04size\x18\x03 \x01(\x0b\x32\r.otg.FlowSize\x12\x1b\n\x04rate\x18\x04 \x01(\x0b\x32\r.otg.FlowRate\x12#\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x11.otg.FlowDuration\x12!\n\x07metrics\x18\x06 \x01(\x0b\x32\x10.otg.FlowMetrics\x12\x11\n\x04name\x18\x07 \x01(\tH\x00\x88\x01\x01\x12!\n\x07payload\x18\x08 \x01(\x0b\x32\x10.otg.FlowPayloadB\x07\n\x05_name\"\xbc\x01\n\x08\x46lowTxRx\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowTxRx.Choice.EnumH\x00\x88\x01\x01\x12\x1b\n\x04port\x18\x02 \x01(\x0b\x32\r.otg.FlowPort\x12\x1f\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x0f.otg.FlowRouter\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\n\n\x06\x64\x65vice\x10\x02\x42\t\n\x07_choice\"`\n\x08\x46lowPort\x12\x14\n\x07tx_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07rx_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x08rx_names\x18\x03 \x03(\tB\n\n\x08_tx_nameB\n\n\x08_rx_name\"\xa2\x01\n\nFlowRouter\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x19.otg.FlowRouter.Mode.EnumH\x00\x88\x01\x01\x12\x10\n\x08tx_names\x18\x02 \x03(\t\x12\x10\n\x08rx_names\x18\x03 \x03(\t\x1a\x39\n\x04Mode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mesh\x10\x01\x12\x0e\n\none_to_one\x10\x02\x42\x07\n\x05_mode\"\xbd\x08\n\nFlowHeader\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowHeader.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x0f.otg.FlowCustom\x12#\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x11.otg.FlowEthernet\x12\x1b\n\x04vlan\x18\x04 \x01(\x0b\x32\r.otg.FlowVlan\x12\x1d\n\x05vxlan\x18\x05 \x01(\x0b\x32\x0e.otg.FlowVxlan\x12\x1b\n\x04ipv4\x18\x06 \x01(\x0b\x32\r.otg.FlowIpv4\x12\x1b\n\x04ipv6\x18\x07 \x01(\x0b\x32\r.otg.FlowIpv6\x12#\n\x08pfcpause\x18\x08 \x01(\x0b\x32\x11.otg.FlowPfcPause\x12-\n\rethernetpause\x18\t \x01(\x0b\x32\x16.otg.FlowEthernetPause\x12\x19\n\x03tcp\x18\n \x01(\x0b\x32\x0c.otg.FlowTcp\x12\x19\n\x03udp\x18\x0b \x01(\x0b\x32\x0c.otg.FlowUdp\x12\x19\n\x03gre\x18\x0c \x01(\x0b\x32\x0c.otg.FlowGre\x12\x1d\n\x05gtpv1\x18\r \x01(\x0b\x32\x0e.otg.FlowGtpv1\x12\x1d\n\x05gtpv2\x18\x0e \x01(\x0b\x32\x0e.otg.FlowGtpv2\x12\x19\n\x03\x61rp\x18\x0f \x01(\x0b\x32\x0c.otg.FlowArp\x12\x1b\n\x04icmp\x18\x10 \x01(\x0b\x32\r.otg.FlowIcmp\x12\x1f\n\x06icmpv6\x18\x11 \x01(\x0b\x32\x0f.otg.FlowIcmpv6\x12\x19\n\x03ppp\x18\x12 \x01(\x0b\x32\x0c.otg.FlowPpp\x12\x1f\n\x06igmpv1\x18\x13 \x01(\x0b\x32\x0f.otg.FlowIgmpv1\x12\x1b\n\x04mpls\x18\x14 \x01(\x0b\x32\r.otg.FlowMpls\x12!\n\x07snmpv2c\x18\x15 \x01(\x0b\x32\x10.otg.FlowSnmpv2c\x12\x1b\n\x04rsvp\x18\x16 \x01(\x0b\x32\r.otg.FlowRsvp\x12\x1f\n\x06macsec\x18\x17 \x01(\x0b\x32\x0f.otg.FlowMacsec\x12\x1b\n\x04lacp\x18\x18 \x01(\x0b\x32\r.otg.FlowLacp\x1a\xa2\x02\n\x06\x43hoice\"\x97\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\t\n\x05vxlan\x10\x04\x12\x08\n\x04ipv4\x10\x05\x12\x08\n\x04ipv6\x10\x06\x12\x0c\n\x08pfcpause\x10\x07\x12\x11\n\rethernetpause\x10\x08\x12\x07\n\x03tcp\x10\t\x12\x07\n\x03udp\x10\n\x12\x07\n\x03gre\x10\x0b\x12\t\n\x05gtpv1\x10\x0c\x12\t\n\x05gtpv2\x10\r\x12\x07\n\x03\x61rp\x10\x0e\x12\x08\n\x04icmp\x10\x0f\x12\n\n\x06icmpv6\x10\x10\x12\x07\n\x03ppp\x10\x11\x12\n\n\x06igmpv1\x10\x12\x12\x08\n\x04mpls\x10\x13\x12\x0b\n\x07snmpv2c\x10\x14\x12\x08\n\x04rsvp\x10\x15\x12\n\n\x06macsec\x10\x16\x12\x08\n\x04lacp\x10\x17\x42\t\n\x07_choice\"Y\n\nFlowCustom\x12\x12\n\x05\x62ytes\x18\x01 \x01(\tH\x00\x88\x01\x01\x12-\n\x0bmetric_tags\x18\x02 \x03(\x0b\x32\x18.otg.FlowCustomMetricTagB\x08\n\x06_bytes\"q\n\x13\x46lowCustomMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xce\x01\n\x0c\x46lowEthernet\x12(\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetDst\x12(\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetSrc\x12\x35\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowEthernetEtherType\x12\x33\n\tpfc_queue\x18\x04 \x01(\x0b\x32 .otg.PatternFlowEthernetPfcQueue\"\xac\x01\n\x08\x46lowVlan\x12.\n\x08priority\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowVlanPriority\x12$\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x17.otg.PatternFlowVlanCfi\x12\"\n\x02id\x18\x03 \x01(\x0b\x32\x16.otg.PatternFlowVlanId\x12&\n\x04tpid\x18\x04 \x01(\x0b\x32\x18.otg.PatternFlowVlanTpid\"\xc3\x01\n\tFlowVxlan\x12)\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowVxlanFlags\x12\x31\n\treserved0\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved0\x12%\n\x03vni\x18\x03 \x01(\x0b\x32\x18.otg.PatternFlowVxlanVni\x12\x31\n\treserved1\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved1\"\x84\x06\n\x08\x46lowIpv4\x12,\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4Version\x12\x37\n\rheader_length\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv4HeaderLength\x12\'\n\x08priority\x18\x03 \x01(\x0b\x32\x15.otg.FlowIpv4Priority\x12\x35\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TotalLength\x12:\n\x0eidentification\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4Identification\x12.\n\x08reserved\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4Reserved\x12\x37\n\rdont_fragment\x18\x07 \x01(\x0b\x32 .otg.PatternFlowIpv4DontFragment\x12\x39\n\x0emore_fragments\x18\x08 \x01(\x0b\x32!.otg.PatternFlowIpv4MoreFragments\x12;\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\".otg.PatternFlowIpv4FragmentOffset\x12\x34\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x1e.otg.PatternFlowIpv4TimeToLive\x12.\n\x08protocol\x18\x0b \x01(\x0b\x32\x1c.otg.PatternFlowIpv4Protocol\x12;\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\".otg.PatternFlowIpv4HeaderChecksum\x12$\n\x03src\x18\r \x01(\x0b\x32\x17.otg.PatternFlowIpv4Src\x12$\n\x03\x64st\x18\x0e \x01(\x0b\x32\x17.otg.PatternFlowIpv4Dst\x12%\n\x07options\x18\x0f \x03(\x0b\x32\x14.otg.FlowIpv4Options\"\xc0\x01\n\x0f\x46lowIpv4Options\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.FlowIpv4Options.Choice.EnumH\x00\x88\x01\x01\x12*\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x1a.otg.FlowIpv4OptionsCustom\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crouter_alert\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choice\"\x95\x01\n\x15\x46lowIpv4OptionsCustom\x12,\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.FlowIpv4OptionsCustomType\x12\x30\n\x06length\x18\x02 \x01(\x0b\x32 .otg.FlowIpv4OptionsCustomLength\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xf3\x01\n\x19\x46lowIpv4OptionsCustomType\x12\x44\n\x0b\x63opied_flag\x18\x01 \x01(\x0b\x32/.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlag\x12\x46\n\x0coption_class\x18\x02 \x01(\x0b\x32\x30.otg.PatternFlowIpv4OptionsCustomTypeOptionClass\x12H\n\roption_number\x18\x03 \x01(\x0b\x32\x31.otg.PatternFlowIpv4OptionsCustomTypeOptionNumber\"\xdd\x01\n\x1b\x46lowIpv4OptionsCustomLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.FlowIpv4OptionsCustomLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x82\x02\n\x10\x46lowIpv4Priority\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.FlowIpv4Priority.Choice.EnumH\x00\x88\x01\x01\x12,\n\x03raw\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4PriorityRaw\x12\x1d\n\x03tos\x18\x03 \x01(\x0b\x32\x10.otg.FlowIpv4Tos\x12\x1f\n\x04\x64scp\x18\x04 \x01(\x0b\x32\x11.otg.FlowIpv4Dscp\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03raw\x10\x01\x12\x07\n\x03tos\x10\x02\x12\x08\n\x04\x64scp\x10\x03\x42\t\n\x07_choice\"b\n\x0c\x46lowIpv4Dscp\x12(\n\x03phb\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpPhb\x12(\n\x03\x65\x63n\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpEcn\"\xc3\x02\n\x0b\x46lowIpv4Tos\x12\x35\n\nprecedence\x18\x01 \x01(\x0b\x32!.otg.PatternFlowIpv4TosPrecedence\x12+\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4TosDelay\x12\x35\n\nthroughput\x18\x03 \x01(\x0b\x32!.otg.PatternFlowIpv4TosThroughput\x12\x37\n\x0breliability\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIpv4TosReliability\x12\x31\n\x08monetary\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TosMonetary\x12-\n\x06unused\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowIpv4TosUnused\"z\n\x0c\x46lowIpv4Auto\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowIpv4Auto.Choice.EnumH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64hcp\x10\x01\x42\t\n\x07_choice\"\x91\x03\n\x08\x46lowIpv6\x12,\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv6Version\x12\x37\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv6TrafficClass\x12\x31\n\nflow_label\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowIpv6FlowLabel\x12\x39\n\x0epayload_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowIpv6PayloadLength\x12\x33\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6NextHeader\x12/\n\thop_limit\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv6HopLimit\x12$\n\x03src\x18\x07 \x01(\x0b\x32\x17.otg.PatternFlowIpv6Src\x12$\n\x03\x64st\x18\x08 \x01(\x0b\x32\x17.otg.PatternFlowIpv6Dst\"z\n\x0c\x46lowIpv6Auto\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowIpv6Auto.Choice.EnumH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64hcp\x10\x01\x42\t\n\x07_choice\"\x81\x06\n\x0c\x46lowPfcPause\x12(\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseDst\x12(\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseSrc\x12\x35\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowPfcPauseEtherType\x12>\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32%.otg.PatternFlowPfcPauseControlOpCode\x12\x46\n\x13\x63lass_enable_vector\x18\x05 \x01(\x0b\x32).otg.PatternFlowPfcPauseClassEnableVector\x12:\n\rpause_class_0\x18\x06 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass0\x12:\n\rpause_class_1\x18\x07 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass1\x12:\n\rpause_class_2\x18\x08 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass2\x12:\n\rpause_class_3\x18\t \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass3\x12:\n\rpause_class_4\x18\n \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass4\x12:\n\rpause_class_5\x18\x0b \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass5\x12:\n\rpause_class_6\x18\x0c \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass6\x12:\n\rpause_class_7\x18\r \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass7\"\xa3\x02\n\x11\x46lowEthernetPause\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseDst\x12-\n\x03src\x18\x02 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseSrc\x12:\n\nether_type\x18\x03 \x01(\x0b\x32&.otg.PatternFlowEthernetPauseEtherType\x12\x43\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32*.otg.PatternFlowEthernetPauseControlOpCode\x12/\n\x04time\x18\x05 \x01(\x0b\x32!.otg.PatternFlowEthernetPauseTime\"\xd7\x05\n\x07\x46lowTcp\x12,\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowTcpSrcPort\x12,\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowTcpDstPort\x12*\n\x07seq_num\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowTcpSeqNum\x12*\n\x07\x61\x63k_num\x18\x04 \x01(\x0b\x32\x19.otg.PatternFlowTcpAckNum\x12\x32\n\x0b\x64\x61ta_offset\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowTcpDataOffset\x12(\n\x06\x65\x63n_ns\x18\x06 \x01(\x0b\x32\x18.otg.PatternFlowTcpEcnNs\x12*\n\x07\x65\x63n_cwr\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowTcpEcnCwr\x12,\n\x08\x65\x63n_echo\x18\x08 \x01(\x0b\x32\x1a.otg.PatternFlowTcpEcnEcho\x12*\n\x07\x63tl_urg\x18\t \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlUrg\x12*\n\x07\x63tl_ack\x18\n \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlAck\x12*\n\x07\x63tl_psh\x18\x0b \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlPsh\x12*\n\x07\x63tl_rst\x18\x0c \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlRst\x12*\n\x07\x63tl_syn\x18\r \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlSyn\x12*\n\x07\x63tl_fin\x18\x0e \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlFin\x12)\n\x06window\x18\x0f \x01(\x0b\x32\x19.otg.PatternFlowTcpWindow\x12-\n\x08\x63hecksum\x18\x10 \x01(\x0b\x32\x1b.otg.PatternFlowTcpChecksum\"\xbf\x01\n\x07\x46lowUdp\x12,\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowUdpSrcPort\x12,\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowUdpDstPort\x12)\n\x06length\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowUdpLength\x12-\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowUdpChecksum\"\xb4\x02\n\x07\x46lowGre\x12<\n\x10\x63hecksum_present\x18\x01 \x01(\x0b\x32\".otg.PatternFlowGreChecksumPresent\x12/\n\treserved0\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved0\x12+\n\x07version\x18\x03 \x01(\x0b\x32\x1a.otg.PatternFlowGreVersion\x12-\n\x08protocol\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGreProtocol\x12-\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\x1b.otg.PatternFlowGreChecksum\x12/\n\treserved1\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved1\"\xbf\x05\n\tFlowGtpv1\x12-\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv1Version\x12\x38\n\rprotocol_type\x18\x02 \x01(\x0b\x32!.otg.PatternFlowGtpv1ProtocolType\x12/\n\x08reserved\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv1Reserved\x12*\n\x06\x65_flag\x18\x04 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1EFlag\x12*\n\x06s_flag\x18\x05 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1SFlag\x12,\n\x07pn_flag\x18\x06 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv1PnFlag\x12\x36\n\x0cmessage_type\x18\x07 \x01(\x0b\x32 .otg.PatternFlowGtpv1MessageType\x12:\n\x0emessage_length\x18\x08 \x01(\x0b\x32\".otg.PatternFlowGtpv1MessageLength\x12\'\n\x04teid\x18\t \x01(\x0b\x32\x19.otg.PatternFlowGtpv1Teid\x12:\n\x0esquence_number\x18\n \x01(\x0b\x32\".otg.PatternFlowGtpv1SquenceNumber\x12\x35\n\x0cn_pdu_number\x18\x0b \x01(\x0b\x32\x1f.otg.PatternFlowGtpv1NPduNumber\x12P\n\x1anext_extension_header_type\x18\x0c \x01(\x0b\x32,.otg.PatternFlowGtpv1NextExtensionHeaderType\x12\x30\n\x11\x65xtension_headers\x18\r \x03(\x0b\x32\x15.otg.FlowGtpExtension\"\xe1\x01\n\x10\x46lowGtpExtension\x12\x45\n\x10\x65xtension_length\x18\x01 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionExtensionLength\x12\x36\n\x08\x63ontents\x18\x02 \x01(\x0b\x32$.otg.PatternFlowGtpExtensionContents\x12N\n\x15next_extension_header\x18\x03 \x01(\x0b\x32/.otg.PatternFlowGtpExtensionNextExtensionHeader\"\xe3\x03\n\tFlowGtpv2\x12-\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv2Version\x12@\n\x11piggybacking_flag\x18\x02 \x01(\x0b\x32%.otg.PatternFlowGtpv2PiggybackingFlag\x12\x30\n\tteid_flag\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv2TeidFlag\x12+\n\x06spare1\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare1\x12\x36\n\x0cmessage_type\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2MessageType\x12:\n\x0emessage_length\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2MessageLength\x12\'\n\x04teid\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowGtpv2Teid\x12<\n\x0fsequence_number\x18\x08 \x01(\x0b\x32#.otg.PatternFlowGtpv2SequenceNumber\x12+\n\x06spare2\x18\t \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare2\"\xb6\x04\n\x07\x46lowArp\x12\x36\n\rhardware_type\x18\x01 \x01(\x0b\x32\x1f.otg.PatternFlowArpHardwareType\x12\x36\n\rprotocol_type\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowArpProtocolType\x12:\n\x0fhardware_length\x18\x03 \x01(\x0b\x32!.otg.PatternFlowArpHardwareLength\x12:\n\x0fprotocol_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowArpProtocolLength\x12/\n\toperation\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowArpOperation\x12\x43\n\x14sender_hardware_addr\x18\x06 \x01(\x0b\x32%.otg.PatternFlowArpSenderHardwareAddr\x12\x43\n\x14sender_protocol_addr\x18\x07 \x01(\x0b\x32%.otg.PatternFlowArpSenderProtocolAddr\x12\x43\n\x14target_hardware_addr\x18\x08 \x01(\x0b\x32%.otg.PatternFlowArpTargetHardwareAddr\x12\x43\n\x14target_protocol_addr\x18\t \x01(\x0b\x32%.otg.PatternFlowArpTargetProtocolAddr\"\x93\x01\n\x08\x46lowIcmp\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowIcmp.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x11.otg.FlowIcmpEcho\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choice\"\x93\x02\n\x0c\x46lowIcmpEcho\x12*\n\x04type\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoType\x12*\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoCode\x12\x32\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowIcmpEchoChecksum\x12\x36\n\nidentifier\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIcmpEchoIdentifier\x12?\n\x0fsequence_number\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIcmpEchoSequenceNumber\"\x99\x01\n\nFlowIcmpv6\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowIcmpv6.Choice.EnumH\x00\x88\x01\x01\x12!\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x13.otg.FlowIcmpv6Echo\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choice\"\x9f\x02\n\x0e\x46lowIcmpv6Echo\x12,\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoType\x12,\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoCode\x12\x38\n\nidentifier\x18\x03 \x01(\x0b\x32$.otg.PatternFlowIcmpv6EchoIdentifier\x12\x41\n\x0fsequence_number\x18\x04 \x01(\x0b\x32(.otg.PatternFlowIcmpv6EchoSequenceNumber\x12\x34\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIcmpv6EchoChecksum\"\x9b\x01\n\x07\x46lowPpp\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowPppAddress\x12+\n\x07\x63ontrol\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowPppControl\x12\x36\n\rprotocol_type\x18\x03 \x01(\x0b\x32\x1f.otg.PatternFlowPppProtocolType\"\x81\x02\n\nFlowIgmpv1\x12.\n\x07version\x18\x01 \x01(\x0b\x32\x1d.otg.PatternFlowIgmpv1Version\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowIgmpv1Type\x12,\n\x06unused\x18\x03 \x01(\x0b\x32\x1c.otg.PatternFlowIgmpv1Unused\x12\x30\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowIgmpv1Checksum\x12\x39\n\rgroup_address\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIgmpv1GroupAddress\"\xdf\x01\n\x08\x46lowMpls\x12(\n\x05label\x18\x01 \x01(\x0b\x32\x19.otg.PatternFlowMplsLabel\x12\x37\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowMplsTrafficClass\x12:\n\x0f\x62ottom_of_stack\x18\x03 \x01(\x0b\x32!.otg.PatternFlowMplsBottomOfStack\x12\x34\n\x0ctime_to_live\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowMplsTimeToLive\"\x88\x01\n\x0b\x46lowSnmpv2c\x12/\n\x07version\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowSnmpv2cVersion\x12\x16\n\tcommunity\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\"\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x14.otg.FlowSnmpv2cDataB\x0c\n\n_community\"\xde\x04\n\x0f\x46lowSnmpv2cData\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.FlowSnmpv2cData.Choice.EnumH\x00\x88\x01\x01\x12(\n\x0bget_request\x18\x02 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12-\n\x10get_next_request\x18\x03 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12%\n\x08response\x18\x04 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12(\n\x0bset_request\x18\x05 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12\x31\n\x10get_bulk_request\x18\x06 \x01(\x0b\x32\x17.otg.FlowSnmpv2cBulkPDU\x12+\n\x0einform_request\x18\x07 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12(\n\x0bsnmpv2_trap\x18\x08 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12#\n\x06report\x18\t \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x1a\xaf\x01\n\x06\x43hoice\"\xa4\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bget_request\x10\x01\x12\x14\n\x10get_next_request\x10\x02\x12\x0c\n\x08response\x10\x03\x12\x0f\n\x0bset_request\x10\x04\x12\x14\n\x10get_bulk_request\x10\x05\x12\x12\n\x0einform_request\x10\x06\x12\x0f\n\x0bsnmpv2_trap\x10\x07\x12\n\n\x06report\x10\x08\x42\t\n\x07_choice\"\x93\x05\n\x0e\x46lowSnmpv2cPDU\x12\x37\n\nrequest_id\x18\x01 \x01(\x0b\x32#.otg.PatternFlowSnmpv2cPDURequestId\x12?\n\x0c\x65rror_status\x18\x02 \x01(\x0e\x32$.otg.FlowSnmpv2cPDU.ErrorStatus.EnumH\x00\x88\x01\x01\x12\x39\n\x0b\x65rror_index\x18\x03 \x01(\x0b\x32$.otg.PatternFlowSnmpv2cPDUErrorIndex\x12:\n\x11variable_bindings\x18\x04 \x03(\x0b\x32\x1f.otg.FlowSnmpv2cVariableBinding\x1a\xfe\x02\n\x0b\x45rrorStatus\"\xee\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08no_error\x10\x01\x12\x0b\n\x07too_big\x10\x02\x12\x10\n\x0cno_such_name\x10\x03\x12\r\n\tbad_value\x10\x04\x12\r\n\tread_only\x10\x05\x12\x0b\n\x07gen_err\x10\x06\x12\r\n\tno_access\x10\x07\x12\x0e\n\nwrong_type\x10\x08\x12\x10\n\x0cwrong_length\x10\t\x12\x12\n\x0ewrong_encoding\x10\n\x12\x0f\n\x0bwrong_value\x10\x0b\x12\x0f\n\x0bno_creation\x10\x0c\x12\x16\n\x12inconsistent_value\x10\r\x12\x18\n\x14resource_unavailable\x10\x0e\x12\x11\n\rcommit_failed\x10\x0f\x12\x0f\n\x0bundo_failed\x10\x10\x12\x17\n\x13\x61uthorization_error\x10\x11\x12\x10\n\x0cnot_writable\x10\x12\x12\x15\n\x11inconsistent_name\x10\x13\x42\x0f\n\r_error_status\"\x97\x02\n\x12\x46lowSnmpv2cBulkPDU\x12;\n\nrequest_id\x18\x01 \x01(\x0b\x32\'.otg.PatternFlowSnmpv2cBulkPDURequestId\x12\x41\n\rnon_repeaters\x18\x02 \x01(\x0b\x32*.otg.PatternFlowSnmpv2cBulkPDUNonRepeaters\x12\x45\n\x0fmax_repetitions\x18\x03 \x01(\x0b\x32,.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitions\x12:\n\x11variable_bindings\x18\x04 \x03(\x0b\x32\x1f.otg.FlowSnmpv2cVariableBinding\"\x87\x01\n\x1a\x46lowSnmpv2cVariableBinding\x12\x1e\n\x11object_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.otg.FlowSnmpv2cVariableBindingValueB\x14\n\x12_object_identifier\"\xa5\x08\n\x1f\x46lowSnmpv2cVariableBindingValue\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.FlowSnmpv2cVariableBindingValue.Choice.EnumH\x00\x88\x01\x01\x12N\n\rinteger_value\x18\x02 \x01(\x0b\x32\x37.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValue\x12@\n\x0cstring_value\x18\x03 \x01(\x0b\x32*.otg.FlowSnmpv2cVariableBindingStringValue\x12$\n\x17object_identifier_value\x18\x04 \x01(\tH\x01\x88\x01\x01\x12S\n\x10ip_address_value\x18\x05 \x01(\x0b\x32\x39.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValue\x12N\n\rcounter_value\x18\x06 \x01(\x0b\x32\x37.otg.PatternFlowSnmpv2cVariableBindingValueCounterValue\x12R\n\x0ftimeticks_value\x18\x07 \x01(\x0b\x32\x39.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValue\x12\x1c\n\x0f\x61rbitrary_value\x18\x08 \x01(\tH\x02\x88\x01\x01\x12U\n\x11\x62ig_counter_value\x18\t \x01(\x0b\x32:.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValue\x12_\n\x16unsigned_integer_value\x18\n \x01(\x0b\x32?.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValue\x1a\xf8\x01\n\x06\x43hoice\"\xed\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08no_value\x10\x01\x12\x11\n\rinteger_value\x10\x02\x12\x10\n\x0cstring_value\x10\x03\x12\x1b\n\x17object_identifier_value\x10\x04\x12\x14\n\x10ip_address_value\x10\x05\x12\x11\n\rcounter_value\x10\x06\x12\x13\n\x0ftimeticks_value\x10\x07\x12\x13\n\x0f\x61rbitrary_value\x10\x08\x12\x15\n\x11\x62ig_counter_value\x10\t\x12\x1a\n\x16unsigned_integer_value\x10\nB\t\n\x07_choiceB\x1a\n\x18_object_identifier_valueB\x12\n\x10_arbitrary_value\"\xee\x01\n%FlowSnmpv2cVariableBindingStringValue\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.FlowSnmpv2cVariableBindingStringValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x61scii\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03raw\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x61scii\x10\x01\x12\x07\n\x03raw\x10\x02\x42\t\n\x07_choiceB\x08\n\x06_asciiB\x06\n\x04_raw\"\xb9\x03\n\x08\x46lowRsvp\x12\x14\n\x07version\x18\x01 \x01(\rH\x00\x88\x01\x01\x12*\n\x04\x66lag\x18\x02 \x01(\x0e\x32\x17.otg.FlowRsvp.Flag.EnumH\x01\x88\x01\x01\x12\x37\n\rrsvp_checksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowRsvpRsvpChecksum\x12\x34\n\x0ctime_to_live\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowRsvpTimeToLive\x12.\n\x08reserved\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowRsvpReserved\x12(\n\x0brsvp_length\x18\x06 \x01(\x0b\x32\x13.otg.FlowRSVPLength\x12*\n\x0cmessage_type\x18\x07 \x01(\x0b\x32\x14.otg.FlowRSVPMessage\x1a\x61\n\x04\x46lag\"Y\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12!\n\x1dnot_refresh_reduction_capable\x10\x01\x12\x1d\n\x19refresh_reduction_capable\x10\x02\x42\n\n\x08_versionB\x07\n\x05_flag\"\xc3\x01\n\x0e\x46lowRSVPLength\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.FlowRSVPLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xa8\x01\n\x0f\x46lowRSVPMessage\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.FlowRSVPMessage.Choice.EnumH\x00\x88\x01\x01\x12&\n\x04path\x18\x02 \x01(\x0b\x32\x18.otg.FlowRSVPPathMessage\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04path\x10\x01\x42\t\n\x07_choice\"@\n\x13\x46lowRSVPPathMessage\x12)\n\x07objects\x18\x01 \x03(\x0b\x32\x18.otg.FlowRSVPPathObjects\"G\n\x13\x46lowRSVPPathObjects\x12\x30\n\tclass_num\x18\x01 \x01(\x0b\x32\x1d.otg.FlowRSVPPathObjectsClass\"\xcf\x01\n\x14\x46lowRSVPObjectLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.FlowRSVPObjectLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xac\x07\n\x18\x46lowRSVPPathObjectsClass\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.FlowRSVPPathObjectsClass.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x07session\x18\x02 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsClassSession\x12\x36\n\x08rsvp_hop\x18\x03 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsClassRsvpHop\x12<\n\x0btime_values\x18\x04 \x01(\x0b\x32\'.otg.FlowRSVPPathObjectsClassTimeValues\x12\x42\n\x0e\x65xplicit_route\x18\x05 \x01(\x0b\x32*.otg.FlowRSVPPathObjectsClassExplicitRoute\x12@\n\rlabel_request\x18\x06 \x01(\x0b\x32).otg.FlowRSVPPathObjectsClassLabelRequest\x12H\n\x11session_attribute\x18\x07 \x01(\x0b\x32-.otg.FlowRSVPPathObjectsClassSessionAttribute\x12\x44\n\x0fsender_template\x18\x08 \x01(\x0b\x32+.otg.FlowRSVPPathObjectsClassSenderTemplate\x12>\n\x0csender_tspec\x18\t \x01(\x0b\x32(.otg.FlowRSVPPathObjectsClassSenderTspec\x12>\n\x0crecord_route\x18\n \x01(\x0b\x32(.otg.FlowRSVPPathObjectsClassRecordRoute\x12.\n\x06\x63ustom\x18\x0b \x01(\x0b\x32\x1e.otg.FlowRSVPPathObjectsCustom\x1a\xd1\x01\n\x06\x43hoice\"\xc6\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07session\x10\x01\x12\x0c\n\x08rsvp_hop\x10\x02\x12\x0f\n\x0btime_values\x10\x03\x12\x12\n\x0e\x65xplicit_route\x10\x04\x12\x11\n\rlabel_request\x10\x05\x12\x15\n\x11session_attribute\x10\x06\x12\x13\n\x0fsender_template\x10\x07\x12\x10\n\x0csender_tspec\x10\x08\x12\x10\n\x0crecord_route\x10\t\x12\n\n\x06\x63ustom\x10\nB\t\n\x07_choice\"\x82\x01\n\x1f\x46lowRSVPPathObjectsClassSession\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x34\n\x06\x63_type\x18\x02 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsSessionCType\"\xeb\x01\n\x1f\x46lowRSVPPathObjectsSessionCType\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.FlowRSVPPathObjectsSessionCType.Choice.EnumH\x00\x88\x01\x01\x12>\n\x0flsp_tunnel_ipv4\x18\x02 \x01(\x0b\x32%.otg.FlowRSVPPathSessionLspTunnelIpv4\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flsp_tunnel_ipv4\x10\x01\x42\t\n\x07_choice\"\xe2\x02\n FlowRSVPPathSessionLspTunnelIpv4\x12l\n\x1dipv4_tunnel_end_point_address\x18\x01 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddress\x12\x46\n\x08reserved\x18\x02 \x01(\x0b\x32\x34.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Reserved\x12G\n\ttunnel_id\x18\x03 \x01(\x0b\x32\x34.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelId\x12?\n\x12\x65xtended_tunnel_id\x18\x04 \x01(\x0b\x32#.otg.FlowRSVPPathSessionExtTunnelId\"\xbd\x02\n\x1e\x46lowRSVPPathSessionExtTunnelId\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.FlowRSVPPathSessionExtTunnelId.Choice.EnumH\x00\x88\x01\x01\x12G\n\nas_integer\x18\x02 \x01(\x0b\x32\x33.otg.PatternFlowRSVPPathSessionExtTunnelIdAsInteger\x12\x41\n\x07\x61s_ipv4\x18\x03 \x01(\x0b\x32\x30.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nas_integer\x10\x01\x12\x0b\n\x07\x61s_ipv4\x10\x02\x42\t\n\x07_choice\"\x82\x01\n\x1f\x46lowRSVPPathObjectsClassRsvpHop\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x34\n\x06\x63_type\x18\x02 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsRsvpHopCType\"\xcc\x01\n\x1f\x46lowRSVPPathObjectsRsvpHopCType\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.FlowRSVPPathObjectsRsvpHopCType.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04ipv4\x18\x02 \x01(\x0b\x32\x1c.otg.FlowRSVPPathRsvpHopIpv4\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x42\t\n\x07_choice\"\xbc\x01\n\x17\x46lowRSVPPathRsvpHopIpv4\x12\x44\n\x0cipv4_address\x18\x01 \x01(\x0b\x32..otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4Address\x12[\n\x18logical_interface_handle\x18\x02 \x01(\x0b\x32\x39.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandle\"\x88\x01\n\"FlowRSVPPathObjectsClassTimeValues\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x37\n\x06\x63_type\x18\x02 \x01(\x0b\x32\'.otg.FlowRSVPPathObjectsTimeValuesCType\"\xda\x01\n\"FlowRSVPPathObjectsTimeValuesCType\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.FlowRSVPPathObjectsTimeValuesCType.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x06type_1\x18\x02 \x01(\x0b\x32 .otg.FlowRSVPPathTimeValuesType1\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_1\x10\x01\x42\t\n\x07_choice\"n\n\x1b\x46lowRSVPPathTimeValuesType1\x12O\n\x10refresh_period_r\x18\x01 \x01(\x0b\x32\x35.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodR\"\x93\x01\n%FlowRSVPPathObjectsClassExplicitRoute\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12?\n\x06\x63_type\x18\x02 \x01(\x0b\x32/.otg.FlowRSVPPathObjectsClassExplicitRouteCType\"\xed\x01\n*FlowRSVPPathObjectsClassExplicitRouteCType\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.FlowRSVPPathObjectsClassExplicitRouteCType.Choice.EnumH\x00\x88\x01\x01\x12\x33\n\x06type_1\x18\x02 \x01(\x0b\x32#.otg.FlowRSVPPathExplicitRouteType1\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_1\x10\x01\x42\t\n\x07_choice\"_\n\x1e\x46lowRSVPPathExplicitRouteType1\x12=\n\nsubobjects\x18\x01 \x03(\x0b\x32).otg.FlowRSVPType1ExplicitRouteSubobjects\"c\n$FlowRSVPType1ExplicitRouteSubobjects\x12;\n\x04type\x18\x01 \x01(\x0b\x32-.otg.FlowRSVPType1ExplicitRouteSubobjectsType\"\xcc\x02\n(FlowRSVPType1ExplicitRouteSubobjectsType\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.FlowRSVPType1ExplicitRouteSubobjectsType.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\x0bipv4_prefix\x18\x02 \x01(\x0b\x32-.otg.FlowRSVPPathExplicitRouteType1Ipv4Prefix\x12>\n\tas_number\x18\x03 \x01(\x0b\x32+.otg.FlowRSVPPathExplicitRouteType1ASNumber\x1a\x41\n\x06\x43hoice\"7\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bipv4_prefix\x10\x01\x12\r\n\tas_number\x10\x02\x42\t\n\x07_choice\"\x9c\x02\n(FlowRSVPPathExplicitRouteType1Ipv4Prefix\x12G\n\x05l_bit\x18\x01 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBit\x12\x30\n\x06length\x18\x02 \x01(\x0b\x32 .otg.FlowRSVPExplicitRouteLength\x12U\n\x0cipv4_address\x18\x03 \x01(\x0b\x32?.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4Address\x12\x13\n\x06prefix\x18\x04 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_prefix\"\xcf\x01\n&FlowRSVPPathExplicitRouteType1ASNumber\x12\x45\n\x05l_bit\x18\x01 \x01(\x0b\x32\x36.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBit\x12\x38\n\x06length\x18\x02 \x01(\x0b\x32(.otg.FlowRSVPExplicitRouteASNumberLength\x12\x16\n\tas_number\x18\x03 \x01(\rH\x00\x88\x01\x01\x42\x0c\n\n_as_number\"\xdd\x01\n\x1b\x46lowRSVPExplicitRouteLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.FlowRSVPExplicitRouteLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xed\x01\n#FlowRSVPExplicitRouteASNumberLength\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.FlowRSVPExplicitRouteASNumberLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x8c\x01\n$FlowRSVPPathObjectsClassLabelRequest\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x39\n\x06\x63_type\x18\x02 \x01(\x0b\x32).otg.FlowRSVPPathObjectsLabelRequestCType\"\x86\x02\n$FlowRSVPPathObjectsLabelRequestCType\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.FlowRSVPPathObjectsLabelRequestCType.Choice.EnumH\x00\x88\x01\x01\x12K\n\x13without_label_range\x18\x02 \x01(\x0b\x32..otg.FlowRSVPPathLabelRequestWithoutLabelRange\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13without_label_range\x10\x01\x42\t\n\x07_choice\"\xc7\x01\n)FlowRSVPPathLabelRequestWithoutLabelRange\x12O\n\x08reserved\x18\x01 \x01(\x0b\x32=.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReserved\x12I\n\x05l3pid\x18\x02 \x01(\x0b\x32:.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pid\"\x94\x01\n(FlowRSVPPathObjectsClassSessionAttribute\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12=\n\x06\x63_type\x18\x02 \x01(\x0b\x32-.otg.FlowRSVPPathObjectsSessionAttributeCType\"\xd0\x02\n(FlowRSVPPathObjectsSessionAttributeCType\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.FlowRSVPPathObjectsSessionAttributeCType.Choice.EnumH\x00\x88\x01\x01\x12>\n\nlsp_tunnel\x18\x02 \x01(\x0b\x32*.otg.FlowRSVPPathSessionAttributeLspTunnel\x12\x43\n\rlsp_tunnel_ra\x18\x03 \x01(\x0b\x32,.otg.FlowRSVPPathSessionAttributeLspTunnelRa\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nlsp_tunnel\x10\x01\x12\x11\n\rlsp_tunnel_ra\x10\x02\x42\t\n\x07_choice\"\xa0\x02\n%FlowRSVPPathSessionAttributeLspTunnel\x12\x1b\n\x0esetup_priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x1a.otg.FlowRSVPLspTunnelFlag\x12<\n\x0bname_length\x18\x04 \x01(\x0b\x32\'.otg.FlowRSVPSessionAttributeNameLength\x12\x19\n\x0csession_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x42\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0f\n\r_session_name\"\xa0\x03\n\'FlowRSVPPathSessionAttributeLspTunnelRa\x12\x18\n\x0b\x65xclude_any\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0esetup_priority\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x05 \x01(\rH\x04\x88\x01\x01\x12)\n\x05\x66lags\x18\x06 \x01(\x0b\x32\x1a.otg.FlowRSVPLspTunnelFlag\x12<\n\x0bname_length\x18\x07 \x01(\x0b\x32\'.otg.FlowRSVPSessionAttributeNameLength\x12\x19\n\x0csession_name\x18\x08 \x01(\tH\x05\x88\x01\x01\x42\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_allB\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0f\n\r_session_name\"\xd3\x01\n\x15\x46lowRSVPLspTunnelFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.FlowRSVPLspTunnelFlag.Choice.EnumH\x00\x88\x01\x01\x1ar\n\x06\x43hoice\"h\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1c\n\x18local_protection_desired\x10\x01\x12\x1b\n\x17label_recording_desired\x10\x02\x12\x14\n\x10se_style_desired\x10\x03\x42\t\n\x07_choice\"\xeb\x01\n\"FlowRSVPSessionAttributeNameLength\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.FlowRSVPSessionAttributeNameLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x90\x01\n&FlowRSVPPathObjectsClassSenderTemplate\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12;\n\x06\x63_type\x18\x02 \x01(\x0b\x32+.otg.FlowRSVPPathObjectsSenderTemplateCType\"\x80\x02\n&FlowRSVPPathObjectsSenderTemplateCType\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.FlowRSVPPathObjectsSenderTemplateCType.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\x0flsp_tunnel_ipv4\x18\x02 \x01(\x0b\x32,.otg.FlowRSVPPathSenderTemplateLspTunnelIpv4\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flsp_tunnel_ipv4\x10\x01\x42\t\n\x07_choice\"\xb2\x02\n\'FlowRSVPPathSenderTemplateLspTunnelIpv4\x12n\n\x1aipv4_tunnel_sender_address\x18\x01 \x01(\x0b\x32J.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddress\x12M\n\x08reserved\x18\x02 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Reserved\x12H\n\x06lsp_id\x18\x03 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspId\"\x8a\x01\n#FlowRSVPPathObjectsClassSenderTspec\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x38\n\x06\x63_type\x18\x02 \x01(\x0b\x32(.otg.FlowRSVPPathObjectsSenderTspecCType\"\xe3\x01\n#FlowRSVPPathObjectsSenderTspecCType\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.FlowRSVPPathObjectsSenderTspecCType.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x08int_serv\x18\x02 \x01(\x0b\x32#.otg.FlowRSVPPathSenderTspecIntServ\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08int_serv\x10\x01\x42\t\n\x07_choice\"\xb0\t\n\x1e\x46lowRSVPPathSenderTspecIntServ\x12\x42\n\x07version\x18\x01 \x01(\x0b\x32\x31.otg.PatternFlowRSVPPathSenderTspecIntServVersion\x12\x46\n\treserved1\x18\x02 \x01(\x0b\x32\x33.otg.PatternFlowRSVPPathSenderTspecIntServReserved1\x12O\n\x0eoverall_length\x18\x03 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSenderTspecIntServOverallLength\x12O\n\x0eservice_header\x18\x04 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeader\x12\x43\n\x08zero_bit\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowRSVPPathSenderTspecIntServZeroBit\x12\x46\n\treserved2\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowRSVPPathSenderTspecIntServReserved2\x12]\n\x16length_of_service_data\x18\x07 \x01(\x0b\x32=.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceData\x12n\n\x1fparameter_id_token_bucket_tspec\x18\x08 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspec\x12V\n\x12parameter_127_flag\x18\t \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Flag\x12Z\n\x14parameter_127_length\x18\n \x01(\x0b\x32<.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Length\x12\x1e\n\x11token_bucket_rate\x18\x0b \x01(\x02H\x00\x88\x01\x01\x12\x1e\n\x11token_bucket_size\x18\x0c \x01(\x02H\x01\x88\x01\x01\x12\x1b\n\x0epeak_data_rate\x18\r \x01(\x02H\x02\x88\x01\x01\x12Z\n\x14minimum_policed_unit\x18\x0e \x01(\x0b\x32<.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnit\x12X\n\x13maximum_packet_size\x18\x0f \x01(\x0b\x32;.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeB\x14\n\x12_token_bucket_rateB\x14\n\x12_token_bucket_sizeB\x11\n\x0f_peak_data_rate\"\x8a\x01\n#FlowRSVPPathObjectsClassRecordRoute\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x38\n\x06\x63_type\x18\x02 \x01(\x0b\x32(.otg.FlowRSVPPathObjectsRecordRouteCType\"\xdd\x01\n#FlowRSVPPathObjectsRecordRouteCType\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.FlowRSVPPathObjectsRecordRouteCType.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x06type_1\x18\x02 \x01(\x0b\x32!.otg.FlowRSVPPathRecordRouteType1\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_1\x10\x01\x42\t\n\x07_choice\"[\n\x1c\x46lowRSVPPathRecordRouteType1\x12;\n\nsubobjects\x18\x01 \x03(\x0b\x32\'.otg.FlowRSVPType1RecordRouteSubobjects\"d\n\"FlowRSVPType1RecordRouteSubobjects\x12>\n\x04type\x18\x01 \x01(\x0b\x32\x30.otg.FlowRSVPPathObjectsRecordRouteSubObjectType\"\xc6\x02\n+FlowRSVPPathObjectsRecordRouteSubObjectType\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.FlowRSVPPathObjectsRecordRouteSubObjectType.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\x0cipv4_address\x18\x02 \x01(\x0b\x32,.otg.FlowRSVPPathRecordRouteType1Ipv4Address\x12\x35\n\x05label\x18\x03 \x01(\x0b\x32&.otg.FlowRSVPPathRecordRouteType1Label\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_address\x10\x01\x12\t\n\x05label\x10\x02\x42\t\n\x07_choice\"\xb8\x02\n\'FlowRSVPPathRecordRouteType1Ipv4Address\x12.\n\x06length\x18\x01 \x01(\x0b\x32\x1e.otg.FlowRSVPRouteRecordLength\x12T\n\x0cipv4_address\x18\x02 \x01(\x0b\x32>.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4Address\x12V\n\rprefix_length\x18\x03 \x01(\x0b\x32?.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLength\x12/\n\x05\x66lags\x18\x04 \x01(\x0b\x32 .otg.FlowRSVPRecordRouteIPv4Flag\"\xcb\x01\n\x1b\x46lowRSVPRecordRouteIPv4Flag\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.FlowRSVPRecordRouteIPv4Flag.Choice.EnumH\x00\x88\x01\x01\x1a^\n\x06\x43hoice\"T\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1e\n\x1alocal_protection_available\x10\x01\x12\x1b\n\x17local_protection_in_use\x10\x02\x42\t\n\x07_choice\"\x8c\x02\n!FlowRSVPPathRecordRouteType1Label\x12.\n\x06length\x18\x01 \x01(\x0b\x32\x1e.otg.FlowRSVPRouteRecordLength\x12\x41\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x32.otg.PatternFlowRSVPPathRecordRouteType1LabelFlags\x12\x42\n\x06\x63_type\x18\x03 \x01(\x0b\x32\x32.otg.PatternFlowRSVPPathRecordRouteType1LabelCType\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.otg.FlowRSVPPathRecordRouteLabel\"\xf4\x01\n\x1c\x46lowRSVPPathRecordRouteLabel\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.FlowRSVPPathRecordRouteLabel.Choice.EnumH\x00\x88\x01\x01\x12\x17\n\nas_integer\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06\x61s_hex\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nas_integer\x10\x01\x12\n\n\x06\x61s_hex\x10\x02\x42\t\n\x07_choiceB\r\n\x0b_as_integerB\t\n\x07_as_hex\"\xd9\x01\n\x19\x46lowRSVPRouteRecordLength\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowRSVPRouteRecordLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x9d\x01\n\x19\x46lowRSVPPathObjectsCustom\x12\x37\n\x04type\x18\x01 \x01(\x0b\x32).otg.PatternFlowRSVPPathObjectsCustomType\x12)\n\x06length\x18\x02 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x12\n\x05\x62ytes\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_bytes\"v\n\nFlowMacsec\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowMacsec.Choice.EnumH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choice\"\xc7\x01\n\x08\x46lowLacp\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowLacp.Choice.EnumH\x00\x88\x01\x01\x12,\n\x07version\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowLacpVersion\x12#\n\x06lacpdu\x18\x03 \x01(\x0b\x32\x13.otg.FlowLacpLacpdu\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06lacpdu\x10\x01\x42\t\n\x07_choice\"\xba\x01\n\x0e\x46lowLacpLacpdu\x12#\n\x05\x61\x63tor\x18\x01 \x01(\x0b\x32\x14.otg.FlowLacpduActor\x12\'\n\x07partner\x18\x02 \x01(\x0b\x32\x16.otg.FlowLacpduPartner\x12+\n\tcollector\x18\x03 \x01(\x0b\x32\x18.otg.FlowLacpduCollector\x12-\n\nterminator\x18\x04 \x01(\x0b\x32\x19.otg.FlowLacpduTerminator\"\xff\x03\n\x0f\x46lowLacpduActor\x12-\n\x04type\x18\x01 \x01(\x0b\x32\x1f.otg.PatternFlowLacpduActorType\x12\x31\n\x06length\x18\x02 \x01(\x0b\x32!.otg.PatternFlowLacpduActorLength\x12\x42\n\x0fsystem_priority\x18\x03 \x01(\x0b\x32).otg.PatternFlowLacpduActorSystemPriority\x12\x36\n\tsystem_id\x18\x04 \x01(\x0b\x32#.otg.PatternFlowLacpduActorSystemId\x12+\n\x03key\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowLacpduActorKey\x12>\n\rport_priority\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowLacpduActorPortPriority\x12:\n\x0bport_number\x18\x07 \x01(\x0b\x32%.otg.PatternFlowLacpduActorPortNumber\x12.\n\x0b\x61\x63tor_state\x18\x08 \x01(\x0b\x32\x19.otg.FlowLacpduActorState\x12\x35\n\x08reserved\x18\t \x01(\x0b\x32#.otg.PatternFlowLacpduActorReserved\"\x95\x04\n\x11\x46lowLacpduPartner\x12/\n\x04type\x18\x01 \x01(\x0b\x32!.otg.PatternFlowLacpduPartnerType\x12\x33\n\x06length\x18\x02 \x01(\x0b\x32#.otg.PatternFlowLacpduPartnerLength\x12\x44\n\x0fsystem_priority\x18\x03 \x01(\x0b\x32+.otg.PatternFlowLacpduPartnerSystemPriority\x12\x38\n\tsystem_id\x18\x04 \x01(\x0b\x32%.otg.PatternFlowLacpduPartnerSystemId\x12-\n\x03key\x18\x05 \x01(\x0b\x32 .otg.PatternFlowLacpduPartnerKey\x12@\n\rport_priority\x18\x06 \x01(\x0b\x32).otg.PatternFlowLacpduPartnerPortPriority\x12<\n\x0bport_number\x18\x07 \x01(\x0b\x32\'.otg.PatternFlowLacpduPartnerPortNumber\x12\x32\n\rpartner_state\x18\x08 \x01(\x0b\x32\x1b.otg.FlowLacpduPartnerState\x12\x37\n\x08reserved\x18\t \x01(\x0b\x32%.otg.PatternFlowLacpduPartnerReserved\"\xdf\x01\n\x13\x46lowLacpduCollector\x12\x31\n\x04type\x18\x01 \x01(\x0b\x32#.otg.PatternFlowLacpduCollectorType\x12\x35\n\x06length\x18\x02 \x01(\x0b\x32%.otg.PatternFlowLacpduCollectorLength\x12:\n\tmax_delay\x18\x03 \x01(\x0b\x32\'.otg.PatternFlowLacpduCollectorMaxDelay\x12\x15\n\x08reserved\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_reserved\"\xa6\x01\n\x14\x46lowLacpduTerminator\x12\x32\n\x04type\x18\x01 \x01(\x0b\x32$.otg.PatternFlowLacpduTerminatorType\x12\x36\n\x06length\x18\x02 \x01(\x0b\x32&.otg.PatternFlowLacpduTerminatorLength\x12\x15\n\x08reserved\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_reserved\"\x94\x04\n\x14\x46lowLacpduActorState\x12:\n\x08\x61\x63tivity\x18\x01 \x01(\x0b\x32(.otg.PatternFlowLacpduActorStateActivity\x12\x38\n\x07timeout\x18\x02 \x01(\x0b\x32\'.otg.PatternFlowLacpduActorStateTimeout\x12@\n\x0b\x61ggregation\x18\x03 \x01(\x0b\x32+.otg.PatternFlowLacpduActorStateAggregation\x12H\n\x0fsynchronization\x18\x04 \x01(\x0b\x32/.otg.PatternFlowLacpduActorStateSynchronization\x12>\n\ncollecting\x18\x05 \x01(\x0b\x32*.otg.PatternFlowLacpduActorStateCollecting\x12\x42\n\x0c\x64istributing\x18\x06 \x01(\x0b\x32,.otg.PatternFlowLacpduActorStateDistributing\x12<\n\tdefaulted\x18\x07 \x01(\x0b\x32).otg.PatternFlowLacpduActorStateDefaulted\x12\x38\n\x07\x65xpired\x18\x08 \x01(\x0b\x32\'.otg.PatternFlowLacpduActorStateExpired\"\xa6\x04\n\x16\x46lowLacpduPartnerState\x12<\n\x08\x61\x63tivity\x18\x01 \x01(\x0b\x32*.otg.PatternFlowLacpduPartnerStateActivity\x12:\n\x07timeout\x18\x02 \x01(\x0b\x32).otg.PatternFlowLacpduPartnerStateTimeout\x12\x42\n\x0b\x61ggregation\x18\x03 \x01(\x0b\x32-.otg.PatternFlowLacpduPartnerStateAggregation\x12J\n\x0fsynchronization\x18\x04 \x01(\x0b\x32\x31.otg.PatternFlowLacpduPartnerStateSynchronization\x12@\n\ncollecting\x18\x05 \x01(\x0b\x32,.otg.PatternFlowLacpduPartnerStateCollecting\x12\x44\n\x0c\x64istributing\x18\x06 \x01(\x0b\x32..otg.PatternFlowLacpduPartnerStateDistributing\x12>\n\tdefaulted\x18\x07 \x01(\x0b\x32+.otg.PatternFlowLacpduPartnerStateDefaulted\x12:\n\x07\x65xpired\x18\x08 \x01(\x0b\x32).otg.PatternFlowLacpduPartnerStateExpired\"\xbe\x02\n\x08\x46lowSize\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x66ixed\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\tincrement\x18\x03 \x01(\x0b\x32\x16.otg.FlowSizeIncrement\x12#\n\x06random\x18\x04 \x01(\x0b\x32\x13.otg.FlowSizeRandom\x12.\n\x0cweight_pairs\x18\x05 \x01(\x0b\x32\x18.otg.FlowSizeWeightPairs\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66ixed\x10\x01\x12\r\n\tincrement\x10\x02\x12\n\n\x06random\x10\x03\x12\x10\n\x0cweight_pairs\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_fixed\"g\n\x11\x46lowSizeIncrement\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03\x65nd\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04step\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x06\n\x04_endB\x07\n\x05_step\"D\n\x0e\x46lowSizeRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_max\"\x8d\x03\n\x13\x46lowSizeWeightPairs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.FlowSizeWeightPairs.Choice.EnumH\x00\x88\x01\x01\x12\x41\n\npredefined\x18\x02 \x01(\x0e\x32(.otg.FlowSizeWeightPairs.Predefined.EnumH\x01\x88\x01\x01\x12.\n\x06\x63ustom\x18\x03 \x03(\x0b\x32\x1e.otg.FlowSizeWeightPairsCustom\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\npredefined\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1ao\n\nPredefined\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04imix\x10\x01\x12\x0e\n\nipsec_imix\x10\x02\x12\r\n\tipv6_imix\x10\x03\x12\x11\n\rstandard_imix\x10\x04\x12\x0c\n\x08tcp_imix\x10\x05\x42\t\n\x07_choiceB\r\n\x0b_predefined\"W\n\x19\x46lowSizeWeightPairsCustom\x12\x11\n\x04size\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06weight\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x07\n\x05_sizeB\t\n\x07_weight\"\xd8\x02\n\x08\x46lowRate\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowRate.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03pps\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x10\n\x03\x62ps\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x11\n\x04kbps\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x11\n\x04mbps\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x11\n\x04gbps\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x17\n\npercentage\x18\x07 \x01(\x02H\x06\x88\x01\x01\x1a\x61\n\x06\x43hoice\"W\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03pps\x10\x01\x12\x07\n\x03\x62ps\x10\x02\x12\x08\n\x04kbps\x10\x03\x12\x08\n\x04mbps\x10\x04\x12\x08\n\x04gbps\x10\x05\x12\x0e\n\npercentage\x10\x06\x42\t\n\x07_choiceB\x06\n\x04_ppsB\x06\n\x04_bpsB\x07\n\x05_kbpsB\x07\n\x05_mbpsB\x07\n\x05_gbpsB\r\n\x0b_percentage\"\xd5\x02\n\x0c\x46lowDuration\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowDuration.Choice.EnumH\x00\x88\x01\x01\x12,\n\rfixed_packets\x18\x02 \x01(\x0b\x32\x15.otg.FlowFixedPackets\x12,\n\rfixed_seconds\x18\x03 \x01(\x0b\x32\x15.otg.FlowFixedSeconds\x12\x1d\n\x05\x62urst\x18\x04 \x01(\x0b\x32\x0e.otg.FlowBurst\x12\'\n\ncontinuous\x18\x05 \x01(\x0b\x32\x13.otg.FlowContinuous\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rfixed_packets\x10\x01\x12\x11\n\rfixed_seconds\x10\x02\x12\t\n\x05\x62urst\x10\x03\x12\x0e\n\ncontinuous\x10\x04\x42\t\n\x07_choice\"I\n\x0e\x46lowContinuous\x12\x10\n\x03gap\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x0e.otg.FlowDelayB\x06\n\x04_gap\"\x8c\x02\n\tFlowDelay\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.FlowDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"m\n\x10\x46lowFixedPackets\x12\x14\n\x07packets\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayB\n\n\x08_packetsB\x06\n\x04_gap\"m\n\x10\x46lowFixedSeconds\x12\x14\n\x07seconds\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayB\n\n\x08_secondsB\x06\n\x04_gap\"\xa0\x01\n\tFlowBurst\x12\x13\n\x06\x62ursts\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x14\n\x07packets\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x10\n\x03gap\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x37\n\x0finter_burst_gap\x18\x04 \x01(\x0b\x32\x1e.otg.FlowDurationInterBurstGapB\t\n\x07_burstsB\n\n\x08_packetsB\x06\n\x04_gap\"\xac\x02\n\x19\x46lowDurationInterBurstGap\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowDurationInterBurstGap.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"\xfd\x01\n\x0b\x46lowMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x11\n\x04loss\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\'\n\x0brx_tx_ratio\x18\x06 \x01(\x0b\x32\x12.otg.FlowRxTxRatio\x12\x17\n\ntimestamps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12(\n\x07latency\x18\x04 \x01(\x0b\x32\x17.otg.FlowLatencyMetrics\x12\x37\n\x16predefined_metric_tags\x18\x05 \x01(\x0b\x32\x17.otg.FlowPredefinedTagsB\t\n\x07_enableB\x07\n\x05_lossB\r\n\x0b_timestamps\"\xb8\x01\n\x12\x46lowLatencyMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32!.otg.FlowLatencyMetrics.Mode.EnumH\x01\x88\x01\x01\x1a\x43\n\x04Mode\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rstore_forward\x10\x01\x12\x0f\n\x0b\x63ut_through\x10\x02\x42\t\n\x07_enableB\x07\n\x05_mode\"6\n\x12\x46lowPredefinedTags\x12\x14\n\x07rx_name\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_rx_name\"\xd6\x01\n\rFlowRxTxRatio\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.FlowRxTxRatio.Choice.EnumH\x00\x88\x01\x01\x12+\n\x08rx_count\x18\x02 \x01(\x0b\x32\x19.otg.FlowRxTxRatioRxCount\x12\x12\n\x05value\x18\x03 \x01(\x02H\x01\x88\x01\x01\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08rx_count\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x08\n\x06_value\"\x16\n\x14\x46lowRxTxRatioRxCount\"\xef\x01\n\x0b\x46lowPayload\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.FlowPayload.Choice.EnumH\x00\x88\x01\x01\x12$\n\x05\x66ixed\x18\x02 \x01(\x0b\x32\x15.otg.FlowPayloadFixed\x1a|\n\x06\x43hoice\"r\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66ixed\x10\x01\x12\x12\n\x0eincrement_byte\x10\x02\x12\x12\n\x0e\x64\x65\x63rement_byte\x10\x03\x12\x12\n\x0eincrement_word\x10\x04\x12\x12\n\x0e\x64\x65\x63rement_word\x10\x05\x42\t\n\x07_choice\"T\n\x10\x46lowPayloadFixed\x12\x14\n\x07pattern\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06repeat\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08_patternB\t\n\x07_repeat\"U\n\x05\x45vent\x12%\n\tcp_events\x18\x01 \x01(\x0b\x32\x12.otg.EventCPEvents\x12%\n\tdp_events\x18\x02 \x01(\x0b\x32\x12.otg.EventDPEvents\"/\n\rEventCPEvents\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"e\n\rEventDPEvents\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1e\n\x11rx_rate_threshold\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\t\n\x07_enableB\x14\n\x12_rx_rate_threshold\"\xf5\x01\n\x0c\x45ventRequest\x12)\n\x04type\x18\x01 \x03(\x0e\x32\x1b.otg.EventRequest.Type.Enum\x12\x0e\n\x06source\x18\x02 \x03(\t\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\"b\n\x11\x45ventSubscription\x12!\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x11.otg.EventRequest\x12\x19\n\x0c\x63\x61llback_url\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_callback_url\"\xca\x02\n\x04Lldp\x12\'\n\nconnection\x18\x01 \x01(\x0b\x32\x13.otg.LldpConnection\x12&\n\nchassis_id\x18\x02 \x01(\x0b\x32\x12.otg.LldpChassisId\x12 \n\x07port_id\x18\x03 \x01(\x0b\x32\x0f.otg.LldpPortId\x12(\n\x0bsystem_name\x18\x04 \x01(\x0b\x32\x13.otg.LldpSystemName\x12\x16\n\thold_time\x18\x05 \x01(\rH\x00\x88\x01\x01\x12#\n\x16\x61\x64vertisement_interval\x18\x06 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x07 \x01(\tH\x02\x88\x01\x01\x12#\n\torg_infos\x18\x08 \x03(\x0b\x32\x10.otg.LldpOrgInfoB\x0c\n\n_hold_timeB\x19\n\x17_advertisement_intervalB\x07\n\x05_name\"\xa9\x01\n\x0eLldpConnection\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.LldpConnection.Choice.EnumH\x00\x88\x01\x01\x12\x16\n\tport_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tport_name\x10\x01\x42\t\n\x07_choiceB\x0c\n\n_port_name\"\xe1\x02\n\rLldpChassisId\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.LldpChassisId.Choice.EnumH\x00\x88\x01\x01\x12\x37\n\x13mac_address_subtype\x18\x02 \x01(\x0b\x32\x1a.otg.LldpChassisMacSubType\x12#\n\x16interface_name_subtype\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rlocal_subtype\x18\x04 \x01(\tH\x02\x88\x01\x01\x1ai\n\x06\x43hoice\"_\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13mac_address_subtype\x10\x01\x12\x1a\n\x16interface_name_subtype\x10\x02\x12\x11\n\rlocal_subtype\x10\x03\x42\t\n\x07_choiceB\x19\n\x17_interface_name_subtypeB\x10\n\x0e_local_subtype\"\xdf\x02\n\nLldpPortId\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.LldpPortId.Choice.EnumH\x00\x88\x01\x01\x12 \n\x13mac_address_subtype\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x41\n\x16interface_name_subtype\x18\x03 \x01(\x0b\x32!.otg.LldpPortInterfaceNameSubType\x12\x1a\n\rlocal_subtype\x18\x04 \x01(\tH\x02\x88\x01\x01\x1ai\n\x06\x43hoice\"_\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13mac_address_subtype\x10\x01\x12\x1a\n\x16interface_name_subtype\x10\x02\x12\x11\n\rlocal_subtype\x10\x03\x42\t\n\x07_choiceB\x16\n\x14_mac_address_subtypeB\x10\n\x0e_local_subtype\"\xd1\x01\n\x15LldpChassisMacSubType\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.LldpChassisMacSubType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xdf\x01\n\x1cLldpPortInterfaceNameSubType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.LldpPortInterfaceNameSubType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xc3\x01\n\x0eLldpSystemName\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.LldpSystemName.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"t\n\x0bLldpOrgInfo\x12\x10\n\x03oui\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07subtype\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x0binformation\x18\x03 \x01(\x0b\x32\x14.otg.LldpOrgInfoTypeB\x06\n\x04_ouiB\n\n\x08_subtype\"\x9c\x01\n\x0fLldpOrgInfoType\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.LldpOrgInfoType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04info\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04info\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_info\"\x9e\x01\n\x0cStatefulFlow\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.StatefulFlow.Choice.EnumH\x00\x88\x01\x01\x12 \n\x06rocev2\x18\x02 \x03(\x0b\x32\x10.otg.Rocev2Flows\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06rocev2\x10\x01\x42\t\n\x07_choice\"3\n\x0bRocev2Flows\x12$\n\x08tx_ports\x18\x01 \x03(\x0b\x32\x12.otg.Rocev2TxPorts\"e\n\rRocev2TxPorts\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12.\n\rtransmit_type\x18\x02 \x01(\x0b\x32\x17.otg.Rocev2TransmitTypeB\x0c\n\n_port_name\"\xc7\x01\n\x12Rocev2TransmitType\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.Rocev2TransmitType.Choice.EnumH\x00\x88\x01\x01\x12\x33\n\x10target_line_rate\x18\x02 \x01(\x0b\x32\x19.otg.Rocev2TargetLineRate\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10target_line_rate\x10\x01\x42\t\n\x07_choice\"T\n\x14Rocev2TargetLineRate\x12\x12\n\x05value\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x1e\n\x05\x66lows\x18\x02 \x03(\x0b\x32\x0f.otg.Rocev2FlowB\x08\n\x06_value\"\xf9\x02\n\nRocev2Flow\x12\x18\n\x0btx_endpoint\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0brx_endpoint\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12$\n\x0brocev2_verb\x18\x04 \x01(\x0b\x32\x0f.otg.Rocev2Verb\x12\x19\n\x0cmessage_size\x18\x05 \x01(\rH\x03\x88\x01\x01\x12\x44\n\x11message_size_unit\x18\x06 \x01(\x0e\x32$.otg.Rocev2Flow.MessageSizeUnit.EnumH\x04\x88\x01\x01\x1aM\n\x0fMessageSizeUnit\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x06\n\x02kb\x10\x02\x12\x06\n\x02mb\x10\x03\x12\x06\n\x02gb\x10\x04\x42\x0e\n\x0c_tx_endpointB\x0e\n\x0c_rx_endpointB\x07\n\x05_nameB\x0f\n\r_message_sizeB\x14\n\x12_message_size_unit\"\xad\x02\n\nRocev2Verb\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.Rocev2Verb.Choice.EnumH\x00\x88\x01\x01\x12\x36\n\x14write_with_immediate\x18\x02 \x01(\x0b\x32\x18.otg.Rocev2ImmediateData\x12\x35\n\x13send_with_immediate\x18\x03 \x01(\x0b\x32\x18.otg.Rocev2ImmediateData\x1as\n\x06\x43hoice\"i\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05write\x10\x01\x12\x18\n\x14write_with_immediate\x10\x02\x12\x08\n\x04send\x10\x03\x12\x17\n\x13send_with_immediate\x10\x04\x12\x08\n\x04read\x10\x05\x42\t\n\x07_choice\"E\n\x13Rocev2ImmediateData\x12\x1b\n\x0eimmediate_data\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x11\n\x0f_immediate_data\"\xd8\x01\n\x12\x45gressOnlyTracking\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x36\n\x0bmetric_tags\x18\x02 \x03(\x0b\x32!.otg.EgressOnlyTrackingMetricTags\x12\x1e\n\x11\x65nable_timestamps\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12.\n\x07\x66ilters\x18\x04 \x03(\x0b\x32\x1d.otg.EgressOnlyTrackingFilterB\x0c\n\n_port_nameB\x14\n\x12_enable_timestamps\"\xb4\x01\n\x1c\x45gressOnlyTrackingMetricTags\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\trx_offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x32\n\ttx_offset\x18\x03 \x01(\x0b\x32\x1f.otg.EgressOnlyTrackingTxOffset\x12\x13\n\x06length\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_rx_offsetB\t\n\x07_length\"\xd9\x01\n\x1a\x45gressOnlyTrackingTxOffset\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.EgressOnlyTrackingTxOffset.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x06\x63ustom\x18\x02 \x01(\x0b\x32%.otg.EgressOnlyTrackingTxOffsetCustom\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choice\"@\n EgressOnlyTrackingTxOffsetCustom\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xa3\x01\n\x18\x45gressOnlyTrackingFilter\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.EgressOnlyTrackingFilter.Choice.EnumH\x00\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04none\x10\x01\x12\x0f\n\x0b\x61uto_macsec\x10\x02\x42\t\n\x07_choice\"\\\n\x0ePerPortOptions\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12$\n\tprotocols\x18\x02 \x03(\x0b\x32\x11.otg.PortProtocolB\x0c\n\n_port_name\"\xa8\x01\n\x0cPortProtocol\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.PortProtocol.Choice.EnumH\x00\x88\x01\x01\x12*\n\x06rocev2\x18\x02 \x01(\x0b\x32\x1a.otg.Rocev2PerPortSettings\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06rocev2\x10\x01\x42\t\n\x07_choice\"\x94\x01\n\x15Rocev2PerPortSettings\x12\x1b\n\x03\x63np\x18\x01 \x01(\x0b\x32\x0e.otg.Rocev2CNP\x12\x34\n\x0f\x63onnection_type\x18\x02 \x01(\x0b\x32\x1b.otg.Rocev2QPConnectionType\x12(\n\x0e\x64\x63qcn_settings\x18\x03 \x01(\x0b\x32\x10.otg.Rocev2DCQCN\"\xe8\x02\n\tRocev2CNP\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.Rocev2CNP.Choice.EnumH\x00\x88\x01\x01\x12)\n\x07ip_dscp\x18\x02 \x01(\x0b\x32\x18.otg.Rocev2PriorityValue\x12\x34\n\tecn_value\x18\x03 \x01(\x0e\x32\x1c.otg.Rocev2CNP.EcnValue.EnumH\x01\x88\x01\x01\x12\x1c\n\x0f\x63np_delay_timer\x18\x04 \x01(\rH\x02\x88\x01\x01\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07ip_dscp\x10\x01\x1aN\n\x08\x45\x63nValue\"B\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07non_ect\x10\x01\x12\t\n\x05\x65\x63t_1\x10\x02\x12\t\n\x05\x65\x63t_0\x10\x03\x12\x06\n\x02\x63\x65\x10\x04\x42\t\n\x07_choiceB\x0c\n\n_ecn_valueB\x12\n\x10_cnp_delay_timer\"\xd0\x01\n\x16Rocev2QPConnectionType\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.Rocev2QPConnectionType.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x13reliable_connection\x18\x02 \x01(\x0b\x32\x14.otg.Rocev2AckAndNak\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13reliable_connection\x10\x01\x42\t\n\x07_choice\"\xad\x02\n\x0fRocev2AckAndNak\x12\x1b\n\x03\x61\x63k\x18\x01 \x01(\x0b\x32\x0e.otg.Rocev2ACK\x12\x1b\n\x03nak\x18\x02 \x01(\x0b\x32\x0e.otg.Rocev2NAK\x12*\n\x1d\x65nable_retransmission_timeout\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12)\n\x1cretransmission_timeout_value\x18\x04 \x01(\rH\x01\x88\x01\x01\x12\'\n\x1aretransmission_retry_count\x18\x05 \x01(\rH\x02\x88\x01\x01\x42 \n\x1e_enable_retransmission_timeoutB\x1f\n\x1d_retransmission_timeout_valueB\x1d\n\x1b_retransmission_retry_count\"\xb6\x02\n\tRocev2ACK\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.Rocev2ACK.Choice.EnumH\x00\x88\x01\x01\x12)\n\x07ip_dscp\x18\x02 \x01(\x0b\x32\x18.otg.Rocev2PriorityValue\x12\x34\n\tecn_value\x18\x03 \x01(\x0e\x32\x1c.otg.Rocev2ACK.EcnValue.EnumH\x01\x88\x01\x01\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07ip_dscp\x10\x01\x1aN\n\x08\x45\x63nValue\"B\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07non_ect\x10\x01\x12\t\n\x05\x65\x63t_1\x10\x02\x12\t\n\x05\x65\x63t_0\x10\x03\x12\x06\n\x02\x63\x65\x10\x04\x42\t\n\x07_choiceB\x0c\n\n_ecn_value\"\xb6\x02\n\tRocev2NAK\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.Rocev2NAK.Choice.EnumH\x00\x88\x01\x01\x12)\n\x07ip_dscp\x18\x02 \x01(\x0b\x32\x18.otg.Rocev2PriorityValue\x12\x34\n\tecn_value\x18\x03 \x01(\x0e\x32\x1c.otg.Rocev2NAK.EcnValue.EnumH\x01\x88\x01\x01\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07ip_dscp\x10\x01\x1aN\n\x08\x45\x63nValue\"B\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07non_ect\x10\x01\x12\t\n\x05\x65\x63t_1\x10\x02\x12\t\n\x05\x65\x63t_0\x10\x03\x12\x06\n\x02\x63\x65\x10\x04\x42\t\n\x07_choiceB\x0c\n\n_ecn_value\"3\n\x13Rocev2PriorityValue\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xdd\x06\n\x0bRocev2DCQCN\x12\x19\n\x0c\x65nable_dcqcn\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x14\n\x07\x61lpha_g\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1a\n\rinitial_alpha\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12 \n\x13\x61lpha_update_period\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\'\n\x1arate_reduction_time_period\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12)\n\x1cinitial_rate_after_first_cnp\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12 \n\x13minimum_rate_limmit\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12+\n\x1emaximum_rate_decrement_at_time\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x1e\n\x11\x63lamp_target_rate\x18\t \x01(\x08H\x08\x88\x01\x01\x12 \n\x13rate_increment_time\x18\n \x01(\x04H\t\x88\x01\x01\x12(\n\x1brate_increment_byte_counter\x18\x0b \x01(\x04H\n\x88\x01\x01\x12%\n\x18rate_increment_threshold\x18\x0c \x01(\rH\x0b\x88\x01\x01\x12$\n\x17\x61\x64\x64itive_increment_rate\x18\r \x01(\x02H\x0c\x88\x01\x01\x12!\n\x14hyper_increment_rate\x18\x0e \x01(\x02H\r\x88\x01\x01\x42\x0f\n\r_enable_dcqcnB\n\n\x08_alpha_gB\x10\n\x0e_initial_alphaB\x16\n\x14_alpha_update_periodB\x1d\n\x1b_rate_reduction_time_periodB\x1f\n\x1d_initial_rate_after_first_cnpB\x16\n\x14_minimum_rate_limmitB!\n\x1f_maximum_rate_decrement_at_timeB\x14\n\x12_clamp_target_rateB\x16\n\x14_rate_increment_timeB\x1e\n\x1c_rate_increment_byte_counterB\x1b\n\x19_rate_increment_thresholdB\x1a\n\x18_additive_increment_rateB\x17\n\x15_hyper_increment_rate\"\xa4\x01\n\x05\x45rror\x12\x11\n\x04\x63ode\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\'\n\x04kind\x18\x02 \x01(\x0e\x32\x14.otg.Error.Kind.EnumH\x01\x88\x01\x01\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\x1a=\n\x04Kind\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nvalidation\x10\x01\x12\x0c\n\x08internal\x10\x02\x42\x07\n\x05_codeB\x07\n\x05_kind\"\x1b\n\x07Warning\x12\x10\n\x08warnings\x18\x01 \x03(\t\"\x9c\x01\n\x0c\x43onfigUpdate\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.ConfigUpdate.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x10.otg.FlowsUpdate\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lows\x10\x01\x42\t\n\x07_choice\"\xa2\x01\n\x0b\x46lowsUpdate\x12;\n\x0eproperty_names\x18\x01 \x03(\x0e\x32#.otg.FlowsUpdate.PropertyNames.Enum\x12\x18\n\x05\x66lows\x18\x02 \x03(\x0b\x32\t.otg.Flow\x1a<\n\rPropertyNames\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04rate\x10\x01\x12\x08\n\x04size\x10\x02\"F\n\x0c\x43onfigAppend\x12\x36\n\x12\x63onfig_append_list\x18\x01 \x03(\x0b\x32\x1a.otg.ConfigAppendResources\"\xa7\x01\n\x15\x43onfigAppendResources\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.ConfigAppendResources.Choice.EnumH\x00\x88\x01\x01\x12\x18\n\x05\x66lows\x18\x02 \x03(\x0b\x32\t.otg.Flow\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lows\x10\x01\x42\t\n\x07_choice\"F\n\x0c\x43onfigDelete\x12\x36\n\x12\x63onfig_delete_list\x18\x01 \x03(\x0b\x32\x1a.otg.ConfigDeleteResources\"\x9c\x01\n\x15\x43onfigDeleteResources\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.ConfigDeleteResources.Choice.EnumH\x00\x88\x01\x01\x12\r\n\x05\x66lows\x18\x02 \x03(\t\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lows\x10\x01\x42\t\n\x07_choice\"\xfd\x01\n\x0c\x43ontrolState\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.ControlState.Choice.EnumH\x00\x88\x01\x01\x12\x1c\n\x04port\x18\x02 \x01(\x0b\x32\x0e.otg.StatePort\x12$\n\x08protocol\x18\x03 \x01(\x0b\x32\x12.otg.StateProtocol\x12\"\n\x07traffic\x18\x04 \x01(\x0b\x32\x11.otg.StateTraffic\x1a\x46\n\x06\x43hoice\"<\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x0c\n\x08protocol\x10\x02\x12\x0b\n\x07traffic\x10\x03\x42\t\n\x07_choice\"\xcb\x01\n\tStatePort\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.StatePort.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04link\x18\x02 \x01(\x0b\x32\x12.otg.StatePortLink\x12&\n\x07\x63\x61pture\x18\x03 \x01(\x0b\x32\x15.otg.StatePortCapture\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04link\x10\x01\x12\x0b\n\x07\x63\x61pture\x10\x02\x42\t\n\x07_choice\"\xb9\x01\n\x0cStateTraffic\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.StateTraffic.Choice.EnumH\x00\x88\x01\x01\x12\x34\n\rflow_transmit\x18\x02 \x01(\x0b\x32\x1d.otg.StateTrafficFlowTransmit\x1a\x34\n\x06\x43hoice\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rflow_transmit\x10\x01\x42\t\n\x07_choice\"\xf5\x03\n\rStateProtocol\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StateProtocol.Choice.EnumH\x00\x88\x01\x01\x12\"\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.otg.StateProtocolAll\x12&\n\x05route\x18\x03 \x01(\x0b\x32\x17.otg.StateProtocolRoute\x12$\n\x04lacp\x18\x04 \x01(\x0b\x32\x16.otg.StateProtocolLacp\x12\"\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x15.otg.StateProtocolBgp\x12$\n\x04isis\x18\x06 \x01(\x0b\x32\x16.otg.StateProtocolIsis\x12(\n\x06ospfv2\x18\x07 \x01(\x0b\x32\x18.otg.StateProtocolOspfv2\x12(\n\x06ospfv3\x18\x08 \x01(\x0b\x32\x18.otg.StateProtocolOspfv3\x12(\n\x06rocev2\x18\t \x01(\x0b\x32\x18.otg.StateProtocolRocev2\x1aj\n\x06\x43hoice\"`\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\t\n\x05route\x10\x02\x12\x08\n\x04lacp\x10\x03\x12\x07\n\x03\x62gp\x10\x04\x12\x08\n\x04isis\x10\x05\x12\n\n\x06ospfv2\x10\x06\x12\n\n\x06ospfv3\x10\x07\x42\t\n\x07_choice\"\x94\x01\n\rStatePortLink\x12\x12\n\nport_names\x18\x01 \x03(\t\x12\x31\n\x05state\x18\x02 \x01(\x0e\x32\x1d.otg.StatePortLink.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\x9d\x01\n\x10StatePortCapture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12\x34\n\x05state\x18\x02 \x01(\x0e\x32 .otg.StatePortCapture.State.EnumH\x00\x88\x01\x01\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x42\x08\n\x06_state\"\xc4\x01\n\x18StateTrafficFlowTransmit\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12<\n\x05state\x18\x02 \x01(\x0e\x32(.otg.StateTrafficFlowTransmit.State.EnumH\x00\x88\x01\x01\x1aL\n\x05State\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x12\t\n\x05pause\x10\x03\x12\n\n\x06resume\x10\x04\x42\x08\n\x06_state\"\x89\x01\n\x10StateProtocolAll\x12\x34\n\x05state\x18\x01 \x01(\x0e\x32 .otg.StateProtocolAll.State.EnumH\x00\x88\x01\x01\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x42\x08\n\x06_state\"\xa4\x01\n\x12StateProtocolRoute\x12\r\n\x05names\x18\x01 \x03(\t\x12\x36\n\x05state\x18\x02 \x01(\x0e\x32\".otg.StateProtocolRoute.State.EnumH\x00\x88\x01\x01\x1a=\n\x05State\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08withdraw\x10\x01\x12\r\n\tadvertise\x10\x02\x42\x08\n\x06_state\"\xfc\x01\n\x11StateProtocolLacp\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.StateProtocolLacp.Choice.EnumH\x00\x88\x01\x01\x12*\n\x05\x61\x64min\x18\x02 \x01(\x0b\x32\x1b.otg.StateProtocolLacpAdmin\x12\x37\n\x0cmember_ports\x18\x03 \x01(\x0b\x32!.otg.StateProtocolLacpMemberPorts\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x61\x64min\x10\x01\x12\x10\n\x0cmember_ports\x10\x02\x42\t\n\x07_choice\"\xac\x01\n\x16StateProtocolLacpAdmin\x12\x18\n\x10lag_member_names\x18\x01 \x03(\t\x12:\n\x05state\x18\x02 \x01(\x0e\x32&.otg.StateProtocolLacpAdmin.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xb8\x01\n\x1cStateProtocolLacpMemberPorts\x12\x18\n\x10lag_member_names\x18\x01 \x03(\t\x12@\n\x05state\x18\x02 \x01(\x0e\x32,.otg.StateProtocolLacpMemberPorts.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xae\x01\n\x10StateProtocolBgp\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.StateProtocolBgp.Choice.EnumH\x00\x88\x01\x01\x12)\n\x05peers\x18\x02 \x01(\x0b\x32\x1a.otg.StateProtocolBgpPeers\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05peers\x10\x01\x42\t\n\x07_choice\"\xa4\x01\n\x15StateProtocolBgpPeers\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x39\n\x05state\x18\x02 \x01(\x0e\x32%.otg.StateProtocolBgpPeers.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xb7\x01\n\x11StateProtocolIsis\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.StateProtocolIsis.Choice.EnumH\x00\x88\x01\x01\x12.\n\x07routers\x18\x02 \x01(\x0b\x32\x1d.otg.StateProtocolIsisRouters\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07routers\x10\x01\x42\t\n\x07_choice\"\xac\x01\n\x18StateProtocolIsisRouters\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12<\n\x05state\x18\x02 \x01(\x0e\x32(.otg.StateProtocolIsisRouters.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xbd\x01\n\x13StateProtocolOspfv2\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.StateProtocolOspfv2.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x07routers\x18\x02 \x01(\x0b\x32\x1f.otg.StateProtocolOspfv2Routers\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07routers\x10\x01\x42\t\n\x07_choice\"\xb0\x01\n\x1aStateProtocolOspfv2Routers\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x05state\x18\x02 \x01(\x0e\x32*.otg.StateProtocolOspfv2Routers.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xbd\x01\n\x13StateProtocolOspfv3\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.StateProtocolOspfv3.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x07routers\x18\x02 \x01(\x0b\x32\x1f.otg.StateProtocolOspfv3Routers\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07routers\x10\x01\x42\t\n\x07_choice\"\xb0\x01\n\x1aStateProtocolOspfv3Routers\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x05state\x18\x02 \x01(\x0e\x32*.otg.StateProtocolOspfv3Routers.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xb7\x01\n\x13StateProtocolRocev2\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.StateProtocolRocev2.Choice.EnumH\x00\x88\x01\x01\x12,\n\x05peers\x18\x02 \x01(\x0b\x32\x1d.otg.StateProtocolRocev2Peers\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05peers\x10\x01\x42\t\n\x07_choice\"\xaa\x01\n\x18StateProtocolRocev2Peers\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12<\n\x05state\x18\x02 \x01(\x0e\x32(.otg.StateProtocolRocev2Peers.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xa7\x01\n\rControlAction\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.ControlAction.Choice.EnumH\x00\x88\x01\x01\x12%\n\x08protocol\x18\x02 \x01(\x0b\x32\x13.otg.ActionProtocol\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08protocol\x10\x01\x42\t\n\x07_choice\"P\n\x15\x43ontrolActionResponse\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12%\n\x08response\x18\x02 \x01(\x0b\x32\x13.otg.ActionResponse\"\xb1\x01\n\x0e\x41\x63tionResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.ActionResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x08protocol\x18\x02 \x01(\x0b\x32\x1b.otg.ActionResponseProtocol\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08protocol\x10\x01\x42\t\n\x07_choice\"\xb5\x02\n\x0e\x41\x63tionProtocol\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.ActionProtocol.Choice.EnumH\x00\x88\x01\x01\x12%\n\x04ipv4\x18\x02 \x01(\x0b\x32\x17.otg.ActionProtocolIpv4\x12%\n\x04ipv6\x18\x03 \x01(\x0b\x32\x17.otg.ActionProtocolIpv6\x12#\n\x03\x62gp\x18\x04 \x01(\x0b\x32\x16.otg.ActionProtocolBgp\x12%\n\x04isis\x18\x05 \x01(\x0b\x32\x17.otg.ActionProtocolIsis\x1aH\n\x06\x43hoice\">\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x07\n\x03\x62gp\x10\x03\x12\x08\n\x04isis\x10\x04\x42\t\n\x07_choice\"\xf6\x01\n\x16\x41\x63tionResponseProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.ActionResponseProtocol.Choice.EnumH\x00\x88\x01\x01\x12-\n\x04ipv4\x18\x02 \x01(\x0b\x32\x1f.otg.ActionResponseProtocolIpv4\x12-\n\x04ipv6\x18\x03 \x01(\x0b\x32\x1f.otg.ActionResponseProtocolIpv6\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\t\n\x07_choice\"\xb1\x01\n\x12\x41\x63tionProtocolIpv4\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIpv4.Choice.EnumH\x00\x88\x01\x01\x12)\n\x04ping\x18\x02 \x01(\x0b\x32\x1b.otg.ActionProtocolIpv4Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"\xc9\x01\n\x1a\x41\x63tionResponseProtocolIpv4\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.ActionResponseProtocolIpv4.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x04ping\x18\x02 \x01(\x0b\x32#.otg.ActionResponseProtocolIpv4Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"N\n\x16\x41\x63tionProtocolIpv4Ping\x12\x34\n\x08requests\x18\x01 \x03(\x0b\x32\".otg.ActionProtocolIpv4PingRequest\"c\n\x1d\x41\x63tionProtocolIpv4PingRequest\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"`\n\x1e\x41\x63tionResponseProtocolIpv4Ping\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.otg.ActionResponseProtocolIpv4PingResponse\"\x83\x02\n&ActionResponseProtocolIpv4PingResponse\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12L\n\x06result\x18\x03 \x01(\x0e\x32\x37.otg.ActionResponseProtocolIpv4PingResponse.Result.EnumH\x02\x88\x01\x01\x1a<\n\x06Result\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xb1\x01\n\x12\x41\x63tionProtocolIpv6\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIpv6.Choice.EnumH\x00\x88\x01\x01\x12)\n\x04ping\x18\x02 \x01(\x0b\x32\x1b.otg.ActionProtocolIpv6Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"\xc9\x01\n\x1a\x41\x63tionResponseProtocolIpv6\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.ActionResponseProtocolIpv6.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x04ping\x18\x02 \x01(\x0b\x32#.otg.ActionResponseProtocolIpv6Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"N\n\x16\x41\x63tionProtocolIpv6Ping\x12\x34\n\x08requests\x18\x01 \x03(\x0b\x32\".otg.ActionProtocolIpv6PingRequest\"c\n\x1d\x41\x63tionProtocolIpv6PingRequest\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"`\n\x1e\x41\x63tionResponseProtocolIpv6Ping\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.otg.ActionResponseProtocolIpv6PingResponse\"\x83\x02\n&ActionResponseProtocolIpv6PingResponse\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12L\n\x06result\x18\x03 \x01(\x0e\x32\x37.otg.ActionResponseProtocolIpv6PingResponse.Result.EnumH\x02\x88\x01\x01\x1a<\n\x06Result\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xb7\x02\n\x11\x41\x63tionProtocolBgp\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.ActionProtocolBgp.Choice.EnumH\x00\x88\x01\x01\x12\x38\n\x0cnotification\x18\x02 \x01(\x0b\x32\".otg.ActionProtocolBgpNotification\x12P\n\x19initiate_graceful_restart\x18\x03 \x01(\x0b\x32-.otg.ActionProtocolBgpInitiateGracefulRestart\x1aR\n\x06\x43hoice\"H\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cnotification\x10\x01\x12\x1d\n\x19initiate_graceful_restart\x10\x02\x42\t\n\x07_choice\"\xd5\x05\n\x1d\x41\x63tionProtocolBgpNotification\x12\r\n\x05names\x18\x01 \x03(\t\x12\x43\n\x06\x63hoice\x18\x02 \x01(\x0e\x32..otg.ActionProtocolBgpNotification.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x05\x63\x65\x61se\x18\x03 \x01(\x0b\x32\x18.otg.DeviceBgpCeaseError\x12>\n\x14message_header_error\x18\x04 \x01(\x0b\x32 .otg.DeviceBgpMessageHeaderError\x12:\n\x12open_message_error\x18\x05 \x01(\x0b\x32\x1e.otg.DeviceBgpOpenMessageError\x12>\n\x14update_message_error\x18\x06 \x01(\x0b\x32 .otg.DeviceBgpUpdateMessageError\x12:\n\x12hold_timer_expired\x18\x07 \x01(\x0b\x32\x1e.otg.DeviceBgpHoldTimerExpired\x12I\n\x1a\x66inite_state_machine_error\x18\x08 \x01(\x0b\x32%.otg.DeviceBgpFiniteStateMachineError\x12)\n\x06\x63ustom\x18\t \x01(\x0b\x32\x19.otg.DeviceBgpCustomError\x1a\xbd\x01\n\x06\x43hoice\"\xb2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x63\x65\x61se\x10\x01\x12\x18\n\x14message_header_error\x10\x02\x12\x16\n\x12open_message_error\x10\x03\x12\x18\n\x14update_message_error\x10\x04\x12\x16\n\x12hold_timer_expired\x10\x05\x12\x1e\n\x1a\x66inite_state_machine_error\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choice\"\xb5\x01\n(ActionProtocolBgpInitiateGracefulRestart\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x1a\n\rrestart_delay\x18\x02 \x01(\rH\x00\x88\x01\x01\x12G\n\x0cnotification\x18\x03 \x01(\x0b\x32\x31.otg.ActionProtocolBgpGracefulRestartNotificationB\x10\n\x0e_restart_delay\"\xe4\x05\n,ActionProtocolBgpGracefulRestartNotification\x12R\n\x06\x63hoice\x18\x02 \x01(\x0e\x32=.otg.ActionProtocolBgpGracefulRestartNotification.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x05\x63\x65\x61se\x18\x03 \x01(\x0b\x32\x18.otg.DeviceBgpCeaseError\x12>\n\x14message_header_error\x18\x04 \x01(\x0b\x32 .otg.DeviceBgpMessageHeaderError\x12:\n\x12open_message_error\x18\x05 \x01(\x0b\x32\x1e.otg.DeviceBgpOpenMessageError\x12>\n\x14update_message_error\x18\x06 \x01(\x0b\x32 .otg.DeviceBgpUpdateMessageError\x12:\n\x12hold_timer_expired\x18\x07 \x01(\x0b\x32\x1e.otg.DeviceBgpHoldTimerExpired\x12I\n\x1a\x66inite_state_machine_error\x18\x08 \x01(\x0b\x32%.otg.DeviceBgpFiniteStateMachineError\x12)\n\x06\x63ustom\x18\t \x01(\x0b\x32\x19.otg.DeviceBgpCustomError\x1a\xbd\x01\n\x06\x43hoice\"\xb2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x63\x65\x61se\x10\x01\x12\x18\n\x14message_header_error\x10\x02\x12\x16\n\x12open_message_error\x10\x03\x12\x18\n\x14update_message_error\x10\x04\x12\x16\n\x12hold_timer_expired\x10\x05\x12\x1e\n\x1a\x66inite_state_machine_error\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choice\"\xe6\x01\n\x12\x41\x63tionProtocolIsis\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIsis.Choice.EnumH\x00\x88\x01\x01\x12I\n\x19initiate_graceful_restart\x18\x02 \x01(\x0b\x32&.otg.ActionProtocolIsisInitiateRestart\x1a@\n\x06\x43hoice\"6\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1d\n\x19initiate_graceful_restart\x10\x01\x42\t\n\x07_choice\"\xc0\x02\n!ActionProtocolIsisInitiateRestart\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12G\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\x32.otg.ActionProtocolIsisInitiateRestart.Choice.EnumH\x00\x88\x01\x01\x12:\n\tunplanned\x18\x03 \x01(\x0b\x32\'.otg.ActionProtocolIsisUnplannedRestart\x12\x36\n\x07planned\x18\x04 \x01(\x0b\x32%.otg.ActionProtocolIsisPlannedRestart\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tunplanned\x10\x01\x12\x0b\n\x07planned\x10\x02\x42\t\n\x07_choice\"~\n\"ActionProtocolIsisUnplannedRestart\x12\x19\n\x0cholding_time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rrestart_after\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_holding_timeB\x10\n\x0e_restart_after\"|\n ActionProtocolIsisPlannedRestart\x12\x19\n\x0crestart_time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rrestart_after\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_restart_timeB\x10\n\x0e_restart_after\"\x9e\x0b\n\x0eMetricsRequest\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12%\n\x04port\x18\x02 \x01(\x0b\x32\x17.otg.PortMetricsRequest\x12%\n\x04\x66low\x18\x03 \x01(\x0b\x32\x17.otg.FlowMetricsRequest\x12\'\n\x05\x62gpv4\x18\x04 \x01(\x0b\x32\x18.otg.Bgpv4MetricsRequest\x12\'\n\x05\x62gpv6\x18\x05 \x01(\x0b\x32\x18.otg.Bgpv6MetricsRequest\x12%\n\x04isis\x18\x06 \x01(\x0b\x32\x17.otg.IsisMetricsRequest\x12#\n\x03lag\x18\x07 \x01(\x0b\x32\x16.otg.LagMetricsRequest\x12%\n\x04lacp\x18\x08 \x01(\x0b\x32\x17.otg.LacpMetricsRequest\x12%\n\x04lldp\x18\t \x01(\x0b\x32\x17.otg.LldpMetricsRequest\x12%\n\x04rsvp\x18\n \x01(\x0b\x32\x17.otg.RsvpMetricsRequest\x12\x36\n\rdhcpv4_client\x18\x0b \x01(\x0b\x32\x1f.otg.Dhcpv4ClientMetricsRequest\x12\x36\n\rdhcpv4_server\x18\x0c \x01(\x0b\x32\x1f.otg.Dhcpv4ServerMetricsRequest\x12\x36\n\rdhcpv6_client\x18\r \x01(\x0b\x32\x1f.otg.Dhcpv6ClientMetricsRequest\x12\x36\n\rdhcpv6_server\x18\x0e \x01(\x0b\x32\x1f.otg.Dhcpv6ServerMetricsRequest\x12)\n\x06ospfv2\x18\x0f \x01(\x0b\x32\x19.otg.Ospfv2MetricsRequest\x12,\n\x0b\x63onvergence\x18\x10 \x01(\x0b\x32\x17.otg.ConvergenceRequest\x12)\n\x06macsec\x18\x11 \x01(\x0b\x32\x19.otg.MacsecMetricsRequest\x12#\n\x03mka\x18\x12 \x01(\x0b\x32\x16.otg.MkaMetricsRequest\x12)\n\x06ospfv3\x18\x13 \x01(\x0b\x32\x19.otg.Ospfv3MetricsRequest\x12\x32\n\x0brocev2_ipv4\x18\x14 \x01(\x0b\x32\x1d.otg.Rocev2IPv4MetricsRequest\x12\x32\n\x0brocev2_ipv6\x18\x15 \x01(\x0b\x32\x1d.otg.Rocev2IPv6MetricsRequest\x12\x32\n\x0brocev2_flow\x18\x16 \x01(\x0b\x32\x1d.otg.Rocev2FlowMetricsRequest\x12\x43\n\x14\x65gress_only_tracking\x18\x17 \x01(\x0b\x32%.otg.EgressOnlyTrackingMetricsRequest\x1a\xd4\x02\n\x06\x43hoice\"\xc9\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x08\n\x04\x66low\x10\x02\x12\t\n\x05\x62gpv4\x10\x03\x12\t\n\x05\x62gpv6\x10\x04\x12\x08\n\x04isis\x10\x05\x12\x07\n\x03lag\x10\x06\x12\x08\n\x04lacp\x10\x07\x12\x08\n\x04lldp\x10\x08\x12\x08\n\x04rsvp\x10\t\x12\x11\n\rdhcpv4_client\x10\n\x12\x11\n\rdhcpv4_server\x10\x0b\x12\x11\n\rdhcpv6_client\x10\x0c\x12\x11\n\rdhcpv6_server\x10\r\x12\n\n\x06ospfv2\x10\x0e\x12\x0f\n\x0b\x63onvergence\x10\x0f\x12\n\n\x06macsec\x10\x10\x12\x07\n\x03mka\x10\x11\x12\n\n\x06ospfv3\x10\x12\x12\x0f\n\x0brocev2_ipv4\x10\x13\x12\x0f\n\x0brocev2_ipv6\x10\x14\x12\x0f\n\x0brocev2_flow\x10\x15\x12\x18\n\x14\x65gress_only_tracking\x10\x16\x42\t\n\x07_choice\"\xf8\x0c\n\x0fMetricsResponse\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.MetricsResponse.Choice.EnumH\x00\x88\x01\x01\x12%\n\x0cport_metrics\x18\x02 \x03(\x0b\x32\x0f.otg.PortMetric\x12%\n\x0c\x66low_metrics\x18\x03 \x03(\x0b\x32\x0f.otg.FlowMetric\x12\'\n\rbgpv4_metrics\x18\x04 \x03(\x0b\x32\x10.otg.Bgpv4Metric\x12\'\n\rbgpv6_metrics\x18\x05 \x03(\x0b\x32\x10.otg.Bgpv6Metric\x12%\n\x0cisis_metrics\x18\x06 \x03(\x0b\x32\x0f.otg.IsisMetric\x12#\n\x0blag_metrics\x18\x07 \x03(\x0b\x32\x0e.otg.LagMetric\x12%\n\x0clacp_metrics\x18\x08 \x03(\x0b\x32\x0f.otg.LacpMetric\x12%\n\x0clldp_metrics\x18\t \x03(\x0b\x32\x0f.otg.LldpMetric\x12%\n\x0crsvp_metrics\x18\n \x03(\x0b\x32\x0f.otg.RsvpMetric\x12\x35\n\x14\x64hcpv4client_metrics\x18\x0b \x03(\x0b\x32\x17.otg.Dhcpv4ClientMetric\x12\x35\n\x14\x64hcpv4server_metrics\x18\x0c \x03(\x0b\x32\x17.otg.Dhcpv4ServerMetric\x12\x35\n\x14\x64hcpv6client_metrics\x18\r \x03(\x0b\x32\x17.otg.Dhcpv6ClientMetric\x12\x35\n\x14\x64hcpv6server_metrics\x18\x0e \x03(\x0b\x32\x17.otg.Dhcpv6ServerMetric\x12)\n\x0eospfv2_metrics\x18\x0f \x03(\x0b\x32\x11.otg.Ospfv2Metric\x12\x33\n\x13\x63onvergence_metrics\x18\x10 \x03(\x0b\x32\x16.otg.ConvergenceMetric\x12)\n\x0emacsec_metrics\x18\x11 \x03(\x0b\x32\x11.otg.MacsecMetric\x12#\n\x0bmka_metrics\x18\x12 \x03(\x0b\x32\x0e.otg.MkaMetric\x12)\n\x0eospfv3_metrics\x18\x13 \x03(\x0b\x32\x11.otg.Ospfv3Metric\x12\x42\n\x1crocev2_ipv4_per_peer_metrics\x18\x14 \x03(\x0b\x32\x1c.otg.Rocev2IPv4MetricPerPeer\x12\x42\n\x1crocev2_ipv6_per_peer_metrics\x18\x15 \x03(\x0b\x32\x1c.otg.Rocev2IPv6MetricPerPeer\x12>\n\x1arocev2_flow_per_qp_metrics\x18\x16 \x03(\x0b\x32\x1a.otg.Rocev2FlowMetricPerQP\x12\x43\n\x1c\x65gress_only_tracking_metrics\x18\x17 \x03(\x0b\x32\x1d.otg.EgressOnlyTrackingMetric\x1a\xfd\x03\n\x06\x43hoice\"\xf2\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66low_metrics\x10\x01\x12\x10\n\x0cport_metrics\x10\x02\x12\x11\n\rbgpv4_metrics\x10\x03\x12\x11\n\rbgpv6_metrics\x10\x04\x12\x10\n\x0cisis_metrics\x10\x05\x12\x0f\n\x0blag_metrics\x10\x06\x12\x10\n\x0clacp_metrics\x10\x07\x12\x10\n\x0clldp_metrics\x10\x08\x12\x10\n\x0crsvp_metrics\x10\t\x12\x11\n\rdhcpv4_client\x10\n\x12\x11\n\rdhcpv4_server\x10\x0b\x12\x11\n\rdhcpv6_client\x10\x0c\x12\x11\n\rdhcpv6_server\x10\r\x12\x12\n\x0eospfv2_metrics\x10\x0e\x12\x17\n\x13\x63onvergence_metrics\x10\x0f\x12\x12\n\x0emacsec_metrics\x10\x10\x12\x0f\n\x0bmka_metrics\x10\x11\x12\x12\n\x0eospfv3_metrics\x10\x12\x12 \n\x1crocev2_ipv4_per_peer_metrics\x10\x13\x12 \n\x1crocev2_ipv6_per_peer_metrics\x10\x14\x12\x1e\n\x1arocev2_flow_per_qp_metrics\x10\x15\x12 \n\x1c\x65gress_only_tracking_metrics\x10\x16\x42\t\n\x07_choice\"\xde\x02\n\x12PortMetricsRequest\x12\x12\n\nport_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.PortMetricsRequest.ColumnNames.Enum\x1a\xf3\x01\n\x0b\x43olumnNames\"\xe3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\x0c\n\x08location\x10\x02\x12\x08\n\x04link\x10\x03\x12\x0b\n\x07\x63\x61pture\x10\x04\x12\r\n\tframes_tx\x10\x05\x12\r\n\tframes_rx\x10\x06\x12\x0c\n\x08\x62ytes_tx\x10\x07\x12\x0c\n\x08\x62ytes_rx\x10\x08\x12\x12\n\x0e\x66rames_tx_rate\x10\t\x12\x12\n\x0e\x66rames_rx_rate\x10\n\x12\x11\n\rbytes_tx_rate\x10\x0b\x12\x11\n\rbytes_rx_rate\x10\x0c\x12\x0f\n\x0blast_change\x10\r\"\xb0\x06\n\nPortMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08location\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\x04link\x18\x03 \x01(\x0e\x32\x19.otg.PortMetric.Link.EnumH\x02\x88\x01\x01\x12\x32\n\x07\x63\x61pture\x18\x04 \x01(\x0e\x32\x1c.otg.PortMetric.Capture.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x12\x34\n\x08transmit\x18\r \x01(\x0e\x32\x1d.otg.PortMetric.Transmit.EnumH\x0c\x88\x01\x01\x12\x18\n\x0blast_change\x18\x0e \x01(\x04H\r\x88\x01\x01\x1a\x31\n\x04Link\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a<\n\x07\x43\x61pture\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x1a=\n\x08Transmit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x42\x07\n\x05_nameB\x0b\n\t_locationB\x07\n\x05_linkB\n\n\x08_captureB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rateB\x0b\n\t_transmitB\x0e\n\x0c_last_change\"\xf0\x03\n\x12\x46lowMetricsRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12>\n\x0cmetric_names\x18\x03 \x03(\x0e\x32(.otg.FlowMetricsRequest.MetricNames.Enum\x12\x34\n\x0etagged_metrics\x18\x04 \x01(\x0b\x32\x1c.otg.FlowTaggedMetricsFilter\x1a\xcf\x02\n\x0bMetricNames\"\xbf\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\r\n\tframes_rx\x10\x03\x12\x0c\n\x08\x62ytes_tx\x10\x04\x12\x0c\n\x08\x62ytes_rx\x10\x05\x12\x12\n\x0e\x66rames_tx_rate\x10\x06\x12\x12\n\x0e\x66rames_rx_rate\x10\x07\x12\x12\n\x0etx_l1_rate_bps\x10\x08\x12\x12\n\x0erx_l1_rate_bps\x10\t\x12\x11\n\rtx_rate_bytes\x10\n\x12\x11\n\rrx_rate_bytes\x10\x0b\x12\x0f\n\x0btx_rate_bps\x10\x0c\x12\x0f\n\x0brx_rate_bps\x10\r\x12\x10\n\x0ctx_rate_kbps\x10\x0e\x12\x10\n\x0crx_rate_kbps\x10\x0f\x12\x10\n\x0ctx_rate_mbps\x10\x10\x12\x10\n\x0crx_rate_mbps\x10\x11\"\xad\x04\n\x17\x46lowTaggedMetricsFilter\x12\x14\n\x07include\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15include_empty_metrics\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x43\n\x0cmetric_names\x18\x03 \x03(\x0e\x32-.otg.FlowTaggedMetricsFilter.MetricNames.Enum\x12)\n\x07\x66ilters\x18\x04 \x03(\x0b\x32\x18.otg.FlowMetricTagFilter\x1a\xc1\x02\n\x0bMetricNames\"\xb1\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_tx\x10\x01\x12\r\n\tframes_rx\x10\x02\x12\x0c\n\x08\x62ytes_tx\x10\x03\x12\x0c\n\x08\x62ytes_rx\x10\x04\x12\x12\n\x0e\x66rames_tx_rate\x10\x05\x12\x12\n\x0e\x66rames_rx_rate\x10\x06\x12\x12\n\x0etx_l1_rate_bps\x10\x07\x12\x12\n\x0erx_l1_rate_bps\x10\x08\x12\x11\n\rtx_rate_bytes\x10\t\x12\x11\n\rrx_rate_bytes\x10\n\x12\x0f\n\x0btx_rate_bps\x10\x0b\x12\x0f\n\x0brx_rate_bps\x10\x0c\x12\x10\n\x0ctx_rate_kbps\x10\r\x12\x10\n\x0crx_rate_kbps\x10\x0e\x12\x10\n\x0ctx_rate_mbps\x10\x0f\x12\x10\n\x0crx_rate_mbps\x10\x10\x42\n\n\x08_includeB\x18\n\x16_include_empty_metrics\"A\n\x13\x46lowMetricTagFilter\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06values\x18\x02 \x03(\tB\x07\n\x05_name\"\xc8\x08\n\nFlowMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_tx\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_rx\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x34\n\x08transmit\x18\x05 \x01(\x0e\x32\x1d.otg.FlowMetric.Transmit.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x07 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x08 \x01(\x04H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\t \x01(\x04H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\n \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x0b \x01(\x02H\t\x88\x01\x01\x12\x11\n\x04loss\x18\x0c \x01(\x02H\n\x88\x01\x01\x12(\n\ntimestamps\x18\r \x01(\x0b\x32\x14.otg.MetricTimestamp\x12#\n\x07latency\x18\x0e \x01(\x0b\x32\x12.otg.MetricLatency\x12-\n\x0etagged_metrics\x18\x0f \x03(\x0b\x32\x15.otg.FlowTaggedMetric\x12\x1b\n\x0etx_l1_rate_bps\x18\x10 \x01(\x02H\x0b\x88\x01\x01\x12\x1b\n\x0erx_l1_rate_bps\x18\x11 \x01(\x02H\x0c\x88\x01\x01\x12\x1a\n\rtx_rate_bytes\x18\x12 \x01(\x02H\r\x88\x01\x01\x12\x1a\n\rrx_rate_bytes\x18\x13 \x01(\x02H\x0e\x88\x01\x01\x12\x18\n\x0btx_rate_bps\x18\x14 \x01(\x02H\x0f\x88\x01\x01\x12\x18\n\x0brx_rate_bps\x18\x15 \x01(\x02H\x10\x88\x01\x01\x12\x19\n\x0ctx_rate_kbps\x18\x16 \x01(\x02H\x11\x88\x01\x01\x12\x19\n\x0crx_rate_kbps\x18\x17 \x01(\x02H\x12\x88\x01\x01\x12\x19\n\x0ctx_rate_mbps\x18\x18 \x01(\x02H\x13\x88\x01\x01\x12\x19\n\x0crx_rate_mbps\x18\x19 \x01(\x02H\x14\x88\x01\x01\x1aI\n\x08Transmit\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x12\n\n\x06paused\x10\x03\x42\x07\n\x05_nameB\n\n\x08_port_txB\n\n\x08_port_rxB\x0b\n\t_transmitB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\x11\n\x0f_tx_l1_rate_bpsB\x11\n\x0f_rx_l1_rate_bpsB\x10\n\x0e_tx_rate_bytesB\x10\n\x0e_rx_rate_bytesB\x0e\n\x0c_tx_rate_bpsB\x0e\n\x0c_rx_rate_bpsB\x0f\n\r_tx_rate_kbpsB\x0f\n\r_rx_rate_kbpsB\x0f\n\r_tx_rate_mbpsB\x0f\n\r_rx_rate_mbps\"\xd3\x06\n\x10\x46lowTaggedMetric\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.otg.FlowMetricTag\x12\x16\n\tframes_tx\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x16\n\tframes_rx\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x06 \x01(\x02H\x04\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x11\n\x04loss\x18\x08 \x01(\x02H\x06\x88\x01\x01\x12(\n\ntimestamps\x18\t \x01(\x0b\x32\x14.otg.MetricTimestamp\x12#\n\x07latency\x18\n \x01(\x0b\x32\x12.otg.MetricLatency\x12\x1b\n\x0etx_l1_rate_bps\x18\x0b \x01(\x02H\x07\x88\x01\x01\x12\x1b\n\x0erx_l1_rate_bps\x18\x0c \x01(\x02H\x08\x88\x01\x01\x12\x1a\n\rtx_rate_bytes\x18\r \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rrx_rate_bytes\x18\x0e \x01(\x02H\n\x88\x01\x01\x12\x18\n\x0btx_rate_bps\x18\x0f \x01(\x02H\x0b\x88\x01\x01\x12\x18\n\x0brx_rate_bps\x18\x10 \x01(\x02H\x0c\x88\x01\x01\x12\x19\n\x0ctx_rate_kbps\x18\x11 \x01(\x02H\r\x88\x01\x01\x12\x19\n\x0crx_rate_kbps\x18\x12 \x01(\x02H\x0e\x88\x01\x01\x12\x19\n\x0ctx_rate_mbps\x18\x13 \x01(\x02H\x0f\x88\x01\x01\x12\x19\n\x0crx_rate_mbps\x18\x14 \x01(\x02H\x10\x88\x01\x01\x42\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\x11\n\x0f_tx_l1_rate_bpsB\x11\n\x0f_rx_l1_rate_bpsB\x10\n\x0e_tx_rate_bytesB\x10\n\x0e_rx_rate_bytesB\x0e\n\x0c_tx_rate_bpsB\x0e\n\x0c_rx_rate_bpsB\x0f\n\r_tx_rate_kbpsB\x0f\n\r_rx_rate_kbpsB\x0f\n\r_tx_rate_mbpsB\x0f\n\r_rx_rate_mbps\"S\n\rFlowMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.otg.FlowMetricTagValueB\x07\n\x05_name\"\xc2\x01\n\x12\x46lowMetricTagValue\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.FlowMetricTagValue.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03hex\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03str\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03hex\x10\x01\x12\x07\n\x03str\x10\x02\x42\t\n\x07_choiceB\x06\n\x04_hexB\x06\n\x04_str\"\x7f\n\x0fMetricTimestamp\x12\x1f\n\x12\x66irst_timestamp_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11last_timestamp_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x15\n\x13_first_timestamp_nsB\x14\n\x12_last_timestamp_ns\"\x87\x01\n\rMetricLatency\x12\x17\n\nminimum_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x17\n\nmaximum_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naverage_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\r\n\x0b_minimum_nsB\r\n\x0b_maximum_nsB\r\n\x0b_average_ns\"\xf9\x03\n\x13\x42gpv4MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv4MetricsRequest.ColumnNames.Enum\x1a\x8c\x03\n\x0b\x43olumnNames\"\xfc\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\x12\r\n\tfsm_state\x10\x0f\x12\x17\n\x13\x65nd_of_rib_received\x10\x10\"\xea\x08\n\x0b\x42gpv4Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv4Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x04H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x36\n\tfsm_state\x18\x10 \x01(\x0e\x32\x1e.otg.Bgpv4Metric.FsmState.EnumH\x0f\x88\x01\x01\x12 \n\x13\x65nd_of_rib_received\x18\x11 \x01(\x04H\x10\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1av\n\x08\x46smState\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04idle\x10\x01\x12\x0b\n\x07\x63onnect\x10\x02\x12\n\n\x06\x61\x63tive\x10\x03\x12\x0c\n\x08opensent\x10\x04\x12\x0f\n\x0bopenconfirm\x10\x05\x12\x0f\n\x0b\x65stablished\x10\x06\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_receivedB\x0c\n\n_fsm_stateB\x16\n\x14_end_of_rib_received\"\xf9\x03\n\x13\x42gpv6MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv6MetricsRequest.ColumnNames.Enum\x1a\x8c\x03\n\x0b\x43olumnNames\"\xfc\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\x12\r\n\tfsm_state\x10\x0f\x12\x17\n\x13\x65nd_of_rib_received\x10\x10\"\xea\x08\n\x0b\x42gpv6Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv6Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x04H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x36\n\tfsm_state\x18\x10 \x01(\x0e\x32\x1e.otg.Bgpv6Metric.FsmState.EnumH\x0f\x88\x01\x01\x12 \n\x13\x65nd_of_rib_received\x18\x11 \x01(\x04H\x10\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1av\n\x08\x46smState\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04idle\x10\x01\x12\x0b\n\x07\x63onnect\x10\x02\x12\n\n\x06\x61\x63tive\x10\x03\x12\x0c\n\x08opensent\x10\x04\x12\x0f\n\x0bopenconfirm\x10\x05\x12\x0f\n\x0b\x65stablished\x10\x06\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_receivedB\x0c\n\n_fsm_stateB\x16\n\x14_end_of_rib_received\"\xec\x06\n\x12IsisMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.IsisMetricsRequest.ColumnNames.Enum\x1a\xff\x05\n\x0b\x43olumnNames\"\xef\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0el1_sessions_up\x10\x01\x12\x13\n\x0fl1_session_flap\x10\x02\x12\x14\n\x10l1_database_size\x10\x03\x12\x1c\n\x18l1_broadcast_hellos_sent\x10\x04\x12 \n\x1cl1_broadcast_hellos_received\x10\x05\x12!\n\x1dl1_point_to_point_hellos_sent\x10\x06\x12%\n!l1_point_to_point_hellos_received\x10\x07\x12\x10\n\x0cl1_psnp_sent\x10\x08\x12\x14\n\x10l1_psnp_received\x10\t\x12\x10\n\x0cl1_csnp_sent\x10\n\x12\x14\n\x10l1_csnp_received\x10\x0b\x12\x0f\n\x0bl1_lsp_sent\x10\x0c\x12\x13\n\x0fl1_lsp_received\x10\r\x12\x12\n\x0el2_sessions_up\x10\x0e\x12\x13\n\x0fl2_session_flap\x10\x0f\x12\x14\n\x10l2_database_size\x10\x10\x12\x1c\n\x18l2_broadcast_hellos_sent\x10\x11\x12 \n\x1cl2_broadcast_hellos_received\x10\x12\x12!\n\x1dl2_point_to_point_hellos_sent\x10\x13\x12%\n!l2_point_to_point_hellos_received\x10\x14\x12\x10\n\x0cl2_psnp_sent\x10\x15\x12\x14\n\x10l2_psnp_received\x10\x16\x12\x10\n\x0cl2_csnp_sent\x10\x17\x12\x14\n\x10l2_csnp_received\x10\x18\x12\x0f\n\x0bl2_lsp_sent\x10\x19\x12\x13\n\x0fl2_lsp_received\x10\x1a\x12\x10\n\x0cgr_initiated\x10\x1b\x12\x10\n\x0cgr_succeeded\x10\x1c\x12\x19\n\x15neighbor_gr_initiated\x10\x1d\x12\x19\n\x15neighbor_gr_succeeded\x10\x1e\"\xc8\r\n\nIsisMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0el1_sessions_up\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1c\n\x0fl1_session_flap\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12%\n\x18l1_broadcast_hellos_sent\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12)\n\x1cl1_broadcast_hellos_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12*\n\x1dl1_point_to_point_hellos_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12.\n!l1_point_to_point_hellos_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1d\n\x10l1_database_size\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x19\n\x0cl1_psnp_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1d\n\x10l1_psnp_received\x18\n \x01(\x04H\t\x88\x01\x01\x12\x19\n\x0cl1_csnp_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1d\n\x10l1_csnp_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x18\n\x0bl1_lsp_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1c\n\x0fl1_lsp_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1b\n\x0el2_sessions_up\x18\x0f \x01(\rH\x0e\x88\x01\x01\x12\x1c\n\x0fl2_session_flap\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12%\n\x18l2_broadcast_hellos_sent\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12)\n\x1cl2_broadcast_hellos_received\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12*\n\x1dl2_point_to_point_hellos_sent\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12.\n!l2_point_to_point_hellos_received\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x1d\n\x10l2_database_size\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12\x19\n\x0cl2_psnp_sent\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x1d\n\x10l2_psnp_received\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12\x19\n\x0cl2_csnp_sent\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x1d\n\x10l2_csnp_received\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\x18\n\x0bl2_lsp_sent\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x1c\n\x0fl2_lsp_received\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x19\n\x0cgr_initiated\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x19\n\x0cgr_succeeded\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12\"\n\x15neighbor_gr_initiated\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12\"\n\x15neighbor_gr_succeeded\x18\x1f \x01(\x04H\x1e\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_l1_sessions_upB\x12\n\x10_l1_session_flapB\x1b\n\x19_l1_broadcast_hellos_sentB\x1f\n\x1d_l1_broadcast_hellos_receivedB \n\x1e_l1_point_to_point_hellos_sentB$\n\"_l1_point_to_point_hellos_receivedB\x13\n\x11_l1_database_sizeB\x0f\n\r_l1_psnp_sentB\x13\n\x11_l1_psnp_receivedB\x0f\n\r_l1_csnp_sentB\x13\n\x11_l1_csnp_receivedB\x0e\n\x0c_l1_lsp_sentB\x12\n\x10_l1_lsp_receivedB\x11\n\x0f_l2_sessions_upB\x12\n\x10_l2_session_flapB\x1b\n\x19_l2_broadcast_hellos_sentB\x1f\n\x1d_l2_broadcast_hellos_receivedB \n\x1e_l2_point_to_point_hellos_sentB$\n\"_l2_point_to_point_hellos_receivedB\x13\n\x11_l2_database_sizeB\x0f\n\r_l2_psnp_sentB\x13\n\x11_l2_psnp_receivedB\x0f\n\r_l2_csnp_sentB\x13\n\x11_l2_csnp_receivedB\x0e\n\x0c_l2_lsp_sentB\x12\n\x10_l2_lsp_receivedB\x0f\n\r_gr_initiatedB\x0f\n\r_gr_succeededB\x18\n\x16_neighbor_gr_initiatedB\x18\n\x16_neighbor_gr_succeeded\"\xbd\x02\n\x11LagMetricsRequest\x12\x11\n\tlag_names\x18\x01 \x03(\t\x12=\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\'.otg.LagMetricsRequest.ColumnNames.Enum\x1a\xd5\x01\n\x0b\x43olumnNames\"\xc5\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0boper_status\x10\x01\x12\x13\n\x0fmember_ports_up\x10\x02\x12\r\n\tframes_tx\x10\x03\x12\r\n\tframes_rx\x10\x04\x12\x0c\n\x08\x62ytes_tx\x10\x05\x12\x0c\n\x08\x62ytes_rx\x10\x06\x12\x12\n\x0e\x66rames_tx_rate\x10\x07\x12\x12\n\x0e\x66rames_rx_rate\x10\x08\x12\x11\n\rbytes_tx_rate\x10\t\x12\x11\n\rbytes_rx_rate\x10\n\"\xac\x04\n\tLagMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x0boper_status\x18\x02 \x01(\x0e\x32\x1e.otg.LagMetric.OperStatus.EnumH\x01\x88\x01\x01\x12\x1c\n\x0fmember_ports_up\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x16\n\tframes_tx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x16\n\tframes_rx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x1a\x37\n\nOperStatus\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x0e\n\x0c_oper_statusB\x12\n\x10_member_ports_upB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rate\"\xb4\x03\n\x12LacpMetricsRequest\x12\x11\n\tlag_names\x18\x01 \x03(\t\x12\x1d\n\x15lag_member_port_names\x18\x02 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x03 \x03(\x0e\x32(.otg.LacpMetricsRequest.ColumnNames.Enum\x1a\xab\x02\n\x0b\x43olumnNames\"\x9b\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flacp_packets_rx\x10\x01\x12\x13\n\x0flacp_packets_tx\x10\x02\x12\x12\n\x0elacp_rx_errors\x10\x03\x12\x0c\n\x08\x61\x63tivity\x10\x04\x12\x0b\n\x07timeout\x10\x05\x12\x13\n\x0fsynchronization\x10\x06\x12\x10\n\x0c\x61ggregatable\x10\x07\x12\x0e\n\ncollecting\x10\x08\x12\x10\n\x0c\x64istributing\x10\t\x12\r\n\tsystem_id\x10\n\x12\x0c\n\x08oper_key\x10\x0b\x12\x0e\n\npartner_id\x10\x0c\x12\x0f\n\x0bpartner_key\x10\r\x12\x0c\n\x08port_num\x10\x0e\x12\x14\n\x10partner_port_num\x10\x0f\"\x8d\x08\n\nLacpMetric\x12\x15\n\x08lag_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12!\n\x14lag_member_port_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0flacp_packets_rx\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0flacp_packets_tx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0elacp_rx_errors\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x34\n\x08\x61\x63tivity\x18\x06 \x01(\x0e\x32\x1d.otg.LacpMetric.Activity.EnumH\x05\x88\x01\x01\x12\x32\n\x07timeout\x18\x07 \x01(\x0e\x32\x1c.otg.LacpMetric.Timeout.EnumH\x06\x88\x01\x01\x12\x42\n\x0fsynchronization\x18\x08 \x01(\x0e\x32$.otg.LacpMetric.Synchronization.EnumH\x07\x88\x01\x01\x12\x19\n\x0c\x61ggregatable\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x17\n\ncollecting\x18\n \x01(\x08H\t\x88\x01\x01\x12\x19\n\x0c\x64istributing\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x16\n\tsystem_id\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x15\n\x08oper_key\x18\r \x01(\rH\x0c\x88\x01\x01\x12\x17\n\npartner_id\x18\x0e \x01(\tH\r\x88\x01\x01\x12\x18\n\x0bpartner_key\x18\x0f \x01(\rH\x0e\x88\x01\x01\x12\x15\n\x08port_num\x18\x10 \x01(\rH\x0f\x88\x01\x01\x12\x1d\n\x10partner_port_num\x18\x11 \x01(\rH\x10\x88\x01\x01\x1a<\n\x08\x41\x63tivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61\x63tive\x10\x01\x12\x0b\n\x07passive\x10\x02\x1a\x37\n\x07Timeout\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05short\x10\x01\x12\x08\n\x04long\x10\x02\x1a\x45\n\x0fSynchronization\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07in_sync\x10\x01\x12\x0c\n\x08out_sync\x10\x02\x42\x0b\n\t_lag_nameB\x17\n\x15_lag_member_port_nameB\x12\n\x10_lacp_packets_rxB\x12\n\x10_lacp_packets_txB\x11\n\x0f_lacp_rx_errorsB\x0b\n\t_activityB\n\n\x08_timeoutB\x12\n\x10_synchronizationB\x0f\n\r_aggregatableB\r\n\x0b_collectingB\x0f\n\r_distributingB\x0c\n\n_system_idB\x0b\n\t_oper_keyB\r\n\x0b_partner_idB\x0e\n\x0c_partner_keyB\x0b\n\t_port_numB\x13\n\x11_partner_port_num\"\xfd\x01\n\x12LldpMetricsRequest\x12\x12\n\nlldp_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.LldpMetricsRequest.ColumnNames.Enum\x1a\x92\x01\n\x0b\x43olumnNames\"\x82\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_rx\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\x13\n\x0f\x66rames_error_rx\x10\x03\x12\x12\n\x0e\x66rames_discard\x10\x04\x12\x10\n\x0ctlvs_discard\x10\x05\x12\x10\n\x0ctlvs_unknown\x10\x06\"\xae\x02\n\nLldpMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tframes_rx\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x16\n\tframes_tx\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0f\x66rames_error_rx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0e\x66rames_discard\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x19\n\x0ctlvs_discard\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x19\n\x0ctlvs_unknown\x18\x07 \x01(\x04H\x06\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_frames_rxB\x0c\n\n_frames_txB\x12\n\x10_frames_error_rxB\x11\n\x0f_frames_discardB\x0f\n\r_tlvs_discardB\x0f\n\r_tlvs_unknown\"\xc2\x05\n\x12RsvpMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.RsvpMetricsRequest.ColumnNames.Enum\x1a\xd5\x04\n\x0b\x43olumnNames\"\xc5\x04\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1f\n\x1bingress_p2p_lsps_configured\x10\x01\x12\x17\n\x13ingress_p2p_lsps_up\x10\x02\x12\x16\n\x12\x65gress_p2p_lsps_up\x10\x03\x12\x12\n\x0elsp_flap_count\x10\x04\x12\x0c\n\x08paths_tx\x10\x05\x12\x0c\n\x08paths_rx\x10\x06\x12\x0c\n\x08resvs_tx\x10\x07\x12\x0c\n\x08resvs_rx\x10\x08\x12\x11\n\rpath_tears_tx\x10\t\x12\x11\n\rpath_tears_rx\x10\n\x12\x11\n\rresv_tears_tx\x10\x0b\x12\x11\n\rresv_tears_rx\x10\x0c\x12\x12\n\x0epath_errors_tx\x10\r\x12\x12\n\x0epath_errors_rx\x10\x0e\x12\x12\n\x0eresv_errors_tx\x10\x0f\x12\x12\n\x0eresv_errors_rx\x10\x10\x12\x10\n\x0cresv_conf_tx\x10\x11\x12\x10\n\x0cresv_conf_rx\x10\x12\x12\r\n\thellos_tx\x10\x13\x12\r\n\thellos_rx\x10\x14\x12\x0b\n\x07\x61\x63ks_tx\x10\x15\x12\x0b\n\x07\x61\x63ks_rx\x10\x16\x12\x0c\n\x08nacks_tx\x10\x17\x12\x0c\n\x08nacks_rx\x10\x18\x12\x0f\n\x0bsrefresh_tx\x10\x19\x12\x0f\n\x0bsrefresh_rx\x10\x1a\x12\r\n\tbundle_tx\x10\x1b\x12\r\n\tbundle_rx\x10\x1c\x12 \n\x1cpath_reevaluation_request_tx\x10\x1d\x12\x18\n\x14path_reoptimizations\x10\x1e\"\xf4\n\n\nRsvpMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\x1bingress_p2p_lsps_configured\x18\x02 \x01(\rH\x01\x88\x01\x01\x12 \n\x13ingress_p2p_lsps_up\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1f\n\x12\x65gress_p2p_lsps_up\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1b\n\x0elsp_flap_count\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x15\n\x08paths_tx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08paths_rx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x15\n\x08resvs_tx\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x15\n\x08resvs_rx\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1a\n\rpath_tears_tx\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1a\n\rpath_tears_rx\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1a\n\rresv_tears_tx\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x1a\n\rresv_tears_rx\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1b\n\x0epath_errors_tx\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1b\n\x0epath_errors_rx\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x1b\n\x0eresv_errors_tx\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12\x1b\n\x0eresv_errors_rx\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12\x19\n\x0cresv_conf_tx\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12\x19\n\x0cresv_conf_rx\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12\x16\n\thellos_tx\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x16\n\thellos_rx\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12\x14\n\x07\x61\x63ks_tx\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x14\n\x07\x61\x63ks_rx\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12\x15\n\x08nacks_tx\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x15\n\x08nacks_rx\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\x18\n\x0bsrefresh_tx\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x18\n\x0bsrefresh_rx\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x16\n\tbundle_tx\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x16\n\tbundle_rx\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12)\n\x1cpath_reevaluation_request_tx\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12!\n\x14path_reoptimizations\x18\x1f \x01(\x04H\x1e\x88\x01\x01\x42\x07\n\x05_nameB\x1e\n\x1c_ingress_p2p_lsps_configuredB\x16\n\x14_ingress_p2p_lsps_upB\x15\n\x13_egress_p2p_lsps_upB\x11\n\x0f_lsp_flap_countB\x0b\n\t_paths_txB\x0b\n\t_paths_rxB\x0b\n\t_resvs_txB\x0b\n\t_resvs_rxB\x10\n\x0e_path_tears_txB\x10\n\x0e_path_tears_rxB\x10\n\x0e_resv_tears_txB\x10\n\x0e_resv_tears_rxB\x11\n\x0f_path_errors_txB\x11\n\x0f_path_errors_rxB\x11\n\x0f_resv_errors_txB\x11\n\x0f_resv_errors_rxB\x0f\n\r_resv_conf_txB\x0f\n\r_resv_conf_rxB\x0c\n\n_hellos_txB\x0c\n\n_hellos_rxB\n\n\x08_acks_txB\n\n\x08_acks_rxB\x0b\n\t_nacks_txB\x0b\n\t_nacks_rxB\x0e\n\x0c_srefresh_txB\x0e\n\x0c_srefresh_rxB\x0c\n\n_bundle_txB\x0c\n\n_bundle_rxB\x1f\n\x1d_path_reevaluation_request_txB\x17\n\x15_path_reoptimizations\"\xad\x02\n\x1a\x44hcpv4ClientMetricsRequest\x12\x14\n\x0c\x63lient_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv4ClientMetricsRequest.ColumnNames.Enum\x1a\xb0\x01\n\x0b\x43olumnNames\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0e\x64iscovers_sent\x10\x01\x12\x13\n\x0foffers_received\x10\x02\x12\x11\n\rrequests_sent\x10\x03\x12\x11\n\racks_received\x10\x04\x12\x12\n\x0enacks_received\x10\x05\x12\x11\n\rreleases_sent\x10\x06\x12\x11\n\rdeclines_sent\x10\x07\"\xfa\x02\n\x12\x44hcpv4ClientMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0e\x64iscovers_sent\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1c\n\x0foffers_received\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1a\n\rrequests_sent\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1a\n\racks_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1b\n\x0enacks_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1a\n\rreleases_sent\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1a\n\rdeclines_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_discovers_sentB\x12\n\x10_offers_receivedB\x10\n\x0e_requests_sentB\x10\n\x0e_acks_receivedB\x11\n\x0f_nacks_receivedB\x10\n\x0e_releases_sentB\x10\n\x0e_declines_sent\"\xb1\x02\n\x1a\x44hcpv4ServerMetricsRequest\x12\x14\n\x0cserver_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv4ServerMetricsRequest.ColumnNames.Enum\x1a\xb4\x01\n\x0b\x43olumnNames\"\xa4\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12\x64iscovers_received\x10\x01\x12\x0f\n\x0boffers_sent\x10\x02\x12\x15\n\x11requests_received\x10\x03\x12\r\n\tacks_sent\x10\x04\x12\x0e\n\nnacks_sent\x10\x05\x12\x15\n\x11releases_received\x10\x06\x12\x15\n\x11\x64\x65\x63lines_received\x10\x07\"\x82\x03\n\x12\x44hcpv4ServerMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12\x64iscovers_received\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x18\n\x0boffers_sent\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1e\n\x11requests_received\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x16\n\tacks_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x17\n\nnacks_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1e\n\x11releases_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1e\n\x11\x64\x65\x63lines_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x42\x07\n\x05_nameB\x15\n\x13_discovers_receivedB\x0e\n\x0c_offers_sentB\x14\n\x12_requests_receivedB\x0c\n\n_acks_sentB\r\n\x0b_nacks_sentB\x14\n\x12_releases_receivedB\x14\n\x12_declines_received\"\xe0\x03\n\x1a\x44hcpv6ClientMetricsRequest\x12\x14\n\x0c\x63lient_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv6ClientMetricsRequest.ColumnNames.Enum\x1a\xe3\x02\n\x0b\x43olumnNames\"\xd3\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsolicits_sent\x10\x01\x12\x1b\n\x17\x61\x64vertisements_received\x10\x02\x12\x1a\n\x16\x61\x64vertisements_ignored\x10\x03\x12\x11\n\rrequests_sent\x10\x04\x12\x12\n\x0enacks_received\x10\x05\x12\x14\n\x10replies_received\x10\x06\x12\x1d\n\x19information_requests_sent\x10\x07\x12\x0f\n\x0brenews_sent\x10\x08\x12\x10\n\x0crebinds_sent\x10\t\x12\x11\n\rreleases_sent\x10\n\x12\x19\n\x15reconfigures_received\x10\x0b\x12\x1e\n\x1arapid_commit_solicits_sent\x10\x0c\x12!\n\x1drapid_commit_replies_received\x10\r\"\x90\x06\n\x12\x44hcpv6ClientMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rsolicits_sent\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12$\n\x17\x61\x64vertisements_received\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12#\n\x16\x61\x64vertisements_ignored\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1a\n\rrequests_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1b\n\x0enacks_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1d\n\x10replies_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12&\n\x19information_requests_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x18\n\x0brenews_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x19\n\x0crebinds_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1a\n\rreleases_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\"\n\x15reconfigures_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\'\n\x1arapid_commit_solicits_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12*\n\x1drapid_commit_replies_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_solicits_sentB\x1a\n\x18_advertisements_receivedB\x19\n\x17_advertisements_ignoredB\x10\n\x0e_requests_sentB\x11\n\x0f_nacks_receivedB\x13\n\x11_replies_receivedB\x1c\n\x1a_information_requests_sentB\x0e\n\x0c_renews_sentB\x0f\n\r_rebinds_sentB\x10\n\x0e_releases_sentB\x18\n\x16_reconfigures_receivedB\x1d\n\x1b_rapid_commit_solicits_sentB \n\x1e_rapid_commit_replies_received\"\x84\x04\n\x1a\x44hcpv6ServerMetricsRequest\x12\x14\n\x0cserver_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv6ServerMetricsRequest.ColumnNames.Enum\x1a\x87\x03\n\x0b\x43olumnNames\"\xf7\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11solicits_received\x10\x01\x12\x14\n\x10solicits_ignored\x10\x02\x12\x17\n\x13\x61\x64vertisements_sent\x10\x03\x12\x15\n\x11requests_received\x10\x04\x12\x0e\n\nnacks_sent\x10\x05\x12\x15\n\x11\x63onfirms_received\x10\x06\x12\x15\n\x11renewals_received\x10\x07\x12\x14\n\x10rebinds_received\x10\x08\x12\x10\n\x0creplies_sent\x10\t\x12\x15\n\x11releases_received\x10\n\x12\x15\n\x11\x64\x65\x63lines_received\x10\x0b\x12!\n\x1dinformation_requests_received\x10\x0c\x12\x1b\n\x17relay_forwards_received\x10\r\x12\x16\n\x12relay_replies_sent\x10\x0e\x12\x15\n\x11reconfigures_sent\x10\x0f\"\xe8\x06\n\x12\x44hcpv6ServerMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11solicits_received\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10solicits_ignored\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12 \n\x13\x61\x64vertisements_sent\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1e\n\x11requests_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x17\n\nnacks_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1e\n\x11\x63onfirms_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1e\n\x11renewals_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1d\n\x10rebinds_received\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x19\n\x0creplies_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1e\n\x11releases_received\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1e\n\x11\x64\x65\x63lines_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12*\n\x1dinformation_requests_received\x18\r \x01(\x04H\x0c\x88\x01\x01\x12$\n\x17relay_forwards_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1f\n\x12relay_replies_sent\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x1e\n\x11reconfigures_sent\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x42\x07\n\x05_nameB\x14\n\x12_solicits_receivedB\x13\n\x11_solicits_ignoredB\x16\n\x14_advertisements_sentB\x14\n\x12_requests_receivedB\r\n\x0b_nacks_sentB\x14\n\x12_confirms_receivedB\x14\n\x12_renewals_receivedB\x13\n\x11_rebinds_receivedB\x0f\n\r_replies_sentB\x14\n\x12_releases_receivedB\x14\n\x12_declines_receivedB \n\x1e_information_requests_receivedB\x1a\n\x18_relay_forwards_receivedB\x15\n\x13_relay_replies_sentB\x14\n\x12_reconfigures_sent\"\xe5\x06\n\x14Ospfv2MetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12@\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32*.otg.Ospfv2MetricsRequest.ColumnNames.Enum\x1a\xf4\x05\n\x0b\x43olumnNames\"\xe4\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10\x66ull_state_count\x10\x01\x12\x14\n\x10\x64own_state_count\x10\x02\x12\x11\n\rsessions_flap\x10\x03\x12\x0f\n\x0bhellos_sent\x10\x04\x12\x13\n\x0fhellos_received\x10\x05\x12\x0c\n\x08\x64\x62\x64_sent\x10\x06\x12\x10\n\x0c\x64\x62\x64_received\x10\x07\x12\x13\n\x0fls_request_sent\x10\x08\x12\x17\n\x13ls_request_received\x10\t\x12\x12\n\x0els_update_sent\x10\n\x12\x16\n\x12ls_update_received\x10\x0b\x12\x0f\n\x0bls_ack_sent\x10\x0c\x12\x13\n\x0fls_ack_received\x10\r\x12\x0c\n\x08lsa_sent\x10\x0e\x12\x10\n\x0clsa_received\x10\x0f\x12\x10\n\x0clsa_ack_sent\x10\x10\x12\x14\n\x10lsa_ack_received\x10\x11\x12\x13\n\x0frouter_lsa_sent\x10\x12\x12\x17\n\x13router_lsa_received\x10\x13\x12\x14\n\x10network_lsa_sent\x10\x14\x12\x18\n\x14network_lsa_received\x10\x15\x12\x14\n\x10summary_lsa_sent\x10\x16\x12\x18\n\x14summary_lsa_received\x10\x17\x12\x15\n\x11\x65xternal_lsa_sent\x10\x18\x12\x19\n\x15\x65xternal_lsa_received\x10\x19\x12\x11\n\rnssa_lsa_sent\x10\x1a\x12\x15\n\x11nssa_lsa_received\x10\x1b\x12\x15\n\x11opaque_local_sent\x10\x1c\x12\x19\n\x15opaque_local_received\x10\x1d\x12\x14\n\x10opaque_area_sent\x10\x1e\x12\x18\n\x14opaque_area_received\x10\x1f\x12\x16\n\x12opaque_domain_sent\x10 \x12\x1a\n\x16opaque_domain_received\x10!\"\xcc\r\n\x0cOspfv2Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x10\x66ull_state_count\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10\x64own_state_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1a\n\rsessions_flap\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x18\n\x0bhellos_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fhellos_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x64\x62\x64_sent\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0c\x64\x62\x64_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1c\n\x0fls_request_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12 \n\x13ls_request_received\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0els_update_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1f\n\x12ls_update_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x18\n\x0bls_ack_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1c\n\x0fls_ack_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x15\n\x08lsa_sent\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x19\n\x0clsa_received\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12\x19\n\x0clsa_ack_sent\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12\x1d\n\x10lsa_ack_received\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12\x1c\n\x0frouter_lsa_sent\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12 \n\x13router_lsa_received\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x1d\n\x10network_lsa_sent\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12!\n\x14network_lsa_received\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x1d\n\x10summary_lsa_sent\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12!\n\x14summary_lsa_received\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x1e\n\x11\x65xternal_lsa_sent\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\"\n\x15\x65xternal_lsa_received\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x1a\n\rnssa_lsa_sent\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x1e\n\x11nssa_lsa_received\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x1e\n\x11opaque_local_sent\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12\"\n\x15opaque_local_received\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12\x1d\n\x10opaque_area_sent\x18\x1f \x01(\x04H\x1e\x88\x01\x01\x12!\n\x14opaque_area_received\x18  \x01(\x04H\x1f\x88\x01\x01\x12\x1f\n\x12opaque_domain_sent\x18! \x01(\x04H \x88\x01\x01\x12#\n\x16opaque_domain_received\x18\" \x01(\x04H!\x88\x01\x01\x42\x07\n\x05_nameB\x13\n\x11_full_state_countB\x13\n\x11_down_state_countB\x10\n\x0e_sessions_flapB\x0e\n\x0c_hellos_sentB\x12\n\x10_hellos_receivedB\x0b\n\t_dbd_sentB\x0f\n\r_dbd_receivedB\x12\n\x10_ls_request_sentB\x16\n\x14_ls_request_receivedB\x11\n\x0f_ls_update_sentB\x15\n\x13_ls_update_receivedB\x0e\n\x0c_ls_ack_sentB\x12\n\x10_ls_ack_receivedB\x0b\n\t_lsa_sentB\x0f\n\r_lsa_receivedB\x0f\n\r_lsa_ack_sentB\x13\n\x11_lsa_ack_receivedB\x12\n\x10_router_lsa_sentB\x16\n\x14_router_lsa_receivedB\x13\n\x11_network_lsa_sentB\x17\n\x15_network_lsa_receivedB\x13\n\x11_summary_lsa_sentB\x17\n\x15_summary_lsa_receivedB\x14\n\x12_external_lsa_sentB\x18\n\x16_external_lsa_receivedB\x10\n\x0e_nssa_lsa_sentB\x14\n\x12_nssa_lsa_receivedB\x14\n\x12_opaque_local_sentB\x18\n\x16_opaque_local_receivedB\x13\n\x11_opaque_area_sentB\x17\n\x15_opaque_area_receivedB\x15\n\x13_opaque_domain_sentB\x19\n\x17_opaque_domain_received\"(\n\x12\x43onvergenceRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\"\xfe\x01\n\x11\x43onvergenceMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\x19\x64\x61ta_plane_convergence_us\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x34\n\'control_plane_data_plane_convergence_us\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12%\n\x06\x65vents\x18\x04 \x03(\x0b\x32\x15.otg.ConvergenceEventB\x07\n\x05_nameB\x1c\n\x1a_data_plane_convergence_usB*\n(_control_plane_data_plane_convergence_us\"\x87\x03\n\x10\x43onvergenceEvent\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.ConvergenceEvent.Type.EnumH\x00\x88\x01\x01\x12\x13\n\x06source\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x62\x65gin_timestamp_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x1d\n\x10\x65nd_timestamp_ns\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\x42\x07\n\x05_typeB\t\n\x07_sourceB\x15\n\x13_begin_timestamp_nsB\x13\n\x11_end_timestamp_ns\"\xc8\x04\n\x14MacsecMetricsRequest\x12\x1b\n\x13secure_entity_names\x18\x01 \x03(\t\x12@\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32*.otg.MacsecMetricsRequest.ColumnNames.Enum\x1a\xd0\x03\n\x0b\x43olumnNames\"\xc0\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x16\n\x12out_pkts_protected\x10\x03\x12\x16\n\x12out_pkts_encrypted\x10\x04\x12\x0e\n\nin_pkts_ok\x10\x05\x12\x0f\n\x0bin_pkts_bad\x10\x06\x12\x13\n\x0fin_pkts_bad_tag\x10\x07\x12\x10\n\x0cin_pkts_late\x10\x08\x12\x12\n\x0ein_pkts_no_sci\x10\t\x12\x18\n\x14in_pkts_not_using_sa\x10\n\x12\x15\n\x11in_pkts_not_valid\x10\x0b\x12\x17\n\x13in_pkts_unknown_sci\x10\x0c\x12\x15\n\x11in_pkts_unused_sa\x10\r\x12\x13\n\x0fin_pkts_invalid\x10\x0e\x12\x14\n\x10in_pkts_untagged\x10\x0f\x12\x18\n\x14out_octets_protected\x10\x10\x12\x18\n\x14out_octets_encrypted\x10\x11\x12\x17\n\x13in_octets_validated\x10\x12\x12\x17\n\x13in_octets_decrypted\x10\x13\"\xf4\x08\n\x0cMacsecMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\rsession_state\x18\x02 \x01(\x0e\x32#.otg.MacsecMetric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1f\n\x12out_pkts_protected\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1f\n\x12out_pkts_encrypted\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x17\n\nin_pkts_ok\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x18\n\x0bin_pkts_bad\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1c\n\x0fin_pkts_bad_tag\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x19\n\x0cin_pkts_late\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1b\n\x0ein_pkts_no_sci\x18\n \x01(\x04H\t\x88\x01\x01\x12!\n\x14in_pkts_not_using_sa\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1e\n\x11in_pkts_not_valid\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13in_pkts_unknown_sci\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1e\n\x11in_pkts_unused_sa\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1c\n\x0fin_pkts_invalid\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x1d\n\x10in_pkts_untagged\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12!\n\x14out_octets_protected\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12!\n\x14out_octets_encrypted\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12 \n\x13in_octets_validated\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12 \n\x13in_octets_decrypted\x18\x14 \x01(\x04H\x13\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x15\n\x13_out_pkts_protectedB\x15\n\x13_out_pkts_encryptedB\r\n\x0b_in_pkts_okB\x0e\n\x0c_in_pkts_badB\x12\n\x10_in_pkts_bad_tagB\x0f\n\r_in_pkts_lateB\x11\n\x0f_in_pkts_no_sciB\x17\n\x15_in_pkts_not_using_saB\x14\n\x12_in_pkts_not_validB\x16\n\x14_in_pkts_unknown_sciB\x14\n\x12_in_pkts_unused_saB\x12\n\x10_in_pkts_invalidB\x13\n\x11_in_pkts_untaggedB\x17\n\x15_out_octets_protectedB\x17\n\x15_out_octets_encryptedB\x16\n\x14_in_octets_validatedB\x16\n\x14_in_octets_decrypted\"\xe9\x02\n\x11MkaMetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12=\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\'.otg.MkaMetricsRequest.ColumnNames.Enum\x1a\x80\x02\n\x0b\x43olumnNames\"\xf0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x0c\n\x08mkpdu_tx\x10\x03\x12\x0c\n\x08mkpdu_rx\x10\x04\x12\x13\n\x0flive_peer_count\x10\x05\x12\x18\n\x14potential_peer_count\x10\x06\x12\x1c\n\x18latest_key_tx_peer_count\x10\x07\x12\x1c\n\x18latest_key_rx_peer_count\x10\x08\x12\x13\n\x0fmalformed_mkpdu\x10\t\x12\x10\n\x0cicv_mismatch\x10\n\"\x86\x05\n\tMkaMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12<\n\rsession_state\x18\x02 \x01(\x0e\x32 .otg.MkaMetric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x15\n\x08mkpdu_tx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x15\n\x08mkpdu_rx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0flive_peer_count\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12!\n\x14potential_peer_count\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12%\n\x18latest_key_tx_peer_count\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12%\n\x18latest_key_rx_peer_count\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1c\n\x0fmalformed_mkpdu\x18\n \x01(\x04H\t\x88\x01\x01\x12\x19\n\x0cicv_mismatch\x18\x0b \x01(\x04H\n\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x0b\n\t_mkpdu_txB\x0b\n\t_mkpdu_rxB\x12\n\x10_live_peer_countB\x17\n\x15_potential_peer_countB\x1b\n\x19_latest_key_tx_peer_countB\x1b\n\x19_latest_key_rx_peer_countB\x12\n\x10_malformed_mkpduB\x0f\n\r_icv_mismatch\"\xed\x06\n\x14Ospfv3MetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12@\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32*.otg.Ospfv3MetricsRequest.ColumnNames.Enum\x1a\xfc\x05\n\x0b\x43olumnNames\"\xec\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10\x66ull_state_count\x10\x01\x12\x14\n\x10\x64own_state_count\x10\x02\x12\x11\n\rsessions_flap\x10\x03\x12\x0f\n\x0bhellos_sent\x10\x04\x12\x13\n\x0fhellos_received\x10\x05\x12\x0c\n\x08\x64\x62\x64_sent\x10\x06\x12\x10\n\x0c\x64\x62\x64_received\x10\x07\x12\x13\n\x0fls_request_sent\x10\x08\x12\x17\n\x13ls_request_received\x10\t\x12\x12\n\x0els_update_sent\x10\n\x12\x16\n\x12ls_update_received\x10\x0b\x12\x0f\n\x0bls_ack_sent\x10\x0c\x12\x13\n\x0fls_ack_received\x10\r\x12\x0c\n\x08lsa_sent\x10\x0e\x12\x10\n\x0clsa_received\x10\x0f\x12\x13\n\x0frouter_lsa_sent\x10\x10\x12\x17\n\x13router_lsa_received\x10\x11\x12\x14\n\x10network_lsa_sent\x10\x12\x12\x18\n\x14network_lsa_received\x10\x13\x12\x1e\n\x1ainter_area_prefix_lsa_sent\x10\x14\x12\"\n\x1einter_area_prefix_lsa_received\x10\x15\x12\x1e\n\x1ainter_area_router_lsa_sent\x10\x16\x12\"\n\x1einter_area_router_lsa_received\x10\x17\x12\x15\n\x11\x65xternal_lsa_sent\x10\x18\x12\x19\n\x15\x65xternal_lsa_received\x10\x19\x12\x11\n\rnssa_lsa_sent\x10\x1a\x12\x15\n\x11nssa_lsa_received\x10\x1b\x12\x11\n\rlink_lsa_sent\x10\x1c\x12\x15\n\x11link_lsa_received\x10\x1d\x12\x1e\n\x1aintra_area_prefix_lsa_sent\x10\x1e\x12\"\n\x1eintra_area_prefix_lsa_received\x10\x1f\"\xcc\r\n\x0cOspfv3Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x10\x66ull_state_count\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10\x64own_state_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1a\n\rsessions_flap\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x18\n\x0bhellos_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fhellos_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x64\x62\x64_sent\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0c\x64\x62\x64_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1c\n\x0fls_request_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12 \n\x13ls_request_received\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0els_update_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1f\n\x12ls_update_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x18\n\x0bls_ack_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1c\n\x0fls_ack_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x15\n\x08lsa_sent\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x19\n\x0clsa_received\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12\x1c\n\x0frouter_lsa_sent\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12 \n\x13router_lsa_received\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12\x1d\n\x10network_lsa_sent\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12!\n\x14network_lsa_received\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\'\n\x1ainter_area_prefix_lsa_sent\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12+\n\x1einter_area_prefix_lsa_received\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\'\n\x1ainter_area_router_lsa_sent\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12+\n\x1einter_area_router_lsa_received\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x1e\n\x11\x65xternal_lsa_sent\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\"\n\x15\x65xternal_lsa_received\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x1a\n\rnssa_lsa_sent\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x1e\n\x11nssa_lsa_received\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x1a\n\rlink_lsa_sent\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12\x1e\n\x11link_lsa_received\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12\'\n\x1aintra_area_prefix_lsa_sent\x18\x1f \x01(\x04H\x1e\x88\x01\x01\x12+\n\x1eintra_area_prefix_lsa_received\x18  \x01(\x04H\x1f\x88\x01\x01\x42\x07\n\x05_nameB\x13\n\x11_full_state_countB\x13\n\x11_down_state_countB\x10\n\x0e_sessions_flapB\x0e\n\x0c_hellos_sentB\x12\n\x10_hellos_receivedB\x0b\n\t_dbd_sentB\x0f\n\r_dbd_receivedB\x12\n\x10_ls_request_sentB\x16\n\x14_ls_request_receivedB\x11\n\x0f_ls_update_sentB\x15\n\x13_ls_update_receivedB\x0e\n\x0c_ls_ack_sentB\x12\n\x10_ls_ack_receivedB\x0b\n\t_lsa_sentB\x0f\n\r_lsa_receivedB\x12\n\x10_router_lsa_sentB\x16\n\x14_router_lsa_receivedB\x13\n\x11_network_lsa_sentB\x17\n\x15_network_lsa_receivedB\x1d\n\x1b_inter_area_prefix_lsa_sentB!\n\x1f_inter_area_prefix_lsa_receivedB\x1d\n\x1b_inter_area_router_lsa_sentB!\n\x1f_inter_area_router_lsa_receivedB\x14\n\x12_external_lsa_sentB\x18\n\x16_external_lsa_receivedB\x10\n\x0e_nssa_lsa_sentB\x14\n\x12_nssa_lsa_receivedB\x10\n\x0e_link_lsa_sentB\x14\n\x12_link_lsa_receivedB\x1d\n\x1b_intra_area_prefix_lsa_sentB!\n\x1f_intra_area_prefix_lsa_received\"\xc4\x01\n\x18Rocev2IPv4MetricsRequest\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.Rocev2IPv4MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12,\n\x08per_peer\x18\x02 \x01(\x0b\x32\x1a.otg.Rocev2IPv4ColumnNames\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08per_peer\x10\x01\x42\t\n\x07_choice\"\xd5\x03\n\x15Rocev2IPv4ColumnNames\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x41\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32+.otg.Rocev2IPv4ColumnNames.ColumnNames.Enum\x1a\xe4\x02\n\x0b\x43olumnNames\"\xd4\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rqp_configured\x10\x01\x12\t\n\x05qp_up\x10\x02\x12\x0b\n\x07qp_down\x10\x03\x12\x16\n\x12\x63onnect_request_tx\x10\x04\x12\x16\n\x12\x63onnect_request_rx\x10\x05\x12\x14\n\x10\x63onnect_reply_tx\x10\x06\x12\x14\n\x10\x63onnect_reply_rx\x10\x07\x12\x0c\n\x08ready_tx\x10\x08\x12\x0c\n\x08ready_rx\x10\t\x12\x19\n\x15\x64isconnect_request_tx\x10\n\x12\x19\n\x15\x64isconnect_request_rx\x10\x0b\x12\x17\n\x13\x64isconnect_reply_tx\x10\x0c\x12\x17\n\x13\x64isconnect_reply_rx\x10\r\x12\r\n\treject_tx\x10\x0e\x12\r\n\treject_rx\x10\x0f\x12\x12\n\x0eunknown_msg_rx\x10\x10\"\x89\x06\n\x17Rocev2IPv4MetricPerPeer\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rqp_configured\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\x05qp_up\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x14\n\x07qp_down\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1f\n\x12\x63onnect_request_tx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1f\n\x12\x63onnect_request_rx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1d\n\x10\x63onnect_reply_tx\x18\x08 \x01(\x04H\x06\x88\x01\x01\x12\x1d\n\x10\x63onnect_reply_rx\x18\t \x01(\x04H\x07\x88\x01\x01\x12\x15\n\x08ready_tx\x18\n \x01(\x04H\x08\x88\x01\x01\x12\x15\n\x08ready_rx\x18\x0b \x01(\x04H\t\x88\x01\x01\x12\"\n\x15\x64isconnect_request_tx\x18\x0c \x01(\x04H\n\x88\x01\x01\x12\"\n\x15\x64isconnect_request_rx\x18\r \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13\x64isconnect_reply_tx\x18\x0e \x01(\x04H\x0c\x88\x01\x01\x12 \n\x13\x64isconnect_reply_rx\x18\x0f \x01(\x04H\r\x88\x01\x01\x12\x16\n\treject_tx\x18\x10 \x01(\x04H\x0e\x88\x01\x01\x12\x1b\n\x0eunknown_msg_rx\x18\x11 \x01(\x04H\x0f\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_qp_configuredB\x08\n\x06_qp_upB\n\n\x08_qp_downB\x15\n\x13_connect_request_txB\x15\n\x13_connect_request_rxB\x13\n\x11_connect_reply_txB\x13\n\x11_connect_reply_rxB\x0b\n\t_ready_txB\x0b\n\t_ready_rxB\x18\n\x16_disconnect_request_txB\x18\n\x16_disconnect_request_rxB\x16\n\x14_disconnect_reply_txB\x16\n\x14_disconnect_reply_rxB\x0c\n\n_reject_txB\x11\n\x0f_unknown_msg_rx\"\xc4\x01\n\x18Rocev2IPv6MetricsRequest\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.Rocev2IPv6MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12,\n\x08per_peer\x18\x02 \x01(\x0b\x32\x1a.otg.Rocev2IPv6ColumnNames\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08per_peer\x10\x01\x42\t\n\x07_choice\"\xd5\x03\n\x15Rocev2IPv6ColumnNames\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x41\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32+.otg.Rocev2IPv6ColumnNames.ColumnNames.Enum\x1a\xe4\x02\n\x0b\x43olumnNames\"\xd4\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rqp_configured\x10\x01\x12\t\n\x05qp_up\x10\x02\x12\x0b\n\x07qp_down\x10\x03\x12\x16\n\x12\x63onnect_request_tx\x10\x04\x12\x16\n\x12\x63onnect_request_rx\x10\x05\x12\x14\n\x10\x63onnect_reply_tx\x10\x06\x12\x14\n\x10\x63onnect_reply_rx\x10\x07\x12\x0c\n\x08ready_tx\x10\x08\x12\x0c\n\x08ready_rx\x10\t\x12\x19\n\x15\x64isconnect_request_tx\x10\n\x12\x19\n\x15\x64isconnect_request_rx\x10\x0b\x12\x17\n\x13\x64isconnect_reply_tx\x10\x0c\x12\x17\n\x13\x64isconnect_reply_rx\x10\r\x12\r\n\treject_tx\x10\x0e\x12\r\n\treject_rx\x10\x0f\x12\x12\n\x0eunknown_msg_rx\x10\x10\"\x89\x06\n\x17Rocev2IPv6MetricPerPeer\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rqp_configured\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\x05qp_up\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x14\n\x07qp_down\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1f\n\x12\x63onnect_request_tx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1f\n\x12\x63onnect_request_rx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1d\n\x10\x63onnect_reply_tx\x18\x08 \x01(\x04H\x06\x88\x01\x01\x12\x1d\n\x10\x63onnect_reply_rx\x18\t \x01(\x04H\x07\x88\x01\x01\x12\x15\n\x08ready_tx\x18\n \x01(\x04H\x08\x88\x01\x01\x12\x15\n\x08ready_rx\x18\x0b \x01(\x04H\t\x88\x01\x01\x12\"\n\x15\x64isconnect_request_tx\x18\x0c \x01(\x04H\n\x88\x01\x01\x12\"\n\x15\x64isconnect_request_rx\x18\r \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13\x64isconnect_reply_tx\x18\x0e \x01(\x04H\x0c\x88\x01\x01\x12 \n\x13\x64isconnect_reply_rx\x18\x0f \x01(\x04H\r\x88\x01\x01\x12\x16\n\treject_tx\x18\x10 \x01(\x04H\x0e\x88\x01\x01\x12\x1b\n\x0eunknown_msg_rx\x18\x11 \x01(\x04H\x0f\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_qp_configuredB\x08\n\x06_qp_upB\n\n\x08_qp_downB\x15\n\x13_connect_request_txB\x15\n\x13_connect_request_rxB\x13\n\x11_connect_reply_txB\x13\n\x11_connect_reply_rxB\x0b\n\t_ready_txB\x0b\n\t_ready_rxB\x18\n\x16_disconnect_request_txB\x18\n\x16_disconnect_request_rxB\x16\n\x14_disconnect_reply_txB\x16\n\x14_disconnect_reply_rxB\x0c\n\n_reject_txB\x11\n\x0f_unknown_msg_rx\"\xc0\x01\n\x18Rocev2FlowMetricsRequest\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.Rocev2FlowMetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12*\n\x06per_qp\x18\x02 \x01(\x0b\x32\x1a.otg.Rocev2FlowColumnNames\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06per_qp\x10\x01\x42\t\n\x07_choice\"\x9d\x05\n\x15Rocev2FlowColumnNames\x12\x41\n\x0c\x63olumn_names\x18\x01 \x03(\x0e\x32+.otg.Rocev2FlowColumnNames.ColumnNames.Enum\x1a\xc0\x04\n\x0b\x43olumnNames\"\xb0\x04\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tflow_name\x10\x01\x12\x0b\n\x07port_tx\x10\x02\x12\x0b\n\x07port_rx\x10\x03\x12\n\n\x06src_qp\x10\x04\x12\x0b\n\x07\x64\x65st_qp\x10\x05\x12\x0c\n\x08src_ipv4\x10\x06\x12\r\n\tdest_ipv4\x10\x07\x12\x12\n\x0e\x64\x61ta_frames_tx\x10\x08\x12\x12\n\x0e\x64\x61ta_frames_rx\x10\t\x12\x0f\n\x0b\x66rame_delta\x10\n\x12\x1d\n\x19\x64\x61ta_frames_retransmitted\x10\x0b\x12\x18\n\x14\x66rame_sequence_error\x10\x0c\x12\x0c\n\x08tx_bytes\x10\r\x12\x0c\n\x08rx_bytes\x10\x0e\x12\x10\n\x0c\x64\x61ta_tx_rate\x10\x0f\x12\x10\n\x0c\x64\x61ta_rx_rate\x10\x10\x12\x0e\n\nmessage_tx\x10\x11\x12\x17\n\x13message_complete_rx\x10\x12\x12\x10\n\x0cmessage_fail\x10\x13\x12\x18\n\x14\x66low_completion_time\x10\x14\x12\x0f\n\x0b\x61vg_latency\x10\x15\x12\x0f\n\x0bmin_latency\x10\x16\x12\x0f\n\x0bmax_latency\x10\x17\x12\r\n\tecn_ce_rx\x10\x18\x12\n\n\x06\x63np_tx\x10\x19\x12\n\n\x06\x63np_rx\x10\x1a\x12\n\n\x06\x61\x63k_tx\x10\x1b\x12\n\n\x06\x61\x63k_rx\x10\x1c\x12\n\n\x06nak_tx\x10\x1d\x12\n\n\x06nak_rx\x10\x1e\x12\x13\n\x0f\x66irst_timestamp\x10\x1f\x12\x12\n\x0elast_timestamp\x10 \"\xc9\n\n\x15Rocev2FlowMetricPerQP\x12\x16\n\tflow_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_tx\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_rx\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06src_qp\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x14\n\x07\x64\x65st_qp\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x15\n\x08src_ipv4\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tdest_ipv4\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0e\x64\x61ta_frames_tx\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1b\n\x0e\x64\x61ta_frames_rx\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x18\n\x0b\x66rame_delta\x18\n \x01(\x04H\t\x88\x01\x01\x12&\n\x19\x64\x61ta_frames_retransmitted\x18\x0b \x01(\x04H\n\x88\x01\x01\x12!\n\x14\x66rame_sequence_error\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x15\n\x08tx_bytes\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x15\n\x08rx_bytes\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x19\n\x0c\x64\x61ta_tx_rate\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x19\n\x0c\x64\x61ta_rx_rate\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12\x17\n\nmessage_tx\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12 \n\x13message_complete_rx\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12\x19\n\x0cmessage_fail\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12!\n\x14\x66low_completion_time\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x18\n\x0b\x61vg_latency\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12\x18\n\x0bmin_latency\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x18\n\x0bmax_latency\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12\x16\n\tecn_ce_rx\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x13\n\x06\x63np_tx\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\x13\n\x06\x63np_rx\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x13\n\x06\x61\x63k_tx\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x13\n\x06\x61\x63k_rx\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x13\n\x06nak_tx\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12\x13\n\x06nak_rx\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12\x1c\n\x0f\x66irst_timestamp\x18\x1f \x01(\tH\x1e\x88\x01\x01\x12\x1b\n\x0elast_timestamp\x18  \x01(\tH\x1f\x88\x01\x01\x42\x0c\n\n_flow_nameB\n\n\x08_port_txB\n\n\x08_port_rxB\t\n\x07_src_qpB\n\n\x08_dest_qpB\x0b\n\t_src_ipv4B\x0c\n\n_dest_ipv4B\x11\n\x0f_data_frames_txB\x11\n\x0f_data_frames_rxB\x0e\n\x0c_frame_deltaB\x1c\n\x1a_data_frames_retransmittedB\x17\n\x15_frame_sequence_errorB\x0b\n\t_tx_bytesB\x0b\n\t_rx_bytesB\x0f\n\r_data_tx_rateB\x0f\n\r_data_rx_rateB\r\n\x0b_message_txB\x16\n\x14_message_complete_rxB\x0f\n\r_message_failB\x17\n\x15_flow_completion_timeB\x0e\n\x0c_avg_latencyB\x0e\n\x0c_min_latencyB\x0e\n\x0c_max_latencyB\x0c\n\n_ecn_ce_rxB\t\n\x07_cnp_txB\t\n\x07_cnp_rxB\t\n\x07_ack_txB\t\n\x07_ack_rxB\t\n\x07_nak_txB\t\n\x07_nak_rxB\x12\n\x10_first_timestampB\x11\n\x0f_last_timestamp\"z\n EgressOnlyTrackingMetricsRequest\x12\x12\n\nport_names\x18\x01 \x03(\t\x12\x42\n\x0etagged_metrics\x18\x02 \x01(\x0b\x32*.otg.EgressOnlyTrackingTaggedMetricsFilter\"\xff\x02\n%EgressOnlyTrackingTaggedMetricsFilter\x12\"\n\x15include_empty_metrics\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12Q\n\x0cmetric_names\x18\x02 \x03(\x0e\x32;.otg.EgressOnlyTrackingTaggedMetricsFilter.MetricNames.Enum\x1a\xc4\x01\n\x0bMetricNames\"\xb4\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_rx\x10\x01\x12\x0c\n\x08\x62ytes_rx\x10\x02\x12\x12\n\x0e\x66rames_rx_rate\x10\x03\x12\x12\n\x0erx_l1_rate_bps\x10\x04\x12\x11\n\rrx_rate_bytes\x10\x05\x12\x0f\n\x0brx_rate_bps\x10\x06\x12\x10\n\x0crx_rate_kbps\x10\x07\x12\x10\n\x0crx_rate_mbps\x10\x08\x12\x0e\n\ntx_metrics\x10\tB\x18\n\x16_include_empty_metrics\"y\n\x18\x45gressOnlyTrackingMetric\x12\x14\n\x07port_rx\x18\x01 \x01(\tH\x00\x88\x01\x01\x12;\n\x0etagged_metrics\x18\x02 \x03(\x0b\x32#.otg.EgressOnlyTrackingTaggedMetricB\n\n\x08_port_rx\"\x96\x04\n\x1e\x45gressOnlyTrackingTaggedMetric\x12.\n\x04tags\x18\x01 \x03(\x0b\x32 .otg.EgressOnlyTrackingMetricTag\x12\x16\n\tframes_rx\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x04 \x01(\x02H\x02\x88\x01\x01\x12\x34\n\ntimestamps\x18\x05 \x01(\x0b\x32 .otg.EgressOnlyTrackingTimestamp\x12\x1b\n\x0erx_l1_rate_bps\x18\x06 \x01(\x02H\x03\x88\x01\x01\x12\x1a\n\rrx_rate_bytes\x18\x07 \x01(\x02H\x04\x88\x01\x01\x12\x18\n\x0brx_rate_bps\x18\x08 \x01(\x02H\x05\x88\x01\x01\x12\x19\n\x0crx_rate_kbps\x18\t \x01(\x02H\x06\x88\x01\x01\x12\x19\n\x0crx_rate_mbps\x18\n \x01(\x02H\x07\x88\x01\x01\x12\x34\n\ntx_metrics\x18\x0b \x01(\x0b\x32 .otg.EgressOnlyTrackingTxMetricsB\x0c\n\n_frames_rxB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_rx_rateB\x11\n\x0f_rx_l1_rate_bpsB\x10\n\x0e_rx_rate_bytesB\x0e\n\x0c_rx_rate_bpsB\x0f\n\r_rx_rate_kbpsB\x0f\n\r_rx_rate_mbps\"W\n\x1b\x45gressOnlyTrackingMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"\x8b\x01\n\x1b\x45gressOnlyTrackingTimestamp\x12\x1f\n\x12\x66irst_timestamp_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11last_timestamp_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x15\n\x13_first_timestamp_nsB\x14\n\x12_last_timestamp_ns\"\xb5\x03\n\x1b\x45gressOnlyTrackingTxMetrics\x12\x14\n\x07port_tx\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tframes_tx\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x11\n\x04loss\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x1b\n\x0etx_l1_rate_bps\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x1a\n\rtx_rate_bytes\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x18\n\x0btx_rate_bps\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x19\n\x0ctx_rate_kbps\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x19\n\x0ctx_rate_mbps\x18\n \x01(\x02H\t\x88\x01\x01\x42\n\n\x08_port_txB\x0c\n\n_frames_txB\x0b\n\t_bytes_txB\x11\n\x0f_frames_tx_rateB\x07\n\x05_lossB\x11\n\x0f_tx_l1_rate_bpsB\x10\n\x0e_tx_rate_bytesB\x0e\n\x0c_tx_rate_bpsB\x0f\n\r_tx_rate_kbpsB\x0f\n\r_tx_rate_mbps\"\x9d\x08\n\rStatesRequest\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StatesRequest.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x0eipv4_neighbors\x18\x02 \x01(\x0b\x32\x1d.otg.Neighborsv4StatesRequest\x12\x35\n\x0eipv6_neighbors\x18\x03 \x01(\x0b\x32\x1d.otg.Neighborsv6StatesRequest\x12\x30\n\x0c\x62gp_prefixes\x18\x04 \x01(\x0b\x32\x1a.otg.BgpPrefixStateRequest\x12,\n\tisis_lsps\x18\x05 \x01(\x0b\x32\x19.otg.IsisLspsStateRequest\x12\x36\n\x0elldp_neighbors\x18\x06 \x01(\x0b\x32\x1e.otg.LldpNeighborsStateRequest\x12,\n\trsvp_lsps\x18\x07 \x01(\x0b\x32\x19.otg.RsvpLspsStateRequest\x12;\n\x11\x64hcpv4_interfaces\x18\x08 \x01(\x0b\x32 .otg.Dhcpv4InterfaceStateRequest\x12\x33\n\rdhcpv4_leases\x18\t \x01(\x0b\x32\x1c.otg.Dhcpv4LeaseStateRequest\x12;\n\x11\x64hcpv6_interfaces\x18\n \x01(\x0b\x32 .otg.Dhcpv6InterfaceStateRequest\x12\x33\n\rdhcpv6_leases\x18\x0b \x01(\x0b\x32\x1c.otg.Dhcpv6LeaseStateRequest\x12\x30\n\x0bospfv2_lsas\x18\x0c \x01(\x0b\x32\x1b.otg.Ospfv2LsasStateRequest\x12\x30\n\x0bospfv3_lsas\x18\r \x01(\x0b\x32\x1b.otg.Ospfv3LsasStateRequest\x12\x33\n\x10isis_adjacencies\x18\x0e \x01(\x0b\x32\x19.otg.IsisIIHsStateRequest\x1a\x9a\x02\n\x06\x43hoice\"\x8f\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x12\x10\n\x0c\x62gp_prefixes\x10\x03\x12\r\n\tisis_lsps\x10\x04\x12\x12\n\x0elldp_neighbors\x10\x05\x12\r\n\trsvp_lsps\x10\x06\x12\x15\n\x11\x64hcpv4_interfaces\x10\x07\x12\x11\n\rdhcpv4_leases\x10\x08\x12\x15\n\x11\x64hcpv6_interfaces\x10\t\x12\x11\n\rdhcpv6_leases\x10\n\x12\x0f\n\x0bospfv2_lsas\x10\x0b\x12\x0f\n\x0bospfv3_lsas\x10\x0c\x12\x14\n\x10isis_adjacencies\x10\rB\t\n\x07_choice\"\xc4\x07\n\x0eStatesResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.StatesResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x0eipv4_neighbors\x18\x02 \x03(\x0b\x32\x15.otg.Neighborsv4State\x12-\n\x0eipv6_neighbors\x18\x03 \x03(\x0b\x32\x15.otg.Neighborsv6State\x12+\n\x0c\x62gp_prefixes\x18\x04 \x03(\x0b\x32\x15.otg.BgpPrefixesState\x12%\n\tisis_lsps\x18\x05 \x03(\x0b\x32\x12.otg.IsisLspsState\x12/\n\x0elldp_neighbors\x18\x06 \x03(\x0b\x32\x17.otg.LldpNeighborsState\x12%\n\trsvp_lsps\x18\x07 \x03(\x0b\x32\x12.otg.RsvpLspsState\x12\x34\n\x11\x64hcpv4_interfaces\x18\x08 \x03(\x0b\x32\x19.otg.Dhcpv4InterfaceState\x12-\n\rdhcpv4_leases\x18\t \x03(\x0b\x32\x16.otg.Dhcpv4LeasesState\x12\x34\n\x11\x64hcpv6_interfaces\x18\n \x03(\x0b\x32\x19.otg.Dhcpv6InterfaceState\x12-\n\rdhcpv6_leases\x18\x0b \x03(\x0b\x32\x16.otg.Dhcpv6LeasesState\x12(\n\x0bospfv2_lsas\x18\x0c \x03(\x0b\x32\x13.otg.Ospfv2LsaState\x12(\n\x0bospfv3_lsas\x18\r \x03(\x0b\x32\x13.otg.Ospfv3LsaState\x12,\n\x10isis_adjacencies\x18\x0e \x03(\x0b\x32\x12.otg.IsisIIHsState\x1a\x9a\x02\n\x06\x43hoice\"\x8f\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x12\x10\n\x0c\x62gp_prefixes\x10\x03\x12\r\n\tisis_lsps\x10\x04\x12\x12\n\x0elldp_neighbors\x10\x05\x12\r\n\trsvp_lsps\x10\x06\x12\x15\n\x11\x64hcpv4_interfaces\x10\x07\x12\x11\n\rdhcpv4_leases\x10\x08\x12\x15\n\x11\x64hcpv6_interfaces\x10\t\x12\x11\n\rdhcpv6_leases\x10\n\x12\x0f\n\x0bospfv2_lsas\x10\x0b\x12\x0f\n\x0bospfv3_lsas\x10\x0c\x12\x14\n\x10isis_adjacencies\x10\rB\t\n\x07_choice\"2\n\x18Neighborsv4StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"\xa4\x01\n\x10Neighborsv4State\x12\x1a\n\rethernet_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_ethernet_nameB\x0f\n\r_ipv4_addressB\x15\n\x13_link_layer_address\"2\n\x18Neighborsv6StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"\xa4\x01\n\x10Neighborsv6State\x12\x1a\n\rethernet_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_ethernet_nameB\x0f\n\r_ipv6_addressB\x15\n\x13_link_layer_address\"\xc2\x02\n\x15\x42gpPrefixStateRequest\x12\x16\n\x0e\x62gp_peer_names\x18\x01 \x03(\t\x12\x45\n\x0eprefix_filters\x18\x02 \x03(\x0e\x32-.otg.BgpPrefixStateRequest.PrefixFilters.Enum\x12=\n\x14ipv4_unicast_filters\x18\x03 \x03(\x0b\x32\x1f.otg.BgpPrefixIpv4UnicastFilter\x12=\n\x14ipv6_unicast_filters\x18\x04 \x03(\x0b\x32\x1f.otg.BgpPrefixIpv6UnicastFilter\x1aL\n\rPrefixFilters\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\"\x91\x02\n\x1a\x42gpPrefixIpv4UnicastFilter\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x00\x88\x01\x01\x12@\n\x06origin\x18\x03 \x01(\x0e\x32+.otg.BgpPrefixIpv4UnicastFilter.Origin.EnumH\x01\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x02\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_id\"\x91\x02\n\x1a\x42gpPrefixIpv6UnicastFilter\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x00\x88\x01\x01\x12@\n\x06origin\x18\x03 \x01(\x0e\x32+.otg.BgpPrefixIpv6UnicastFilter.Origin.EnumH\x01\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x02\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_id\"\xbe\x01\n\x10\x42gpPrefixesState\x12\x1a\n\rbgp_peer_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12=\n\x15ipv4_unicast_prefixes\x18\x02 \x03(\x0b\x32\x1e.otg.BgpPrefixIpv4UnicastState\x12=\n\x15ipv6_unicast_prefixes\x18\x03 \x03(\x0b\x32\x1e.otg.BgpPrefixIpv6UnicastStateB\x10\n\x0e_bgp_peer_name\"\x8d\x05\n\x19\x42gpPrefixIpv4UnicastState\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12?\n\x06origin\x18\x03 \x01(\x0e\x32*.otg.BgpPrefixIpv4UnicastState.Origin.EnumH\x02\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\ripv4_next_hop\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\ripv6_next_hop\x18\x06 \x01(\tH\x05\x88\x01\x01\x12,\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x17.otg.ResultBgpCommunity\x12:\n\x14\x65xtended_communities\x18\x0b \x03(\x0b\x32\x1c.otg.ResultExtendedCommunity\x12%\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x14.otg.ResultBgpAsPath\x12\x1d\n\x10local_preference\x18\t \x01(\rH\x06\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\n \x01(\rH\x07\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_idB\x10\n\x0e_ipv4_next_hopB\x10\n\x0e_ipv6_next_hopB\x13\n\x11_local_preferenceB\x1b\n\x19_multi_exit_discriminator\"\x8d\x05\n\x19\x42gpPrefixIpv6UnicastState\x12\x19\n\x0cipv6_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12?\n\x06origin\x18\x03 \x01(\x0e\x32*.otg.BgpPrefixIpv6UnicastState.Origin.EnumH\x02\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\ripv4_next_hop\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\ripv6_next_hop\x18\x06 \x01(\tH\x05\x88\x01\x01\x12,\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x17.otg.ResultBgpCommunity\x12:\n\x14\x65xtended_communities\x18\x0b \x03(\x0b\x32\x1c.otg.ResultExtendedCommunity\x12%\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x14.otg.ResultBgpAsPath\x12\x1d\n\x10local_preference\x18\t \x01(\rH\x06\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\n \x01(\rH\x07\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x0f\n\r_ipv6_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_idB\x10\n\x0e_ipv4_next_hopB\x10\n\x0e_ipv6_next_hopB\x13\n\x11_local_preferenceB\x1b\n\x19_multi_exit_discriminator\"o\n\x17ResultExtendedCommunity\x12\x10\n\x03raw\x18\x01 \x01(\tH\x00\x88\x01\x01\x12:\n\nstructured\x18\x02 \x01(\x0b\x32&.otg.ResultExtendedCommunityStructuredB\x06\n\x04_raw\"\xf6\x05\n!ResultExtendedCommunityStructured\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.ResultExtendedCommunityStructured.Choice.EnumH\x00\x88\x01\x01\x12U\n\x19transitive_2octet_as_type\x18\x02 \x01(\x0b\x32\x32.otg.ResultExtendedCommunityTransitive2OctetAsType\x12[\n\x1ctransitive_ipv4_address_type\x18\x03 \x01(\x0b\x32\x35.otg.ResultExtendedCommunityTransitiveIpv4AddressType\x12U\n\x19transitive_4octet_as_type\x18\x04 \x01(\x0b\x32\x32.otg.ResultExtendedCommunityTransitive4OctetAsType\x12P\n\x16transitive_opaque_type\x18\x05 \x01(\x0b\x32\x30.otg.ResultExtendedCommunityTransitiveOpaqueType\x12\\\n\x1dnon_transitive_2octet_as_type\x18\x06 \x01(\x0b\x32\x35.otg.ResultExtendedCommunityNonTransitive2OctetAsType\x1a\xc1\x01\n\x06\x43hoice\"\xb6\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1d\n\x19transitive_2octet_as_type\x10\x01\x12 \n\x1ctransitive_ipv4_address_type\x10\x02\x12\x1d\n\x19transitive_4octet_as_type\x10\x03\x12\x1a\n\x16transitive_opaque_type\x10\x04\x12!\n\x1dnon_transitive_2octet_as_type\x10\x05\x42\t\n\x07_choice\"\xa2\x01\n8ResultExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\xa2\x01\n8ResultExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\xa0\x03\n-ResultExtendedCommunityTransitive2OctetAsType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.ResultExtendedCommunityTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12[\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12[\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\xa9\x01\n;ResultExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xa9\x01\n;ResultExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xac\x03\n0ResultExtendedCommunityTransitiveIpv4AddressType\x12V\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x41.otg.ResultExtendedCommunityTransitiveIpv4AddressType.Choice.EnumH\x00\x88\x01\x01\x12^\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32@.otg.ResultExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12^\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32@.otg.ResultExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\xa2\x01\n8ResultExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\xa2\x01\n8ResultExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\xa0\x03\n-ResultExtendedCommunityTransitive4OctetAsType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.ResultExtendedCommunityTransitive4OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12[\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12[\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"n\n0ResultExtendedCommunityTransitiveOpaqueTypeColor\x12\x12\n\x05\x66lags\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_color\"\x88\x01\n8ResultExtendedCommunityTransitiveOpaqueTypeEncapsulation\x12\x15\n\x08reserved\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0btunnel_type\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0b\n\t_reservedB\x0e\n\x0c_tunnel_type\"\x88\x03\n+ResultExtendedCommunityTransitiveOpaqueType\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.ResultExtendedCommunityTransitiveOpaqueType.Choice.EnumH\x00\x88\x01\x01\x12L\n\rcolor_subtype\x18\x02 \x01(\x0b\x32\x35.otg.ResultExtendedCommunityTransitiveOpaqueTypeColor\x12\\\n\x15\x65ncapsulation_subtype\x18\x03 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitiveOpaqueTypeEncapsulation\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rcolor_subtype\x10\x01\x12\x19\n\x15\x65ncapsulation_subtype\x10\x02\x42\t\n\x07_choice\"\x97\x01\n=ResultExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tbandwidth\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x0c\n\n_bandwidth\"\xb8\x02\n0ResultExtendedCommunityNonTransitive2OctetAsType\x12V\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x41.otg.ResultExtendedCommunityNonTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12\x62\n\x16link_bandwidth_subtype\x18\x02 \x01(\x0b\x32\x42.otg.ResultExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1a\n\x16link_bandwidth_subtype\x10\x01\x42\t\n\x07_choice\"\xb0\x02\n\x12ResultBgpCommunity\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32!.otg.ResultBgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"@\n\x0fResultBgpAsPath\x12-\n\x08segments\x18\x01 \x03(\x0b\x32\x1b.otg.ResultBgpAsPathSegment\"\xce\x01\n\x16ResultBgpAsPathSegment\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32%.otg.ResultBgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"1\n\x14IsisLspsStateRequest\x12\x19\n\x11isis_router_names\x18\x01 \x03(\t\"d\n\rIsisLspsState\x12\x1d\n\x10isis_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x04lsps\x18\x02 \x03(\x0b\x32\x11.otg.IsisLspStateB\x13\n\x11_isis_router_name\"\xa6\x03\n\x0cIsisLspState\x12\x13\n\x06lsp_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x35\n\x08pdu_type\x18\x02 \x01(\x0e\x32\x1e.otg.IsisLspState.PduType.EnumH\x01\x88\x01\x01\x12\x1f\n\x12remaining_lifetime\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1c\n\x0fsequence_number\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x17\n\npdu_length\x18\x05 \x01(\rH\x04\x88\x01\x01\x12 \n\x05\x66lags\x18\x06 \x01(\x0b\x32\x11.otg.IsisLspFlags\x12\x14\n\x07is_type\x18\x07 \x01(\rH\x05\x88\x01\x01\x12\x1e\n\x04tlvs\x18\x08 \x01(\x0b\x32\x10.otg.IsisLspTlvs\x1a<\n\x07PduType\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x42\t\n\x07_lsp_idB\x0b\n\t_pdu_typeB\x15\n\x13_remaining_lifetimeB\x12\n\x10_sequence_numberB\r\n\x0b_pdu_lengthB\n\n\x08_is_type\"\xb1\x04\n\x0bIsisLspTlvs\x12+\n\rhostname_tlvs\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspHostname\x12;\n\x14is_reachability_tlvs\x18\x02 \x03(\x0b\x32\x1d.otg.IsisLspIsReachabilityTlv\x12L\n\x1d\x65xtended_is_reachability_tlvs\x18\x03 \x03(\x0b\x32%.otg.IsisLspExtendedIsReachabilityTlv\x12P\n\x1fipv4_internal_reachability_tlvs\x18\x04 \x03(\x0b\x32\'.otg.IsisLspIpv4InternalReachabilityTlv\x12P\n\x1fipv4_external_reachability_tlvs\x18\x05 \x03(\x0b\x32\'.otg.IsisLspIpv4ExternalReachabilityTlv\x12P\n\x1f\x65xtended_ipv4_reachability_tlvs\x18\x06 \x03(\x0b\x32\'.otg.IsisLspExtendedIpv4ReachabilityTlv\x12?\n\x16ipv6_reachability_tlvs\x18\x07 \x03(\x0b\x32\x1f.otg.IsisLspIpv6ReachabilityTlv\x12\x33\n\x13router_capabilities\x18\x08 \x03(\x0b\x32\x16.otg.IsisLspCapability\"5\n\x0fIsisLspHostname\x12\x15\n\x08hostname\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_hostname\"\xae\x02\n\x0cIsisLspFlags\x12\x1d\n\x10partition_repair\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0e\x61ttached_error\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1d\n\x10\x61ttached_expense\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0e\x61ttached_delay\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1d\n\x10\x61ttached_default\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08overload\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\x13\n\x11_partition_repairB\x11\n\x0f_attached_errorB\x13\n\x11_attached_expenseB\x11\n\x0f_attached_delayB\x13\n\x11_attached_defaultB\x0b\n\t_overload\"C\n\x18IsisLspIsReachabilityTlv\x12\'\n\tneighbors\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspneighbor\"S\n IsisLspExtendedIsReachabilityTlv\x12/\n\tneighbors\x18\x01 \x03(\x0b\x32\x1c.otg.IsisLspExtendedNeighbor\"7\n\x0fIsisLspneighbor\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_system_id\"q\n\x17IsisLspExtendedNeighbor\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x30\n\x0e\x61\x64jacency_sids\x18\x02 \x03(\x0b\x32\x18.otg.IsisLspAdjacencySidB\x0c\n\n_system_id\"L\n\"IsisLspIpv4InternalReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV4Prefix\"L\n\"IsisLspIpv4ExternalReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV4Prefix\"\xd7\x03\n\x0fIsisLspV4Prefix\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12N\n\x13redistribution_type\x18\x03 \x01(\x0e\x32,.otg.IsisLspV4Prefix.RedistributionType.EnumH\x02\x88\x01\x01\x12\x1b\n\x0e\x64\x65\x66\x61ult_metric\x18\x04 \x01(\rH\x03\x88\x01\x01\x12>\n\x0borigin_type\x18\x05 \x01(\x0e\x32$.otg.IsisLspV4Prefix.OriginType.EnumH\x04\x88\x01\x01\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x16\n\x14_redistribution_typeB\x11\n\x0f_default_metricB\x0e\n\x0c_origin_type\"T\n\"IsisLspExtendedIpv4ReachabilityTlv\x12.\n\x08prefixes\x18\x01 \x03(\x0b\x32\x1c.otg.IsisLspExtendedV4Prefix\"\xa9\x03\n\x17IsisLspExtendedV4Prefix\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12V\n\x13redistribution_type\x18\x04 \x01(\x0e\x32\x34.otg.IsisLspExtendedV4Prefix.RedistributionType.EnumH\x03\x88\x01\x01\x12\x37\n\x11prefix_attributes\x18\x05 \x01(\x0b\x32\x1c.otg.IsisLspPrefixAttributes\x12*\n\x0bprefix_sids\x18\x06 \x03(\x0b\x32\x15.otg.IsisLspPrefixSid\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x16\n\x14_redistribution_type\"D\n\x1aIsisLspIpv6ReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV6Prefix\"\xac\x04\n\x0fIsisLspV6Prefix\x12\x19\n\x0cipv6_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12N\n\x13redistribution_type\x18\x04 \x01(\x0e\x32,.otg.IsisLspV6Prefix.RedistributionType.EnumH\x03\x88\x01\x01\x12>\n\x0borigin_type\x18\x05 \x01(\x0e\x32$.otg.IsisLspV6Prefix.OriginType.EnumH\x04\x88\x01\x01\x12\x37\n\x11prefix_attributes\x18\x06 \x01(\x0b\x32\x1c.otg.IsisLspPrefixAttributes\x12*\n\x0bprefix_sids\x18\x07 \x03(\x0b\x32\x15.otg.IsisLspPrefixSid\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x42\x0f\n\r_ipv6_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x16\n\x14_redistribution_typeB\x0e\n\x0c_origin_type\"y\n\x17IsisLspPrefixAttributes\x12\x13\n\x06x_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06r_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06n_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"q\n\x10IsisLspPrefixSid\x12\x0c\n\x04sids\x18\x01 \x03(\r\x12)\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x1a.otg.IsisLspPrefixSidFlags\x12\x16\n\talgorithm\x18\x03 \x01(\rH\x00\x88\x01\x01\x42\x0c\n\n_algorithm\"\xa1\x03\n\x11IsisLspCapability\x12\x1a\n\rrouter_cap_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x34\n\x05s_bit\x18\x02 \x01(\x0e\x32 .otg.IsisLspCapability.SBit.EnumH\x01\x88\x01\x01\x12\x34\n\x05\x64_bit\x18\x03 \x01(\x0e\x32 .otg.IsisLspCapability.DBit.EnumH\x02\x88\x01\x01\x12/\n\rsr_capability\x18\x04 \x01(\x0b\x32\x18.otg.IsisLspSRCapability\x12\x12\n\nalgorithms\x18\x05 \x03(\r\x12%\n\x0bsrlb_ranges\x18\x06 \x03(\x0b\x32\x10.otg.IsisLspSrlb\x1a\x39\n\x04SBit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lood\x10\x01\x12\r\n\tnot_flood\x10\x02\x1a\x37\n\x04\x44\x42it\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64own\x10\x01\x12\x0c\n\x08not_down\x10\x02\x42\x10\n\x0e_router_cap_idB\x08\n\x06_s_bitB\x08\n\x06_d_bit\"c\n\x13IsisLspSRCapability\x12%\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x16.otg.IsisLspCapasFlags\x12%\n\x0bsrgb_ranges\x18\x02 \x03(\x0b\x32\x10.otg.IsisLspSrgb\"_\n\x11IsisLspCapasFlags\x12\x16\n\tipv4_mpls\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tipv6_mpls\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0c\n\n_ipv4_mplsB\x0c\n\n_ipv6_mpls\"W\n\x0bIsisLspSrgb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"W\n\x0bIsisLspSrlb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"\xea\x01\n\x13IsisLspAdjacencySid\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\".otg.IsisLspAdjacencySid.Type.EnumH\x00\x88\x01\x01\x12\x0c\n\x04sids\x18\x02 \x03(\r\x12&\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x17.otg.IsisLspAdjSidFlags\x12\x13\n\x06weight\x18\x04 \x01(\rH\x01\x88\x01\x01\x1a=\n\x04Type\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07\x61\x64j_sid\x10\x01\x12\x0f\n\x0blan_adj_sid\x10\x02\x42\x07\n\x05_typeB\t\n\x07_weight\"\xd7\x01\n\x15IsisLspPrefixSidFlags\x12\x13\n\x06r_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06n_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06p_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06\x65_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06v_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06l_flag\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\t\n\x07_r_flagB\t\n\x07_n_flagB\t\n\x07_p_flagB\t\n\x07_e_flagB\t\n\x07_v_flagB\t\n\x07_l_flag\"\xd4\x01\n\x12IsisLspAdjSidFlags\x12\x13\n\x06\x66_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x62_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06v_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06l_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06s_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06p_flag\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\t\n\x07_f_flagB\t\n\x07_b_flagB\t\n\x07_v_flagB\t\n\x07_l_flagB\t\n\x07_s_flagB\t\n\x07_p_flag\"L\n\x19LldpNeighborsStateRequest\x12\x12\n\nlldp_names\x18\x01 \x03(\t\x12\x1b\n\x13neighbor_id_filters\x18\x02 \x03(\t\"\x8b\t\n\x12LldpNeighborsState\x12\x16\n\tlldp_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsystem_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12system_description\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nchassis_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12H\n\x0f\x63hassis_id_type\x18\x05 \x01(\x0e\x32*.otg.LldpNeighborsState.ChassisIdType.EnumH\x04\x88\x01\x01\x12\x18\n\x0bneighbor_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x10\n\x03\x61ge\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x18\n\x0blast_update\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x10\n\x03ttl\x18\t \x01(\rH\x08\x88\x01\x01\x12\x14\n\x07port_id\x18\n \x01(\tH\t\x88\x01\x01\x12\x42\n\x0cport_id_type\x18\x0b \x01(\x0e\x32\'.otg.LldpNeighborsState.PortIdType.EnumH\n\x88\x01\x01\x12\x1d\n\x10port_description\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x1f\n\x12management_address\x18\r \x01(\tH\x0c\x88\x01\x01\x12$\n\x17management_address_type\x18\x0e \x01(\tH\r\x88\x01\x01\x12,\n\x0b\x63ustom_tlvs\x18\x0f \x03(\x0b\x32\x17.otg.LldpCustomTLVState\x12.\n\x0c\x63\x61pabilities\x18\x10 \x03(\x0b\x32\x18.otg.LldpCapabilityState\x1a\xae\x01\n\rChassisIdType\"\x9c\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eport_component\x10\x01\x12\x13\n\x0fnetwork_address\x10\x02\x12\x15\n\x11\x63hassis_component\x10\x03\x12\x0f\n\x0bmac_address\x10\x04\x12\x12\n\x0einterface_name\x10\x05\x12\t\n\x05local\x10\x06\x12\x13\n\x0finterface_alias\x10\x07\x1a\xaa\x01\n\nPortIdType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eport_component\x10\x01\x12\x13\n\x0fnetwork_address\x10\x02\x12\x14\n\x10\x61gent_circuit_id\x10\x03\x12\x0f\n\x0bmac_address\x10\x04\x12\x12\n\x0einterface_name\x10\x05\x12\t\n\x05local\x10\x06\x12\x13\n\x0finterface_alias\x10\x07\x42\x0c\n\n_lldp_nameB\x0e\n\x0c_system_nameB\x15\n\x13_system_descriptionB\r\n\x0b_chassis_idB\x12\n\x10_chassis_id_typeB\x0e\n\x0c_neighbor_idB\x06\n\x04_ageB\x0e\n\x0c_last_updateB\x06\n\x04_ttlB\n\n\x08_port_idB\x0f\n\r_port_id_typeB\x13\n\x11_port_descriptionB\x15\n\x13_management_addressB\x1a\n\x18_management_address_type\"\xac\x01\n\x12LldpCustomTLVState\x12\x18\n\x0b\x63ustom_type\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03oui\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0boui_subtype\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0binformation\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x0e\n\x0c_custom_typeB\x06\n\x04_ouiB\x0e\n\x0c_oui_subtypeB\x0e\n\x0c_information\"\x90\x03\n\x13LldpCapabilityState\x12J\n\x0f\x63\x61pability_name\x18\x01 \x01(\x0e\x32,.otg.LldpCapabilityState.CapabilityName.EnumH\x00\x88\x01\x01\x12\x1f\n\x12\x63\x61pability_enabled\x18\x02 \x01(\x08H\x01\x88\x01\x01\x1a\xe0\x01\n\x0e\x43\x61pabilityName\"\xcd\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nmac_bridge\x10\x01\x12\x16\n\x12two_port_mac_relay\x10\x02\x12\x0c\n\x08repeater\x10\x03\x12\x17\n\x13\x64ocsis_cable_device\x10\x04\x12\n\n\x06s_vlan\x10\x05\x12\r\n\ttelephone\x10\x06\x12\t\n\x05other\x10\x07\x12\n\n\x06router\x10\x08\x12\n\n\x06\x63_vlan\x10\t\x12\x10\n\x0cstation_only\x10\n\x12\x15\n\x11wlan_access_point\x10\x0b\x42\x12\n\x10_capability_nameB\x15\n\x13_capability_enabled\"1\n\x14RsvpLspsStateRequest\x12\x19\n\x11rsvp_router_names\x18\x01 \x03(\t\"m\n\rRsvpLspsState\x12\x1d\n\x10rsvp_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\tipv4_lsps\x18\x02 \x03(\x0b\x32\x15.otg.RsvpIPv4LspStateB\x13\n\x11_rsvp_router_name\"\xe2\x01\n\x10RsvpIPv4LspState\x12\x1b\n\x0esource_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x64\x65stination_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x03lsp\x18\x03 \x01(\x0b\x32\x11.otg.RsvpLspState\x12!\n\x04rros\x18\x04 \x03(\x0b\x32\x13.otg.RsvpLspIpv4Rro\x12!\n\x04\x65ros\x18\x05 \x03(\x0b\x32\x13.otg.RsvpLspIpv4EroB\x11\n\x0f_source_addressB\x16\n\x14_destination_address\"\xb4\x04\n\x0cRsvpLspState\x12\x16\n\ttunnel_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06lsp_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0csession_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08label_in\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x16\n\tlabel_out\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x41\n\x0esession_status\x18\x06 \x01(\x0e\x32$.otg.RsvpLspState.SessionStatus.EnumH\x05\x88\x01\x01\x12\x44\n\x10last_flap_reason\x18\x07 \x01(\x0e\x32%.otg.RsvpLspState.LastFlapReason.EnumH\x06\x88\x01\x01\x12\x14\n\x07up_time\x18\x08 \x01(\x04H\x07\x88\x01\x01\x1a:\n\rSessionStatus\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1aY\n\x0eLastFlapReason\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tresv_tear\x10\x01\x12\r\n\tpath_tear\x10\x02\x12\x10\n\x0cpath_timeout\x10\x03\x42\x0c\n\n_tunnel_idB\t\n\x07_lsp_idB\x0f\n\r_session_nameB\x0b\n\t_label_inB\x0c\n\n_label_outB\x11\n\x0f_session_statusB\x13\n\x11_last_flap_reasonB\n\n\x08_up_time\"b\n\x0eRsvpLspIpv4Rro\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0ereported_label\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\n\n\x08_addressB\x11\n\x0f_reported_label\"\xf2\x01\n\x0eRsvpLspIpv4Ero\x12\x13\n\x06prefix\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03\x61sn\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x30\n\x04type\x18\x03 \x01(\x0e\x32\x1d.otg.RsvpLspIpv4Ero.Type.EnumH\x02\x88\x01\x01\x1ak\n\x04Type\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x07\n\x03\x61sn\x10\x03\x12\x08\n\x04\x61sn4\x10\x04\x12\t\n\x05label\x10\x05\x12\x18\n\x14unnumbered_interface\x10\x06\x42\t\n\x07_prefixB\x06\n\x04_asnB\x07\n\x05_type\"8\n\x1b\x44hcpv4InterfaceStateRequest\x12\x19\n\x11\x64hcp_client_names\x18\x01 \x03(\t\"\xd0\x02\n\x14\x44hcpv4InterfaceState\x12\x1d\n\x10\x64hcp_client_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1c\n\x0fgateway_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nlease_time\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x17\n\nrenew_time\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0brebind_time\x18\x07 \x01(\rH\x06\x88\x01\x01\x42\x13\n\x11_dhcp_client_nameB\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x12\n\x10_gateway_addressB\r\n\x0b_lease_timeB\r\n\x0b_renew_timeB\x0e\n\x0c_rebind_time\"4\n\x17\x44hcpv4LeaseStateRequest\x12\x19\n\x11\x64hcp_server_names\x18\x01 \x03(\t\"n\n\x11\x44hcpv4LeasesState\x12\x1d\n\x10\x64hcp_server_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12%\n\x06leases\x18\x02 \x03(\x0b\x32\x15.otg.Dhcpv4LeaseStateB\x13\n\x11_dhcp_server_name\"\xd2\x02\n\x10\x44hcpv4LeaseState\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nvalid_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0epreferred_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\nrenew_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0brebind_time\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x16\n\tclient_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\ncircuit_id\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tremote_id\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\n\n\x08_addressB\r\n\x0b_valid_timeB\x11\n\x0f_preferred_timeB\r\n\x0b_renew_timeB\x0e\n\x0c_rebind_timeB\x0c\n\n_client_idB\r\n\x0b_circuit_idB\x0c\n\n_remote_id\"8\n\x1b\x44hcpv6InterfaceStateRequest\x12\x19\n\x11\x64hcp_client_names\x18\x01 \x03(\t\"\xaa\x01\n\x14\x44hcpv6InterfaceState\x12\x1d\n\x10\x64hcp_client_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x30\n\x0eiapd_addresses\x18\x02 \x03(\x0b\x32\x18.otg.Dhcpv6InterfaceIapd\x12,\n\x0cia_addresses\x18\x03 \x03(\x0b\x32\x16.otg.Dhcpv6InterfaceIaB\x13\n\x11_dhcp_client_name\"\x8d\x01\n\x13\x44hcpv6InterfaceIapd\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x17\n\nlease_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\n\n\x08_addressB\x10\n\x0e_prefix_lengthB\r\n\x0b_lease_time\"\x7f\n\x11\x44hcpv6InterfaceIa\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07gateway\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlease_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\n\n\x08_addressB\n\n\x08_gatewayB\r\n\x0b_lease_time\"4\n\x17\x44hcpv6LeaseStateRequest\x12\x19\n\x11\x64hcp_server_names\x18\x01 \x03(\t\"t\n\x11\x44hcpv6LeasesState\x12\x1d\n\x10\x64hcp_server_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12+\n\x06leases\x18\x02 \x03(\x0b\x32\x1b.otg.Dhcpv6ServerLeaseStateB\x13\n\x11_dhcp_server_name\"\xdc\x02\n\x16\x44hcpv6ServerLeaseState\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nvalid_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0epreferred_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\nrenew_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0brebind_time\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x16\n\tclient_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tremote_id\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x19\n\x0cinterface_id\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\n\n\x08_addressB\r\n\x0b_valid_timeB\x11\n\x0f_preferred_timeB\r\n\x0b_renew_timeB\x0e\n\x0c_rebind_timeB\x0c\n\n_client_idB\x0c\n\n_remote_idB\x0f\n\r_interface_id\".\n\x16Ospfv2LsasStateRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\"\x86\x03\n\x0eOspfv2LsaState\x12\x18\n\x0brouter_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x0brouter_lsas\x18\x02 \x03(\x0b\x32\x14.otg.Ospfv2RouterLsa\x12+\n\x0cnetwork_lsas\x18\x03 \x03(\x0b\x32\x15.otg.Ospfv2NetworkLsa\x12:\n\x14network_summary_lsas\x18\x04 \x03(\x0b\x32\x1c.otg.Ospfv2NetworkSummaryLsa\x12\x30\n\x0fsummary_as_lsas\x18\x05 \x03(\x0b\x32\x17.otg.Ospfv2SummaryAsLsa\x12\x32\n\x10\x65xternal_as_lsas\x18\x06 \x03(\x0b\x32\x18.otg.Ospfv2ExternalAsLsa\x12%\n\tnssa_lsas\x18\x07 \x03(\x0b\x32\x12.otg.Ospfv2NssaLsa\x12)\n\x0bopaque_lsas\x18\x08 \x03(\x0b\x32\x14.otg.Ospfv2OpaqueLsaB\x0e\n\x0c_router_name\"W\n\x0fOspfv2RouterLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x1e\n\x05links\x18\x02 \x03(\x0b\x32\x0f.otg.Ospfv2Link\"\x81\x01\n\x10Ospfv2NetworkLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x13neighbor_router_ids\x18\x03 \x03(\tB\x0f\n\r_network_mask\"\x8b\x01\n\x17Ospfv2NetworkSummaryLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metric\"\x86\x01\n\x12Ospfv2SummaryAsLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metric\"\xb1\x01\n\x13Ospfv2ExternalAsLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bmetric_type\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metricB\x0e\n\x0c_metric_type\"\xe3\x01\n\rOspfv2NssaLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bmetric_type\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x1f\n\x12\x66orwarding_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metricB\x0e\n\x0c_metric_typeB\x15\n\x13_forwarding_address\"\xb5\x01\n\x0fOspfv2OpaqueLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32\x1e.otg.Ospfv2OpaqueLsa.Type.EnumH\x00\x88\x01\x01\x1a@\n\x04Type\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05local\x10\x01\x12\x08\n\x04\x61rea\x10\x02\x12\n\n\x06\x64omain\x10\x03\x42\x07\n\x05_type\"\xe5\x01\n\x0fOspfv2LsaHeader\x12\x13\n\x06lsa_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertising_router_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fsequence_number\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x10\n\x03\x61ge\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0boption_bits\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\t\n\x07_lsa_idB\x18\n\x16_advertising_router_idB\x12\n\x10_sequence_numberB\x06\n\x04_ageB\x0e\n\x0c_option_bits\"\xf0\x01\n\nOspfv2Link\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x19.otg.Ospfv2Link.Type.EnumH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04\x64\x61ta\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06metric\x18\x04 \x01(\rH\x03\x88\x01\x01\x1aW\n\x04Type\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0epoint_to_point\x10\x01\x12\x0b\n\x07transit\x10\x02\x12\x08\n\x04stub\x10\x03\x12\x0b\n\x07virtual\x10\x04\x42\x07\n\x05_typeB\x05\n\x03_idB\x07\n\x05_dataB\t\n\x07_metric\".\n\x16Ospfv3LsasStateRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\"\xd1\x03\n\x0eOspfv3LsaState\x12\x18\n\x0brouter_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x0brouter_lsas\x18\x02 \x03(\x0b\x32\x14.otg.Ospfv3RouterLsa\x12+\n\x0cnetwork_lsas\x18\x03 \x03(\x0b\x32\x15.otg.Ospfv3NetworkLsa\x12=\n\x16inter_area_prefix_lsas\x18\x04 \x03(\x0b\x32\x1d.otg.Ospfv3InterAreaPrefixLsa\x12=\n\x16inter_area_router_lsas\x18\x05 \x03(\x0b\x32\x1d.otg.Ospfv3InterAreaRouterLsa\x12\x32\n\x10\x65xternal_as_lsas\x18\x06 \x03(\x0b\x32\x18.otg.Ospfv3ExternalAsLsa\x12%\n\tnssa_lsas\x18\x07 \x03(\x0b\x32\x12.otg.Ospfv3NssaLsa\x12%\n\tlink_lsas\x18\x08 \x03(\x0b\x32\x12.otg.Ospfv3LinkLsa\x12=\n\x16intra_area_prefix_lsas\x18\t \x03(\x0b\x32\x1d.otg.Ospfv3IntraAreaPrefixLsaB\x0e\n\x0c_router_name\"\x8f\x01\n\x0fOspfv3RouterLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1f\n\x12neighbor_router_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x05links\x18\x03 \x03(\x0b\x32\x0f.otg.Ospfv3LinkB\x15\n\x13_neighbor_router_id\"U\n\x10Ospfv3NetworkLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1b\n\x13\x61ttached_router_ids\x18\x02 \x03(\t\"\xbe\x01\n\x18Ospfv3InterAreaPrefixLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1b\n\x0e\x61\x64\x64ress_prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\x11\n\x0f_address_prefixB\x10\n\x0e_prefix_lengthB\t\n\x07_metric\"\x9e\x01\n\x18Ospfv3InterAreaRouterLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x13\n\x06metric\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\"\n\x15\x64\x65stination_router_id\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_metricB\x18\n\x16_destination_router_id\"\xcf\x02\n\x13Ospfv3ExternalAsLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1b\n\x0e\x61\x64\x64ress_prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x1f\n\x12referenced_ls_type\x18\x05 \x01(\rH\x03\x88\x01\x01\x12\x1f\n\x12\x66orwarding_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x16\n\troute_tag\x18\x07 \x01(\tH\x05\x88\x01\x01\x42\x11\n\x0f_address_prefixB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x15\n\x13_referenced_ls_typeB\x15\n\x13_forwarding_addressB\x0c\n\n_route_tag\"\x91\x02\n\rOspfv3NssaLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1b\n\x0e\x61\x64\x64ress_prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x1f\n\x12\x66orwarding_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x16\n\troute_tag\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x11\n\x0f_address_prefixB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x15\n\x13_forwarding_addressB\x0c\n\n_route_tag\"\xcb\x01\n\rOspfv3LinkLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1b\n\x0e\x61\x64\x64ress_prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12link_local_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x11\n\x0f_address_prefixB\x10\n\x0e_prefix_lengthB\x15\n\x13_link_local_address\"\xbe\x01\n\x18Ospfv3IntraAreaPrefixLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv3LsaHeader\x12\x1b\n\x0e\x61\x64\x64ress_prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\x11\n\x0f_address_prefixB\x10\n\x0e_prefix_lengthB\t\n\x07_metric\"\xbb\x01\n\x0fOspfv3LsaHeader\x12\x13\n\x06lsa_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertising_router_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fsequence_number\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x10\n\x03\x61ge\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\t\n\x07_lsa_idB\x18\n\x16_advertising_router_idB\x12\n\x10_sequence_numberB\x06\n\x04_age\"\xbc\x01\n\nOspfv3Link\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x19.otg.Ospfv3Link.Type.EnumH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x02 \x01(\rH\x01\x88\x01\x01\x1aW\n\x04Type\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0epoint_to_point\x10\x01\x12\x0b\n\x07transit\x10\x02\x12\x08\n\x04stub\x10\x03\x12\x0b\n\x07virtual\x10\x04\x42\x07\n\x05_typeB\t\n\x07_metric\"1\n\x14IsisIIHsStateRequest\x12\x19\n\x11isis_router_names\x18\x01 \x03(\t\"\x7f\n\rIsisIIHsState\x12\x1d\n\x10isis_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12:\n\x10\x61\x64jacency_states\x18\x02 \x03(\x0b\x32 .otg.IsisLocalIIHAdjacencyStatesB\x13\n\x11_isis_router_name\"\xe5\x01\n\x1bIsisLocalIIHAdjacencyStates\x12\x1f\n\x12neighbor_system_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0einterface_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12+\n\x0blocal_state\x18\x03 \x01(\x0b\x32\x16.otg.IsisLocalIIHState\x12\x31\n\x0eneighbor_state\x18\x04 \x01(\x0b\x32\x19.otg.IsisNeighborIIHStateB\x15\n\x13_neighbor_system_idB\x11\n\x0f_interface_name\"\x94\x02\n\x11IsisLocalIIHState\x12>\n\nlevel_type\x18\x01 \x01(\x0e\x32%.otg.IsisLocalIIHState.LevelType.EnumH\x00\x88\x01\x01\x12\x17\n\nhold_timer\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x39\n\x11restarting_status\x18\x03 \x01(\x0b\x32\x1e.otg.IsisIIHLocalRestartStatus\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\r\n\x0b_level_typeB\r\n\x0b_hold_timer\"\xc5\x02\n\x14IsisNeighborIIHState\x12\x41\n\nlevel_type\x18\x01 \x01(\x0e\x32(.otg.IsisNeighborIIHState.LevelType.EnumH\x00\x88\x01\x01\x12\x17\n\nhold_timer\x18\x02 \x01(\rH\x01\x88\x01\x01\x12<\n\x11restarting_status\x18\x03 \x01(\x0b\x32!.otg.IsisIIHNeighborRestartStatus\x12&\n\x04tlvs\x18\x04 \x01(\x0b\x32\x18.otg.IsisIIHNeighborTlvs\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\r\n\x0b_level_typeB\r\n\x0b_hold_timer\"\xf4\x01\n\x19IsisIIHLocalRestartStatus\x12=\n\x05state\x18\x01 \x01(\x0e\x32).otg.IsisIIHLocalRestartStatus.State.EnumH\x00\x88\x01\x01\x12\x41\n\x13last_attempt_status\x18\x02 \x01(\x0b\x32$.otg.IsisIIHLocalGRLastAttemptStatus\x1aK\n\x05State\"B\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07running\x10\x01\x12\x0c\n\x08starting\x10\x02\x12\x0e\n\nrestarting\x10\x03\x42\x08\n\x06_state\"\xfd\x01\n\x1cIsisIIHNeighborRestartStatus\x12@\n\x05state\x18\x01 \x01(\x0e\x32,.otg.IsisIIHNeighborRestartStatus.State.EnumH\x00\x88\x01\x01\x12\x44\n\x13last_attempt_status\x18\x02 \x01(\x0b\x32\'.otg.IsisIIHNeighborGRLastAttemptStatus\x1aK\n\x05State\"B\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07running\x10\x01\x12\x0c\n\x08starting\x10\x02\x12\x0e\n\nrestarting\x10\x03\x42\x08\n\x06_state\"\xc4\x02\n\x1fIsisIIHLocalGRLastAttemptStatus\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.IsisIIHLocalGRLastAttemptStatus.Choice.EnumH\x00\x88\x01\x01\x12:\n\tsucceeded\x18\x02 \x01(\x0b\x32\'.otg.IsisIIHLocalGRLastAttemptSucceeded\x12\x34\n\x06\x66\x61iled\x18\x03 \x01(\x0b\x32$.otg.IsisIIHLocalGRLastAttemptFailed\x1a]\n\x06\x43hoice\"S\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\x12\x0e\n\ninprogress\x10\x03\x12\x0f\n\x0bunavailable\x10\x04\x42\t\n\x07_choice\"A\n\x1fIsisIIHLocalGRLastAttemptFailed\x12\x13\n\x06reason\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_reason\"\x9a\x01\n\"IsisIIHLocalGRLastAttemptSucceeded\x12\x1d\n\x10lsdb_syncup_time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12$\n\x17\x61\x64jacency_bring_up_time\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x13\n\x11_lsdb_syncup_timeB\x1a\n\x18_adjacency_bring_up_time\"\xd0\x02\n\"IsisIIHNeighborGRLastAttemptStatus\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.IsisIIHNeighborGRLastAttemptStatus.Choice.EnumH\x00\x88\x01\x01\x12=\n\tsucceeded\x18\x02 \x01(\x0b\x32*.otg.IsisIIHNeighborGRLastAttemptSucceeded\x12\x37\n\x06\x66\x61iled\x18\x03 \x01(\x0b\x32\'.otg.IsisIIHNeighborGRLastAttemptFailed\x1a]\n\x06\x43hoice\"S\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\x12\x0e\n\ninprogress\x10\x03\x12\x0f\n\x0bunavailable\x10\x04\x42\t\n\x07_choice\"D\n\"IsisIIHNeighborGRLastAttemptFailed\x12\x13\n\x06reason\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_reason\"i\n%IsisIIHNeighborGRLastAttemptSucceeded\x12$\n\x17\x61\x64jacency_bring_up_time\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x1a\n\x18_adjacency_bring_up_time\"B\n\x13IsisIIHNeighborTlvs\x12+\n\x0brestart_tlv\x18\x01 \x01(\x0b\x32\x16.otg.IsisIIHRestartTlv\"\xac\x01\n\x11IsisIIHRestartTlv\x12\'\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x18.otg.IsisIIHRestartFlags\x12\x1b\n\x0eremaining_time\x18\x02 \x01(\rH\x00\x88\x01\x01\x12#\n\x16restarting_neighbor_id\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x11\n\x0f_remaining_timeB\x19\n\x17_restarting_neighbor_id\"\xb5\x01\n\x13IsisIIHRestartFlags\x12\x13\n\x06rr_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06ra_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06sa_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06pr_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06pa_bit\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_rr_bitB\t\n\x07_ra_bitB\t\n\x07_sa_bitB\t\n\x07_pr_bitB\t\n\x07_pa_bit\"c\n\x0e\x43\x61ptureRequest\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12+\n\x07packets\x18\x02 \x01(\x0b\x32\x1a.otg.CaptureRequestPacketsB\x0c\n\n_port_name\"\xc6\x01\n\x15\x43\x61ptureRequestPackets\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.CaptureRequestPackets.Choice.EnumH\x00\x88\x01\x01\x12.\n\x05slice\x18\x02 \x01(\x0b\x32\x1f.otg.CaptureRequestCaptureSlice\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\t\n\x05slice\x10\x02\x42\t\n\x07_choice\"\xd2\x01\n\x1a\x43\x61ptureRequestCaptureSlice\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.CaptureRequestCaptureSlice.Choice.EnumH\x00\x88\x01\x01\x12\x37\n\x07initial\x18\x02 \x01(\x0b\x32&.otg.CaptureRequestCaptureSliceInitial\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07initial\x10\x01\x42\t\n\x07_choice\"_\n!CaptureRequestCaptureSliceInitial\x12\x12\n\x05start\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x02 \x01(\x04H\x01\x88\x01\x01\x42\x08\n\x06_startB\x08\n\x06_count\"w\n\x1dPatternFlowEthernetDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowEthernetDstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowEthernetDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x11\n\x04\x61uto\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x35\n\tincrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounter\x12\x35\n\tdecrement\x18\x07 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounter\x12\x39\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32$.otg.PatternFlowEthernetDstMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"w\n\x1dPatternFlowEthernetSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowEthernetSrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowEthernetSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowEthernetSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowEthernetEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowEthernetEtherTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowEthernetEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounter\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounter\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowEthernetEtherTypeMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"|\n\"PatternFlowEthernetPfcQueueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowEthernetPfcQueueMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowEthernetPfcQueue\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPfcQueue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPfcQueueMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowVlanPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowVlanPriorityMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowVlanPriority\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowVlanPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowVlanPriorityMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowVlanCfiCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowVlanCfiMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xfc\x02\n\x12PatternFlowVlanCfi\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowVlanCfi.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowVlanCfiMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"r\n\x18PatternFlowVlanIdCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"x\n\x1aPatternFlowVlanIdMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xf7\x02\n\x11PatternFlowVlanId\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.PatternFlowVlanId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x30\n\tincrement\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounter\x12\x30\n\tdecrement\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounter\x12\x34\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x1f.otg.PatternFlowVlanIdMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"t\n\x1aPatternFlowVlanTpidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n\x1cPatternFlowVlanTpidMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x81\x03\n\x13PatternFlowVlanTpid\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVlanTpid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x32\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounter\x12\x32\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounter\x12\x36\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32!.otg.PatternFlowVlanTpidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowVxlanFlagsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowVxlanFlagsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowVxlanFlags\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowVxlanFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowVxlanFlagsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowVxlanReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowVxlanReserved0MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowVxlanReserved0\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0Counter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0Counter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowVxlanReserved0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"t\n\x1aPatternFlowVxlanVniCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n\x1cPatternFlowVxlanVniMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x13PatternFlowVxlanVni\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVxlanVni.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x32\n\tincrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounter\x12\x32\n\tdecrement\x18\x07 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounter\x12\x36\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32!.otg.PatternFlowVxlanVniMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"z\n PatternFlowVxlanReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowVxlanReserved1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowVxlanReserved1\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1Counter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1Counter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowVxlanReserved1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv4VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv4VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv4Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowIpv4HeaderLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowIpv4HeaderLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowIpv4HeaderLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4HeaderLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12:\n\tincrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounter\x12:\n\tdecrement\x18\x07 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounter\x12>\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32).otg.PatternFlowIpv4HeaderLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"{\n!PatternFlowIpv4TotalLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowIpv4TotalLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowIpv4TotalLength\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TotalLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounter\x12\x39\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounter\x12=\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32(.otg.PatternFlowIpv4TotalLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"~\n$PatternFlowIpv4IdentificationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIpv4IdentificationMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIpv4Identification\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4Identification.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4IdentificationMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv4ReservedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIpv4Reserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv4ReservedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowIpv4DontFragmentCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowIpv4DontFragmentMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowIpv4DontFragment\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4DontFragment.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowIpv4DontFragmentMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv4MoreFragmentsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv4MoreFragmentsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowIpv4MoreFragments\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4MoreFragments.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4MoreFragmentsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowIpv4FragmentOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIpv4FragmentOffsetMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIpv4FragmentOffset\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4FragmentOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4FragmentOffsetMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowIpv4TimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIpv4TimeToLiveMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowIpv4TimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv4TimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIpv4TimeToLiveMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIpv4ProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv4ProtocolMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIpv4Protocol\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Protocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounter\x12\x36\n\tdecrement\x18\x07 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounter\x12:\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32%.otg.PatternFlowIpv4ProtocolMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"\xdf\x02\n\x1dPatternFlowIpv4HeaderChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4HeaderChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIpv4HeaderChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"s\n\x19PatternFlowIpv4SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv4SrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x88\x01\n\x18PatternFlowIpv4SrcRandom\x12\x10\n\x03min\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xe2\x03\n\x12PatternFlowIpv4Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv4SrcMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv4Auto\x12-\n\x06random\x18\t \x01(\x0b\x32\x1d.otg.PatternFlowIpv4SrcRandom\x1al\n\x06\x43hoice\"b\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowIpv4DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv4DstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x88\x01\n\x18PatternFlowIpv4DstRandom\x12\x10\n\x03min\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xe2\x03\n\x12PatternFlowIpv4Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv4DstMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv4Auto\x12-\n\x06random\x18\t \x01(\x0b\x32\x1d.otg.PatternFlowIpv4DstRandom\x1al\n\x06\x43hoice\"b\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8b\x01\n1PatternFlowIpv4OptionsCustomTypeCopiedFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa5\x03\n*PatternFlowIpv4OptionsCustomTypeCopiedFlag\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlagCounter\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlagCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8c\x01\n2PatternFlowIpv4OptionsCustomTypeOptionClassCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa9\x03\n+PatternFlowIpv4OptionsCustomTypeOptionClass\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.PatternFlowIpv4OptionsCustomTypeOptionClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x37.otg.PatternFlowIpv4OptionsCustomTypeOptionClassCounter\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x37.otg.PatternFlowIpv4OptionsCustomTypeOptionClassCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowIpv4OptionsCustomTypeOptionNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowIpv4OptionsCustomTypeOptionNumber\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowIpv4OptionsCustomTypeOptionNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowIpv4OptionsCustomTypeOptionNumberCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowIpv4OptionsCustomTypeOptionNumberCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowIpv4PriorityRawCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowIpv4PriorityRawMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowIpv4PriorityRaw\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4PriorityRaw.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowIpv4PriorityRawMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv4DscpPhbCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv4DscpPhbMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv4DscpPhb\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpPhb.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4DscpPhbMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv4DscpEcnCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv4DscpEcnMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv4DscpEcn\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpEcn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4DscpEcnMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv4TosPrecedenceCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv4TosPrecedenceMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowIpv4TosPrecedence\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosPrecedence.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4TosPrecedenceMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIpv4TosDelayCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv4TosDelayMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIpv4TosDelay\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4TosDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv4TosDelayMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv4TosThroughputCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv4TosThroughputMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowIpv4TosThroughput\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosThroughput.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4TosThroughputMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowIpv4TosReliabilityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIpv4TosReliabilityMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIpv4TosReliability\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4TosReliability.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4TosReliabilityMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowIpv4TosMonetaryCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowIpv4TosMonetaryMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowIpv4TosMonetary\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TosMonetary.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowIpv4TosMonetaryMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowIpv4TosUnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowIpv4TosUnusedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowIpv4TosUnused\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv4TosUnused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIpv4TosUnusedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv6VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv6VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv6Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv6Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv6VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowIpv6TrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowIpv6TrafficClassMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowIpv6TrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv6TrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowIpv6TrafficClassMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowIpv6FlowLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowIpv6FlowLabelMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8e\x01\n\x1ePatternFlowIpv6FlowLabelRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xdb\x03\n\x18PatternFlowIpv6FlowLabel\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv6FlowLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIpv6FlowLabelMetricTag\x12\x33\n\x06random\x18\x08 \x01(\x0b\x32#.otg.PatternFlowIpv6FlowLabelRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv6PayloadLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv6PayloadLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowIpv6PayloadLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv6PayloadLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounter\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounter\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowIpv6PayloadLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"z\n PatternFlowIpv6NextHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIpv6NextHeaderMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowIpv6NextHeader\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv6NextHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounter\x12\x38\n\tdecrement\x18\x07 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounter\x12<\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32\'.otg.PatternFlowIpv6NextHeaderMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"x\n\x1ePatternFlowIpv6HopLimitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv6HopLimitMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIpv6HopLimit\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv6HopLimit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv6HopLimitMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowIpv6SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv6SrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x12PatternFlowIpv6Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv6SrcMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv6Auto\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowIpv6DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv6DstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x12PatternFlowIpv6Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv6DstMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv6Auto\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowPfcPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowPfcPauseDstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowPfcPauseDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowPfcPauseDstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowPfcPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowPfcPauseSrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowPfcPauseSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowPfcPauseSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowPfcPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowPfcPauseEtherTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowPfcPauseEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowPfcPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowPfcPauseEtherTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowPfcPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowPfcPauseControlOpCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowPfcPauseControlOpCode\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowPfcPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowPfcPauseControlOpCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowPfcPauseClassEnableVectorCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8b\x01\n-PatternFlowPfcPauseClassEnableVectorMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd6\x03\n$PatternFlowPfcPauseClassEnableVector\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowPfcPauseClassEnableVector.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounter\x12G\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x32.otg.PatternFlowPfcPauseClassEnableVectorMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass0Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass0MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass0\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass1\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass2Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass2MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass2\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass2MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass3Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass3MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass3\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass3.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass3MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass4Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass4MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass4\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass4MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass5Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass5MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass5\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass5.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass5MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass6Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass6MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass6\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass6.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass6MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass7Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass7MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass7\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass7.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass7MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowEthernetPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowEthernetPauseDstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowEthernetPauseDst\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPauseDstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowEthernetPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowEthernetPauseSrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowEthernetPauseSrc\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPauseSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowEthernetPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x88\x01\n*PatternFlowEthernetPauseEtherTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc7\x03\n!PatternFlowEthernetPauseEtherType\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowEthernetPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounter\x12\x44\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32/.otg.PatternFlowEthernetPauseEtherTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x86\x01\n,PatternFlowEthernetPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8c\x01\n.PatternFlowEthernetPauseControlOpCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xdb\x03\n%PatternFlowEthernetPauseControlOpCode\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowEthernetPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounter\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounter\x12H\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x33.otg.PatternFlowEthernetPauseControlOpCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowEthernetPauseTimeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowEthernetPauseTimeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowEthernetPauseTime\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetPauseTime.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowEthernetPauseTimeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowTcpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowTcpSrcPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowTcpSrcPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowTcpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpSrcPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowTcpSrcPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowTcpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowTcpDstPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowTcpDstPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowTcpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpDstPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowTcpDstPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpSeqNumCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpSeqNumMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpSeqNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpSeqNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpSeqNumMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpAckNumCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpAckNumMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpAckNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpAckNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpAckNumMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowTcpDataOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowTcpDataOffsetMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowTcpDataOffset\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowTcpDataOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowTcpDataOffsetMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"t\n\x1aPatternFlowTcpEcnNsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n\x1cPatternFlowTcpEcnNsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x81\x03\n\x13PatternFlowTcpEcnNs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowTcpEcnNs.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x32\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounter\x12\x32\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounter\x12\x36\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32!.otg.PatternFlowTcpEcnNsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpEcnCwrCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpEcnCwrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpEcnCwr\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpEcnCwr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpEcnCwrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowTcpEcnEchoCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowTcpEcnEchoMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowTcpEcnEcho\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpEcnEcho.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpEcnEchoMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlUrgCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlUrgMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlUrg\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlUrg.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlUrgMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlAckCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlAckMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlAck\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlAck.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlAckMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlPshCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlPshMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlPsh\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlPsh.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlPshMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlRstCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlRstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlRst\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlRst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlRstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlSynCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlSynMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlSyn\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlSyn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlSynMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlFinCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlFinMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlFin\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlFin.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlFinMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpWindowCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpWindowMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpWindow\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpWindow.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpWindowMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xca\x02\n\x16PatternFlowTcpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowTcpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowTcpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowUdpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowUdpSrcPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowUdpSrcPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowUdpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowUdpSrcPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowUdpSrcPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowUdpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowUdpDstPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowUdpDstPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowUdpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowUdpDstPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowUdpDstPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowUdpLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowUdpLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowUdpLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowUdpLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowUdpLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xca\x02\n\x16PatternFlowUdpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowUdpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowUdpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowGreChecksumPresentCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGreChecksumPresentMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGreChecksumPresent\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGreChecksumPresent.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGreChecksumPresentMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowGreReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGreReserved0MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGreReserved0\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved0Counter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved0Counter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGreReserved0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowGreVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowGreVersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowGreVersion\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGreVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGreVersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGreProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGreProtocolMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowGreProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGreProtocolMetricTag\x12\x11\n\x04\x61uto\x18\x08 \x01(\rH\x02\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"\xca\x02\n\x16PatternFlowGreChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowGreChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"x\n\x1ePatternFlowGreReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGreReserved1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGreReserved1\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved1Counter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved1Counter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGreReserved1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowGtpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGtpv1VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGtpv1Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGtpv1VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowGtpv1ProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowGtpv1ProtocolTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowGtpv1ProtocolType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowGtpv1ProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowGtpv1ProtocolTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowGtpv1ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowGtpv1ReservedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowGtpv1Reserved\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv1Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowGtpv1ReservedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowGtpv1EFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowGtpv1EFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowGtpv1EFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1EFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGtpv1EFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowGtpv1SFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowGtpv1SFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowGtpv1SFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1SFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGtpv1SFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGtpv1PnFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGtpv1PnFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowGtpv1PnFlag\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv1PnFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv1PnFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowGtpv1MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowGtpv1MessageTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowGtpv1MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv1MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowGtpv1MessageTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowGtpv1MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGtpv1MessageLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGtpv1MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv1MessageLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowGtpv1TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowGtpv1TeidMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowGtpv1Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv1Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowGtpv1TeidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowGtpv1SquenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGtpv1SquenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGtpv1SquenceNumber\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1SquenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv1SquenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowGtpv1NPduNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowGtpv1NPduNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowGtpv1NPduNumber\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowGtpv1NPduNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowGtpv1NPduNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8e\x01\n0PatternFlowGtpv1NextExtensionHeaderTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xe5\x03\n\'PatternFlowGtpv1NextExtensionHeaderType\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowGtpv1NextExtensionHeaderType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12J\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x35.otg.PatternFlowGtpv1NextExtensionHeaderTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x87\x01\n-PatternFlowGtpExtensionExtensionLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x01\n/PatternFlowGtpExtensionExtensionLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xe0\x03\n&PatternFlowGtpExtensionExtensionLength\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowGtpExtensionExtensionLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounter\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounter\x12I\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x34.otg.PatternFlowGtpExtensionExtensionLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowGtpExtensionContentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x86\x01\n(PatternFlowGtpExtensionContentsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xbd\x03\n\x1fPatternFlowGtpExtensionContents\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowGtpExtensionContents.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x04\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounter\x12\x42\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32-.otg.PatternFlowGtpExtensionContentsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8b\x01\n1PatternFlowGtpExtensionNextExtensionHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x91\x01\n3PatternFlowGtpExtensionNextExtensionHeaderMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xf4\x03\n*PatternFlowGtpExtensionNextExtensionHeader\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowGtpExtensionNextExtensionHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounter\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounter\x12M\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x38.otg.PatternFlowGtpExtensionNextExtensionHeaderMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowGtpv2VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGtpv2VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGtpv2Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv2Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGtpv2VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowGtpv2PiggybackingFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowGtpv2PiggybackingFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowGtpv2PiggybackingFlag\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowGtpv2PiggybackingFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowGtpv2PiggybackingFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowGtpv2TeidFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowGtpv2TeidFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowGtpv2TeidFlag\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv2TeidFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowGtpv2TeidFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGtpv2Spare1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGtpv2Spare1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowGtpv2Spare1\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1Counter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1Counter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv2Spare1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowGtpv2MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowGtpv2MessageTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowGtpv2MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv2MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowGtpv2MessageTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowGtpv2MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGtpv2MessageLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGtpv2MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv2MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv2MessageLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowGtpv2TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowGtpv2TeidMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowGtpv2Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv2Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowGtpv2TeidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowGtpv2SequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowGtpv2SequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowGtpv2SequenceNumber\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowGtpv2SequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowGtpv2SequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGtpv2Spare2Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGtpv2Spare2MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowGtpv2Spare2\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2Counter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2Counter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv2Spare2MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowArpHardwareTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowArpHardwareTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowArpHardwareType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpHardwareType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowArpHardwareTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowArpProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowArpProtocolTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowArpProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowArpProtocolTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowArpHardwareLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowArpHardwareLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowArpHardwareLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpHardwareLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowArpHardwareLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowArpProtocolLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowArpProtocolLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowArpProtocolLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpProtocolLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowArpProtocolLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowArpOperationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowArpOperationMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowArpOperation\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowArpOperation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowArpOperationMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpSenderHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpSenderHardwareAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpSenderHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpSenderHardwareAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpSenderProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpSenderProtocolAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpSenderProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpSenderProtocolAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpTargetHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpTargetHardwareAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpTargetHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpTargetHardwareAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpTargetProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpTargetProtocolAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpTargetProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpTargetProtocolAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIcmpEchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIcmpEchoTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIcmpEchoType\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIcmpEchoTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIcmpEchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIcmpEchoCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIcmpEchoCode\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIcmpEchoCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xd9\x02\n\x1bPatternFlowIcmpEchoChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIcmpEchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowIcmpEchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIcmpEchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIcmpEchoIdentifierMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIcmpEchoIdentifier\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpEchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIcmpEchoIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowIcmpEchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x88\x01\n*PatternFlowIcmpEchoSequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc7\x03\n!PatternFlowIcmpEchoSequenceNumber\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowIcmpEchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounter\x12\x44\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32/.otg.PatternFlowIcmpEchoSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xdf\x02\n\x1dPatternFlowIcmpCommonChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpCommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpCommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\x84\x01\n*PatternFlowIcmpNextFieldsIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8a\x01\n,PatternFlowIcmpNextFieldsIdentifierMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd1\x03\n#PatternFlowIcmpNextFieldsIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpNextFieldsIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounter\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounter\x12\x46\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x31.otg.PatternFlowIcmpNextFieldsIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8e\x01\n0PatternFlowIcmpNextFieldsSequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xe5\x03\n\'PatternFlowIcmpNextFieldsSequenceNumber\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12J\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x35.otg.PatternFlowIcmpNextFieldsSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowIcmpv6EchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIcmpv6EchoTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowIcmpv6EchoType\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIcmpv6EchoTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowIcmpv6EchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIcmpv6EchoCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowIcmpv6EchoCode\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIcmpv6EchoCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowIcmpv6EchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x86\x01\n(PatternFlowIcmpv6EchoIdentifierMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xbd\x03\n\x1fPatternFlowIcmpv6EchoIdentifier\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6EchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounter\x12\x42\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32-.otg.PatternFlowIcmpv6EchoIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x84\x01\n*PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8a\x01\n,PatternFlowIcmpv6EchoSequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd1\x03\n#PatternFlowIcmpv6EchoSequenceNumber\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpv6EchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x46\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x31.otg.PatternFlowIcmpv6EchoSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xdf\x02\n\x1dPatternFlowIcmpv6EchoChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpv6EchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpv6EchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\xe5\x02\n\x1fPatternFlowIcmpv6CommonChecksum\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6CommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12K\n\tgenerated\x18\x02 \x01(\x0e\x32\x33.otg.PatternFlowIcmpv6CommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowPppAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowPppAddressMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowPppAddress\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowPppAddressMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowPppControlCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowPppControlMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowPppControl\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppControl.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppControlCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppControlCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowPppControlMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowPppProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowPppProtocolTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowPppProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowPppProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounter\x12\x39\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounter\x12=\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32(.otg.PatternFlowPppProtocolTypeMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"y\n\x1fPatternFlowIgmpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowIgmpv1VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowIgmpv1Version\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIgmpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIgmpv1VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowIgmpv1TypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowIgmpv1TypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowIgmpv1Type\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowIgmpv1Type.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowIgmpv1TypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIgmpv1UnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIgmpv1UnusedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIgmpv1Unused\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIgmpv1Unused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIgmpv1UnusedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xd3\x02\n\x19PatternFlowIgmpv1Checksum\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIgmpv1Checksum.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\tgenerated\x18\x02 \x01(\x0e\x32-.otg.PatternFlowIgmpv1Checksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIgmpv1GroupAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIgmpv1GroupAddressMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIgmpv1GroupAddress\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIgmpv1GroupAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIgmpv1GroupAddressMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowMplsLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowMplsLabelMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowMplsLabel\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowMplsLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x33\n\tincrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounter\x12\x33\n\tdecrement\x18\x07 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounter\x12\x37\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32\".otg.PatternFlowMplsLabelMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"|\n\"PatternFlowMplsTrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowMplsTrafficClassMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowMplsTrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowMplsTrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowMplsTrafficClassMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowMplsBottomOfStackCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowMplsBottomOfStackMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowMplsBottomOfStack\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowMplsBottomOfStack.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounter\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounter\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowMplsBottomOfStackMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"z\n PatternFlowMplsTimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowMplsTimeToLiveMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowMplsTimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowMplsTimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowMplsTimeToLiveMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowSnmpv2cVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x02\n\x19PatternFlowSnmpv2cVersion\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowSnmpv2cVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowSnmpv2cVersionCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowSnmpv2cVersionCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowSnmpv2cPDURequestIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf5\x02\n\x1ePatternFlowSnmpv2cPDURequestId\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowSnmpv2cPDURequestId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowSnmpv2cPDURequestIdCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowSnmpv2cPDURequestIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowSnmpv2cPDUErrorIndexCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf9\x02\n\x1fPatternFlowSnmpv2cPDUErrorIndex\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowSnmpv2cPDUErrorIndex.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowSnmpv2cPDUErrorIndexCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowSnmpv2cPDUErrorIndexCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowSnmpv2cBulkPDURequestIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowSnmpv2cBulkPDURequestId\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowSnmpv2cBulkPDURequestId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowSnmpv2cBulkPDURequestIdCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowSnmpv2cBulkPDURequestIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xe7\x01\n%PatternFlowSnmpv2cBulkPDUNonRepeaters\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowSnmpv2cBulkPDUNonRepeaters.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowSnmpv2cBulkPDUMaxRepetitionsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x99\x03\n\'PatternFlowSnmpv2cBulkPDUMaxRepetitions\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitions.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitionsCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitionsCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowSnmpv2cVariableBindingValueIntegerValueCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowSnmpv2cVariableBindingValueIntegerValue\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValueCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x95\x01\n;PatternFlowSnmpv2cVariableBindingValueIpAddressValueCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n4PatternFlowSnmpv2cVariableBindingValueIpAddressValue\x12Z\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x45.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12S\n\tincrement\x18\x05 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValueCounter\x12S\n\tdecrement\x18\x06 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowSnmpv2cVariableBindingValueCounterValueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowSnmpv2cVariableBindingValueCounterValue\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowSnmpv2cVariableBindingValueCounterValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueCounterValueCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueCounterValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x95\x01\n;PatternFlowSnmpv2cVariableBindingValueTimeticksValueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n4PatternFlowSnmpv2cVariableBindingValueTimeticksValue\x12Z\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x45.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12S\n\tincrement\x18\x05 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValueCounter\x12S\n\tdecrement\x18\x06 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x96\x01\n<PatternFlowSnmpv2cVariableBindingValueBigCounterValueCounter\x12\x12\n\x05start\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n5PatternFlowSnmpv2cVariableBindingValueBigCounterValue\x12[\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x46.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x04\x12T\n\tincrement\x18\x05 \x01(\x0b\x32\x41.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValueCounter\x12T\n\tdecrement\x18\x06 \x01(\x0b\x32\x41.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9b\x01\nAPatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n:PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValue\x12`\n\x06\x63hoice\x18\x01 \x01(\x0e\x32K.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Y\n\tincrement\x18\x05 \x01(\x0b\x32\x46.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValueCounter\x12Y\n\tdecrement\x18\x06 \x01(\x0b\x32\x46.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowSnmpv2cCommonRequestIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x03\n!PatternFlowSnmpv2cCommonRequestId\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowSnmpv2cCommonRequestId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowSnmpv2cCommonRequestIdCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowSnmpv2cCommonRequestIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xd9\x02\n\x1bPatternFlowRsvpRsvpChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowRsvpRsvpChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowRsvpRsvpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"z\n PatternFlowRsvpTimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x02\n\x19PatternFlowRsvpTimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowRsvpTimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowRsvpTimeToLiveCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowRsvpTimeToLiveCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowRsvpReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd9\x02\n\x17PatternFlowRsvpReserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowRsvpReserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowRsvpReservedCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowRsvpReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xa1\x01\nGPatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x03\n@PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddress\x12\x66\n\x06\x63hoice\x18\x01 \x01(\x0e\x32Q.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12_\n\tincrement\x18\x05 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddressCounter\x12_\n\tdecrement\x18\x06 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x90\x01\n6PatternFlowRSVPPathSessionLspTunnelIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb9\x03\n/PatternFlowRSVPPathSessionLspTunnelIpv4Reserved\x12U\n\x06\x63hoice\x18\x01 \x01(\x0e\x32@.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12N\n\tincrement\x18\x05 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4ReservedCounter\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4ReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x90\x01\n6PatternFlowRSVPPathSessionLspTunnelIpv4TunnelIdCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb9\x03\n/PatternFlowRSVPPathSessionLspTunnelIpv4TunnelId\x12U\n\x06\x63hoice\x18\x01 \x01(\x0e\x32@.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12N\n\tincrement\x18\x05 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelIdCounter\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8f\x01\n5PatternFlowRSVPPathSessionExtTunnelIdAsIntegerCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb5\x03\n.PatternFlowRSVPPathSessionExtTunnelIdAsInteger\x12T\n\x06\x63hoice\x18\x01 \x01(\x0e\x32?.otg.PatternFlowRSVPPathSessionExtTunnelIdAsInteger.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12M\n\tincrement\x18\x05 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIntegerCounter\x12M\n\tdecrement\x18\x06 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIntegerCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8c\x01\n2PatternFlowRSVPPathSessionExtTunnelIdAsIpv4Counter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa9\x03\n+PatternFlowRSVPPathSessionExtTunnelIdAsIpv4\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4Counter\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4Counter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8a\x01\n0PatternFlowRSVPPathRsvpHopIpv4Ipv4AddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa1\x03\n)PatternFlowRSVPPathRsvpHopIpv4Ipv4Address\x12O\n\x06\x63hoice\x18\x01 \x01(\x0e\x32:.otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4Address.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12H\n\tincrement\x18\x05 \x01(\x0b\x32\x35.otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4AddressCounter\x12H\n\tdecrement\x18\x06 \x01(\x0b\x32\x35.otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4AddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x95\x01\n;PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandleCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n4PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandle\x12Z\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x45.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandle.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12S\n\tincrement\x18\x05 \x01(\x0b\x32@.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandleCounter\x12S\n\tdecrement\x18\x06 \x01(\x0b\x32@.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandleCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x91\x01\n7PatternFlowRSVPPathTimeValuesType1RefreshPeriodRCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbd\x03\n0PatternFlowRSVPPathTimeValuesType1RefreshPeriodR\x12V\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x41.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodR.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12O\n\tincrement\x18\x05 \x01(\x0b\x32<.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodRCounter\x12O\n\tdecrement\x18\x06 \x01(\x0b\x32<.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodRCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x94\x01\n:PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc9\x03\n3PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBit\x12Y\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x44.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12R\n\tincrement\x18\x05 \x01(\x0b\x32?.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBitCounter\x12R\n\tdecrement\x18\x06 \x01(\x0b\x32?.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9b\x01\nAPatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4AddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n:PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4Address\x12`\n\x06\x63hoice\x18\x01 \x01(\x0e\x32K.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4Address.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12Y\n\tincrement\x18\x05 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4AddressCounter\x12Y\n\tdecrement\x18\x06 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4AddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x92\x01\n8PatternFlowRSVPPathExplicitRouteType1ASNumberLBitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc1\x03\n1PatternFlowRSVPPathExplicitRouteType1ASNumberLBit\x12W\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x42.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12P\n\tincrement\x18\x05 \x01(\x0b\x32=.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBitCounter\x12P\n\tdecrement\x18\x06 \x01(\x0b\x32=.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x99\x01\n?PatternFlowRSVPPathLabelRequestWithoutLabelRangeReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdd\x03\n8PatternFlowRSVPPathLabelRequestWithoutLabelRangeReserved\x12^\n\x06\x63hoice\x18\x01 \x01(\x0e\x32I.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12W\n\tincrement\x18\x05 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReservedCounter\x12W\n\tdecrement\x18\x06 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x96\x01\n<PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n5PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pid\x12[\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x46.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12T\n\tincrement\x18\x05 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pidCounter\x12T\n\tdecrement\x18\x06 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pidCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xa6\x01\nLPatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x91\x04\nEPatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddress\x12k\n\x06\x63hoice\x18\x01 \x01(\x0e\x32V.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x64\n\tincrement\x18\x05 \x01(\x0b\x32Q.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddressCounter\x12\x64\n\tdecrement\x18\x06 \x01(\x0b\x32Q.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x97\x01\n=PatternFlowRSVPPathSenderTemplateLspTunnelIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd5\x03\n6PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Reserved\x12\\\n\x06\x63hoice\x18\x01 \x01(\x0e\x32G.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12U\n\tincrement\x18\x05 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4ReservedCounter\x12U\n\tdecrement\x18\x06 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4ReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x94\x01\n:PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspIdCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc9\x03\n3PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspId\x12Y\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x44.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12R\n\tincrement\x18\x05 \x01(\x0b\x32?.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspIdCounter\x12R\n\tdecrement\x18\x06 \x01(\x0b\x32?.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowRSVPPathSenderTspecIntServVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowRSVPPathSenderTspecIntServVersion\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowRSVPPathSenderTspecIntServVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServVersionCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServVersionCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8f\x01\n5PatternFlowRSVPPathSenderTspecIntServReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb5\x03\n.PatternFlowRSVPPathSenderTspecIntServReserved1\x12T\n\x06\x63hoice\x18\x01 \x01(\x0e\x32?.otg.PatternFlowRSVPPathSenderTspecIntServReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12M\n\tincrement\x18\x05 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved1Counter\x12M\n\tdecrement\x18\x06 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved1Counter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowRSVPPathSenderTspecIntServOverallLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowRSVPPathSenderTspecIntServOverallLength\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServOverallLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServOverallLengthCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServOverallLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowRSVPPathSenderTspecIntServServiceHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowRSVPPathSenderTspecIntServServiceHeader\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeaderCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeaderCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowRSVPPathSenderTspecIntServZeroBitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowRSVPPathSenderTspecIntServZeroBit\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowRSVPPathSenderTspecIntServZeroBit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServZeroBitCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServZeroBitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8f\x01\n5PatternFlowRSVPPathSenderTspecIntServReserved2Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb5\x03\n.PatternFlowRSVPPathSenderTspecIntServReserved2\x12T\n\x06\x63hoice\x18\x01 \x01(\x0e\x32?.otg.PatternFlowRSVPPathSenderTspecIntServReserved2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12M\n\tincrement\x18\x05 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved2Counter\x12M\n\tdecrement\x18\x06 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved2Counter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x99\x01\n?PatternFlowRSVPPathSenderTspecIntServLengthOfServiceDataCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdd\x03\n8PatternFlowRSVPPathSenderTspecIntServLengthOfServiceData\x12^\n\x06\x63hoice\x18\x01 \x01(\x0e\x32I.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceData.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12W\n\tincrement\x18\x05 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceDataCounter\x12W\n\tdecrement\x18\x06 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceDataCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xa1\x01\nGPatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspecCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x03\n@PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspec\x12\x66\n\x06\x63hoice\x18\x01 \x01(\x0e\x32Q.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspec.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12_\n\tincrement\x18\x05 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspecCounter\x12_\n\tdecrement\x18\x06 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspecCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x96\x01\n<PatternFlowRSVPPathSenderTspecIntServParameter127FlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n5PatternFlowRSVPPathSenderTspecIntServParameter127Flag\x12[\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x46.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Flag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12T\n\tincrement\x18\x05 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathSenderTspecIntServParameter127FlagCounter\x12T\n\tdecrement\x18\x06 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathSenderTspecIntServParameter127FlagCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x98\x01\n>PatternFlowRSVPPathSenderTspecIntServParameter127LengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd9\x03\n7PatternFlowRSVPPathSenderTspecIntServParameter127Length\x12]\n\x06\x63hoice\x18\x01 \x01(\x0e\x32H.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Length.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12V\n\tincrement\x18\x05 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServParameter127LengthCounter\x12V\n\tdecrement\x18\x06 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServParameter127LengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x98\x01\n>PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd9\x03\n7PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnit\x12]\n\x06\x63hoice\x18\x01 \x01(\x0e\x32H.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12V\n\tincrement\x18\x05 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnitCounter\x12V\n\tdecrement\x18\x06 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x97\x01\n=PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd5\x03\n6PatternFlowRSVPPathSenderTspecIntServMaximumPacketSize\x12\\\n\x06\x63hoice\x18\x01 \x01(\x0e\x32G.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12U\n\tincrement\x18\x05 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeCounter\x12U\n\tdecrement\x18\x06 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9a\x01\n@PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4AddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x03\n9PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4Address\x12_\n\x06\x63hoice\x18\x01 \x01(\x0e\x32J.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4Address.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12X\n\tincrement\x18\x05 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4AddressCounter\x12X\n\tdecrement\x18\x06 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4AddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9b\x01\nAPatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n:PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLength\x12`\n\x06\x63hoice\x18\x01 \x01(\x0e\x32K.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Y\n\tincrement\x18\x05 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLengthCounter\x12Y\n\tdecrement\x18\x06 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xf7\x01\n-PatternFlowRSVPPathRecordRouteType1LabelFlags\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.PatternFlowRSVPPathRecordRouteType1LabelFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_value\"\xf7\x01\n-PatternFlowRSVPPathRecordRouteType1LabelCType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.PatternFlowRSVPPathRecordRouteType1LabelCType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowRSVPPathObjectsCustomTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowRSVPPathObjectsCustomType\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowRSVPPathObjectsCustomType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowRSVPPathObjectsCustomTypeCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowRSVPPathObjectsCustomTypeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowLacpVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd5\x02\n\x16PatternFlowLacpVersion\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowLacpVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowLacpVersionCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowLacpVersionCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowLacpduActorTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x02\n\x1aPatternFlowLacpduActorType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowLacpduActorType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowLacpduActorTypeCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowLacpduActorTypeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowLacpduActorLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xed\x02\n\x1cPatternFlowLacpduActorLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowLacpduActorLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowLacpduActorLengthCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowLacpduActorLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowLacpduActorSystemPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowLacpduActorSystemPriority\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowLacpduActorSystemPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowLacpduActorSystemPriorityCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowLacpduActorSystemPriorityCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowLacpduActorSystemIdCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf5\x02\n\x1ePatternFlowLacpduActorSystemId\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowLacpduActorSystemId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowLacpduActorSystemIdCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowLacpduActorSystemIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowLacpduActorKeyCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x02\n\x19PatternFlowLacpduActorKey\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowLacpduActorKey.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowLacpduActorKeyCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowLacpduActorKeyCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowLacpduActorPortPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowLacpduActorPortPriority\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowLacpduActorPortPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowLacpduActorPortPriorityCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowLacpduActorPortPriorityCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowLacpduActorPortNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x02\n PatternFlowLacpduActorPortNumber\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowLacpduActorPortNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowLacpduActorPortNumberCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowLacpduActorPortNumberCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowLacpduActorReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf5\x02\n\x1ePatternFlowLacpduActorReserved\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowLacpduActorReserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowLacpduActorReservedCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowLacpduActorReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowLacpduPartnerTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xed\x02\n\x1cPatternFlowLacpduPartnerType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowLacpduPartnerType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowLacpduPartnerTypeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowLacpduPartnerTypeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowLacpduPartnerLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf5\x02\n\x1ePatternFlowLacpduPartnerLength\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowLacpduPartnerLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowLacpduPartnerLengthCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowLacpduPartnerLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x87\x01\n-PatternFlowLacpduPartnerSystemPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x95\x03\n&PatternFlowLacpduPartnerSystemPriority\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowLacpduPartnerSystemPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowLacpduPartnerSystemPriorityCounter\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowLacpduPartnerSystemPriorityCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowLacpduPartnerSystemIdCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x02\n PatternFlowLacpduPartnerSystemId\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowLacpduPartnerSystemId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowLacpduPartnerSystemIdCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowLacpduPartnerSystemIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowLacpduPartnerKeyCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe9\x02\n\x1bPatternFlowLacpduPartnerKey\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowLacpduPartnerKey.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowLacpduPartnerKeyCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowLacpduPartnerKeyCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowLacpduPartnerPortPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowLacpduPartnerPortPriority\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowLacpduPartnerPortPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowLacpduPartnerPortPriorityCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowLacpduPartnerPortPriorityCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowLacpduPartnerPortNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowLacpduPartnerPortNumber\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowLacpduPartnerPortNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowLacpduPartnerPortNumberCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowLacpduPartnerPortNumberCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowLacpduPartnerReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x02\n PatternFlowLacpduPartnerReserved\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowLacpduPartnerReserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowLacpduPartnerReservedCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowLacpduPartnerReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowLacpduCollectorTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf5\x02\n\x1ePatternFlowLacpduCollectorType\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowLacpduCollectorType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowLacpduCollectorTypeCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowLacpduCollectorTypeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowLacpduCollectorLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x02\n PatternFlowLacpduCollectorLength\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowLacpduCollectorLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowLacpduCollectorLengthCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowLacpduCollectorLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowLacpduCollectorMaxDelayCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowLacpduCollectorMaxDelay\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowLacpduCollectorMaxDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowLacpduCollectorMaxDelayCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowLacpduCollectorMaxDelayCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowLacpduTerminatorTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf9\x02\n\x1fPatternFlowLacpduTerminatorType\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowLacpduTerminatorType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowLacpduTerminatorTypeCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowLacpduTerminatorTypeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowLacpduTerminatorLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x03\n!PatternFlowLacpduTerminatorLength\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowLacpduTerminatorLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowLacpduTerminatorLengthCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowLacpduTerminatorLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x84\x01\n*PatternFlowLacpduActorStateActivityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x89\x03\n#PatternFlowLacpduActorStateActivity\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowLacpduActorStateActivity.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowLacpduActorStateActivityCounter\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowLacpduActorStateActivityCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowLacpduActorStateTimeoutCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowLacpduActorStateTimeout\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowLacpduActorStateTimeout.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowLacpduActorStateTimeoutCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowLacpduActorStateTimeoutCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x87\x01\n-PatternFlowLacpduActorStateAggregationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x95\x03\n&PatternFlowLacpduActorStateAggregation\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowLacpduActorStateAggregation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowLacpduActorStateAggregationCounter\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowLacpduActorStateAggregationCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8b\x01\n1PatternFlowLacpduActorStateSynchronizationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa5\x03\n*PatternFlowLacpduActorStateSynchronization\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowLacpduActorStateSynchronization.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowLacpduActorStateSynchronizationCounter\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowLacpduActorStateSynchronizationCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x86\x01\n,PatternFlowLacpduActorStateCollectingCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x91\x03\n%PatternFlowLacpduActorStateCollecting\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowLacpduActorStateCollecting.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowLacpduActorStateCollectingCounter\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowLacpduActorStateCollectingCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowLacpduActorStateDistributingCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x99\x03\n\'PatternFlowLacpduActorStateDistributing\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowLacpduActorStateDistributing.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowLacpduActorStateDistributingCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowLacpduActorStateDistributingCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowLacpduActorStateDefaultedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowLacpduActorStateDefaulted\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowLacpduActorStateDefaulted.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowLacpduActorStateDefaultedCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowLacpduActorStateDefaultedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowLacpduActorStateExpiredCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowLacpduActorStateExpired\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowLacpduActorStateExpired.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowLacpduActorStateExpiredCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowLacpduActorStateExpiredCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x86\x01\n,PatternFlowLacpduPartnerStateActivityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x91\x03\n%PatternFlowLacpduPartnerStateActivity\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowLacpduPartnerStateActivity.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowLacpduPartnerStateActivityCounter\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowLacpduPartnerStateActivityCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowLacpduPartnerStateTimeoutCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowLacpduPartnerStateTimeout\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowLacpduPartnerStateTimeout.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowLacpduPartnerStateTimeoutCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowLacpduPartnerStateTimeoutCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x89\x01\n/PatternFlowLacpduPartnerStateAggregationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9d\x03\n(PatternFlowLacpduPartnerStateAggregation\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.PatternFlowLacpduPartnerStateAggregation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12G\n\tincrement\x18\x05 \x01(\x0b\x32\x34.otg.PatternFlowLacpduPartnerStateAggregationCounter\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32\x34.otg.PatternFlowLacpduPartnerStateAggregationCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowLacpduPartnerStateSynchronizationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowLacpduPartnerStateSynchronization\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowLacpduPartnerStateSynchronization.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowLacpduPartnerStateSynchronizationCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowLacpduPartnerStateSynchronizationCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowLacpduPartnerStateCollectingCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x99\x03\n\'PatternFlowLacpduPartnerStateCollecting\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowLacpduPartnerStateCollecting.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowLacpduPartnerStateCollectingCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowLacpduPartnerStateCollectingCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8a\x01\n0PatternFlowLacpduPartnerStateDistributingCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa1\x03\n)PatternFlowLacpduPartnerStateDistributing\x12O\n\x06\x63hoice\x18\x01 \x01(\x0e\x32:.otg.PatternFlowLacpduPartnerStateDistributing.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12H\n\tincrement\x18\x05 \x01(\x0b\x32\x35.otg.PatternFlowLacpduPartnerStateDistributingCounter\x12H\n\tdecrement\x18\x06 \x01(\x0b\x32\x35.otg.PatternFlowLacpduPartnerStateDistributingCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x87\x01\n-PatternFlowLacpduPartnerStateDefaultedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x95\x03\n&PatternFlowLacpduPartnerStateDefaulted\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowLacpduPartnerStateDefaulted.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowLacpduPartnerStateDefaultedCounter\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowLacpduPartnerStateDefaultedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowLacpduPartnerStateExpiredCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowLacpduPartnerStateExpired\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowLacpduPartnerStateExpired.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowLacpduPartnerStateExpiredCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowLacpduPartnerStateExpiredCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x91\x01\n\x07Version\x12\x1d\n\x10\x61pi_spec_version\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsdk_version\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x61pp_version\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_api_spec_versionB\x0e\n\x0c_sdk_versionB\x0e\n\x0c_app_version\"(\n\x07Success\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"$\n\x07\x46\x61ilure\x12\x19\n\x05\x65rror\x18\x01 \x01(\x0b\x32\n.otg.Error\")\n\x04\x44\x61ta\x12\x12\n\nchunk_size\x18\x01 \x01(\x04\x12\r\n\x05\x64\x61tum\x18\x02 \x01(\x0c\"/\n\x10SetConfigRequest\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"?\n\x13UpdateConfigRequest\x12(\n\rconfig_update\x18\x01 \x01(\x0b\x32\x11.otg.ConfigUpdate\"2\n\x11SetConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"0\n\x11GetConfigResponse\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"5\n\x14UpdateConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"?\n\x13\x41ppendConfigRequest\x12(\n\rconfig_append\x18\x01 \x01(\x0b\x32\x11.otg.ConfigAppend\"5\n\x14\x41ppendConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"?\n\x13\x44\x65leteConfigRequest\x12(\n\rconfig_delete\x18\x01 \x01(\x0b\x32\x11.otg.ConfigDelete\"5\n\x14\x44\x65leteConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"B\n\x16SetControlStateRequest\x12(\n\rcontrol_state\x18\x01 \x01(\x0b\x32\x11.otg.ControlState\"8\n\x17SetControlStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"E\n\x17SetControlActionRequest\x12*\n\x0e\x63ontrol_action\x18\x01 \x01(\x0b\x32\x12.otg.ControlAction\"W\n\x18SetControlActionResponse\x12;\n\x17\x63ontrol_action_response\x18\x01 \x01(\x0b\x32\x1a.otg.ControlActionResponse\"A\n\x11GetMetricsRequest\x12,\n\x0fmetrics_request\x18\x01 \x01(\x0b\x32\x13.otg.MetricsRequest\"D\n\x12GetMetricsResponse\x12.\n\x10metrics_response\x18\x01 \x01(\x0b\x32\x14.otg.MetricsResponse\">\n\x10GetStatesRequest\x12*\n\x0estates_request\x18\x01 \x01(\x0b\x32\x12.otg.StatesRequest\"A\n\x11GetStatesResponse\x12,\n\x0fstates_response\x18\x01 \x01(\x0b\x32\x13.otg.StatesResponse\"A\n\x11GetCaptureRequest\x12,\n\x0f\x63\x61pture_request\x18\x01 \x01(\x0b\x32\x13.otg.CaptureRequest\",\n\x12GetCaptureResponse\x12\x16\n\x0eresponse_bytes\x18\x01 \x01(\x0c\"3\n\x12GetVersionResponse\x12\x1d\n\x07version\x18\x01 \x01(\x0b\x32\x0c.otg.Version2\x8c\t\n\x07Openapi\x12:\n\tSetConfig\x12\x15.otg.SetConfigRequest\x1a\x16.otg.SetConfigResponse\x12\x36\n\x0fstreamSetConfig\x12\t.otg.Data\x1a\x16.otg.SetConfigResponse(\x01\x12;\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a\x16.otg.GetConfigResponse\x12\x36\n\x0fstreamGetConfig\x12\x16.google.protobuf.Empty\x1a\t.otg.Data0\x01\x12\x43\n\x0cUpdateConfig\x12\x18.otg.UpdateConfigRequest\x1a\x19.otg.UpdateConfigResponse\x12\x43\n\x0c\x41ppendConfig\x12\x18.otg.AppendConfigRequest\x1a\x19.otg.AppendConfigResponse\x12\x43\n\x0c\x44\x65leteConfig\x12\x18.otg.DeleteConfigRequest\x1a\x19.otg.DeleteConfigResponse\x12L\n\x0fSetControlState\x12\x1b.otg.SetControlStateRequest\x1a\x1c.otg.SetControlStateResponse\x12\x42\n\x15streamSetControlState\x12\t.otg.Data\x1a\x1c.otg.SetControlStateResponse(\x01\x12O\n\x10SetControlAction\x12\x1c.otg.SetControlActionRequest\x1a\x1d.otg.SetControlActionResponse\x12\x44\n\x16streamSetControlAction\x12\t.otg.Data\x1a\x1d.otg.SetControlActionResponse(\x01\x12=\n\nGetMetrics\x12\x16.otg.GetMetricsRequest\x1a\x17.otg.GetMetricsResponse\x12\x37\n\x10streamGetMetrics\x12\x16.otg.GetMetricsRequest\x1a\t.otg.Data0\x01\x12:\n\tGetStates\x12\x15.otg.GetStatesRequest\x1a\x16.otg.GetStatesResponse\x12\x35\n\x0fstreamGetStates\x12\x15.otg.GetStatesRequest\x1a\t.otg.Data0\x01\x12=\n\nGetCapture\x12\x16.otg.GetCaptureRequest\x1a\x17.otg.GetCaptureResponse\x12\x37\n\x10streamGetCapture\x12\x16.otg.GetCaptureRequest\x1a\t.otg.Data0\x01\x12=\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x17.otg.GetVersionResponseB\x0bZ\t./otg;otgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'otg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\t./otg;otg'
  _globals['_CONFIG']._serialized_start=82
  _globals['_CONFIG']._serialized_end=445
  _globals['_CONFIGOPTIONS']._serialized_start=448
  _globals['_CONFIGOPTIONS']._serialized_end=598
  _globals['_PORT']._serialized_start=600
  _globals['_PORT']._serialized_end=670
  _globals['_PORTOPTIONS']._serialized_start=672
  _globals['_PORTOPTIONS']._serialized_end=743
  _globals['_LAG']._serialized_start=746
  _globals['_LAG']._serialized_end=882
  _globals['_LAGPORT']._serialized_start=884
  _globals['_LAGPORT']._serialized_end=1006
  _globals['_LAGPROTOCOL']._serialized_start=1009
  _globals['_LAGPROTOCOL']._serialized_end=1217
  _globals['_LAGPROTOCOL_CHOICE']._serialized_start=1151
  _globals['_LAGPROTOCOL_CHOICE']._serialized_end=1206
  _globals['_LAGPROTOCOL_CHOICE_ENUM']._serialized_start=1161
  _globals['_LAGPROTOCOL_CHOICE_ENUM']._serialized_end=1206
  _globals['_LAGPROTOCOLSTATIC']._serialized_start=1219
  _globals['_LAGPROTOCOLSTATIC']._serialized_end=1270
  _globals['_LAGPROTOCOLLACP']._serialized_start=1273
  _globals['_LAGPROTOCOLLACP']._serialized_end=1440
  _globals['_LAGPORTLACP']._serialized_start=1443
  _globals['_LAGPORTLACP']._serialized_end=1846
  _globals['_LAGPORTLACP_ACTORACTIVITY']._serialized_start=1663
  _globals['_LAGPORTLACP_ACTORACTIVITY']._serialized_end=1728
  _globals['_LAGPORTLACP_ACTORACTIVITY_ENUM']._serialized_start=1680
  _globals['_LAGPORTLACP_ACTORACTIVITY_ENUM']._serialized_end=1728
  _globals['_DEVICEETHERNETBASE']._serialized_start=1849
  _globals['_DEVICEETHERNETBASE']._serialized_end=1981
  _globals['_DEVICEETHERNET']._serialized_start=1984
  _globals['_DEVICEETHERNET']._serialized_end=2343
  _globals['_ETHERNETCONNECTION']._serialized_start=2346
  _globals['_ETHERNETCONNECTION']._serialized_end=2701
  _globals['_ETHERNETCONNECTION_CHOICE']._serialized_start=2550
  _globals['_ETHERNETCONNECTION_CHOICE']._serialized_end=2648
  _globals['_ETHERNETCONNECTION_CHOICE_ENUM']._serialized_start=2560
  _globals['_ETHERNETCONNECTION_CHOICE_ENUM']._serialized_end=2648
  _globals['_ETHERNETSIMULATEDLINK']._serialized_start=2704
  _globals['_ETHERNETSIMULATEDLINK']._serialized_end=2934
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE']._serialized_start=2831
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE']._serialized_end=2894
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE_ENUM']._serialized_start=2843
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE_ENUM']._serialized_end=2894
  _globals['_DEVICEVLAN']._serialized_start=2937
  _globals['_DEVICEVLAN']._serialized_end=3180
  _globals['_DEVICEVLAN_TPID']._serialized_start=3056
  _globals['_DEVICEVLAN_TPID']._serialized_end=3142
  _globals['_DEVICEVLAN_TPID_ENUM']._serialized_start=3064
  _globals['_DEVICEVLAN_TPID_ENUM']._serialized_end=3142
  _globals['_DEVICEIPV4']._serialized_start=3183
  _globals['_DEVICEIPV4']._serialized_end=3371
  _globals['_DEVICEIPV4LOOPBACK']._serialized_start=3373
  _globals['_DEVICEIPV4LOOPBACK']._serialized_end=3491
  _globals['_DEVICEIPV4GATEWAYMAC']._serialized_start=3494
  _globals['_DEVICEIPV4GATEWAYMAC']._serialized_end=3701
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE']._serialized_start=3617
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE']._serialized_end=3671
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE_ENUM']._serialized_start=3627
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE_ENUM']._serialized_end=3671
  _globals['_DEVICEIPV6']._serialized_start=3704
  _globals['_DEVICEIPV6']._serialized_end=3892
  _globals['_DEVICEIPV6LOOPBACK']._serialized_start=3894
  _globals['_DEVICEIPV6LOOPBACK']._serialized_end=4012
  _globals['_DEVICEIPV6GATEWAYMAC']._serialized_start=4015
  _globals['_DEVICEIPV6GATEWAYMAC']._serialized_end=4222
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE']._serialized_start=3617
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE']._serialized_end=3671
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE_ENUM']._serialized_start=3627
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE_ENUM']._serialized_end=3671
  _globals['_DEVICEDHCPV4CLIENT']._serialized_start=4225
  _globals['_DEVICEDHCPV4CLIENT']._serialized_end=4559
  _globals['_DEVICEDHCPV4CLIENT_CHOICE']._serialized_start=4435
  _globals['_DEVICEDHCPV4CLIENT_CHOICE']._serialized_end=4506
  _globals['_DEVICEDHCPV4CLIENT_CHOICE_ENUM']._serialized_start=4445
  _globals['_DEVICEDHCPV4CLIENT_CHOICE_ENUM']._serialized_end=4506
  _globals['_DHCPV4CLIENTPARAMS']._serialized_start=4562
  _globals['_DHCPV4CLIENTPARAMS']._serialized_end=4752
  _globals['_DEVICEDHCPV6CLIENT']._serialized_start=4755
  _globals['_DEVICEDHCPV6CLIENT']._serialized_end=5060
  _globals['_DEVICEDHCPV6CLIENTOPTIONSREQUEST']._serialized_start=5063
  _globals['_DEVICEDHCPV6CLIENTOPTIONSREQUEST']._serialized_end=5230
  _globals['_DEVICEDHCPV6CLIENTOPTIONS']._serialized_start=5233
  _globals['_DEVICEDHCPV6CLIENTOPTIONS']._serialized_end=5489
  _globals['_DEVICEDHCPV6CLIENTIATYPE']._serialized_start=5492
  _globals['_DEVICEDHCPV6CLIENTIATYPE']._serialized_end=5822
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE']._serialized_start=5736
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE']._serialized_end=5811
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE_ENUM']._serialized_start=5746
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE_ENUM']._serialized_end=5811
  _globals['_DEVICEDHCPV6CLIENTIATIMEVALUE']._serialized_start=5824
  _globals['_DEVICEDHCPV6CLIENTIATIMEVALUE']._serialized_end=5903
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE']._serialized_start=5906
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE']._serialized_end=6204
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE']._serialized_start=6135
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE']._serialized_end=6193
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE_ENUM']._serialized_start=6145
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE_ENUM']._serialized_end=6193
  _globals['_DEVICEDHCPV6CLIENTDUIDVALUE']._serialized_start=6206
  _globals['_DEVICEDHCPV6CLIENTDUIDVALUE']._serialized_end=6319
  _globals['_DEVICEDHCPV6CLIENTNODUID']._serialized_start=6321
  _globals['_DEVICEDHCPV6CLIENTNODUID']._serialized_end=6347
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER']._serialized_start=6350
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER']._serialized_end=6765
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE']._serialized_start=6666
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE']._serialized_end=6754
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE_ENUM']._serialized_start=6676
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE_ENUM']._serialized_end=6754
  _globals['_DHCPV6CLIENTOPTIONSDUIDLLT']._serialized_start=6767
  _globals['_DHCPV6CLIENTOPTIONSDUIDLLT']._serialized_end=6893
  _globals['_DHCPV6CLIENTOPTIONSDUIDEN']._serialized_start=6895
  _globals['_DHCPV6CLIENTOPTIONSDUIDEN']._serialized_end=7016
  _globals['_DHCPV6CLIENTOPTIONSDUIDLL']._serialized_start=7018
  _globals['_DHCPV6CLIENTOPTIONSDUIDLL']._serialized_end=7115
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUID']._serialized_start=7118
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUID']._serialized_end=7537
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION']._serialized_start=7540
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION']._serialized_end=7741
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE']._serialized_start=7652
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE']._serialized_end=7730
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE_ENUM']._serialized_start=7662
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE_ENUM']._serialized_end=7730
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT']._serialized_start=7744
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT']._serialized_end=7946
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE']._serialized_start=7856
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE']._serialized_end=7935
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE_ENUM']._serialized_start=7866
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE_ENUM']._serialized_end=7935
  _globals['_DHCPV6CLIENTOPTIONSLINKLAYERADDRESS']._serialized_start=7948
  _globals['_DHCPV6CLIENTOPTIONSLINKLAYERADDRESS']._serialized_end=8015
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST']._serialized_start=8018
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST']._serialized_end=8312
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE']._serialized_start=8176
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE']._serialized_end=8301
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE_ENUM']._serialized_start=8186
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE_ENUM']._serialized_end=8301
  _globals['_DHCPV6CLIENTOPTIONSCUSTOM']._serialized_start=8314
  _globals['_DHCPV6CLIENTOPTIONSCUSTOM']._serialized_end=8369
  _globals['_DHCPV6CLIENTOPTIONSVENDORCLASS']._serialized_start=8372
  _globals['_DHCPV6CLIENTOPTIONSVENDORCLASS']._serialized_end=8554
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES']._serialized_start=8557
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES']._serialized_end=8795
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_start=8727
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_end=8784
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_start=8737
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_end=8784
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE']._serialized_start=8798
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE']._serialized_end=9028
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE']._serialized_start=8902
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE']._serialized_end=9017
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_start=8912
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_end=9017
  _globals['_DHCPV6CLIENTOPTIONSVENDORINFO']._serialized_start=9031
  _globals['_DHCPV6CLIENTOPTIONSVENDORINFO']._serialized_end=9254
  _globals['_DHCPV6SERVEROPTIONSVENDORINFO']._serialized_start=9257
  _globals['_DHCPV6SERVEROPTIONSVENDORINFO']._serialized_end=9480
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES']._serialized_start=9483
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES']._serialized_end=9721
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_start=8727
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_end=8784
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_start=8737
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_end=8784
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE']._serialized_start=9724
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE']._serialized_end=9916
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE']._serialized_start=9828
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE']._serialized_end=9905
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_start=9838
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_end=9905
  _globals['_DHCPV6OPTIONSVENDORSPECIFICOPTIONS']._serialized_start=9918
  _globals['_DHCPV6OPTIONSVENDORSPECIFICOPTIONS']._serialized_end=10010
  _globals['_DHCPV6CLIENTOPTIONSFQDN']._serialized_start=10013
  _globals['_DHCPV6CLIENTOPTIONSFQDN']._serialized_end=10252
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEURL']._serialized_start=10255
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEURL']._serialized_end=10454
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEPARAMS']._serialized_start=10456
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEPARAMS']._serialized_end=10529
  _globals['_LAYER1']._serialized_start=10532
  _globals['_LAYER1']._serialized_end=11338
  _globals['_LAYER1_SPEED']._serialized_start=10877
  _globals['_LAYER1_SPEED']._serialized_end=11174
  _globals['_LAYER1_SPEED_ENUM']._serialized_start=10887
  _globals['_LAYER1_SPEED_ENUM']._serialized_end=11174
  _globals['_LAYER1_MEDIA']._serialized_start=11176
  _globals['_LAYER1_MEDIA']._serialized_end=11242
  _globals['_LAYER1_MEDIA_ENUM']._serialized_start=11185
  _globals['_LAYER1_MEDIA_ENUM']._serialized_end=11242
  _globals['_LAYER1AUTONEGOTIATION']._serialized_start=11341
  _globals['_LAYER1AUTONEGOTIATION']._serialized_end=11744
  _globals['_LAYER1FLOWCONTROL']._serialized_start=11747
  _globals['_LAYER1FLOWCONTROL']._serialized_end=12047
  _globals['_LAYER1FLOWCONTROL_CHOICE']._serialized_start=11946
  _globals['_LAYER1FLOWCONTROL_CHOICE']._serialized_end=12015
  _globals['_LAYER1FLOWCONTROL_CHOICE_ENUM']._serialized_start=11956
  _globals['_LAYER1FLOWCONTROL_CHOICE_ENUM']._serialized_end=12015
  _globals['_LAYER1IEEE8023X']._serialized_start=12049
  _globals['_LAYER1IEEE8023X']._serialized_end=12066
  _globals['_LAYER1IEEE8021QBB']._serialized_start=12069
  _globals['_LAYER1IEEE8021QBB']._serialized_end=12462
  _globals['_CAPTURE']._serialized_start=12465
  _globals['_CAPTURE']._serialized_end=12754
  _globals['_CAPTURE_FORMAT']._serialized_start=12649
  _globals['_CAPTURE_FORMAT']._serialized_end=12704
  _globals['_CAPTURE_FORMAT_ENUM']._serialized_start=12659
  _globals['_CAPTURE_FORMAT_ENUM']._serialized_end=12704
  _globals['_CAPTUREFILTER']._serialized_start=12757
  _globals['_CAPTUREFILTER']._serialized_end=13099
  _globals['_CAPTUREFILTER_CHOICE']._serialized_start=12999
  _globals['_CAPTUREFILTER_CHOICE']._serialized_end=13088
  _globals['_CAPTUREFILTER_CHOICE_ENUM']._serialized_start=13009
  _globals['_CAPTUREFILTER_CHOICE_ENUM']._serialized_end=13088
  _globals['_CAPTURECUSTOM']._serialized_start=13102
  _globals['_CAPTURECUSTOM']._serialized_end=13279
  _globals['_CAPTUREFIELD']._serialized_start=13281
  _globals['_CAPTUREFIELD']._serialized_end=13385
  _globals['_CAPTUREETHERNET']._serialized_start=13388
  _globals['_CAPTUREETHERNET']._serialized_end=13546
  _globals['_CAPTUREVLAN']._serialized_start=13549
  _globals['_CAPTUREVLAN']._serialized_end=13699
  _globals['_CAPTUREIPV4']._serialized_start=13702
  _globals['_CAPTUREIPV4']._serialized_end=14266
  _globals['_CAPTUREIPV6']._serialized_start=14269
  _globals['_CAPTUREIPV6']._serialized_end=14584
  _globals['_DEVICE']._serialized_start=14587
  _globals['_DEVICE']._serialized_end=15097
  _globals['_PROTOCOLOPTIONS']._serialized_start=15099
  _globals['_PROTOCOLOPTIONS']._serialized_end=15164
  _globals['_DEVICEISISROUTER']._serialized_start=15167
  _globals['_DEVICEISISROUTER']._serialized_end=15639
  _globals['_DEVICEISISMULTIINSTANCE']._serialized_start=15641
  _globals['_DEVICEISISMULTIINSTANCE']._serialized_end=15707
  _globals['_ISISINTERFACE']._serialized_start=15710
  _globals['_ISISINTERFACE']._serialized_end=16551
  _globals['_ISISINTERFACE_NETWORKTYPE']._serialized_start=16334
  _globals['_ISISINTERFACE_NETWORKTYPE']._serialized_end=16407
  _globals['_ISISINTERFACE_NETWORKTYPE_ENUM']._serialized_start=16349
  _globals['_ISISINTERFACE_NETWORKTYPE_ENUM']._serialized_end=16407
  _globals['_ISISINTERFACE_LEVELTYPE']._serialized_start=16409
  _globals['_ISISINTERFACE_LEVELTYPE']._serialized_end=16486
  _globals['_ISISINTERFACE_LEVELTYPE_ENUM']._serialized_start=16422
  _globals['_ISISINTERFACE_LEVELTYPE_ENUM']._serialized_end=16486
  _globals['_ISISINTERFACELEVEL']._serialized_start=16554
  _globals['_ISISINTERFACELEVEL']._serialized_end=16704
  _globals['_ISISMT']._serialized_start=16706
  _globals['_ISISMT']._serialized_end=16786
  _globals['_LINKSTATETE']._serialized_start=16789
  _globals['_LINKSTATETE']._serialized_end=17081
  _globals['_LINKSTATEPRIORITYBANDWIDTHS']._serialized_start=17084
  _globals['_LINKSTATEPRIORITYBANDWIDTHS']._serialized_end=17321
  _globals['_ISISINTERFACEAUTHENTICATION']._serialized_start=17324
  _globals['_ISISINTERFACEAUTHENTICATION']._serialized_end=17561
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE']._serialized_start=17468
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE']._serialized_end=17526
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM']._serialized_start=17480
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM']._serialized_end=17526
  _globals['_ISISINTERFACEADVANCED']._serialized_start=17564
  _globals['_ISISINTERFACEADVANCED']._serialized_end=17903
  _globals['_ISISINTERFACELINKPROTECTION']._serialized_start=17906
  _globals['_ISISINTERFACELINKPROTECTION']._serialized_end=18283
  _globals['_ISISINTERFACEADJACENCYSID']._serialized_start=18286
  _globals['_ISISINTERFACEADJACENCYSID']._serialized_end=18690
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE']._serialized_start=18547
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE']._serialized_end=18613
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE_ENUM']._serialized_start=18557
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE_ENUM']._serialized_end=18613
  _globals['_ISISBASIC']._serialized_start=18693
  _globals['_ISISBASIC']._serialized_end=18906
  _globals['_ISISADVANCED']._serialized_start=18909
  _globals['_ISISADVANCED']._serialized_end=19431
  _globals['_ISISAUTHENTICATION']._serialized_start=19434
  _globals['_ISISAUTHENTICATION']._serialized_end=19608
  _globals['_ISISAUTHENTICATIONBASE']._serialized_start=19611
  _globals['_ISISAUTHENTICATIONBASE']._serialized_end=19838
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE']._serialized_start=17468
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE']._serialized_end=17526
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM']._serialized_start=17480
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM']._serialized_end=17526
  _globals['_ISISV4ROUTERANGE']._serialized_start=19841
  _globals['_ISISV4ROUTERANGE']._serialized_end=20484
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE']._serialized_start=20232
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE']._serialized_end=20297
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE_ENUM']._serialized_start=20246
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE_ENUM']._serialized_end=20297
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_start=20299
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_end=20362
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20321
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20362
  _globals['_V4ROUTEADDRESS']._serialized_start=20487
  _globals['_V4ROUTEADDRESS']._serialized_end=20627
  _globals['_V6ROUTEADDRESS']._serialized_start=20630
  _globals['_V6ROUTEADDRESS']._serialized_end=20770
  _globals['_MACROUTEADDRESS']._serialized_start=20773
  _globals['_MACROUTEADDRESS']._serialized_end=20914
  _globals['_ISISSRPREFIXSID']._serialized_start=20917
  _globals['_ISISSRPREFIXSID']._serialized_end=21307
  _globals['_ISISSRPREFIXSID_CHOICE']._serialized_start=18547
  _globals['_ISISSRPREFIXSID_CHOICE']._serialized_end=18613
  _globals['_ISISSRPREFIXSID_CHOICE_ENUM']._serialized_start=18557
  _globals['_ISISSRPREFIXSID_CHOICE_ENUM']._serialized_end=18613
  _globals['_ISISV6ROUTERANGE']._serialized_start=21310
  _globals['_ISISV6ROUTERANGE']._serialized_end=21953
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE']._serialized_start=20232
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE']._serialized_end=20297
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE_ENUM']._serialized_start=20246
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE_ENUM']._serialized_end=20297
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_start=20299
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_end=20362
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20321
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20362
  _globals['_ISISSEGMENTROUTING']._serialized_start=21955
  _globals['_ISISSEGMENTROUTING']._serialized_end=22029
  _globals['_ISISROUTERCAPABILITY']._serialized_start=22032
  _globals['_ISISROUTERCAPABILITY']._serialized_end=22641
  _globals['_ISISROUTERCAPABILITY_CHOICE']._serialized_start=22369
  _globals['_ISISROUTERCAPABILITY_CHOICE']._serialized_end=22469
  _globals['_ISISROUTERCAPABILITY_CHOICE_ENUM']._serialized_start=22379
  _globals['_ISISROUTERCAPABILITY_CHOICE_ENUM']._serialized_end=22469
  _globals['_ISISROUTERCAPABILITY_SBIT']._serialized_start=22471
  _globals['_ISISROUTERCAPABILITY_SBIT']._serialized_end=22528
  _globals['_ISISROUTERCAPABILITY_SBIT_ENUM']._serialized_start=22479
  _globals['_ISISROUTERCAPABILITY_SBIT_ENUM']._serialized_end=22528
  _globals['_ISISROUTERCAPABILITY_DBIT']._serialized_start=22530
  _globals['_ISISROUTERCAPABILITY_DBIT']._serialized_end=22585
  _globals['_ISISROUTERCAPABILITY_DBIT_ENUM']._serialized_start=22538
  _globals['_ISISROUTERCAPABILITY_DBIT_ENUM']._serialized_end=22585
  _globals['_ISISSRCAPABILITY']._serialized_start=22643
  _globals['_ISISSRCAPABILITY']._serialized_end=22742
  _globals['_ISISSRCAPABILITYFLAGS']._serialized_start=22744
  _globals['_ISISSRCAPABILITYFLAGS']._serialized_end=22843
  _globals['_ISISSRSRGB']._serialized_start=22845
  _globals['_ISISSRSRGB']._serialized_end=22931
  _globals['_ISISSRSRLB']._serialized_start=22933
  _globals['_ISISSRSRLB']._serialized_end=23019
  _globals['_ISISGRACEFULRESTART']._serialized_start=23021
  _globals['_ISISGRACEFULRESTART']._serialized_end=23084
  _globals['_DEVICEBGPROUTER']._serialized_start=23087
  _globals['_DEVICEBGPROUTER']._serialized_end=23234
  _globals['_DEVICEBGPMESSAGEHEADERERROR']._serialized_start=23237
  _globals['_DEVICEBGPMESSAGEHEADERERROR']._serialized_end=23509
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE']._serialized_start=23338
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE']._serialized_end=23497
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM']._serialized_start=23350
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM']._serialized_end=23497
  _globals['_DEVICEBGPOPENMESSAGEERROR']._serialized_start=23512
  _globals['_DEVICEBGPOPENMESSAGEERROR']._serialized_end=23938
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE']._serialized_start=23609
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE']._serialized_end=23926
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM']._serialized_start=23621
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM']._serialized_end=23926
  _globals['_DEVICEBGPUPDATEMESSAGEERROR']._serialized_start=23941
  _globals['_DEVICEBGPUPDATEMESSAGEERROR']._serialized_end=24545
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE']._serialized_start=24042
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE']._serialized_end=24533
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM']._serialized_start=24054
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM']._serialized_end=24533
  _globals['_DEVICEBGPHOLDTIMEREXPIRED']._serialized_start=24547
  _globals['_DEVICEBGPHOLDTIMEREXPIRED']._serialized_end=24574
  _globals['_DEVICEBGPFINITESTATEMACHINEERROR']._serialized_start=24576
  _globals['_DEVICEBGPFINITESTATEMACHINEERROR']._serialized_end=24610
  _globals['_DEVICEBGPCEASEERROR']._serialized_start=24613
  _globals['_DEVICEBGPCEASEERROR']._serialized_end=25128
  _globals['_DEVICEBGPCEASEERROR_SUBCODE']._serialized_start=24698
  _globals['_DEVICEBGPCEASEERROR_SUBCODE']._serialized_end=25116
  _globals['_DEVICEBGPCEASEERROR_SUBCODE_ENUM']._serialized_start=24710
  _globals['_DEVICEBGPCEASEERROR_SUBCODE_ENUM']._serialized_end=25116
  _globals['_DEVICEBGPCUSTOMERROR']._serialized_start=25130
  _globals['_DEVICEBGPCUSTOMERROR']._serialized_end=25214
  _globals['_BGPV4PEER']._serialized_start=25217
  _globals['_BGPV4PEER']._serialized_end=26081
  _globals['_BGPV4PEER_ASTYPE']._serialized_start=25895
  _globals['_BGPV4PEER_ASTYPE']._serialized_end=25948
  _globals['_BGPV4PEER_ASTYPE_ENUM']._serialized_start=25905
  _globals['_BGPV4PEER_ASTYPE_ENUM']._serialized_end=25948
  _globals['_BGPV4PEER_ASNUMBERWIDTH']._serialized_start=25950
  _globals['_BGPV4PEER_ASNUMBERWIDTH']._serialized_end=26009
  _globals['_BGPV4PEER_ASNUMBERWIDTH_ENUM']._serialized_start=25967
  _globals['_BGPV4PEER_ASNUMBERWIDTH_ENUM']._serialized_end=26009
  _globals['_BGPV4INTERFACE']._serialized_start=26083
  _globals['_BGPV4INTERFACE']._serialized_end=26168
  _globals['_BGPV4ETHERNETSEGMENT']._serialized_start=26171
  _globals['_BGPV4ETHERNETSEGMENT']._serialized_end=26667
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE']._serialized_start=26557
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE']._serialized_end=26629
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_start=26571
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_end=26629
  _globals['_BGPETHERNETSEGMENTDFELECTION']._serialized_start=26669
  _globals['_BGPETHERNETSEGMENTDFELECTION']._serialized_end=26747
  _globals['_BGPROUTEADVANCED']._serialized_start=26750
  _globals['_BGPROUTEADVANCED']._serialized_end=27224
  _globals['_BGPROUTEADVANCED_ORIGIN']._serialized_start=27011
  _globals['_BGPROUTEADVANCED_ORIGIN']._serialized_end=27078
  _globals['_BGPROUTEADVANCED_ORIGIN_ENUM']._serialized_start=27021
  _globals['_BGPROUTEADVANCED_ORIGIN_ENUM']._serialized_end=27078
  _globals['_BGPCOMMUNITY']._serialized_start=27227
  _globals['_BGPCOMMUNITY']._serialized_end=27519
  _globals['_BGPCOMMUNITY_TYPE']._serialized_start=27340
  _globals['_BGPCOMMUNITY_TYPE']._serialized_end=27482
  _globals['_BGPCOMMUNITY_TYPE_ENUM']._serialized_start=27349
  _globals['_BGPCOMMUNITY_TYPE_ENUM']._serialized_end=27482
  _globals['_BGPEXTCOMMUNITY']._serialized_start=27522
  _globals['_BGPEXTCOMMUNITY']._serialized_end=28027
  _globals['_BGPEXTCOMMUNITY_TYPE']._serialized_start=27670
  _globals['_BGPEXTCOMMUNITY_TYPE']._serialized_end=27858
  _globals['_BGPEXTCOMMUNITY_TYPE_ENUM']._serialized_start=27679
  _globals['_BGPEXTCOMMUNITY_TYPE_ENUM']._serialized_end=27858
  _globals['_BGPEXTCOMMUNITY_SUBTYPE']._serialized_start=27861
  _globals['_BGPEXTCOMMUNITY_SUBTYPE']._serialized_end=27996
  _globals['_BGPEXTCOMMUNITY_SUBTYPE_ENUM']._serialized_start=27872
  _globals['_BGPEXTCOMMUNITY_SUBTYPE_ENUM']._serialized_end=27996
  _globals['_BGPASPATH']._serialized_start=28030
  _globals['_BGPASPATH']._serialized_end=28348
  _globals['_BGPASPATH_ASSETMODE']._serialized_start=28142
  _globals['_BGPASPATH_ASSETMODE']._serialized_end=28332
  _globals['_BGPASPATH_ASSETMODE_ENUM']._serialized_start=28156
  _globals['_BGPASPATH_ASSETMODE_ENUM']._serialized_end=28332
  _globals['_BGPASPATHSEGMENT']._serialized_start=28351
  _globals['_BGPASPATHSEGMENT']._serialized_end=28545
  _globals['_BGPASPATHSEGMENT_TYPE']._serialized_start=28443
  _globals['_BGPASPATHSEGMENT_TYPE']._serialized_end=28536
  _globals['_BGPASPATHSEGMENT_TYPE_ENUM']._serialized_start=28451
  _globals['_BGPASPATHSEGMENT_TYPE_ENUM']._serialized_end=28536
  _globals['_BGPV4EVPNEVIS']._serialized_start=28548
  _globals['_BGPV4EVPNEVIS']._serialized_end=28716
  _globals['_BGPV4EVPNEVIS_CHOICE']._serialized_start=28657
  _globals['_BGPV4EVPNEVIS_CHOICE']._serialized_end=28705
  _globals['_BGPV4EVPNEVIS_CHOICE_ENUM']._serialized_start=28667
  _globals['_BGPV4EVPNEVIS_CHOICE_ENUM']._serialized_end=28705
  _globals['_BGPV4EVIVXLAN']._serialized_start=28719
  _globals['_BGPV4EVIVXLAN']._serialized_end=29458
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE']._serialized_start=29342
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE']._serialized_end=29409
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_start=29361
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_end=29409
  _globals['_BGPV4EVIVXLANBROADCASTDOMAIN']._serialized_start=29461
  _globals['_BGPV4EVIVXLANBROADCASTDOMAIN']._serialized_end=29641
  _globals['_BGPCMACIPRANGE']._serialized_start=29644
  _globals['_BGPCMACIPRANGE']._serialized_end=30110
  _globals['_BGPROUTEDISTINGUISHER']._serialized_start=30113
  _globals['_BGPROUTEDISTINGUISHER']._serialized_end=30393
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE']._serialized_start=30260
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE']._serialized_end=30341
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE_ENUM']._serialized_start=30270
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE_ENUM']._serialized_end=30341
  _globals['_BGPROUTETARGET']._serialized_start=30396
  _globals['_BGPROUTETARGET']._serialized_end=30598
  _globals['_BGPROUTETARGET_RTTYPE']._serialized_start=30492
  _globals['_BGPROUTETARGET_RTTYPE']._serialized_end=30573
  _globals['_BGPROUTETARGET_RTTYPE_ENUM']._serialized_start=30270
  _globals['_BGPROUTETARGET_RTTYPE_ENUM']._serialized_end=30341
  _globals['_BGPADVANCED']._serialized_start=30601
  _globals['_BGPADVANCED']._serialized_end=30988
  _globals['_BGPCAPABILITY']._serialized_start=30991
  _globals['_BGPCAPABILITY']._serialized_end=32288
  _globals['_BGPLEARNEDINFORMATIONFILTER']._serialized_start=32291
  _globals['_BGPLEARNEDINFORMATIONFILTER']._serialized_end=32436
  _globals['_BGPV4ROUTERANGE']._serialized_start=32439
  _globals['_BGPV4ROUTERANGE']._serialized_end=33227
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE']._serialized_start=32991
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE']._serialized_end=33055
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_start=33006
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_end=33055
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_start=33057
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_end=33122
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=33079
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=33122
  _globals['_BGPADDPATH']._serialized_start=33229
  _globals['_BGPADDPATH']._serialized_end=33275
  _globals['_BGPEXTENDEDCOMMUNITY']._serialized_start=33278
  _globals['_BGPEXTENDEDCOMMUNITY']._serialized_end=34161
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE']._serialized_start=33919
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE']._serialized_end=34150
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE_ENUM']._serialized_start=33930
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE_ENUM']._serialized_end=34150
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_start=34164
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_end=34323
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_start=34326
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_end=34485
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_start=34488
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_end=34892
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=34796
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=34881
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=34806
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=34881
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_start=34895
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_end=35061
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_start=35064
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_end=35230
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_start=35233
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_end=35649
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_start=34796
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_end=34881
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_start=34806
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_end=34881
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_start=35652
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_end=35811
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_start=35814
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_end=35973
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_start=35976
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_end=36380
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_start=34796
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_end=34881
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_start=34806
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_end=34881
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_start=36382
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_end=36489
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_start=36492
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_end=36625
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_start=36628
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_end=37008
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_start=36918
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_end=36997
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_start=36928
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_end=36997
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPEROUTERMAC']._serialized_start=37010
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPEROUTERMAC']._serialized_end=37099
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE']._serialized_start=37102
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE']._serialized_end=37372
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE']._serialized_start=37304
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE']._serialized_end=37361
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE_ENUM']._serialized_start=37314
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE_ENUM']._serialized_end=37361
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_start=37375
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_end=37523
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_start=37526
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_end=37829
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=37757
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=37818
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=37767
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=37818
  _globals['_BGPEXTENDEDCOMMUNITYCUSTOMTYPE']._serialized_start=37832
  _globals['_BGPEXTENDEDCOMMUNITYCUSTOMTYPE']._serialized_end=37996
  _globals['_BGPV6ROUTERANGE']._serialized_start=37999
  _globals['_BGPV6ROUTERANGE']._serialized_end=38787
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE']._serialized_start=32991
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE']._serialized_end=33055
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_start=33006
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_end=33055
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_start=33057
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_end=33122
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=33079
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=33122
  _globals['_BGPSRTEV4POLICY']._serialized_start=38790
  _globals['_BGPSRTEV4POLICY']._serialized_end=39681
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE']._serialized_start=32991
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE']._serialized_end=33055
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM']._serialized_start=33006
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM']._serialized_end=33055
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE']._serialized_start=33057
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE']._serialized_end=33122
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=33079
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=33122
  _globals['_BGPSRTEV4TUNNELTLV']._serialized_start=39684
  _globals['_BGPSRTEV4TUNNELTLV']._serialized_end=40250
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV']._serialized_start=40253
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV']._serialized_end=40571
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY']._serialized_start=40444
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY']._serialized_end=40504
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM']._serialized_start=33079
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM']._serialized_end=33122
  _globals['_BGPSRTECOLORSUBTLV']._serialized_start=40573
  _globals['_BGPSRTECOLORSUBTLV']._serialized_end=40623
  _globals['_BGPSRTEBINDINGSUBTLV']._serialized_start=40626
  _globals['_BGPSRTEBINDINGSUBTLV']._serialized_end=40988
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE']._serialized_start=40822
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE']._serialized_end=40913
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM']._serialized_start=40840
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM']._serialized_end=40913
  _globals['_BGPSRTEPREFERENCESUBTLV']._serialized_start=40990
  _globals['_BGPSRTEPREFERENCESUBTLV']._serialized_end=41055
  _globals['_BGPSRTEPOLICYPRIORITYSUBTLV']._serialized_start=41057
  _globals['_BGPSRTEPOLICYPRIORITYSUBTLV']._serialized_end=41136
  _globals['_BGPSRTEPOLICYNAMESUBTLV']._serialized_start=41138
  _globals['_BGPSRTEPOLICYNAMESUBTLV']._serialized_end=41205
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV']._serialized_start=41208
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV']._serialized_end=41550
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY']._serialized_start=41362
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY']._serialized_end=41519
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM']._serialized_start=41390
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM']._serialized_end=41519
  _globals['_BGPSRTESEGMENTLIST']._serialized_start=41553
  _globals['_BGPSRTESEGMENTLIST']._serialized_end=41704
  _globals['_BGPSRTESEGMENT']._serialized_start=41707
  _globals['_BGPSRTESEGMENT']._serialized_end=42567
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE']._serialized_start=42359
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE']._serialized_end=42530
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE_ENUM']._serialized_start=42375
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE_ENUM']._serialized_end=42530
  _globals['_BGPSRTESRMPLSSID']._serialized_start=42570
  _globals['_BGPSRTESRMPLSSID']._serialized_end=42698
  _globals['_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_start=42701
  _globals['_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_end=42903
  _globals['_BGPSRTESEGMENTATYPESUBTLV']._serialized_start=42906
  _globals['_BGPSRTESEGMENTATYPESUBTLV']._serialized_end=43073
  _globals['_BGPSRTESEGMENTBTYPESUBTLV']._serialized_start=43076
  _globals['_BGPSRTESEGMENTBTYPESUBTLV']._serialized_end=43254
  _globals['_BGPSRTESEGMENTCTYPESUBTLV']._serialized_start=43257
  _globals['_BGPSRTESEGMENTCTYPESUBTLV']._serialized_end=43456
  _globals['_BGPSRTESEGMENTDTYPESUBTLV']._serialized_start=43459
  _globals['_BGPSRTESEGMENTDTYPESUBTLV']._serialized_end=43658
  _globals['_BGPSRTESEGMENTETYPESUBTLV']._serialized_start=43661
  _globals['_BGPSRTESEGMENTETYPESUBTLV']._serialized_end=43872
  _globals['_BGPSRTESEGMENTFTYPESUBTLV']._serialized_start=43875
  _globals['_BGPSRTESEGMENTFTYPESUBTLV']._serialized_end=44090
  _globals['_BGPSRTESEGMENTGTYPESUBTLV']._serialized_start=44093
  _globals['_BGPSRTESEGMENTGTYPESUBTLV']._serialized_end=44442
  _globals['_BGPSRTESEGMENTHTYPESUBTLV']._serialized_start=44445
  _globals['_BGPSRTESEGMENTHTYPESUBTLV']._serialized_end=44660
  _globals['_BGPSRTESEGMENTITYPESUBTLV']._serialized_start=44663
  _globals['_BGPSRTESEGMENTITYPESUBTLV']._serialized_end=44895
  _globals['_BGPSRTESEGMENTJTYPESUBTLV']._serialized_start=44898
  _globals['_BGPSRTESEGMENTJTYPESUBTLV']._serialized_end=45368
  _globals['_BGPSRTESEGMENTKTYPESUBTLV']._serialized_start=45371
  _globals['_BGPSRTESEGMENTKTYPESUBTLV']._serialized_end=45707
  _globals['_BGPSRTEV6POLICY']._serialized_start=45710
  _globals['_BGPSRTEV6POLICY']._serialized_end=46600
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE']._serialized_start=32991
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE']._serialized_end=33055
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM']._serialized_start=33006
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM']._serialized_end=33055
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE']._serialized_start=33057
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE']._serialized_end=33122
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=33079
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=33122
  _globals['_BGPSRTEV6TUNNELTLV']._serialized_start=46603
  _globals['_BGPSRTEV6TUNNELTLV']._serialized_end=47169
  _globals['_BGPGRACEFULRESTART']._serialized_start=47172
  _globals['_BGPGRACEFULRESTART']._serialized_end=47414
  _globals['_BGPUPDATEREPLAY']._serialized_start=47417
  _globals['_BGPUPDATEREPLAY']._serialized_end=47657
  _globals['_BGPUPDATEREPLAY_CHOICE']._serialized_start=47577
  _globals['_BGPUPDATEREPLAY_CHOICE']._serialized_end=47646
  _globals['_BGPUPDATEREPLAY_CHOICE_ENUM']._serialized_start=47587
  _globals['_BGPUPDATEREPLAY_CHOICE_ENUM']._serialized_end=47646
  _globals['_BGPRAWBYTES']._serialized_start=47659
  _globals['_BGPRAWBYTES']._serialized_end=47714
  _globals['_BGPONEUPDATEREPLAY']._serialized_start=47716
  _globals['_BGPONEUPDATEREPLAY']._serialized_end=47816
  _globals['_BGPSTRUCTUREDPDUS']._serialized_start=47818
  _globals['_BGPSTRUCTUREDPDUS']._serialized_end=47889
  _globals['_BGPONESTRUCTUREDUPDATEREPLAY']._serialized_start=47892
  _globals['_BGPONESTRUCTUREDUPDATEREPLAY']._serialized_end=48139
  _globals['_BGPONETRADITIONALNLRIPREFIX']._serialized_start=48142
  _globals['_BGPONETRADITIONALNLRIPREFIX']._serialized_end=48280
  _globals['_BGPONEIPV4NLRIPREFIX']._serialized_start=48283
  _globals['_BGPONEIPV4NLRIPREFIX']._serialized_end=48414
  _globals['_BGPONEIPV6NLRIPREFIX']._serialized_start=48417
  _globals['_BGPONEIPV6NLRIPREFIX']._serialized_end=48548
  _globals['_BGPNLRIPREFIXPATHID']._serialized_start=48550
  _globals['_BGPNLRIPREFIXPATHID']._serialized_end=48601
  _globals['_BGPIPV4SRPOLICYNLRIPREFIX']._serialized_start=48604
  _globals['_BGPIPV4SRPOLICYNLRIPREFIX']._serialized_end=48743
  _globals['_BGPIPV6SRPOLICYNLRIPREFIX']._serialized_start=48746
  _globals['_BGPIPV6SRPOLICYNLRIPREFIX']._serialized_end=48885
  _globals['_BGPATTRIBUTES']._serialized_start=48888
  _globals['_BGPATTRIBUTES']._serialized_end=49895
  _globals['_BGPATTRIBUTES_ORIGIN']._serialized_start=27011
  _globals['_BGPATTRIBUTES_ORIGIN']._serialized_end=27078
  _globals['_BGPATTRIBUTES_ORIGIN_ENUM']._serialized_start=27021
  _globals['_BGPATTRIBUTES_ORIGIN_ENUM']._serialized_end=27078
  _globals['_BGPATTRIBUTESOTHERATTRIBUTE']._serialized_start=49898
  _globals['_BGPATTRIBUTESOTHERATTRIBUTE']._serialized_end=50193
  _globals['_BGPATTRIBUTESASPATH']._serialized_start=50196
  _globals['_BGPATTRIBUTESASPATH']._serialized_end=50499
  _globals['_BGPATTRIBUTESASPATH_CHOICE']._serialized_start=50410
  _globals['_BGPATTRIBUTESASPATH_CHOICE']._serialized_end=50488
  _globals['_BGPATTRIBUTESASPATH_CHOICE_ENUM']._serialized_start=50420
  _globals['_BGPATTRIBUTESASPATH_CHOICE_ENUM']._serialized_end=50488
  _globals['_BGPATTRIBUTESASPATHFOURBYTEASPATH']._serialized_start=50501
  _globals['_BGPATTRIBUTESASPATHFOURBYTEASPATH']._serialized_end=50595
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT']._serialized_start=50598
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT']._serialized_end=50828
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE']._serialized_start=28443
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE']._serialized_end=28536
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_start=28451
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_end=28536
  _globals['_BGPATTRIBUTESASPATHTWOBYTEASPATH']._serialized_start=50830
  _globals['_BGPATTRIBUTESASPATHTWOBYTEASPATH']._serialized_end=50922
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT']._serialized_start=50925
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT']._serialized_end=51153
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE']._serialized_start=28443
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE']._serialized_end=28536
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_start=28451
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_end=28536
  _globals['_BGPATTRIBUTESAS4PATH']._serialized_start=51155
  _globals['_BGPATTRIBUTESAS4PATH']._serialized_end=51236
  _globals['_BGPATTRIBUTESAGGREGATOR']._serialized_start=51239
  _globals['_BGPATTRIBUTESAGGREGATOR']._serialized_end=51538
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE']._serialized_start=51409
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE']._serialized_end=51477
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE_ENUM']._serialized_start=51419
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE_ENUM']._serialized_end=51477
  _globals['_BGPATTRIBUTESAS4AGGREGATOR']._serialized_start=51540
  _globals['_BGPATTRIBUTESAS4AGGREGATOR']._serialized_end=51644
  _globals['_BGPATTRIBUTESCOMMUNITY']._serialized_start=51647
  _globals['_BGPATTRIBUTESCOMMUNITY']._serialized_end=51952
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE']._serialized_start=51797
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE']._serialized_end=51941
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE_ENUM']._serialized_start=51808
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE_ENUM']._serialized_end=51941
  _globals['_BGPATTRIBUTESCUSTOMCOMMUNITY']._serialized_start=51954
  _globals['_BGPATTRIBUTESCUSTOMCOMMUNITY']._serialized_end=52054
  _globals['_BGPATTRIBUTESNEXTHOP']._serialized_start=52057
  _globals['_BGPATTRIBUTESNEXTHOP']._serialized_end=52356
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE']._serialized_start=52250
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE']._serialized_end=52327
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE_ENUM']._serialized_start=52260
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE_ENUM']._serialized_end=52327
  _globals['_BGPATTRIBUTESNEXTHOPIPV6TWOADDRESSES']._serialized_start=52358
  _globals['_BGPATTRIBUTESNEXTHOPIPV6TWOADDRESSES']._serialized_end=52458
  _globals['_BGPATTRIBUTESMPREACHNLRI']._serialized_start=52461
  _globals['_BGPATTRIBUTESMPREACHNLRI']._serialized_end=52924
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE']._serialized_start=52806
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE']._serialized_end=52913
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE_ENUM']._serialized_start=52816
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE_ENUM']._serialized_end=52913
  _globals['_BGPATTRIBUTESMPUNREACHNLRI']._serialized_start=52927
  _globals['_BGPATTRIBUTESMPUNREACHNLRI']._serialized_end=53349
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE']._serialized_start=52806
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE']._serialized_end=52913
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE_ENUM']._serialized_start=52816
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE_ENUM']._serialized_end=52913
  _globals['_BGPATTRIBUTESMULTIEXITDISCRIMINATOR']._serialized_start=53351
  _globals['_BGPATTRIBUTESMULTIEXITDISCRIMINATOR']._serialized_end=53418
  _globals['_BGPATTRIBUTESLOCALPREFERENCE']._serialized_start=53420
  _globals['_BGPATTRIBUTESLOCALPREFERENCE']._serialized_end=53480
  _globals['_BGPATTRIBUTESORIGINATORID']._serialized_start=53482
  _globals['_BGPATTRIBUTESORIGINATORID']._serialized_end=53539
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION']._serialized_start=53542
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION']._serialized_end=53768
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE']._serialized_start=53709
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE']._serialized_end=53757
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE_ENUM']._serialized_start=53719
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE_ENUM']._serialized_end=53757
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICY']._serialized_start=53771
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICY']._serialized_end=54327
  _globals['_BGPATTRIBUTESBSID']._serialized_start=54330
  _globals['_BGPATTRIBUTESBSID']._serialized_end=54556
  _globals['_BGPATTRIBUTESBSID_CHOICE']._serialized_start=54492
  _globals['_BGPATTRIBUTESBSID_CHOICE']._serialized_end=54545
  _globals['_BGPATTRIBUTESBSID_CHOICE_ENUM']._serialized_start=54502
  _globals['_BGPATTRIBUTESBSID_CHOICE_ENUM']._serialized_end=54545
  _globals['_BGPATTRIBUTESBSIDMPLS']._serialized_start=54559
  _globals['_BGPATTRIBUTESBSIDMPLS']._serialized_end=54759
  _globals['_BGPATTRIBUTESBSIDSRV6']._serialized_start=54762
  _globals['_BGPATTRIBUTESBSIDSRV6']._serialized_end=54955
  _globals['_BGPATTRIBUTESSRV6BSID']._serialized_start=54958
  _globals['_BGPATTRIBUTESSRV6BSID']._serialized_end=55332
  _globals['_BGPATTRIBUTESSIDMPLS']._serialized_start=55335
  _globals['_BGPATTRIBUTESSIDMPLS']._serialized_end=55495
  _globals['_BGPATTRIBUTESSIDSRV6']._serialized_start=55497
  _globals['_BGPATTRIBUTESSIDSRV6']._serialized_end=55543
  _globals['_BGPATTRIBUTESSRPOLICYPREFERENCE']._serialized_start=55545
  _globals['_BGPATTRIBUTESSRPOLICYPREFERENCE']._serialized_end=55608
  _globals['_BGPATTRIBUTESSRPOLICYPRIORITY']._serialized_start=55610
  _globals['_BGPATTRIBUTESSRPOLICYPRIORITY']._serialized_end=55671
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYCANDIDATENAME']._serialized_start=55673
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYCANDIDATENAME']._serialized_end=55745
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYNAME']._serialized_start=55747
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYNAME']._serialized_end=55810
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY']._serialized_start=55813
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY']._serialized_end=56062
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE']._serialized_start=55935
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE']._serialized_end=56051
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE_ENUM']._serialized_start=55945
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE_ENUM']._serialized_end=56051
  _globals['_BGPATTRIBUTESSRPOLICYSEGMENTLIST']._serialized_start=56065
  _globals['_BGPATTRIBUTESSRPOLICYSEGMENTLIST']._serialized_end=56248
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTWEIGHT']._serialized_start=56250
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTWEIGHT']._serialized_end=56332
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT']._serialized_start=56335
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT']._serialized_end=57330
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE']._serialized_start=57153
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE']._serialized_end=57319
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE_ENUM']._serialized_start=42375
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE_ENUM']._serialized_end=42530
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEA']._serialized_start=57333
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEA']._serialized_end=57482
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEB']._serialized_start=57485
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEB']._serialized_end=57732
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEC']._serialized_start=57735
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEC']._serialized_end=57985
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPED']._serialized_start=57988
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPED']._serialized_end=58238
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEE']._serialized_start=58241
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEE']._serialized_end=58503
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEF']._serialized_start=58506
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEF']._serialized_end=58772
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEG']._serialized_start=58775
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEG']._serialized_end=59175
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEH']._serialized_start=59178
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEH']._serialized_end=59444
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEI']._serialized_start=59447
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEI']._serialized_end=59801
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEJ']._serialized_start=59804
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEJ']._serialized_end=60352
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEK']._serialized_start=60355
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEK']._serialized_end=60769
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEFLAGS']._serialized_start=60772
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEFLAGS']._serialized_end=60944
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_start=60947
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_end=61231
  _globals['_BGPNLRIPREFIXSEGMENTROUTINGDISTINGUISHER']._serialized_start=61233
  _globals['_BGPNLRIPREFIXSEGMENTROUTINGDISTINGUISHER']._serialized_end=61305
  _globals['_BGPV6PEER']._serialized_start=61308
  _globals['_BGPV6PEER']._serialized_end=62223
  _globals['_BGPV6PEER_ASTYPE']._serialized_start=25895
  _globals['_BGPV6PEER_ASTYPE']._serialized_end=25948
  _globals['_BGPV6PEER_ASTYPE_ENUM']._serialized_start=25905
  _globals['_BGPV6PEER_ASTYPE_ENUM']._serialized_end=25948
  _globals['_BGPV6PEER_ASNUMBERWIDTH']._serialized_start=25950
  _globals['_BGPV6PEER_ASNUMBERWIDTH']._serialized_end=26009
  _globals['_BGPV6PEER_ASNUMBERWIDTH_ENUM']._serialized_start=25967
  _globals['_BGPV6PEER_ASNUMBERWIDTH_ENUM']._serialized_end=26009
  _globals['_BGPV6INTERFACE']._serialized_start=62225
  _globals['_BGPV6INTERFACE']._serialized_end=62310
  _globals['_BGPV6SEGMENTROUTING']._serialized_start=62313
  _globals['_BGPV6SEGMENTROUTING']._serialized_end=62810
  _globals['_BGPV6ETHERNETSEGMENT']._serialized_start=62813
  _globals['_BGPV6ETHERNETSEGMENT']._serialized_end=63309
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE']._serialized_start=26557
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE']._serialized_end=26629
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_start=26571
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_end=26629
  _globals['_BGPV6EVPNEVIS']._serialized_start=63312
  _globals['_BGPV6EVPNEVIS']._serialized_end=63480
  _globals['_BGPV6EVPNEVIS_CHOICE']._serialized_start=28657
  _globals['_BGPV6EVPNEVIS_CHOICE']._serialized_end=28705
  _globals['_BGPV6EVPNEVIS_CHOICE_ENUM']._serialized_start=28667
  _globals['_BGPV6EVPNEVIS_CHOICE_ENUM']._serialized_end=28705
  _globals['_BGPV6EVIVXLAN']._serialized_start=63483
  _globals['_BGPV6EVIVXLAN']._serialized_end=64222
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE']._serialized_start=29342
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE']._serialized_end=29409
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_start=29361
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_end=29409
  _globals['_BGPV6EVIVXLANBROADCASTDOMAIN']._serialized_start=64225
  _globals['_BGPV6EVIVXLANBROADCASTDOMAIN']._serialized_end=64405
  _globals['_DEVICEVXLAN']._serialized_start=64407
  _globals['_DEVICEVXLAN']._serialized_end=64500
  _globals['_VXLANV4TUNNEL']._serialized_start=64503
  _globals['_VXLANV4TUNNEL']._serialized_end=64690
  _globals['_VXLANV6TUNNEL']._serialized_start=64693
  _globals['_VXLANV6TUNNEL']._serialized_end=64880
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE']._serialized_start=64883
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE']._serialized_end=65185
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE']._serialized_start=65113
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE']._serialized_end=65174
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_start=65123
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_end=65174
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE']._serialized_start=65188
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE']._serialized_end=65490
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE']._serialized_start=65113
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE']._serialized_end=65174
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_start=65123
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_end=65174
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICAST']._serialized_start=65492
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICAST']._serialized_end=65594
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICAST']._serialized_start=65596
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICAST']._serialized_end=65698
  _globals['_VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE']._serialized_start=65701
  _globals['_VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE']._serialized_end=65851
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_start=65854
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_end=66047
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_start=66050
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_end=66243
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEMULTICAST']._serialized_start=66245
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEMULTICAST']._serialized_end=66320
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEMULTICAST']._serialized_start=66322
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEMULTICAST']._serialized_end=66397
  _globals['_DEVICERSVP']._serialized_start=66400
  _globals['_DEVICERSVP']._serialized_end=66545
  _globals['_RSVPIPV4INTERFACE']._serialized_start=66548
  _globals['_RSVPIPV4INTERFACE']._serialized_end=67129
  _globals['_RSVPLSPIPV4INTERFACE']._serialized_start=67132
  _globals['_RSVPLSPIPV4INTERFACE']._serialized_end=67340
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP']._serialized_start=67343
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP']._serialized_end=67840
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE']._serialized_start=67628
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE']._serialized_end=67720
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM']._serialized_start=67648
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM']._serialized_end=67720
  _globals['_RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP']._serialized_start=67843
  _globals['_RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP']._serialized_end=68398
  _globals['_RSVPSESSIONATTRIBUTE']._serialized_start=68401
  _globals['_RSVPSESSIONATTRIBUTE']._serialized_end=69025
  _globals['_RSVPRESOURCEAFFINITIES']._serialized_start=69028
  _globals['_RSVPRESOURCEAFFINITIES']._serialized_end=69178
  _globals['_RSVPTSPEC']._serialized_start=69181
  _globals['_RSVPTSPEC']._serialized_end=69468
  _globals['_RSVPFASTREROUTE']._serialized_start=69471
  _globals['_RSVPFASTREROUTE']._serialized_end=69926
  _globals['_RSVPERO']._serialized_start=69929
  _globals['_RSVPERO']._serialized_end=70225
  _globals['_RSVPERO_PREPENDNEIGHBORIP']._serialized_start=70082
  _globals['_RSVPERO_PREPENDNEIGHBORIP']._serialized_end=70183
  _globals['_RSVPERO_PREPENDNEIGHBORIP_ENUM']._serialized_start=70103
  _globals['_RSVPERO_PREPENDNEIGHBORIP_ENUM']._serialized_end=70183
  _globals['_RSVPEROSUBOBJECT']._serialized_start=70228
  _globals['_RSVPEROSUBOBJECT']._serialized_end=70624
  _globals['_RSVPEROSUBOBJECT_TYPE']._serialized_start=70438
  _globals['_RSVPEROSUBOBJECT_TYPE']._serialized_end=70494
  _globals['_RSVPEROSUBOBJECT_TYPE_ENUM']._serialized_start=70446
  _globals['_RSVPEROSUBOBJECT_TYPE_ENUM']._serialized_end=70494
  _globals['_RSVPEROSUBOBJECT_HOPTYPE']._serialized_start=70496
  _globals['_RSVPEROSUBOBJECT_HOPTYPE']._serialized_end=70553
  _globals['_RSVPEROSUBOBJECT_HOPTYPE_ENUM']._serialized_start=70507
  _globals['_RSVPEROSUBOBJECT_HOPTYPE_ENUM']._serialized_end=70553
  _globals['_DEVICEDHCPSERVER']._serialized_start=70626
  _globals['_DEVICEDHCPSERVER']._serialized_end=70732
  _globals['_DHCPSERVERV4']._serialized_start=70734
  _globals['_DHCPSERVERV4']._serialized_end=70860
  _globals['_DHCPSERVERV4POOL']._serialized_start=70863
  _globals['_DHCPSERVERV4POOL']._serialized_end=71145
  _globals['_DHCPSERVERV4POOLOPTION']._serialized_start=71148
  _globals['_DHCPSERVERV4POOLOPTION']._serialized_end=71400
  _globals['_DHCPSERVERV6']._serialized_start=71403
  _globals['_DHCPSERVERV6']._serialized_end=71684
  _globals['_DHCPV6SERVEROPTIONS']._serialized_start=71687
  _globals['_DHCPV6SERVEROPTIONS']._serialized_end=71859
  _globals['_DHCPV6SERVERLEASE']._serialized_start=71861
  _globals['_DHCPV6SERVERLEASE']._serialized_end=71962
  _globals['_DHCPV6SERVERIATYPE']._serialized_start=71965
  _globals['_DHCPV6SERVERIATYPE']._serialized_end=72307
  _globals['_DHCPV6SERVERIATYPE_CHOICE']._serialized_start=5736
  _globals['_DHCPV6SERVERIATYPE_CHOICE']._serialized_end=5811
  _globals['_DHCPV6SERVERIATYPE_CHOICE_ENUM']._serialized_start=5746
  _globals['_DHCPV6SERVERIATYPE_CHOICE_ENUM']._serialized_end=5811
  _globals['_DHCPV6SERVERPOOLINFO']._serialized_start=72310
  _globals['_DHCPV6SERVERPOOLINFO']._serialized_end=72474
  _globals['_DHCPV6SERVERIAPDPOOLINFO']._serialized_start=72477
  _globals['_DHCPV6SERVERIAPDPOOLINFO']._serialized_end=72771
  _globals['_DHCPV6SERVERIANAPDPOOLINFO']._serialized_start=72773
  _globals['_DHCPV6SERVERIANAPDPOOLINFO']._serialized_end=72887
  _globals['_DHCPV6SERVERDNS']._serialized_start=72889
  _globals['_DHCPV6SERVERDNS']._serialized_end=72994
  _globals['_DHCPV6SERVERSECONDARYDNS']._serialized_start=72996
  _globals['_DHCPV6SERVERSECONDARYDNS']._serialized_end=73046
  _globals['_DEVICEOSPFV2ROUTER']._serialized_start=73049
  _globals['_DEVICEOSPFV2ROUTER']._serialized_end=73601
  _globals['_OSPFV2ROUTERID']._serialized_start=73604
  _globals['_OSPFV2ROUTERID']._serialized_end=73782
  _globals['_OSPFV2ROUTERID_CHOICE']._serialized_start=73697
  _globals['_OSPFV2ROUTERID_CHOICE']._serialized_end=73760
  _globals['_OSPFV2ROUTERID_CHOICE_ENUM']._serialized_start=73707
  _globals['_OSPFV2ROUTERID_CHOICE_ENUM']._serialized_end=73760
  _globals['_OSPFV2OPTIONS']._serialized_start=73785
  _globals['_OSPFV2OPTIONS']._serialized_end=74134
  _globals['_OSPFV2GRACEFULRESTART']._serialized_start=74136
  _globals['_OSPFV2GRACEFULRESTART']._serialized_end=74201
  _globals['_OSPFV2INTERFACE']._serialized_start=74204
  _globals['_OSPFV2INTERFACE']._serialized_end=74619
  _globals['_OSPFV2INTERFACEAREA']._serialized_start=74622
  _globals['_OSPFV2INTERFACEAREA']._serialized_end=74812
  _globals['_OSPFV2INTERFACEAREA_CHOICE']._serialized_start=74738
  _globals['_OSPFV2INTERFACEAREA_CHOICE']._serialized_end=74787
  _globals['_OSPFV2INTERFACEAREA_CHOICE_ENUM']._serialized_start=74748
  _globals['_OSPFV2INTERFACEAREA_CHOICE_ENUM']._serialized_end=74787
  _globals['_OSPFV2INTERFACENETWORKTYPE']._serialized_start=74815
  _globals['_OSPFV2INTERFACENETWORKTYPE']._serialized_end=75074
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE']._serialized_start=74970
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE']._serialized_end=75063
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE_ENUM']._serialized_start=74980
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE_ENUM']._serialized_end=75063
  _globals['_OSPFV2INTERFACENEIGHBOR']._serialized_start=75076
  _globals['_OSPFV2INTERFACENEIGHBOR']._serialized_end=75143
  _globals['_OSPFV2INTERFACEADVANCED']._serialized_start=75146
  _globals['_OSPFV2INTERFACEADVANCED']._serialized_end=75411
  _globals['_OSPFV2INTERFACEOPTIONS']._serialized_start=75414
  _globals['_OSPFV2INTERFACEOPTIONS']._serialized_end=75696
  _globals['_OSPFV2INTERFACEAUTHENTICATION']._serialized_start=75699
  _globals['_OSPFV2INTERFACEAUTHENTICATION']._serialized_end=75955
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE']._serialized_start=75870
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE']._serialized_end=75929
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE_ENUM']._serialized_start=75880
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE_ENUM']._serialized_end=75929
  _globals['_OSPFV2AUTHENTICATIONMD5']._serialized_start=75957
  _globals['_OSPFV2AUTHENTICATIONMD5']._serialized_end=76040
  _globals['_OSPFV2INTERFACELINKPROTECTION']._serialized_start=76043
  _globals['_OSPFV2INTERFACELINKPROTECTION']._serialized_end=76422
  _globals['_OSPFV2V4ROUTERANGE']._serialized_start=76425
  _globals['_OSPFV2V4ROUTERANGE']._serialized_end=76595
  _globals['_OSPFV2V4RRROUTEORIGIN']._serialized_start=76598
  _globals['_OSPFV2V4RRROUTEORIGIN']._serialized_end=77075
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE']._serialized_start=76938
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE']._serialized_end=77064
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE_ENUM']._serialized_start=76948
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE_ENUM']._serialized_end=77064
  _globals['_OSPFV2V4RRINTRAAREA']._serialized_start=77077
  _globals['_OSPFV2V4RRINTRAAREA']._serialized_end=77145
  _globals['_OSPFV2V4RRINTERAREA']._serialized_start=77147
  _globals['_OSPFV2V4RRINTERAREA']._serialized_end=77215
  _globals['_OSPFV2V4RREXTERNALTYPE1']._serialized_start=77217
  _globals['_OSPFV2V4RREXTERNALTYPE1']._serialized_end=77289
  _globals['_OSPFV2V4RREXTERNALTYPE2']._serialized_start=77291
  _globals['_OSPFV2V4RREXTERNALTYPE2']._serialized_end=77363
  _globals['_OSPFV2V4RRNSSAEXTERNAL']._serialized_start=77365
  _globals['_OSPFV2V4RRNSSAEXTERNAL']._serialized_end=77478
  _globals['_OSPFV2V4RREXTDPREFIXFLAGS']._serialized_start=77480
  _globals['_OSPFV2V4RREXTDPREFIXFLAGS']._serialized_end=77571
  _globals['_DEVICEMACSEC']._serialized_start=77573
  _globals['_DEVICEMACSEC']._serialized_end=77652
  _globals['_DEVICEMACSECETHERNETINTERFACE']._serialized_start=77654
  _globals['_DEVICEMACSECETHERNETINTERFACE']._serialized_end=77763
  _globals['_SECUREENTITY']._serialized_start=77766
  _globals['_SECUREENTITY']._serialized_end=77929
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL']._serialized_start=77932
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL']._serialized_end=78182
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE']._serialized_start=78113
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE']._serialized_end=78171
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE_ENUM']._serialized_start=78123
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE_ENUM']._serialized_end=78171
  _globals['_SECUREENTITYDATAPLANE']._serialized_start=78185
  _globals['_SECUREENTITYDATAPLANE']._serialized_end=78420
  _globals['_SECUREENTITYDATAPLANE_CHOICE']._serialized_start=78335
  _globals['_SECUREENTITYDATAPLANE_CHOICE']._serialized_end=78409
  _globals['_SECUREENTITYDATAPLANE_CHOICE_ENUM']._serialized_start=78345
  _globals['_SECUREENTITYDATAPLANE_CHOICE_ENUM']._serialized_end=78409
  _globals['_SECUREENTITYDATAPLANEENCAPSULATION']._serialized_start=78423
  _globals['_SECUREENTITYDATAPLANEENCAPSULATION']._serialized_end=78597
  _globals['_SECUREENTITYDATAPLANETX']._serialized_start=78599
  _globals['_SECUREENTITYDATAPLANETX']._serialized_end=78708
  _globals['_SECUREENTITYDATAPLANERX']._serialized_start=78710
  _globals['_SECUREENTITYDATAPLANERX']._serialized_end=78835
  _globals['_SECUREENTITYCRYPTOENGINE']._serialized_start=78838
  _globals['_SECUREENTITYCRYPTOENGINE']._serialized_end=79056
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE']._serialized_start=78994
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE']._serialized_end=79045
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE_ENUM']._serialized_start=79004
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE_ENUM']._serialized_end=79045
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLY']._serialized_start=79059
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLY']._serialized_end=79248
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSC']._serialized_start=79250
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSC']._serialized_end=79356
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN']._serialized_start=79359
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN']._serialized_end=79710
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE']._serialized_start=79631
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE']._serialized_end=79699
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE_ENUM']._serialized_start=79641
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE_ENUM']._serialized_end=79699
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYFIXEDPN']._serialized_start=79712
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYFIXEDPN']._serialized_end=79806
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYINCREMENTINGPN']._serialized_start=79809
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYINCREMENTINGPN']._serialized_end=79976
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTRAFFICOPTIONS']._serialized_start=79978
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTRAFFICOPTIONS']._serialized_end=80087
  _globals['_MKA']._serialized_start=80089
  _globals['_MKA']._serialized_end=80215
  _globals['_MKABASIC']._serialized_start=80218
  _globals['_MKABASIC']._serialized_end=81368
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION']._serialized_start=80844
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION']._serialized_end=80928
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION_ENUM']._serialized_start=80869
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION_ENUM']._serialized_end=80928
  _globals['_MKABASIC_MACSECCAPABILITY']._serialized_start=80931
  _globals['_MKABASIC_MACSECCAPABILITY']._serialized_end=81152
  _globals['_MKABASIC_MACSECCAPABILITY_ENUM']._serialized_start=80952
  _globals['_MKABASIC_MACSECCAPABILITY_ENUM']._serialized_end=81152
  _globals['_MKABASICSUPPORTEDCIPHERSUITES']._serialized_start=81371
  _globals['_MKABASICSUPPORTEDCIPHERSUITES']._serialized_end=81586
  _globals['_MKABASICKEYSOURCE']._serialized_start=81589
  _globals['_MKABASICKEYSOURCE']._serialized_end=81770
  _globals['_MKABASICKEYSOURCE_CHOICE']._serialized_start=81708
  _globals['_MKABASICKEYSOURCE_CHOICE']._serialized_end=81759
  _globals['_MKABASICKEYSOURCE_CHOICE_ENUM']._serialized_start=81718
  _globals['_MKABASICKEYSOURCE_CHOICE_ENUM']._serialized_end=81759
  _globals['_MKABASICKEYSOURCEPSK']._serialized_start=81773
  _globals['_MKABASICKEYSOURCEPSK']._serialized_end=81979
  _globals['_MKABASICSTARTOFFSETTIME']._serialized_start=81981
  _globals['_MKABASICSTARTOFFSETTIME']._serialized_end=82054
  _globals['_MKABASICENDOFFSETTIME']._serialized_start=82056
  _globals['_MKABASICENDOFFSETTIME']._serialized_end=82127
  _globals['_MKABASICPSKCHAINSTARTTIME']._serialized_start=82130
  _globals['_MKABASICPSKCHAINSTARTTIME']._serialized_end=82312
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE']._serialized_start=82259
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE']._serialized_end=82301
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE_ENUM']._serialized_start=82269
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE_ENUM']._serialized_end=82301
  _globals['_MKABASICTIMEUTC']._serialized_start=82315
  _globals['_MKABASICTIMEUTC']._serialized_end=82508
  _globals['_MKABASICREKEYMODE']._serialized_start=82511
  _globals['_MKABASICREKEYMODE']._serialized_end=82735
  _globals['_MKABASICREKEYMODE_CHOICE']._serialized_start=82644
  _globals['_MKABASICREKEYMODE_CHOICE']._serialized_end=82724
  _globals['_MKABASICREKEYMODE_CHOICE_ENUM']._serialized_start=82654
  _globals['_MKABASICREKEYMODE_CHOICE_ENUM']._serialized_end=82724
  _globals['_MKABASICREKEYMODETIMERBASED']._serialized_start=82738
  _globals['_MKABASICREKEYMODETIMERBASED']._serialized_end=82991
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE']._serialized_start=82885
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE']._serialized_end=82951
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_start=82895
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_end=82951
  _globals['_MKAKEYSERVER']._serialized_start=82994
  _globals['_MKAKEYSERVER']._serialized_end=83731
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET']._serialized_start=83294
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET']._serialized_end=83473
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET_ENUM']._serialized_start=83319
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET_ENUM']._serialized_end=83473
  _globals['_MKAKEYSERVER_CIPHERSUITE']._serialized_start=83475
  _globals['_MKAKEYSERVER_CIPHERSUITE']._serialized_end=83589
  _globals['_MKAKEYSERVER_CIPHERSUITE_ENUM']._serialized_start=83490
  _globals['_MKAKEYSERVER_CIPHERSUITE_ENUM']._serialized_end=83589
  _globals['_MKATX']._serialized_start=83733
  _globals['_MKATX']._serialized_end=83779
  _globals['_MKATXSC']._serialized_start=83782
  _globals['_MKATXSC']._serialized_end=83957
  _globals['_SECUREENTITYSTATICKEY']._serialized_start=83960
  _globals['_SECUREENTITYSTATICKEY']._serialized_end=84524
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE']._serialized_start=83475
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE']._serialized_end=83589
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE_ENUM']._serialized_start=83490
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE_ENUM']._serialized_end=83589
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET']._serialized_start=84379
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET']._serialized_end=84460
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET_ENUM']._serialized_start=84404
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET_ENUM']._serialized_end=84460
  _globals['_SECUREENTITYSTATICKEYREKEYMODE']._serialized_start=84527
  _globals['_SECUREENTITYSTATICKEYREKEYMODE']._serialized_end=84790
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE']._serialized_start=82644
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE']._serialized_end=82724
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE_ENUM']._serialized_start=82654
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE_ENUM']._serialized_end=82724
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED']._serialized_start=84793
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED']._serialized_end=85072
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE']._serialized_start=82885
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE']._serialized_end=82951
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_start=82895
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_end=82951
  _globals['_SECUREENTITYSTATICKEYSAK']._serialized_start=85074
  _globals['_SECUREENTITYSTATICKEYSAK']._serialized_end=85182
  _globals['_SECUREENTITYSTATICKEYTX']._serialized_start=85185
  _globals['_SECUREENTITYSTATICKEYTX']._serialized_end=85324
  _globals['_SECUREENTITYSTATICKEYTXSC']._serialized_start=85327
  _globals['_SECUREENTITYSTATICKEYTXSC']._serialized_end=85471
  _globals['_SECUREENTITYSTATICKEYRX']._serialized_start=85473
  _globals['_SECUREENTITYSTATICKEYRX']._serialized_end=85555
  _globals['_SECUREENTITYSTATICKEYRXSC']._serialized_start=85558
  _globals['_SECUREENTITYSTATICKEYRXSC']._serialized_end=85776
  _globals['_DEVICEOSPFV3ROUTER']._serialized_start=85778
  _globals['_DEVICEOSPFV3ROUTER']._serialized_end=85884
  _globals['_OSPFV3ROUTERINSTANCE']._serialized_start=85887
  _globals['_OSPFV3ROUTERINSTANCE']._serialized_end=86340
  _globals['_OSPFV3ROUTERID']._serialized_start=86343
  _globals['_OSPFV3ROUTERID']._serialized_end=86513
  _globals['_OSPFV3ROUTERID_CHOICE']._serialized_start=86436
  _globals['_OSPFV3ROUTERID_CHOICE']._serialized_end=86491
  _globals['_OSPFV3ROUTERID_CHOICE_ENUM']._serialized_start=86446
  _globals['_OSPFV3ROUTERID_CHOICE_ENUM']._serialized_end=86491
  _globals['_OSPFV3CAPABILITIES']._serialized_start=86515
  _globals['_OSPFV3CAPABILITIES']._serialized_end=86611
  _globals['_OSPFV3GRACEFULRESTART']._serialized_start=86613
  _globals['_OSPFV3GRACEFULRESTART']._serialized_end=86678
  _globals['_OSPFV3INTERFACE']._serialized_start=86681
  _globals['_OSPFV3INTERFACE']._serialized_end=86995
  _globals['_OSPFV3INTERFACEAREA']._serialized_start=86998
  _globals['_OSPFV3INTERFACEAREA']._serialized_end=87188
  _globals['_OSPFV3INTERFACEAREA_CHOICE']._serialized_start=74738
  _globals['_OSPFV3INTERFACEAREA_CHOICE']._serialized_end=74787
  _globals['_OSPFV3INTERFACEAREA_CHOICE_ENUM']._serialized_start=74748
  _globals['_OSPFV3INTERFACEAREA_CHOICE_ENUM']._serialized_end=74787
  _globals['_OSPFV3INTERFACENETWORKTYPE']._serialized_start=87191
  _globals['_OSPFV3INTERFACENETWORKTYPE']._serialized_end=87416
  _globals['_OSPFV3INTERFACENETWORKTYPE_CHOICE']._serialized_start=87337
  _globals['_OSPFV3INTERFACENETWORKTYPE_CHOICE']._serialized_end=87405
  _globals['_OSPFV3INTERFACENETWORKTYPE_CHOICE_ENUM']._serialized_start=16349
  _globals['_OSPFV3INTERFACENETWORKTYPE_CHOICE_ENUM']._serialized_end=16407
  _globals['_OSPFV3INTERFACEADVANCED']._serialized_start=87419
  _globals['_OSPFV3INTERFACEADVANCED']._serialized_end=87642
  _globals['_OSPFV3INTERFACEOPTIONS']._serialized_start=87645
  _globals['_OSPFV3INTERFACEOPTIONS']._serialized_end=87823
  _globals['_OSPFV3INTERFACEBROADCAST']._serialized_start=87825
  _globals['_OSPFV3INTERFACEBROADCAST']._serialized_end=87887
  _globals['_OSPFV3V6ROUTERANGE']._serialized_start=87890
  _globals['_OSPFV3V6ROUTERANGE']._serialized_end=88060
  _globals['_OSPFV3V6RRROUTEORIGIN']._serialized_start=88063
  _globals['_OSPFV3V6RRROUTEORIGIN']._serialized_end=88338
  _globals['_OSPFV3V6RRROUTEORIGIN_CHOICE']._serialized_start=76938
  _globals['_OSPFV3V6RRROUTEORIGIN_CHOICE']._serialized_end=77064
  _globals['_OSPFV3V6RRROUTEORIGIN_CHOICE_ENUM']._serialized_start=76948
  _globals['_OSPFV3V6RRROUTEORIGIN_CHOICE_ENUM']._serialized_end=77064
  _globals['_OSPFV3V6RRNSSAEXTERNAL']._serialized_start=88340
  _globals['_OSPFV3V6RRNSSAEXTERNAL']._serialized_end=88415
  _globals['_OSPFV3V6RRCAPABILITIES']._serialized_start=88418
  _globals['_OSPFV3V6RRCAPABILITIES']._serialized_end=88546
  _globals['_OSPFV3V6RRFORWARDINGADDRESS']._serialized_start=88549
  _globals['_OSPFV3V6RRFORWARDINGADDRESS']._serialized_end=88753
  _globals['_OSPFV3V6RRFORWARDINGADDRESS_CHOICE']._serialized_start=73697
  _globals['_OSPFV3V6RRFORWARDINGADDRESS_CHOICE']._serialized_end=73760
  _globals['_OSPFV3V6RRFORWARDINGADDRESS_CHOICE_ENUM']._serialized_start=73707
  _globals['_OSPFV3V6RRFORWARDINGADDRESS_CHOICE_ENUM']._serialized_end=73760
  _globals['_DEVICEROCEV2PEER']._serialized_start=88755
  _globals['_DEVICEROCEV2PEER']._serialized_end=88871
  _globals['_ROCEV2V4INTERFACE']._serialized_start=88873
  _globals['_ROCEV2V4INTERFACE']._serialized_end=88996
  _globals['_ROCEV2V4PEER']._serialized_start=88999
  _globals['_ROCEV2V4PEER']._serialized_end=89134
  _globals['_ROCEV2QPS']._serialized_start=89136
  _globals['_ROCEV2QPS']._serialized_end=89233
  _globals['_ROCEV2CONNECTIONTYPE']._serialized_start=89236
  _globals['_ROCEV2CONNECTIONTYPE']._serialized_end=89443
  _globals['_ROCEV2CONNECTIONTYPE_CHOICE']._serialized_start=89374
  _globals['_ROCEV2CONNECTIONTYPE_CHOICE']._serialized_end=89432
  _globals['_ROCEV2CONNECTIONTYPE_CHOICE_ENUM']._serialized_start=89384
  _globals['_ROCEV2CONNECTIONTYPE_CHOICE_ENUM']._serialized_end=89432
  _globals['_ROCEV2QPPARAMETERS']._serialized_start=89446
  _globals['_ROCEV2QPPARAMETERS']._serialized_end=89863
  _globals['_ROCEV2QPPARAMETERS_ECN']._serialized_start=89681
  _globals['_ROCEV2QPPARAMETERS_ECN']._serialized_end=89754
  _globals['_ROCEV2QPPARAMETERS_ECN_ENUM']._serialized_start=89688
  _globals['_ROCEV2QPPARAMETERS_ECN_ENUM']._serialized_end=89754
  _globals['_ROCEV2V6INTERFACE']._serialized_start=89865
  _globals['_ROCEV2V6INTERFACE']._serialized_end=89988
  _globals['_ROCEV2V6PEER']._serialized_start=89991
  _globals['_ROCEV2V6PEER']._serialized_end=90126
  _globals['_FLOW']._serialized_start=90129
  _globals['_FLOW']._serialized_end=90431
  _globals['_FLOWTXRX']._serialized_start=90434
  _globals['_FLOWTXRX']._serialized_end=90622
  _globals['_FLOWTXRX_CHOICE']._serialized_start=90556
  _globals['_FLOWTXRX_CHOICE']._serialized_end=90611
  _globals['_FLOWTXRX_CHOICE_ENUM']._serialized_start=90566
  _globals['_FLOWTXRX_CHOICE_ENUM']._serialized_end=90611
  _globals['_FLOWPORT']._serialized_start=90624
  _globals['_FLOWPORT']._serialized_end=90720
  _globals['_FLOWROUTER']._serialized_start=90723
  _globals['_FLOWROUTER']._serialized_end=90885
  _globals['_FLOWROUTER_MODE']._serialized_start=90819
  _globals['_FLOWROUTER_MODE']._serialized_end=90876
  _globals['_FLOWROUTER_MODE_ENUM']._serialized_start=90827
  _globals['_FLOWROUTER_MODE_ENUM']._serialized_end=90876
  _globals['_FLOWHEADER']._serialized_start=90888
  _globals['_FLOWHEADER']._serialized_end=91973
  _globals['_FLOWHEADER_CHOICE']._serialized_start=91672
  _globals['_FLOWHEADER_CHOICE']._serialized_end=91962
  _globals['_FLOWHEADER_CHOICE_ENUM']._serialized_start=91683
  _globals['_FLOWHEADER_CHOICE_ENUM']._serialized_end=91962
  _globals['_FLOWCUSTOM']._serialized_start=91975
  _globals['_FLOWCUSTOM']._serialized_end=92064
  _globals['_FLOWCUSTOMMETRICTAG']._serialized_start=92066
  _globals['_FLOWCUSTOMMETRICTAG']._serialized_end=92179
  _globals['_FLOWETHERNET']._serialized_start=92182
  _globals['_FLOWETHERNET']._serialized_end=92388
  _globals['_FLOWVLAN']._serialized_start=92391
  _globals['_FLOWVLAN']._serialized_end=92563
  _globals['_FLOWVXLAN']._serialized_start=92566
  _globals['_FLOWVXLAN']._serialized_end=92761
  _globals['_FLOWIPV4']._serialized_start=92764
  _globals['_FLOWIPV4']._serialized_end=93536
  _globals['_FLOWIPV4OPTIONS']._serialized_start=93539
  _globals['_FLOWIPV4OPTIONS']._serialized_end=93731
  _globals['_FLOWIPV4OPTIONS_CHOICE']._serialized_start=93657
  _globals['_FLOWIPV4OPTIONS_CHOICE']._serialized_end=93720
  _globals['_FLOWIPV4OPTIONS_CHOICE_ENUM']._serialized_start=93667
  _globals['_FLOWIPV4OPTIONS_CHOICE_ENUM']._serialized_end=93720
  _globals['_FLOWIPV4OPTIONSCUSTOM']._serialized_start=93734
  _globals['_FLOWIPV4OPTIONSCUSTOM']._serialized_end=93883
  _globals['_FLOWIPV4OPTIONSCUSTOMTYPE']._serialized_start=93886
  _globals['_FLOWIPV4OPTIONSCUSTOMTYPE']._serialized_end=94129
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH']._serialized_start=94132
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH']._serialized_end=94353
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWIPV4PRIORITY']._serialized_start=94356
  _globals['_FLOWIPV4PRIORITY']._serialized_end=94614
  _globals['_FLOWIPV4PRIORITY_CHOICE']._serialized_start=94542
  _globals['_FLOWIPV4PRIORITY_CHOICE']._serialized_end=94603
  _globals['_FLOWIPV4PRIORITY_CHOICE_ENUM']._serialized_start=94552
  _globals['_FLOWIPV4PRIORITY_CHOICE_ENUM']._serialized_end=94603
  _globals['_FLOWIPV4DSCP']._serialized_start=94616
  _globals['_FLOWIPV4DSCP']._serialized_end=94714
  _globals['_FLOWIPV4TOS']._serialized_start=94717
  _globals['_FLOWIPV4TOS']._serialized_end=95040
  _globals['_FLOWIPV4AUTO']._serialized_start=95042
  _globals['_FLOWIPV4AUTO']._serialized_end=95164
  _globals['_FLOWIPV4AUTO_CHOICE']._serialized_start=95110
  _globals['_FLOWIPV4AUTO_CHOICE']._serialized_end=95153
  _globals['_FLOWIPV4AUTO_CHOICE_ENUM']._serialized_start=95120
  _globals['_FLOWIPV4AUTO_CHOICE_ENUM']._serialized_end=95153
  _globals['_FLOWIPV6']._serialized_start=95167
  _globals['_FLOWIPV6']._serialized_end=95568
  _globals['_FLOWIPV6AUTO']._serialized_start=95570
  _globals['_FLOWIPV6AUTO']._serialized_end=95692
  _globals['_FLOWIPV6AUTO_CHOICE']._serialized_start=95110
  _globals['_FLOWIPV6AUTO_CHOICE']._serialized_end=95153
  _globals['_FLOWIPV6AUTO_CHOICE_ENUM']._serialized_start=95120
  _globals['_FLOWIPV6AUTO_CHOICE_ENUM']._serialized_end=95153
  _globals['_FLOWPFCPAUSE']._serialized_start=95695
  _globals['_FLOWPFCPAUSE']._serialized_end=96464
  _globals['_FLOWETHERNETPAUSE']._serialized_start=96467
  _globals['_FLOWETHERNETPAUSE']._serialized_end=96758
  _globals['_FLOWTCP']._serialized_start=96761
  _globals['_FLOWTCP']._serialized_end=97488
  _globals['_FLOWUDP']._serialized_start=97491
  _globals['_FLOWUDP']._serialized_end=97682
  _globals['_FLOWGRE']._serialized_start=97685
  _globals['_FLOWGRE']._serialized_end=97993
  _globals['_FLOWGTPV1']._serialized_start=97996
  _globals['_FLOWGTPV1']._serialized_end=98699
  _globals['_FLOWGTPEXTENSION']._serialized_start=98702
  _globals['_FLOWGTPEXTENSION']._serialized_end=98927
  _globals['_FLOWGTPV2']._serialized_start=98930
  _globals['_FLOWGTPV2']._serialized_end=99413
  _globals['_FLOWARP']._serialized_start=99416
  _globals['_FLOWARP']._serialized_end=99982
  _globals['_FLOWICMP']._serialized_start=99985
  _globals['_FLOWICMP']._serialized_end=100132
  _globals['_FLOWICMP_CHOICE']._serialized_start=100078
  _globals['_FLOWICMP_CHOICE']._serialized_end=100121
  _globals['_FLOWICMP_CHOICE_ENUM']._serialized_start=100088
  _globals['_FLOWICMP_CHOICE_ENUM']._serialized_end=100121
  _globals['_FLOWICMPECHO']._serialized_start=100135
  _globals['_FLOWICMPECHO']._serialized_end=100410
  _globals['_FLOWICMPV6']._serialized_start=100413
  _globals['_FLOWICMPV6']._serialized_end=100566
  _globals['_FLOWICMPV6_CHOICE']._serialized_start=100078
  _globals['_FLOWICMPV6_CHOICE']._serialized_end=100121
  _globals['_FLOWICMPV6_CHOICE_ENUM']._serialized_start=100088
  _globals['_FLOWICMPV6_CHOICE_ENUM']._serialized_end=100121
  _globals['_FLOWICMPV6ECHO']._serialized_start=100569
  _globals['_FLOWICMPV6ECHO']._serialized_end=100856
  _globals['_FLOWPPP']._serialized_start=100859
  _globals['_FLOWPPP']._serialized_end=101014
  _globals['_FLOWIGMPV1']._serialized_start=101017
  _globals['_FLOWIGMPV1']._serialized_end=101274
  _globals['_FLOWMPLS']._serialized_start=101277
  _globals['_FLOWMPLS']._serialized_end=101500
  _globals['_FLOWSNMPV2C']._serialized_start=101503
  _globals['_FLOWSNMPV2C']._serialized_end=101639
  _globals['_FLOWSNMPV2CDATA']._serialized_start=101642
  _globals['_FLOWSNMPV2CDATA']._serialized_end=102248
  _globals['_FLOWSNMPV2CDATA_CHOICE']._serialized_start=102062
  _globals['_FLOWSNMPV2CDATA_CHOICE']._serialized_end=102237
  _globals['_FLOWSNMPV2CDATA_CHOICE_ENUM']._serialized_start=102073
  _globals['_FLOWSNMPV2CDATA_CHOICE_ENUM']._serialized_end=102237
  _globals['_FLOWSNMPV2CPDU']._serialized_start=102251
  _globals['_FLOWSNMPV2CPDU']._serialized_end=102910
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS']._serialized_start=102511
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS']._serialized_end=102893
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS_ENUM']._serialized_start=102527
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS_ENUM']._serialized_end=102893
  _globals['_FLOWSNMPV2CBULKPDU']._serialized_start=102913
  _globals['_FLOWSNMPV2CBULKPDU']._serialized_end=103192
  _globals['_FLOWSNMPV2CVARIABLEBINDING']._serialized_start=103195
  _globals['_FLOWSNMPV2CVARIABLEBINDING']._serialized_end=103330
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE']._serialized_start=103333
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE']._serialized_end=104394
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE']._serialized_start=104087
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE']._serialized_end=104335
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE_ENUM']._serialized_start=104098
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE_ENUM']._serialized_end=104335
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE']._serialized_start=104397
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE']._serialized_end=104635
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE']._serialized_start=104553
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE']._serialized_end=104606
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE_ENUM']._serialized_start=104563
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE_ENUM']._serialized_end=104606
  _globals['_FLOWRSVP']._serialized_start=104638
  _globals['_FLOWRSVP']._serialized_end=105079
  _globals['_FLOWRSVP_FLAG']._serialized_start=104961
  _globals['_FLOWRSVP_FLAG']._serialized_end=105058
  _globals['_FLOWRSVP_FLAG_ENUM']._serialized_start=104969
  _globals['_FLOWRSVP_FLAG_ENUM']._serialized_end=105058
  _globals['_FLOWRSVPLENGTH']._serialized_start=105082
  _globals['_FLOWRSVPLENGTH']._serialized_end=105277
  _globals['_FLOWRSVPLENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWRSVPLENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWRSVPLENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWRSVPLENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWRSVPMESSAGE']._serialized_start=105280
  _globals['_FLOWRSVPMESSAGE']._serialized_end=105448
  _globals['_FLOWRSVPMESSAGE_CHOICE']._serialized_start=105394
  _globals['_FLOWRSVPMESSAGE_CHOICE']._serialized_end=105437
  _globals['_FLOWRSVPMESSAGE_CHOICE_ENUM']._serialized_start=105404
  _globals['_FLOWRSVPMESSAGE_CHOICE_ENUM']._serialized_end=105437
  _globals['_FLOWRSVPPATHMESSAGE']._serialized_start=105450
  _globals['_FLOWRSVPPATHMESSAGE']._serialized_end=105514
  _globals['_FLOWRSVPPATHOBJECTS']._serialized_start=105516
  _globals['_FLOWRSVPPATHOBJECTS']._serialized_end=105587
  _globals['_FLOWRSVPOBJECTLENGTH']._serialized_start=105590
  _globals['_FLOWRSVPOBJECTLENGTH']._serialized_end=105797
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWRSVPPATHOBJECTSCLASS']._serialized_start=105800
  _globals['_FLOWRSVPPATHOBJECTSCLASS']._serialized_end=106740
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE']._serialized_start=106520
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE']._serialized_end=106729
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE_ENUM']._serialized_start=106531
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE_ENUM']._serialized_end=106729
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSION']._serialized_start=106743
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSION']._serialized_end=106873
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE']._serialized_start=106876
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE']._serialized_end=107111
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE']._serialized_start=107046
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE']._serialized_end=107100
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE_ENUM']._serialized_start=107056
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE_ENUM']._serialized_end=107100
  _globals['_FLOWRSVPPATHSESSIONLSPTUNNELIPV4']._serialized_start=107114
  _globals['_FLOWRSVPPATHSESSIONLSPTUNNELIPV4']._serialized_end=107468
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID']._serialized_start=107471
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID']._serialized_end=107788
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE']._serialized_start=107715
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE']._serialized_end=107777
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE_ENUM']._serialized_start=107725
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE_ENUM']._serialized_end=107777
  _globals['_FLOWRSVPPATHOBJECTSCLASSRSVPHOP']._serialized_start=107791
  _globals['_FLOWRSVPPATHOBJECTSCLASSRSVPHOP']._serialized_end=107921
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE']._serialized_start=107924
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE']._serialized_end=108128
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE']._serialized_start=108074
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE']._serialized_end=108117
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE_ENUM']._serialized_start=33079
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE_ENUM']._serialized_end=33112
  _globals['_FLOWRSVPPATHRSVPHOPIPV4']._serialized_start=108131
  _globals['_FLOWRSVPPATHRSVPHOPIPV4']._serialized_end=108319
  _globals['_FLOWRSVPPATHOBJECTSCLASSTIMEVALUES']._serialized_start=108322
  _globals['_FLOWRSVPPATHOBJECTSCLASSTIMEVALUES']._serialized_end=108458
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE']._serialized_start=108461
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE']._serialized_end=108679
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE']._serialized_start=108623
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE']._serialized_end=108668
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE_ENUM']._serialized_start=108633
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE_ENUM']._serialized_end=108668
  _globals['_FLOWRSVPPATHTIMEVALUESTYPE1']._serialized_start=108681
  _globals['_FLOWRSVPPATHTIMEVALUESTYPE1']._serialized_end=108791
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTE']._serialized_start=108794
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTE']._serialized_end=108941
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE']._serialized_start=108944
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE']._serialized_end=109181
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE']._serialized_start=108623
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE']._serialized_end=108668
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE_ENUM']._serialized_start=108633
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE_ENUM']._serialized_end=108668
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1']._serialized_start=109183
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1']._serialized_end=109278
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTS']._serialized_start=109280
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTS']._serialized_end=109379
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE']._serialized_start=109382
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE']._serialized_end=109714
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE']._serialized_start=109638
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE']._serialized_end=109703
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE_ENUM']._serialized_start=109648
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE_ENUM']._serialized_end=109703
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIX']._serialized_start=109717
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIX']._serialized_end=110001
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBER']._serialized_start=110004
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBER']._serialized_end=110211
  _globals['_FLOWRSVPEXPLICITROUTELENGTH']._serialized_start=110214
  _globals['_FLOWRSVPEXPLICITROUTELENGTH']._serialized_end=110435
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH']._serialized_start=110438
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH']._serialized_end=110675
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWRSVPPATHOBJECTSCLASSLABELREQUEST']._serialized_start=110678
  _globals['_FLOWRSVPPATHOBJECTSCLASSLABELREQUEST']._serialized_end=110818
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE']._serialized_start=110821
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE']._serialized_end=111083
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE']._serialized_start=111014
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE']._serialized_end=111072
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE_ENUM']._serialized_start=111024
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE_ENUM']._serialized_end=111072
  _globals['_FLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGE']._serialized_start=111086
  _globals['_FLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGE']._serialized_end=111285
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSIONATTRIBUTE']._serialized_start=111288
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSIONATTRIBUTE']._serialized_end=111436
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE']._serialized_start=111439
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE']._serialized_end=111775
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE']._serialized_start=111696
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE']._serialized_end=111764
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE_ENUM']._serialized_start=111706
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE_ENUM']._serialized_end=111764
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNEL']._serialized_start=111778
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNEL']._serialized_end=112066
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNELRA']._serialized_start=112069
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNELRA']._serialized_end=112485
  _globals['_FLOWRSVPLSPTUNNELFLAG']._serialized_start=112488
  _globals['_FLOWRSVPLSPTUNNELFLAG']._serialized_end=112699
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE']._serialized_start=112574
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE']._serialized_end=112688
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE_ENUM']._serialized_start=112584
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE_ENUM']._serialized_end=112688
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH']._serialized_start=112702
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH']._serialized_end=112937
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTEMPLATE']._serialized_start=112940
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTEMPLATE']._serialized_end=113084
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE']._serialized_start=113087
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE']._serialized_end=113343
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE']._serialized_start=107046
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE']._serialized_end=107100
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE_ENUM']._serialized_start=107056
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE_ENUM']._serialized_end=107100
  _globals['_FLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4']._serialized_start=113346
  _globals['_FLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4']._serialized_end=113652
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTSPEC']._serialized_start=113655
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTSPEC']._serialized_end=113793
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE']._serialized_start=113796
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE']._serialized_end=114023
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE']._serialized_start=113965
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE']._serialized_end=114012
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE_ENUM']._serialized_start=113975
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE_ENUM']._serialized_end=114012
  _globals['_FLOWRSVPPATHSENDERTSPECINTSERV']._serialized_start=114026
  _globals['_FLOWRSVPPATHSENDERTSPECINTSERV']._serialized_end=115226
  _globals['_FLOWRSVPPATHOBJECTSCLASSRECORDROUTE']._serialized_start=115229
  _globals['_FLOWRSVPPATHOBJECTSCLASSRECORDROUTE']._serialized_end=115367
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE']._serialized_start=115370
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE']._serialized_end=115591
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE']._serialized_start=108623
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE']._serialized_end=108668
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE_ENUM']._serialized_start=108633
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE_ENUM']._serialized_end=108668
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1']._serialized_start=115593
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1']._serialized_end=115684
  _globals['_FLOWRSVPTYPE1RECORDROUTESUBOBJECTS']._serialized_start=115686
  _globals['_FLOWRSVPTYPE1RECORDROUTESUBOBJECTS']._serialized_end=115786
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE']._serialized_start=115789
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE']._serialized_end=116115
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE']._serialized_start=116042
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE']._serialized_end=116104
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE_ENUM']._serialized_start=116052
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE_ENUM']._serialized_end=116104
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESS']._serialized_start=116118
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESS']._serialized_end=116430
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG']._serialized_start=116433
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG']._serialized_end=116636
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE']._serialized_start=116531
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE']._serialized_end=116625
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE_ENUM']._serialized_start=116541
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE_ENUM']._serialized_end=116625
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1LABEL']._serialized_start=116639
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1LABEL']._serialized_end=116907
  _globals['_FLOWRSVPPATHRECORDROUTELABEL']._serialized_start=116910
  _globals['_FLOWRSVPPATHRECORDROUTELABEL']._serialized_end=117154
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE']._serialized_start=117056
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE']._serialized_end=117117
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE_ENUM']._serialized_start=117066
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE_ENUM']._serialized_end=117117
  _globals['_FLOWRSVPROUTERECORDLENGTH']._serialized_start=117157
  _globals['_FLOWRSVPROUTERECORDLENGTH']._serialized_end=117374
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE']._serialized_start=3617
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE']._serialized_end=3671
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE_ENUM']._serialized_end=3671
  _globals['_FLOWRSVPPATHOBJECTSCUSTOM']._serialized_start=117377
  _globals['_FLOWRSVPPATHOBJECTSCUSTOM']._serialized_end=117534
  _globals['_FLOWMACSEC']._serialized_start=117536
  _globals['_FLOWMACSEC']._serialized_end=117654
  _globals['_FLOWMACSEC_CHOICE']._serialized_start=117600
  _globals['_FLOWMACSEC_CHOICE']._serialized_end=117643
  _globals['_FLOWMACSEC_CHOICE_ENUM']._serialized_start=3627
  _globals['_FLOWMACSEC_CHOICE_ENUM']._serialized_end=3660
  _globals['_FLOWLACP']._serialized_start=117657
  _globals['_FLOWLACP']._serialized_end=117856
  _globals['_FLOWLACP_CHOICE']._serialized_start=117800
  _globals['_FLOWLACP_CHOICE']._serialized_end=117845
  _globals['_FLOWLACP_CHOICE_ENUM']._serialized_start=117810
  _globals['_FLOWLACP_CHOICE_ENUM']._serialized_end=117845
  _globals['_FLOWLACPLACPDU']._serialized_start=117859
  _globals['_FLOWLACPLACPDU']._serialized_end=118045
  _globals['_FLOWLACPDUACTOR']._serialized_start=118048
  _globals['_FLOWLACPDUACTOR']._serialized_end=118559
  _globals['_FLOWLACPDUPARTNER']._serialized_start=118562
  _globals['_FLOWLACPDUPARTNER']._serialized_end=119095
  _globals['_FLOWLACPDUCOLLECTOR']._serialized_start=119098
  _globals['_FLOWLACPDUCOLLECTOR']._serialized_end=119321
  _globals['_FLOWLACPDUTERMINATOR']._serialized_start=119324
  _globals['_FLOWLACPDUTERMINATOR']._serialized_end=119490
  _globals['_FLOWLACPDUACTORSTATE']._serialized_start=119493
  _globals['_FLOWLACPDUACTORSTATE']._serialized_end=120025
  _globals['_FLOWLACPDUPARTNERSTATE']._serialized_start=120028
  _globals['_FLOWLACPDUPARTNERSTATE']._serialized_end=120578
  _globals['_FLOWSIZE']._serialized_start=120581
  _globals['_FLOWSIZE']._serialized_end=120899
  _globals['_FLOWSIZE_CHOICE']._serialized_start=120789
  _globals['_FLOWSIZE_CHOICE']._serialized_end=120878
  _globals['_FLOWSIZE_CHOICE_ENUM']._serialized_start=120799
  _globals['_FLOWSIZE_CHOICE_ENUM']._serialized_end=120878
  _globals['_FLOWSIZEINCREMENT']._serialized_start=120901
  _globals['_FLOWSIZEINCREMENT']._serialized_end=121004
  _globals['_FLOWSIZERANDOM']._serialized_start=121006
  _globals['_FLOWSIZERANDOM']._serialized_end=121074
  _globals['_FLOWSIZEWEIGHTPAIRS']._serialized_start=121077
  _globals['_FLOWSIZEWEIGHTPAIRS']._serialized_end=121474
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE']._serialized_start=121274
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE']._serialized_end=121335
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM']._serialized_start=121284
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM']._serialized_end=121335
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED']._serialized_start=121337
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED']._serialized_end=121448
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM']._serialized_start=121351
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM']._serialized_end=121448
  _globals['_FLOWSIZEWEIGHTPAIRSCUSTOM']._serialized_start=121476
  _globals['_FLOWSIZEWEIGHTPAIRSCUSTOM']._serialized_end=121563
  _globals['_FLOWRATE']._serialized_start=121566
  _globals['_FLOWRATE']._serialized_end=121910
  _globals['_FLOWRATE_CHOICE']._serialized_start=121744
  _globals['_FLOWRATE_CHOICE']._serialized_end=121841
  _globals['_FLOWRATE_CHOICE_ENUM']._serialized_start=121754
  _globals['_FLOWRATE_CHOICE_ENUM']._serialized_end=121841
  _globals['_FLOWDURATION']._serialized_start=121913
  _globals['_FLOWDURATION']._serialized_end=122254
  _globals['_FLOWDURATION_CHOICE']._serialized_start=122145
  _globals['_FLOWDURATION_CHOICE']._serialized_end=122243
  _globals['_FLOWDURATION_CHOICE_ENUM']._serialized_start=122155
  _globals['_FLOWDURATION_CHOICE_ENUM']._serialized_end=122243
  _globals['_FLOWCONTINUOUS']._serialized_start=122256
  _globals['_FLOWCONTINUOUS']._serialized_end=122329
  _globals['_FLOWDELAY']._serialized_start=122332
  _globals['_FLOWDELAY']._serialized_end=122600
  _globals['_FLOWDELAY_CHOICE']._serialized_start=122467
  _globals['_FLOWDELAY_CHOICE']._serialized_end=122546
  _globals['_FLOWDELAY_CHOICE_ENUM']._serialized_start=122477
  _globals['_FLOWDELAY_CHOICE_ENUM']._serialized_end=122546
  _globals['_FLOWFIXEDPACKETS']._serialized_start=122602
  _globals['_FLOWFIXEDPACKETS']._serialized_end=122711
  _globals['_FLOWFIXEDSECONDS']._serialized_start=122713
  _globals['_FLOWFIXEDSECONDS']._serialized_end=122822
  _globals['_FLOWBURST']._serialized_start=122825
  _globals['_FLOWBURST']._serialized_end=122985
  _globals['_FLOWDURATIONINTERBURSTGAP']._serialized_start=122988
  _globals['_FLOWDURATIONINTERBURSTGAP']._serialized_end=123288
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE']._serialized_start=122467
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE']._serialized_end=122546
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM']._serialized_start=122477
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM']._serialized_end=122546
  _globals['_FLOWMETRICS']._serialized_start=123291
  _globals['_FLOWMETRICS']._serialized_end=123544
  _globals['_FLOWLATENCYMETRICS']._serialized_start=123547
  _globals['_FLOWLATENCYMETRICS']._serialized_end=123731
  _globals['_FLOWLATENCYMETRICS_MODE']._serialized_start=123644
  _globals['_FLOWLATENCYMETRICS_MODE']._serialized_end=123711
  _globals['_FLOWLATENCYMETRICS_MODE_ENUM']._serialized_start=123652
  _globals['_FLOWLATENCYMETRICS_MODE_ENUM']._serialized_end=123711
  _globals['_FLOWPREDEFINEDTAGS']._serialized_start=123733
  _globals['_FLOWPREDEFINEDTAGS']._serialized_end=123787
  _globals['_FLOWRXTXRATIO']._serialized_start=123790
  _globals['_FLOWRXTXRATIO']._serialized_end=124004
  _globals['_FLOWRXTXRATIO_CHOICE']._serialized_start=123925
  _globals['_FLOWRXTXRATIO_CHOICE']._serialized_end=123983
  _globals['_FLOWRXTXRATIO_CHOICE_ENUM']._serialized_start=123935
  _globals['_FLOWRXTXRATIO_CHOICE_ENUM']._serialized_end=123983
  _globals['_FLOWRXTXRATIORXCOUNT']._serialized_start=124006
  _globals['_FLOWRXTXRATIORXCOUNT']._serialized_end=124028
  _globals['_FLOWPAYLOAD']._serialized_start=124031
  _globals['_FLOWPAYLOAD']._serialized_end=124270
  _globals['_FLOWPAYLOAD_CHOICE']._serialized_start=124135
  _globals['_FLOWPAYLOAD_CHOICE']._serialized_end=124259
  _globals['_FLOWPAYLOAD_CHOICE_ENUM']._serialized_start=124145
  _globals['_FLOWPAYLOAD_CHOICE_ENUM']._serialized_end=124259
  _globals['_FLOWPAYLOADFIXED']._serialized_start=124272
  _globals['_FLOWPAYLOADFIXED']._serialized_end=124356
  _globals['_EVENT']._serialized_start=124358
  _globals['_EVENT']._serialized_end=124443
  _globals['_EVENTCPEVENTS']._serialized_start=124445
  _globals['_EVENTCPEVENTS']._serialized_end=124492
  _globals['_EVENTDPEVENTS']._serialized_start=124494
  _globals['_EVENTDPEVENTS']._serialized_end=124595
  _globals['_EVENTREQUEST']._serialized_start=124598
  _globals['_EVENTREQUEST']._serialized_end=124843
  _globals['_EVENTREQUEST_TYPE']._serialized_start=124674
  _globals['_EVENTREQUEST_TYPE']._serialized_end=124843
  _globals['_EVENTREQUEST_TYPE_ENUM']._serialized_start=124683
  _globals['_EVENTREQUEST_TYPE_ENUM']._serialized_end=124843
  _globals['_EVENTSUBSCRIPTION']._serialized_start=124845
  _globals['_EVENTSUBSCRIPTION']._serialized_end=124943
  _globals['_LLDP']._serialized_start=124946
  _globals['_LLDP']._serialized_end=125276
  _globals['_LLDPCONNECTION']._serialized_start=125279
  _globals['_LLDPCONNECTION']._serialized_end=125448
  _globals['_LLDPCONNECTION_CHOICE']._serialized_start=125375
  _globals['_LLDPCONNECTION_CHOICE']._serialized_end=125423
  _globals['_LLDPCONNECTION_CHOICE_ENUM']._serialized_start=2560
  _globals['_LLDPCONNECTION_CHOICE_ENUM']._serialized_end=2598
  _globals['_LLDPCHASSISID']._serialized_start=125451
  _globals['_LLDPCHASSISID']._serialized_end=125804
  _globals['_LLDPCHASSISID_CHOICE']._serialized_start=125643
  _globals['_LLDPCHASSISID_CHOICE']._serialized_end=125748
  _globals['_LLDPCHASSISID_CHOICE_ENUM']._serialized_start=125653
  _globals['_LLDPCHASSISID_CHOICE_ENUM']._serialized_end=125748
  _globals['_LLDPPORTID']._serialized_start=125807
  _globals['_LLDPPORTID']._serialized_end=126158
  _globals['_LLDPPORTID_CHOICE']._serialized_start=125643
  _globals['_LLDPPORTID_CHOICE']._serialized_end=125748
  _globals['_LLDPPORTID_CHOICE_ENUM']._serialized_start=125653
  _globals['_LLDPPORTID_CHOICE_ENUM']._serialized_end=125748
  _globals['_LLDPCHASSISMACSUBTYPE']._serialized_start=126161
  _globals['_LLDPCHASSISMACSUBTYPE']._serialized_end=126370
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE']._serialized_start=3617
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE']._serialized_end=3671
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE_ENUM']._serialized_start=3627
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE_ENUM']._serialized_end=3671
  _globals['_LLDPPORTINTERFACENAMESUBTYPE']._serialized_start=126373
  _globals['_LLDPPORTINTERFACENAMESUBTYPE']._serialized_end=126596
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE']._serialized_start=3617
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE']._serialized_end=3671
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM']._serialized_start=3627
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM']._serialized_end=3671
  _globals['_LLDPSYSTEMNAME']._serialized_start=126599
  _globals['_LLDPSYSTEMNAME']._serialized_end=126794
  _globals['_LLDPSYSTEMNAME_CHOICE']._serialized_start=3617
  _globals['_LLDPSYSTEMNAME_CHOICE']._serialized_end=3671
  _globals['_LLDPSYSTEMNAME_CHOICE_ENUM']._serialized_start=3627
  _globals['_LLDPSYSTEMNAME_CHOICE_ENUM']._serialized_end=3671
  _globals['_LLDPORGINFO']._serialized_start=126796
  _globals['_LLDPORGINFO']._serialized_end=126912
  _globals['_LLDPORGINFOTYPE']._serialized_start=126915
  _globals['_LLDPORGINFOTYPE']._serialized_end=127071
  _globals['_LLDPORGINFOTYPE_CHOICE']._serialized_start=127008
  _globals['_LLDPORGINFOTYPE_CHOICE']._serialized_end=127051
  _globals['_LLDPORGINFOTYPE_CHOICE_ENUM']._serialized_start=127018
  _globals['_LLDPORGINFOTYPE_CHOICE_ENUM']._serialized_end=127051
  _globals['_STATEFULFLOW']._serialized_start=127074
  _globals['_STATEFULFLOW']._serialized_end=127232
  _globals['_STATEFULFLOW_CHOICE']._serialized_start=127176
  _globals['_STATEFULFLOW_CHOICE']._serialized_end=127221
  _globals['_STATEFULFLOW_CHOICE_ENUM']._serialized_start=127186
  _globals['_STATEFULFLOW_CHOICE_ENUM']._serialized_end=127221
  _globals['_ROCEV2FLOWS']._serialized_start=127234
  _globals['_ROCEV2FLOWS']._serialized_end=127285
  _globals['_ROCEV2TXPORTS']._serialized_start=127287
  _globals['_ROCEV2TXPORTS']._serialized_end=127388
  _globals['_ROCEV2TRANSMITTYPE']._serialized_start=127391
  _globals['_ROCEV2TRANSMITTYPE']._serialized_end=127590
  _globals['_ROCEV2TRANSMITTYPE_CHOICE']._serialized_start=127524
  _globals['_ROCEV2TRANSMITTYPE_CHOICE']._serialized_end=127579
  _globals['_ROCEV2TRANSMITTYPE_CHOICE_ENUM']._serialized_start=127534
  _globals['_ROCEV2TRANSMITTYPE_CHOICE_ENUM']._serialized_end=127579
  _globals['_ROCEV2TARGETLINERATE']._serialized_start=127592
  _globals['_ROCEV2TARGETLINERATE']._serialized_end=127676
  _globals['_ROCEV2FLOW']._serialized_start=127679
  _globals['_ROCEV2FLOW']._serialized_end=128056
  _globals['_ROCEV2FLOW_MESSAGESIZEUNIT']._serialized_start=127899
  _globals['_ROCEV2FLOW_MESSAGESIZEUNIT']._serialized_end=127976
  _globals['_ROCEV2FLOW_MESSAGESIZEUNIT_ENUM']._serialized_start=127918
  _globals['_ROCEV2FLOW_MESSAGESIZEUNIT_ENUM']._serialized_end=127976
  _globals['_ROCEV2VERB']._serialized_start=128059
  _globals['_ROCEV2VERB']._serialized_end=128360
  _globals['_ROCEV2VERB_CHOICE']._serialized_start=128234
  _globals['_ROCEV2VERB_CHOICE']._serialized_end=128349
  _globals['_ROCEV2VERB_CHOICE_ENUM']._serialized_start=128244
  _globals['_ROCEV2VERB_CHOICE_ENUM']._serialized_end=128349
  _globals['_ROCEV2IMMEDIATEDATA']._serialized_start=128362
  _globals['_ROCEV2IMMEDIATEDATA']._serialized_end=128431
  _globals['_EGRESSONLYTRACKING']._serialized_start=128434
  _globals['_EGRESSONLYTRACKING']._serialized_end=128650
  _globals['_EGRESSONLYTRACKINGMETRICTAGS']._serialized_start=128653
  _globals['_EGRESSONLYTRACKINGMETRICTAGS']._serialized_end=128833
  _globals['_EGRESSONLYTRACKINGTXOFFSET']._serialized_start=128836
  _globals['_EGRESSONLYTRACKINGTXOFFSET']._serialized_end=129053
  _globals['_EGRESSONLYTRACKINGTXOFFSET_CHOICE']._serialized_start=86436
  _globals['_EGRESSONLYTRACKINGTXOFFSET_CHOICE']._serialized_end=86491
  _globals['_EGRESSONLYTRACKINGTXOFFSET_CHOICE_ENUM']._serialized_start=86446
  _globals['_EGRESSONLYTRACKINGTXOFFSET_CHOICE_ENUM']._serialized_end=86491
  _globals['_EGRESSONLYTRACKINGTXOFFSETCUSTOM']._serialized_start=129055
  _globals['_EGRESSONLYTRACKINGTXOFFSETCUSTOM']._serialized_end=129119
  _globals['_EGRESSONLYTRACKINGFILTER']._serialized_start=129122
  _globals['_EGRESSONLYTRACKINGFILTER']._serialized_end=129285
  _globals['_EGRESSONLYTRACKINGFILTER_CHOICE']._serialized_start=129214
  _globals['_EGRESSONLYTRACKINGFILTER_CHOICE']._serialized_end=129274
  _globals['_EGRESSONLYTRACKINGFILTER_CHOICE_ENUM']._serialized_start=129224
  _globals['_EGRESSONLYTRACKINGFILTER_CHOICE_ENUM']._serialized_end=129274
  _globals['_PERPORTOPTIONS']._serialized_start=129287
  _globals['_PERPORTOPTIONS']._serialized_end=129379
  _globals['_PORTPROTOCOL']._serialized_start=129382
  _globals['_PORTPROTOCOL']._serialized_end=129550
  _globals['_PORTPROTOCOL_CHOICE']._serialized_start=127176
  _globals['_PORTPROTOCOL_CHOICE']._serialized_end=127221
  _globals['_PORTPROTOCOL_CHOICE_ENUM']._serialized_start=127186
  _globals['_PORTPROTOCOL_CHOICE_ENUM']._serialized_end=127221
  _globals['_ROCEV2PERPORTSETTINGS']._serialized_start=129553
  _globals['_ROCEV2PERPORTSETTINGS']._serialized_end=129701
  _globals['_ROCEV2CNP']._serialized_start=129704
  _globals['_ROCEV2CNP']._serialized_end=130064
  _globals['_ROCEV2CNP_CHOICE']._serialized_start=129893
  _globals['_ROCEV2CNP_CHOICE']._serialized_end=129939
  _globals['_ROCEV2CNP_CHOICE_ENUM']._serialized_start=129903
  _globals['_ROCEV2CNP_CHOICE_ENUM']._serialized_end=129939
  _globals['_ROCEV2CNP_ECNVALUE']._serialized_start=129941
  _globals['_ROCEV2CNP_ECNVALUE']._serialized_end=130019
  _globals['_ROCEV2CNP_ECNVALUE_ENUM']._serialized_start=89688
  _globals['_ROCEV2CNP_ECNVALUE_ENUM']._serialized_end=89754
  _globals['_ROCEV2QPCONNECTIONTYPE']._serialized_start=130067
  _globals['_ROCEV2QPCONNECTIONTYPE']._serialized_end=130275
  _globals['_ROCEV2QPCONNECTIONTYPE_CHOICE']._serialized_start=89374
  _globals['_ROCEV2QPCONNECTIONTYPE_CHOICE']._serialized_end=89432
  _globals['_ROCEV2QPCONNECTIONTYPE_CHOICE_ENUM']._serialized_start=89384
  _globals['_ROCEV2QPCONNECTIONTYPE_CHOICE_ENUM']._serialized_end=89432
  _globals['_ROCEV2ACKANDNAK']._serialized_start=130278
  _globals['_ROCEV2ACKANDNAK']._serialized_end=130579
  _globals['_ROCEV2ACK']._serialized_start=130582
  _globals['_ROCEV2ACK']._serialized_end=130892
  _globals['_ROCEV2ACK_CHOICE']._serialized_start=129893
  _globals['_ROCEV2ACK_CHOICE']._serialized_end=129939
  _globals['_ROCEV2ACK_CHOICE_ENUM']._serialized_start=129903
  _globals['_ROCEV2ACK_CHOICE_ENUM']._serialized_end=129939
  _globals['_ROCEV2ACK_ECNVALUE']._serialized_start=129941
  _globals['_ROCEV2ACK_ECNVALUE']._serialized_end=130019
  _globals['_ROCEV2ACK_ECNVALUE_ENUM']._serialized_start=89688
  _globals['_ROCEV2ACK_ECNVALUE_ENUM']._serialized_end=89754
  _globals['_ROCEV2NAK']._serialized_start=130895
  _globals['_ROCEV2NAK']._serialized_end=131205
  _globals['_ROCEV2NAK_CHOICE']._serialized_start=129893
  _globals['_ROCEV2NAK_CHOICE']._serialized_end=129939
  _globals['_ROCEV2NAK_CHOICE_ENUM']._serialized_start=129903
  _globals['_ROCEV2NAK_CHOICE_ENUM']._serialized_end=129939
  _globals['_ROCEV2NAK_ECNVALUE']._serialized_start=129941
  _globals['_ROCEV2NAK_ECNVALUE']._serialized_end=130019
  _globals['_ROCEV2NAK_ECNVALUE_ENUM']._serialized_start=89688
  _globals['_ROCEV2NAK_ECNVALUE_ENUM']._serialized_end=89754
  _globals['_ROCEV2PRIORITYVALUE']._serialized_start=131207
  _globals['_ROCEV2PRIORITYVALUE']._serialized_end=131258
  _globals['_ROCEV2DCQCN']._serialized_start=131261
  _globals['_ROCEV2DCQCN']._serialized_end=132122
  _globals['_ERROR']._serialized_start=132125
  _globals['_ERROR']._serialized_end=132289
  _globals['_ERROR_KIND']._serialized_start=132210
  _globals['_ERROR_KIND']._serialized_end=132271
  _globals['_ERROR_KIND_ENUM']._serialized_start=132218
  _globals['_ERROR_KIND_ENUM']._serialized_end=132271
  _globals['_WARNING']._serialized_start=132291
  _globals['_WARNING']._serialized_end=132318
  _globals['_CONFIGUPDATE']._serialized_start=132321
  _globals['_CONFIGUPDATE']._serialized_end=132477
  _globals['_CONFIGUPDATE_CHOICE']._serialized_start=132422
  _globals['_CONFIGUPDATE_CHOICE']._serialized_end=132466
  _globals['_CONFIGUPDATE_CHOICE_ENUM']._serialized_start=132432
  _globals['_CONFIGUPDATE_CHOICE_ENUM']._serialized_end=132466
  _globals['_FLOWSUPDATE']._serialized_start=132480
  _globals['_FLOWSUPDATE']._serialized_end=132642
  _globals['_FLOWSUPDATE_PROPERTYNAMES']._serialized_start=132582
  _globals['_FLOWSUPDATE_PROPERTYNAMES']._serialized_end=132642
  _globals['_FLOWSUPDATE_PROPERTYNAMES_ENUM']._serialized_start=132599
  _globals['_FLOWSUPDATE_PROPERTYNAMES_ENUM']._serialized_end=132642
  _globals['_CONFIGAPPEND']._serialized_start=132644
  _globals['_CONFIGAPPEND']._serialized_end=132714
  _globals['_CONFIGAPPENDRESOURCES']._serialized_start=132717
  _globals['_CONFIGAPPENDRESOURCES']._serialized_end=132884
  _globals['_CONFIGAPPENDRESOURCES_CHOICE']._serialized_start=132422
  _globals['_CONFIGAPPENDRESOURCES_CHOICE']._serialized_end=132466
  _globals['_CONFIGAPPENDRESOURCES_CHOICE_ENUM']._serialized_start=132432
  _globals['_CONFIGAPPENDRESOURCES_CHOICE_ENUM']._serialized_end=132466
  _globals['_CONFIGDELETE']._serialized_start=132886
  _globals['_CONFIGDELETE']._serialized_end=132956
  _globals['_CONFIGDELETERESOURCES']._serialized_start=132959
  _globals['_CONFIGDELETERESOURCES']._serialized_end=133115
  _globals['_CONFIGDELETERESOURCES_CHOICE']._serialized_start=132422
  _globals['_CONFIGDELETERESOURCES_CHOICE']._serialized_end=132466
  _globals['_CONFIGDELETERESOURCES_CHOICE_ENUM']._serialized_start=132432
  _globals['_CONFIGDELETERESOURCES_CHOICE_ENUM']._serialized_end=132466
  _globals['_CONTROLSTATE']._serialized_start=133118
  _globals['_CONTROLSTATE']._serialized_end=133371
  _globals['_CONTROLSTATE_CHOICE']._serialized_start=133290
  _globals['_CONTROLSTATE_CHOICE']._serialized_end=133360
  _globals['_CONTROLSTATE_CHOICE_ENUM']._serialized_start=133300
  _globals['_CONTROLSTATE_CHOICE_ENUM']._serialized_end=133360
  _globals['_STATEPORT']._serialized_start=133374
  _globals['_STATEPORT']._serialized_end=133577
  _globals['_STATEPORT_CHOICE']._serialized_start=133510
  _globals['_STATEPORT_CHOICE']._serialized_end=133566
  _globals['_STATEPORT_CHOICE_ENUM']._serialized_start=133520
  _globals['_STATEPORT_CHOICE_ENUM']._serialized_end=133566
  _globals['_STATETRAFFIC']._serialized_start=133580
  _globals['_STATETRAFFIC']._serialized_end=133765
  _globals['_STATETRAFFIC_CHOICE']._serialized_start=133702
  _globals['_STATETRAFFIC_CHOICE']._serialized_end=133754
  _globals['_STATETRAFFIC_CHOICE_ENUM']._serialized_start=133712
  _globals['_STATETRAFFIC_CHOICE_ENUM']._serialized_end=133754
  _globals['_STATEPROTOCOL']._serialized_start=133768
  _globals['_STATEPROTOCOL']._serialized_end=134269
  _globals['_STATEPROTOCOL_CHOICE']._serialized_start=134152
  _globals['_STATEPROTOCOL_CHOICE']._serialized_end=134258
  _globals['_STATEPROTOCOL_CHOICE_ENUM']._serialized_start=134162
  _globals['_STATEPROTOCOL_CHOICE_ENUM']._serialized_end=134258
  _globals['_STATEPORTLINK']._serialized_start=134272
  _globals['_STATEPORTLINK']._serialized_end=134420
  _globals['_STATEPORTLINK_STATE']._serialized_start=134360
  _globals['_STATEPORTLINK_STATE']._serialized_end=134410
  _globals['_STATEPORTLINK_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPORTLINK_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPORTCAPTURE']._serialized_start=134423
  _globals['_STATEPORTCAPTURE']._serialized_end=134580
  _globals['_STATEPORTCAPTURE_STATE']._serialized_start=134517
  _globals['_STATEPORTCAPTURE_STATE']._serialized_end=134570
  _globals['_STATEPORTCAPTURE_STATE_ENUM']._serialized_start=134526
  _globals['_STATEPORTCAPTURE_STATE_ENUM']._serialized_end=134570
  _globals['_STATETRAFFICFLOWTRANSMIT']._serialized_start=134583
  _globals['_STATETRAFFICFLOWTRANSMIT']._serialized_end=134779
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE']._serialized_start=134693
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE']._serialized_end=134769
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE_ENUM']._serialized_start=134702
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE_ENUM']._serialized_end=134769
  _globals['_STATEPROTOCOLALL']._serialized_start=134782
  _globals['_STATEPROTOCOLALL']._serialized_end=134919
  _globals['_STATEPROTOCOLALL_STATE']._serialized_start=134517
  _globals['_STATEPROTOCOLALL_STATE']._serialized_end=134570
  _globals['_STATEPROTOCOLALL_STATE_ENUM']._serialized_start=134526
  _globals['_STATEPROTOCOLALL_STATE_ENUM']._serialized_end=134570
  _globals['_STATEPROTOCOLROUTE']._serialized_start=134922
  _globals['_STATEPROTOCOLROUTE']._serialized_end=135086
  _globals['_STATEPROTOCOLROUTE_STATE']._serialized_start=135015
  _globals['_STATEPROTOCOLROUTE_STATE']._serialized_end=135076
  _globals['_STATEPROTOCOLROUTE_STATE_ENUM']._serialized_start=135024
  _globals['_STATEPROTOCOLROUTE_STATE_ENUM']._serialized_end=135076
  _globals['_STATEPROTOCOLLACP']._serialized_start=135089
  _globals['_STATEPROTOCOLLACP']._serialized_end=135341
  _globals['_STATEPROTOCOLLACP_CHOICE']._serialized_start=135268
  _globals['_STATEPROTOCOLLACP_CHOICE']._serialized_end=135330
  _globals['_STATEPROTOCOLLACP_CHOICE_ENUM']._serialized_start=135278
  _globals['_STATEPROTOCOLLACP_CHOICE_ENUM']._serialized_end=135330
  _globals['_STATEPROTOCOLLACPADMIN']._serialized_start=135344
  _globals['_STATEPROTOCOLLACPADMIN']._serialized_end=135516
  _globals['_STATEPROTOCOLLACPADMIN_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLLACPADMIN_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLLACPADMIN_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLLACPADMIN_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPROTOCOLLACPMEMBERPORTS']._serialized_start=135519
  _globals['_STATEPROTOCOLLACPMEMBERPORTS']._serialized_end=135703
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPROTOCOLBGP']._serialized_start=135706
  _globals['_STATEPROTOCOLBGP']._serialized_end=135880
  _globals['_STATEPROTOCOLBGP_CHOICE']._serialized_start=135825
  _globals['_STATEPROTOCOLBGP_CHOICE']._serialized_end=135869
  _globals['_STATEPROTOCOLBGP_CHOICE_ENUM']._serialized_start=135835
  _globals['_STATEPROTOCOLBGP_CHOICE_ENUM']._serialized_end=135869
  _globals['_STATEPROTOCOLBGPPEERS']._serialized_start=135883
  _globals['_STATEPROTOCOLBGPPEERS']._serialized_end=136047
  _globals['_STATEPROTOCOLBGPPEERS_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLBGPPEERS_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLBGPPEERS_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLBGPPEERS_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPROTOCOLISIS']._serialized_start=136050
  _globals['_STATEPROTOCOLISIS']._serialized_end=136233
  _globals['_STATEPROTOCOLISIS_CHOICE']._serialized_start=136176
  _globals['_STATEPROTOCOLISIS_CHOICE']._serialized_end=136222
  _globals['_STATEPROTOCOLISIS_CHOICE_ENUM']._serialized_start=136186
  _globals['_STATEPROTOCOLISIS_CHOICE_ENUM']._serialized_end=136222
  _globals['_STATEPROTOCOLISISROUTERS']._serialized_start=136236
  _globals['_STATEPROTOCOLISISROUTERS']._serialized_end=136408
  _globals['_STATEPROTOCOLISISROUTERS_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLISISROUTERS_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLISISROUTERS_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLISISROUTERS_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPROTOCOLOSPFV2']._serialized_start=136411
  _globals['_STATEPROTOCOLOSPFV2']._serialized_end=136600
  _globals['_STATEPROTOCOLOSPFV2_CHOICE']._serialized_start=136176
  _globals['_STATEPROTOCOLOSPFV2_CHOICE']._serialized_end=136222
  _globals['_STATEPROTOCOLOSPFV2_CHOICE_ENUM']._serialized_start=136186
  _globals['_STATEPROTOCOLOSPFV2_CHOICE_ENUM']._serialized_end=136222
  _globals['_STATEPROTOCOLOSPFV2ROUTERS']._serialized_start=136603
  _globals['_STATEPROTOCOLOSPFV2ROUTERS']._serialized_end=136779
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPROTOCOLOSPFV3']._serialized_start=136782
  _globals['_STATEPROTOCOLOSPFV3']._serialized_end=136971
  _globals['_STATEPROTOCOLOSPFV3_CHOICE']._serialized_start=136176
  _globals['_STATEPROTOCOLOSPFV3_CHOICE']._serialized_end=136222
  _globals['_STATEPROTOCOLOSPFV3_CHOICE_ENUM']._serialized_start=136186
  _globals['_STATEPROTOCOLOSPFV3_CHOICE_ENUM']._serialized_end=136222
  _globals['_STATEPROTOCOLOSPFV3ROUTERS']._serialized_start=136974
  _globals['_STATEPROTOCOLOSPFV3ROUTERS']._serialized_end=137150
  _globals['_STATEPROTOCOLOSPFV3ROUTERS_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLOSPFV3ROUTERS_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLOSPFV3ROUTERS_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLOSPFV3ROUTERS_STATE_ENUM']._serialized_end=20362
  _globals['_STATEPROTOCOLROCEV2']._serialized_start=137153
  _globals['_STATEPROTOCOLROCEV2']._serialized_end=137336
  _globals['_STATEPROTOCOLROCEV2_CHOICE']._serialized_start=135825
  _globals['_STATEPROTOCOLROCEV2_CHOICE']._serialized_end=135869
  _globals['_STATEPROTOCOLROCEV2_CHOICE_ENUM']._serialized_start=135835
  _globals['_STATEPROTOCOLROCEV2_CHOICE_ENUM']._serialized_end=135869
  _globals['_STATEPROTOCOLROCEV2PEERS']._serialized_start=137339
  _globals['_STATEPROTOCOLROCEV2PEERS']._serialized_end=137509
  _globals['_STATEPROTOCOLROCEV2PEERS_STATE']._serialized_start=134360
  _globals['_STATEPROTOCOLROCEV2PEERS_STATE']._serialized_end=134410
  _globals['_STATEPROTOCOLROCEV2PEERS_STATE_ENUM']._serialized_start=20321
  _globals['_STATEPROTOCOLROCEV2PEERS_STATE_ENUM']._serialized_end=20362
  _globals['_CONTROLACTION']._serialized_start=137512
  _globals['_CONTROLACTION']._serialized_end=137679
  _globals['_CONTROLACTION_CHOICE']._serialized_start=137621
  _globals['_CONTROLACTION_CHOICE']._serialized_end=137668
  _globals['_CONTROLACTION_CHOICE_ENUM']._serialized_start=137631
  _globals['_CONTROLACTION_CHOICE_ENUM']._serialized_end=137668
  _globals['_CONTROLACTIONRESPONSE']._serialized_start=137681
  _globals['_CONTROLACTIONRESPONSE']._serialized_end=137761
  _globals['_ACTIONRESPONSE']._serialized_start=137764
  _globals['_ACTIONRESPONSE']._serialized_end=137941
  _globals['_ACTIONRESPONSE_CHOICE']._serialized_start=137621
  _globals['_ACTIONRESPONSE_CHOICE']._serialized_end=137668
  _globals['_ACTIONRESPONSE_CHOICE_ENUM']._serialized_start=137631
  _globals['_ACTIONRESPONSE_CHOICE_ENUM']._serialized_end=137668
  _globals['_ACTIONPROTOCOL']._serialized_start=137944
  _globals['_ACTIONPROTOCOL']._serialized_end=138253
  _globals['_ACTIONPROTOCOL_CHOICE']._serialized_start=138170
  _globals['_ACTIONPROTOCOL_CHOICE']._serialized_end=138242
  _globals['_ACTIONPROTOCOL_CHOICE_ENUM']._serialized_start=138180
  _globals['_ACTIONPROTOCOL_CHOICE_ENUM']._serialized_end=138242
  _globals['_ACTIONRESPONSEPROTOCOL']._serialized_start=138256
  _globals['_ACTIONRESPONSEPROTOCOL']._serialized_end=138502
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE']._serialized_start=138438
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE']._serialized_end=138491
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE_ENUM']._serialized_start=33079
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE_ENUM']._serialized_end=33122
  _globals['_ACTIONPROTOCOLIPV4']._serialized_start=138505
  _globals['_ACTIONPROTOCOLIPV4']._serialized_end=138682
  _globals['_ACTIONPROTOCOLIPV4_CHOICE']._serialized_start=138628
  _globals['_ACTIONPROTOCOLIPV4_CHOICE']._serialized_end=138671
  _globals['_ACTIONPROTOCOLIPV4_CHOICE_ENUM']._serialized_start=138638
  _globals['_ACTIONPROTOCOLIPV4_CHOICE_ENUM']._serialized_end=138671
  _globals['_ACTIONRESPONSEPROTOCOLIPV4']._serialized_start=138685
  _globals['_ACTIONRESPONSEPROTOCOLIPV4']._serialized_end=138886
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE']._serialized_start=138628
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE']._serialized_end=138671
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM']._serialized_start=138638
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM']._serialized_end=138671
  _globals['_ACTIONPROTOCOLIPV4PING']._serialized_start=138888
  _globals['_ACTIONPROTOCOLIPV4PING']._serialized_end=138966
  _globals['_ACTIONPROTOCOLIPV4PINGREQUEST']._serialized_start=138968
  _globals['_ACTIONPROTOCOLIPV4PINGREQUEST']._serialized_end=139067
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PING']._serialized_start=139069
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PING']._serialized_end=139165
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE']._serialized_start=139168
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE']._serialized_end=139427
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT']._serialized_start=139332
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT']._serialized_end=139392
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM']._serialized_start=139342
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM']._serialized_end=139392
  _globals['_ACTIONPROTOCOLIPV6']._serialized_start=139430
  _globals['_ACTIONPROTOCOLIPV6']._serialized_end=139607
  _globals['_ACTIONPROTOCOLIPV6_CHOICE']._serialized_start=138628
  _globals['_ACTIONPROTOCOLIPV6_CHOICE']._serialized_end=138671
  _globals['_ACTIONPROTOCOLIPV6_CHOICE_ENUM']._serialized_start=138638
  _globals['_ACTIONPROTOCOLIPV6_CHOICE_ENUM']._serialized_end=138671
  _globals['_ACTIONRESPONSEPROTOCOLIPV6']._serialized_start=139610
  _globals['_ACTIONRESPONSEPROTOCOLIPV6']._serialized_end=139811
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE']._serialized_start=138628
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE']._serialized_end=138671
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM']._serialized_start=138638
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM']._serialized_end=138671
  _globals['_ACTIONPROTOCOLIPV6PING']._serialized_start=139813
  _globals['_ACTIONPROTOCOLIPV6PING']._serialized_end=139891
  _globals['_ACTIONPROTOCOLIPV6PINGREQUEST']._serialized_start=139893
  _globals['_ACTIONPROTOCOLIPV6PINGREQUEST']._serialized_end=139992
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PING']._serialized_start=139994
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PING']._serialized_end=140090
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE']._serialized_start=140093
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE']._serialized_end=140352
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT']._serialized_start=139332
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT']._serialized_end=139392
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM']._serialized_start=139342
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM']._serialized_end=139392
  _globals['_ACTIONPROTOCOLBGP']._serialized_start=140355
  _globals['_ACTIONPROTOCOLBGP']._serialized_end=140666
  _globals['_ACTIONPROTOCOLBGP_CHOICE']._serialized_start=140573
  _globals['_ACTIONPROTOCOLBGP_CHOICE']._serialized_end=140655
  _globals['_ACTIONPROTOCOLBGP_CHOICE_ENUM']._serialized_start=140583
  _globals['_ACTIONPROTOCOLBGP_CHOICE_ENUM']._serialized_end=140655
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION']._serialized_start=140669
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION']._serialized_end=141394
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE']._serialized_start=141194
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE']._serialized_end=141383
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM']._serialized_start=141205
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM']._serialized_end=141383
  _globals['_ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART']._serialized_start=141397
  _globals['_ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART']._serialized_end=141578
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION']._serialized_start=141581
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION']._serialized_end=142321
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE']._serialized_start=141194
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE']._serialized_end=141383
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE_ENUM']._serialized_start=141205
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE_ENUM']._serialized_end=141383
  _globals['_ACTIONPROTOCOLISIS']._serialized_start=142324
  _globals['_ACTIONPROTOCOLISIS']._serialized_end=142554
  _globals['_ACTIONPROTOCOLISIS_CHOICE']._serialized_start=142479
  _globals['_ACTIONPROTOCOLISIS_CHOICE']._serialized_end=142543
  _globals['_ACTIONPROTOCOLISIS_CHOICE_ENUM']._serialized_start=142489
  _globals['_ACTIONPROTOCOLISIS_CHOICE_ENUM']._serialized_end=142543
  _globals['_ACTIONPROTOCOLISISINITIATERESTART']._serialized_start=142557
  _globals['_ACTIONPROTOCOLISISINITIATERESTART']._serialized_end=142877
  _globals['_ACTIONPROTOCOLISISINITIATERESTART_CHOICE']._serialized_start=142805
  _globals['_ACTIONPROTOCOLISISINITIATERESTART_CHOICE']._serialized_end=142866
  _globals['_ACTIONPROTOCOLISISINITIATERESTART_CHOICE_ENUM']._serialized_start=142815
  _globals['_ACTIONPROTOCOLISISINITIATERESTART_CHOICE_ENUM']._serialized_end=142866
  _globals['_ACTIONPROTOCOLISISUNPLANNEDRESTART']._serialized_start=142879
  _globals['_ACTIONPROTOCOLISISUNPLANNEDRESTART']._serialized_end=143005
  _globals['_ACTIONPROTOCOLISISPLANNEDRESTART']._serialized_start=143007
  _globals['_ACTIONPROTOCOLISISPLANNEDRESTART']._serialized_end=143131
  _globals['_METRICSREQUEST']._serialized_start=143134
  _globals['_METRICSREQUEST']._serialized_end=144572
  _globals['_METRICSREQUEST_CHOICE']._serialized_start=144221
  _globals['_METRICSREQUEST_CHOICE']._serialized_end=144561
  _globals['_METRICSREQUEST_CHOICE_ENUM']._serialized_start=144232
  _globals['_METRICSREQUEST_CHOICE_ENUM']._serialized_end=144561
  _globals['_METRICSRESPONSE']._serialized_start=144575
  _globals['_METRICSRESPONSE']._serialized_end=146231
  _globals['_METRICSRESPONSE_CHOICE']._serialized_start=145711
  _globals['_METRICSRESPONSE_CHOICE']._serialized_end=146220
  _globals['_METRICSRESPONSE_CHOICE_ENUM']._serialized_start=145722
  _globals['_METRICSRESPONSE_CHOICE_ENUM']._serialized_end=146220
  _globals['_PORTMETRICSREQUEST']._serialized_start=146234
  _globals['_PORTMETRICSREQUEST']._serialized_end=146584
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES']._serialized_start=146341
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES']._serialized_end=146584
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=146357
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=146584
  _globals['_PORTMETRIC']._serialized_start=146587
  _globals['_PORTMETRIC']._serialized_end=147403
  _globals['_PORTMETRIC_LINK']._serialized_start=147029
  _globals['_PORTMETRIC_LINK']._serialized_end=147078
  _globals['_PORTMETRIC_LINK_ENUM']._serialized_start=20321
  _globals['_PORTMETRIC_LINK_ENUM']._serialized_end=20362
  _globals['_PORTMETRIC_CAPTURE']._serialized_start=147080
  _globals['_PORTMETRIC_CAPTURE']._serialized_end=147140
  _globals['_PORTMETRIC_CAPTURE_ENUM']._serialized_start=147091
  _globals['_PORTMETRIC_CAPTURE_ENUM']._serialized_end=147140
  _globals['_PORTMETRIC_TRANSMIT']._serialized_start=147142
  _globals['_PORTMETRIC_TRANSMIT']._serialized_end=147203
  _globals['_PORTMETRIC_TRANSMIT_ENUM']._serialized_start=147091
  _globals['_PORTMETRIC_TRANSMIT_ENUM']._serialized_end=147140
  _globals['_FLOWMETRICSREQUEST']._serialized_start=147406
  _globals['_FLOWMETRICSREQUEST']._serialized_end=147902
  _globals['_FLOWMETRICSREQUEST_METRICNAMES']._serialized_start=147567
  _globals['_FLOWMETRICSREQUEST_METRICNAMES']._serialized_end=147902
  _globals['_FLOWMETRICSREQUEST_METRICNAMES_ENUM']._serialized_start=147583
  _globals['_FLOWMETRICSREQUEST_METRICNAMES_ENUM']._serialized_end=147902
  _globals['_FLOWTAGGEDMETRICSFILTER']._serialized_start=147905
  _globals['_FLOWTAGGEDMETRICSFILTER']._serialized_end=148462
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES']._serialized_start=148103
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES']._serialized_end=148424
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM']._serialized_start=148119
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM']._serialized_end=148424
  _globals['_FLOWMETRICTAGFILTER']._serialized_start=148464
  _globals['_FLOWMETRICTAGFILTER']._serialized_end=148529
  _globals['_FLOWMETRIC']._serialized_start=148532
  _globals['_FLOWMETRIC']._serialized_end=149628
  _globals['_FLOWMETRIC_TRANSMIT']._serialized_start=149234
  _globals['_FLOWMETRIC_TRANSMIT']._serialized_end=149307
  _globals['_FLOWMETRIC_TRANSMIT_ENUM']._serialized_start=149246
  _globals['_FLOWMETRIC_TRANSMIT_ENUM']._serialized_end=149307
  _globals['_FLOWTAGGEDMETRIC']._serialized_start=149631
  _globals['_FLOWTAGGEDMETRIC']._serialized_end=150482
  _globals['_FLOWMETRICTAG']._serialized_start=150484
  _globals['_FLOWMETRICTAG']._serialized_end=150567
  _globals['_FLOWMETRICTAGVALUE']._serialized_start=150570
  _globals['_FLOWMETRICTAGVALUE']._serialized_end=150764
  _globals['_FLOWMETRICTAGVALUE_CHOICE']._serialized_start=150686
  _globals['_FLOWMETRICTAGVALUE_CHOICE']._serialized_end=150737
  _globals['_FLOWMETRICTAGVALUE_CHOICE_ENUM']._serialized_start=150696
  _globals['_FLOWMETRICTAGVALUE_CHOICE_ENUM']._serialized_end=150737
  _globals['_METRICTIMESTAMP']._serialized_start=150766
  _globals['_METRICTIMESTAMP']._serialized_end=150893
  _globals['_METRICLATENCY']._serialized_start=150896
  _globals['_METRICLATENCY']._serialized_end=151031
  _globals['_BGPV4METRICSREQUEST']._serialized_start=151034
  _globals['_BGPV4METRICSREQUEST']._serialized_end=151539
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES']._serialized_start=151143
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES']._serialized_end=151539
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=151159
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=151539
  _globals['_BGPV4METRIC']._serialized_start=151542
  _globals['_BGPV4METRIC']._serialized_end=152672
  _globals['_BGPV4METRIC_SESSIONSTATE']._serialized_start=152145
  _globals['_BGPV4METRIC_SESSIONSTATE']._serialized_end=152202
  _globals['_BGPV4METRIC_SESSIONSTATE_ENUM']._serialized_start=20321
  _globals['_BGPV4METRIC_SESSIONSTATE_ENUM']._serialized_end=20362
  _globals['_BGPV4METRIC_FSMSTATE']._serialized_start=152204
  _globals['_BGPV4METRIC_FSMSTATE']._serialized_end=152322
  _globals['_BGPV4METRIC_FSMSTATE_ENUM']._serialized_start=152216
  _globals['_BGPV4METRIC_FSMSTATE_ENUM']._serialized_end=152322
  _globals['_BGPV6METRICSREQUEST']._serialized_start=152675
  _globals['_BGPV6METRICSREQUEST']._serialized_end=153180
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES']._serialized_start=151143
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES']._serialized_end=151539
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=151159
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=151539
  _globals['_BGPV6METRIC']._serialized_start=153183
  _globals['_BGPV6METRIC']._serialized_end=154313
  _globals['_BGPV6METRIC_SESSIONSTATE']._serialized_start=152145
  _globals['_BGPV6METRIC_SESSIONSTATE']._serialized_end=152202
  _globals['_BGPV6METRIC_SESSIONSTATE_ENUM']._serialized_start=20321
  _globals['_BGPV6METRIC_SESSIONSTATE_ENUM']._serialized_end=20362
  _globals['_BGPV6METRIC_FSMSTATE']._serialized_start=152204
  _globals['_BGPV6METRIC_FSMSTATE']._serialized_end=152322
  _globals['_BGPV6METRIC_FSMSTATE_ENUM']._serialized_start=152216
  _globals['_BGPV6METRIC_FSMSTATE_ENUM']._serialized_end=152322
  _globals['_ISISMETRICSREQUEST']._serialized_start=154316
  _globals['_ISISMETRICSREQUEST']._serialized_end=155192
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES']._serialized_start=154425
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES']._serialized_end=155192
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=154441
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=155192
  _globals['_ISISMETRIC']._serialized_start=155195
  _globals['_ISISMETRIC']._serialized_end=156931
  _globals['_LAGMETRICSREQUEST']._serialized_start=156934
  _globals['_LAGMETRICSREQUEST']._serialized_end=157251
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES']._serialized_start=157038
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES']._serialized_end=157251
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=157054
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=157251
  _globals['_LAGMETRIC']._serialized_start=157254
  _globals['_LAGMETRIC']._serialized_end=157810
  _globals['_LAGMETRIC_OPERSTATUS']._serialized_start=157582
  _globals['_LAGMETRIC_OPERSTATUS']._serialized_end=157637
  _globals['_LAGMETRIC_OPERSTATUS_ENUM']._serialized_start=20321
  _globals['_LAGMETRIC_OPERSTATUS_ENUM']._serialized_end=20362
  _globals['_LACPMETRICSREQUEST']._serialized_start=157813
  _globals['_LACPMETRICSREQUEST']._serialized_end=158249
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES']._serialized_start=157950
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES']._serialized_end=158249
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=157966
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=158249
  _globals['_LACPMETRIC']._serialized_start=158252
  _globals['_LACPMETRIC']._serialized_end=159289
  _globals['_LACPMETRIC_ACTIVITY']._serialized_start=158818
  _globals['_LACPMETRIC_ACTIVITY']._serialized_end=158878
  _globals['_LACPMETRIC_ACTIVITY_ENUM']._serialized_start=158830
  _globals['_LACPMETRIC_ACTIVITY_ENUM']._serialized_end=158878
  _globals['_LACPMETRIC_TIMEOUT']._serialized_start=158880
  _globals['_LACPMETRIC_TIMEOUT']._serialized_end=158935
  _globals['_LACPMETRIC_TIMEOUT_ENUM']._serialized_start=158891
  _globals['_LACPMETRIC_TIMEOUT_ENUM']._serialized_end=158935
  _globals['_LACPMETRIC_SYNCHRONIZATION']._serialized_start=158937
  _globals['_LACPMETRIC_SYNCHRONIZATION']._serialized_end=159006
  _globals['_LACPMETRIC_SYNCHRONIZATION_ENUM']._serialized_start=158956
  _globals['_LACPMETRIC_SYNCHRONIZATION_ENUM']._serialized_end=159006
  _globals['_LLDPMETRICSREQUEST']._serialized_start=159292
  _globals['_LLDPMETRICSREQUEST']._serialized_end=159545
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES']._serialized_start=159399
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES']._serialized_end=159545
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=159415
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=159545
  _globals['_LLDPMETRIC']._serialized_start=159548
  _globals['_LLDPMETRIC']._serialized_end=159850
  _globals['_RSVPMETRICSREQUEST']._serialized_start=159853
  _globals['_RSVPMETRICSREQUEST']._serialized_end=160559
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES']._serialized_start=159962
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES']._serialized_end=160559
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=159978
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=160559
  _globals['_RSVPMETRIC']._serialized_start=160562
  _globals['_RSVPMETRIC']._serialized_end=161958
  _globals['_DHCPV4CLIENTMETRICSREQUEST']._serialized_start=161961
  _globals['_DHCPV4CLIENTMETRICSREQUEST']._serialized_end=162262
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_start=162086
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_end=162262
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=162102
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=162262
  _globals['_DHCPV4CLIENTMETRIC']._serialized_start=162265
  _globals['_DHCPV4CLIENTMETRIC']._serialized_end=162643
  _globals['_DHCPV4SERVERMETRICSREQUEST']._serialized_start=162646
  _globals['_DHCPV4SERVERMETRICSREQUEST']._serialized_end=162951
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_start=162771
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_end=162951
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=162787
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=162951
  _globals['_DHCPV4SERVERMETRIC']._serialized_start=162954
  _globals['_DHCPV4SERVERMETRIC']._serialized_end=163340
  _globals['_DHCPV6CLIENTMETRICSREQUEST']._serialized_start=163343
  _globals['_DHCPV6CLIENTMETRICSREQUEST']._serialized_end=163823
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_start=163468
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_end=163823
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=163484
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=163823
  _globals['_DHCPV6CLIENTMETRIC']._serialized_start=163826
  _globals['_DHCPV6CLIENTMETRIC']._serialized_end=164610
  _globals['_DHCPV6SERVERMETRICSREQUEST']._serialized_start=164613
  _globals['_DHCPV6SERVERMETRICSREQUEST']._serialized_end=165129
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_start=164738
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_end=165129
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=164754
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=165129
  _globals['_DHCPV6SERVERMETRIC']._serialized_start=165132
  _globals['_DHCPV6SERVERMETRIC']._serialized_end=166004
  _globals['_OSPFV2METRICSREQUEST']._serialized_start=166007
  _globals['_OSPFV2METRICSREQUEST']._serialized_end=166876
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES']._serialized_start=166120
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES']._serialized_end=166876
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=166136
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=166876
  _globals['_OSPFV2METRIC']._serialized_start=166879
  _globals['_OSPFV2METRIC']._serialized_end=168619
  _globals['_CONVERGENCEREQUEST']._serialized_start=168621
  _globals['_CONVERGENCEREQUEST']._serialized_end=168661
  _globals['_CONVERGENCEMETRIC']._serialized_start=168664
  _globals['_CONVERGENCEMETRIC']._serialized_end=168918
  _globals['_CONVERGENCEEVENT']._serialized_start=168921
  _globals['_CONVERGENCEEVENT']._serialized_end=169312
  _globals['_CONVERGENCEEVENT_TYPE']._serialized_start=124674
  _globals['_CONVERGENCEEVENT_TYPE']._serialized_end=124843
  _globals['_CONVERGENCEEVENT_TYPE_ENUM']._serialized_start=124683
  _globals['_CONVERGENCEEVENT_TYPE_ENUM']._serialized_end=124843
  _globals['_MACSECMETRICSREQUEST']._serialized_start=169315
  _globals['_MACSECMETRICSREQUEST']._serialized_end=169899
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES']._serialized_start=169435
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES']._serialized_end=169899
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=169451
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=169899
  _globals['_MACSECMETRIC']._serialized_start=169902
  _globals['_MACSECMETRIC']._serialized_end=171042
  _globals['_MACSECMETRIC_SESSIONSTATE']._serialized_start=152145
  _globals['_MACSECMETRIC_SESSIONSTATE']._serialized_end=152202
  _globals['_MACSECMETRIC_SESSIONSTATE_ENUM']._serialized_start=20321
  _globals['_MACSECMETRIC_SESSIONSTATE_ENUM']._serialized_end=20362
  _globals['_MKAMETRICSREQUEST']._serialized_start=171045
  _globals['_MKAMETRICSREQUEST']._serialized_end=171406
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES']._serialized_start=171150
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES']._serialized_end=171406
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=171166
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=171406
  _globals['_MKAMETRIC']._serialized_start=171409
  _globals['_MKAMETRIC']._serialized_end=172055
  _globals['_MKAMETRIC_SESSIONSTATE']._serialized_start=152145
  _globals['_MKAMETRIC_SESSIONSTATE']._serialized_end=152202
  _globals['_MKAMETRIC_SESSIONSTATE_ENUM']._serialized_start=20321
  _globals['_MKAMETRIC_SESSIONSTATE_ENUM']._serialized_end=20362
  _globals['_OSPFV3METRICSREQUEST']._serialized_start=172058
  _globals['_OSPFV3METRICSREQUEST']._serialized_end=172935
  _globals['_OSPFV3METRICSREQUEST_COLUMNNAMES']._serialized_start=172171
  _globals['_OSPFV3METRICSREQUEST_COLUMNNAMES']._serialized_end=172935
  _globals['_OSPFV3METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=172187
  _globals['_OSPFV3METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=172935
  _globals['_OSPFV3METRIC']._serialized_start=172938
  _globals['_OSPFV3METRIC']._serialized_end=174678
  _globals['_ROCEV2IPV4METRICSREQUEST']._serialized_start=174681
  _globals['_ROCEV2IPV4METRICSREQUEST']._serialized_end=174877
  _globals['_ROCEV2IPV4METRICSREQUEST_CHOICE']._serialized_start=174819
  _globals['_ROCEV2IPV4METRICSREQUEST_CHOICE']._serialized_end=174866
  _globals['_ROCEV2IPV4METRICSREQUEST_CHOICE_ENUM']._serialized_start=174829
  _globals['_ROCEV2IPV4METRICSREQUEST_CHOICE_ENUM']._serialized_end=174866
  _globals['_ROCEV2IPV4COLUMNNAMES']._serialized_start=174880
  _globals['_ROCEV2IPV4COLUMNNAMES']._serialized_end=175349
  _globals['_ROCEV2IPV4COLUMNNAMES_COLUMNNAMES']._serialized_start=174993
  _globals['_ROCEV2IPV4COLUMNNAMES_COLUMNNAMES']._serialized_end=175349
  _globals['_ROCEV2IPV4COLUMNNAMES_COLUMNNAMES_ENUM']._serialized_start=175009
  _globals['_ROCEV2IPV4COLUMNNAMES_COLUMNNAMES_ENUM']._serialized_end=175349
  _globals['_ROCEV2IPV4METRICPERPEER']._serialized_start=175352
  _globals['_ROCEV2IPV4METRICPERPEER']._serialized_end=176129
  _globals['_ROCEV2IPV6METRICSREQUEST']._serialized_start=176132
  _globals['_ROCEV2IPV6METRICSREQUEST']._serialized_end=176328
  _globals['_ROCEV2IPV6METRICSREQUEST_CHOICE']._serialized_start=174819
  _globals['_ROCEV2IPV6METRICSREQUEST_CHOICE']._serialized_end=174866
  _globals['_ROCEV2IPV6METRICSREQUEST_CHOICE_ENUM']._serialized_start=174829
  _globals['_ROCEV2IPV6METRICSREQUEST_CHOICE_ENUM']._serialized_end=174866
  _globals['_ROCEV2IPV6COLUMNNAMES']._serialized_start=176331
  _globals['_ROCEV2IPV6COLUMNNAMES']._serialized_end=176800
  _globals['_ROCEV2IPV6COLUMNNAMES_COLUMNNAMES']._serialized_start=174993
  _globals['_ROCEV2IPV6COLUMNNAMES_COLUMNNAMES']._serialized_end=175349
  _globals['_ROCEV2IPV6COLUMNNAMES_COLUMNNAMES_ENUM']._serialized_start=175009
  _globals['_ROCEV2IPV6COLUMNNAMES_COLUMNNAMES_ENUM']._serialized_end=175349
  _globals['_ROCEV2IPV6METRICPERPEER']._serialized_start=176803
  _globals['_ROCEV2IPV6METRICPERPEER']._serialized_end=177580
  _globals['_ROCEV2FLOWMETRICSREQUEST']._serialized_start=177583
  _globals['_ROCEV2FLOWMETRICSREQUEST']._serialized_end=177775
  _globals['_ROCEV2FLOWMETRICSREQUEST_CHOICE']._serialized_start=177719
  _globals['_ROCEV2FLOWMETRICSREQUEST_CHOICE']._serialized_end=177764
  _globals['_ROCEV2FLOWMETRICSREQUEST_CHOICE_ENUM']._serialized_start=177729
  _globals['_ROCEV2FLOWMETRICSREQUEST_CHOICE_ENUM']._serialized_end=177764
  _globals['_ROCEV2FLOWCOLUMNNAMES']._serialized_start=177778
  _globals['_ROCEV2FLOWCOLUMNNAMES']._serialized_end=178447
  _globals['_ROCEV2FLOWCOLUMNNAMES_COLUMNNAMES']._serialized_start=177871
  _globals['_ROCEV2FLOWCOLUMNNAMES_COLUMNNAMES']._serialized_end=178447
  _globals['_ROCEV2FLOWCOLUMNNAMES_COLUMNNAMES_ENUM']._serialized_start=177887
  _globals['_ROCEV2FLOWCOLUMNNAMES_COLUMNNAMES_ENUM']._serialized_end=178447
  _globals['_ROCEV2FLOWMETRICPERQP']._serialized_start=178450
  _globals['_ROCEV2FLOWMETRICPERQP']._serialized_end=179803
  _globals['_EGRESSONLYTRACKINGMETRICSREQUEST']._serialized_start=179805
  _globals['_EGRESSONLYTRACKINGMETRICSREQUEST']._serialized_end=179927
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRICSFILTER']._serialized_start=179930
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRICSFILTER']._serialized_end=180313
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRICSFILTER_METRICNAMES']._serialized_start=180091
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRICSFILTER_METRICNAMES']._serialized_end=180287
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRICSFILTER_METRICNAMES_ENUM']._serialized_start=180107
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRICSFILTER_METRICNAMES_ENUM']._serialized_end=180287
  _globals['_EGRESSONLYTRACKINGMETRIC']._serialized_start=180315
  _globals['_EGRESSONLYTRACKINGMETRIC']._serialized_end=180436
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRIC']._serialized_start=180439
  _globals['_EGRESSONLYTRACKINGTAGGEDMETRIC']._serialized_end=180973
  _globals['_EGRESSONLYTRACKINGMETRICTAG']._serialized_start=180975
  _globals['_EGRESSONLYTRACKINGMETRICTAG']._serialized_end=181062
  _globals['_EGRESSONLYTRACKINGTIMESTAMP']._serialized_start=181065
  _globals['_EGRESSONLYTRACKINGTIMESTAMP']._serialized_end=181204
  _globals['_EGRESSONLYTRACKINGTXMETRICS']._serialized_start=181207
  _globals['_EGRESSONLYTRACKINGTXMETRICS']._serialized_end=181644
  _globals['_STATESREQUEST']._serialized_start=181647
  _globals['_STATESREQUEST']._serialized_end=182700
  _globals['_STATESREQUEST_CHOICE']._serialized_start=182407
  _globals['_STATESREQUEST_CHOICE']._serialized_end=182689
  _globals['_STATESREQUEST_CHOICE_ENUM']._serialized_start=182418
  _globals['_STATESREQUEST_CHOICE_ENUM']._serialized_end=182689
  _globals['_STATESRESPONSE']._serialized_start=182703
  _globals['_STATESRESPONSE']._serialized_end=183667
  _globals['_STATESRESPONSE_CHOICE']._serialized_start=182407
  _globals['_STATESRESPONSE_CHOICE']._serialized_end=182689
  _globals['_STATESRESPONSE_CHOICE_ENUM']._serialized_start=182418
  _globals['_STATESRESPONSE_CHOICE_ENUM']._serialized_end=182689
  _globals['_NEIGHBORSV4STATESREQUEST']._serialized_start=183669
  _globals['_NEIGHBORSV4STATESREQUEST']._serialized_end=183719
  _globals['_NEIGHBORSV4STATE']._serialized_start=183722
  _globals['_NEIGHBORSV4STATE']._serialized_end=183886
  _globals['_NEIGHBORSV6STATESREQUEST']._serialized_start=183888
  _globals['_NEIGHBORSV6STATESREQUEST']._serialized_end=183938
  _globals['_NEIGHBORSV6STATE']._serialized_start=183941
  _globals['_NEIGHBORSV6STATE']._serialized_end=184105
  _globals['_BGPPREFIXSTATEREQUEST']._serialized_start=184108
  _globals['_BGPPREFIXSTATEREQUEST']._serialized_end=184430
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS']._serialized_start=184354
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS']._serialized_end=184430
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM']._serialized_start=52816
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM']._serialized_end=52875
  _globals['_BGPPREFIXIPV4UNICASTFILTER']._serialized_start=184433
  _globals['_BGPPREFIXIPV4UNICASTFILTER']._serialized_end=184706
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN']._serialized_start=27011
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN']._serialized_end=27078
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM']._serialized_start=27021
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM']._serialized_end=27078
  _globals['_BGPPREFIXIPV6UNICASTFILTER']._serialized_start=184709
  _globals['_BGPPREFIXIPV6UNICASTFILTER']._serialized_end=184982
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN']._serialized_start=27011
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN']._serialized_end=27078
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM']._serialized_start=27021
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM']._serialized_end=27078
  _globals['_BGPPREFIXESSTATE']._serialized_start=184985
  _globals['_BGPPREFIXESSTATE']._serialized_end=185175
  _globals['_BGPPREFIXIPV4UNICASTSTATE']._serialized_start=185178
  _globals['_BGPPREFIXIPV4UNICASTSTATE']._serialized_end=185831
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN']._serialized_start=27011
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN']._serialized_end=27078
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM']._serialized_start=27021
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM']._serialized_end=27078
  _globals['_BGPPREFIXIPV6UNICASTSTATE']._serialized_start=185834
  _globals['_BGPPREFIXIPV6UNICASTSTATE']._serialized_end=186487
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN']._serialized_start=27011
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN']._serialized_end=27078
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM']._serialized_start=27021
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM']._serialized_end=27078
  _globals['_RESULTEXTENDEDCOMMUNITY']._serialized_start=186489
  _globals['_RESULTEXTENDEDCOMMUNITY']._serialized_end=186600
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED']._serialized_start=186603
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED']._serialized_end=187361
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE']._serialized_start=187157
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE']._serialized_end=187350
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE_ENUM']._serialized_start=187168
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE_ENUM']._serialized_end=187350
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_start=187364
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_end=187526
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_start=187529
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_end=187691
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_start=187694
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_end=188110
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=34796
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=34881
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=34806
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=34881
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_start=188113
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_end=188282
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_start=188285
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_end=188454
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_start=188457
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_end=188885
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_start=34796
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_end=34881
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_start=34806
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_end=34881
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_start=188888
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_end=189050
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_start=189053
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_end=189215
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_start=189218
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_end=189634
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_start=34796
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_end=34881
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_start=34806
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_end=34881
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_start=189636
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_end=189746
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_start=189749
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_end=189885
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_start=189888
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_end=190280
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_start=36918
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_end=36997
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_start=36928
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_end=36997
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_start=190283
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_end=190434
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_start=190437
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_end=190749
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=37757
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=37818
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=37767
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=37818
  _globals['_RESULTBGPCOMMUNITY']._serialized_start=190752
  _globals['_RESULTBGPCOMMUNITY']._serialized_end=191056
  _globals['_RESULTBGPCOMMUNITY_TYPE']._serialized_start=27340
  _globals['_RESULTBGPCOMMUNITY_TYPE']._serialized_end=27482
  _globals['_RESULTBGPCOMMUNITY_TYPE_ENUM']._serialized_start=27349
  _globals['_RESULTBGPCOMMUNITY_TYPE_ENUM']._serialized_end=27482
  _globals['_RESULTBGPASPATH']._serialized_start=191058
  _globals['_RESULTBGPASPATH']._serialized_end=191122
  _globals['_RESULTBGPASPATHSEGMENT']._serialized_start=191125
  _globals['_RESULTBGPASPATHSEGMENT']._serialized_end=191331
  _globals['_RESULTBGPASPATHSEGMENT_TYPE']._serialized_start=28443
  _globals['_RESULTBGPASPATHSEGMENT_TYPE']._serialized_end=28536
  _globals['_RESULTBGPASPATHSEGMENT_TYPE_ENUM']._serialized_start=28451
  _globals['_RESULTBGPASPATHSEGMENT_TYPE_ENUM']._serialized_end=28536
  _globals['_ISISLSPSSTATEREQUEST']._serialized_start=191333
  _globals['_ISISLSPSSTATEREQUEST']._serialized_end=191382
  _globals['_ISISLSPSSTATE']._serialized_start=191384
  _globals['_ISISLSPSSTATE']._serialized_end=191484
  _globals['_ISISLSPSTATE']._serialized_start=191487
  _globals['_ISISLSPSTATE']._serialized_end=191909
  _globals['_ISISLSPSTATE_PDUTYPE']._serialized_start=191755
  _globals['_ISISLSPSTATE_PDUTYPE']._serialized_end=191815
  _globals['_ISISLSPSTATE_PDUTYPE_ENUM']._serialized_start=16422
  _globals['_ISISLSPSTATE_PDUTYPE_ENUM']._serialized_end=16471
  _globals['_ISISLSPTLVS']._serialized_start=191912
  _globals['_ISISLSPTLVS']._serialized_end=192473
  _globals['_ISISLSPHOSTNAME']._serialized_start=192475
  _globals['_ISISLSPHOSTNAME']._serialized_end=192528
  _globals['_ISISLSPFLAGS']._serialized_start=192531
  _globals['_ISISLSPFLAGS']._serialized_end=192833
  _globals['_ISISLSPISREACHABILITYTLV']._serialized_start=192835
  _globals['_ISISLSPISREACHABILITYTLV']._serialized_end=192902
  _globals['_ISISLSPEXTENDEDISREACHABILITYTLV']._serialized_start=192904
  _globals['_ISISLSPEXTENDEDISREACHABILITYTLV']._serialized_end=192987
  _globals['_ISISLSPNEIGHBOR']._serialized_start=192989
  _globals['_ISISLSPNEIGHBOR']._serialized_end=193044
  _globals['_ISISLSPEXTENDEDNEIGHBOR']._serialized_start=193046
  _globals['_ISISLSPEXTENDEDNEIGHBOR']._serialized_end=193159
  _globals['_ISISLSPIPV4INTERNALREACHABILITYTLV']._serialized_start=193161
  _globals['_ISISLSPIPV4INTERNALREACHABILITYTLV']._serialized_end=193237
  _globals['_ISISLSPIPV4EXTERNALREACHABILITYTLV']._serialized_start=193239
  _globals['_ISISLSPIPV4EXTERNALREACHABILITYTLV']._serialized_end=193315
  _globals['_ISISLSPV4PREFIX']._serialized_start=193318
  _globals['_ISISLSPV4PREFIX']._serialized_end=193789
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE']._serialized_start=20299
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE']._serialized_end=20362
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20321
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20362
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE']._serialized_start=20232
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE']._serialized_end=20297
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE_ENUM']._serialized_start=20246
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE_ENUM']._serialized_end=20297
  _globals['_ISISLSPEXTENDEDIPV4REACHABILITYTLV']._serialized_start=193791
  _globals['_ISISLSPEXTENDEDIPV4REACHABILITYTLV']._serialized_end=193875
  _globals['_ISISLSPEXTENDEDV4PREFIX']._serialized_start=193878
  _globals['_ISISLSPEXTENDEDV4PREFIX']._serialized_end=194303
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE']._serialized_start=20299
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE']._serialized_end=20362
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20321
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20362
  _globals['_ISISLSPIPV6REACHABILITYTLV']._serialized_start=194305
  _globals['_ISISLSPIPV6REACHABILITYTLV']._serialized_end=194373
  _globals['_ISISLSPV6PREFIX']._serialized_start=194376
  _globals['_ISISLSPV6PREFIX']._serialized_end=194932
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE']._serialized_start=20299
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE']._serialized_end=20362
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20321
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20362
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE']._serialized_start=20232
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE']._serialized_end=20297
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE_ENUM']._serialized_start=20246
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE_ENUM']._serialized_end=20297
  _globals['_ISISLSPPREFIXATTRIBUTES']._serialized_start=194934
  _globals['_ISISLSPPREFIXATTRIBUTES']._serialized_end=195055
  _globals['_ISISLSPPREFIXSID']._serialized_start=195057
  _globals['_ISISLSPPREFIXSID']._serialized_end=195170
  _globals['_ISISLSPCAPABILITY']._serialized_start=195173
  _globals['_ISISLSPCAPABILITY']._serialized_end=195590
  _globals['_ISISLSPCAPABILITY_SBIT']._serialized_start=22471
  _globals['_ISISLSPCAPABILITY_SBIT']._serialized_end=22528
  _globals['_ISISLSPCAPABILITY_SBIT_ENUM']._serialized_start=22479
  _globals['_ISISLSPCAPABILITY_SBIT_ENUM']._serialized_end=22528
  _globals['_ISISLSPCAPABILITY_DBIT']._serialized_start=22530
  _globals['_ISISLSPCAPABILITY_DBIT']._serialized_end=22585
  _globals['_ISISLSPCAPABILITY_DBIT_ENUM']._serialized_start=22538
  _globals['_ISISLSPCAPABILITY_DBIT_ENUM']._serialized_end=22585
  _globals['_ISISLSPSRCAPABILITY']._serialized_start=195592
  _globals['_ISISLSPSRCAPABILITY']._serialized_end=195691
  _globals['_ISISLSPCAPASFLAGS']._serialized_start=195693
  _globals['_ISISLSPCAPASFLAGS']._serialized_end=195788
  _globals['_ISISLSPSRGB']._serialized_start=195790
  _globals['_ISISLSPSRGB']._serialized_end=195877
  _globals['_ISISLSPSRLB']._serialized_start=195879
  _globals['_ISISLSPSRLB']._serialized_end=195966
  _globals['_ISISLSPADJACENCYSID']._serialized_start=195969
  _globals['_ISISLSPADJACENCYSID']._serialized_end=196203
  _globals['_ISISLSPADJACENCYSID_TYPE']._serialized_start=196122
  _globals['_ISISLSPADJACENCYSID_TYPE']._serialized_end=196183
  _globals['_ISISLSPADJACENCYSID_TYPE_ENUM']._serialized_start=196130
  _globals['_ISISLSPADJACENCYSID_TYPE_ENUM']._serialized_end=196183
  _globals['_ISISLSPPREFIXSIDFLAGS']._serialized_start=196206
  _globals['_ISISLSPPREFIXSIDFLAGS']._serialized_end=196421
  _globals['_ISISLSPADJSIDFLAGS']._serialized_start=196424
  _globals['_ISISLSPADJSIDFLAGS']._serialized_end=196636
  _globals['_LLDPNEIGHBORSSTATEREQUEST']._serialized_start=196638
  _globals['_LLDPNEIGHBORSSTATEREQUEST']._serialized_end=196714
  _globals['_LLDPNEIGHBORSSTATE']._serialized_start=196717
  _globals['_LLDPNEIGHBORSSTATE']._serialized_end=197880
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE']._serialized_start=197296
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE']._serialized_end=197470
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM']._serialized_start=197314
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM']._serialized_end=197470
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE']._serialized_start=197473
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE']._serialized_end=197643
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM']._serialized_start=197488
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM']._serialized_end=197643
  _globals['_LLDPCUSTOMTLVSTATE']._serialized_start=197883
  _globals['_LLDPCUSTOMTLVSTATE']._serialized_end=198055
  _globals['_LLDPCAPABILITYSTATE']._serialized_start=198058
  _globals['_LLDPCAPABILITYSTATE']._serialized_end=198458
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME']._serialized_start=198191
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME']._serialized_end=198415
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM']._serialized_start=198210
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM']._serialized_end=198415
  _globals['_RSVPLSPSSTATEREQUEST']._serialized_start=198460
  _globals['_RSVPLSPSSTATEREQUEST']._serialized_end=198509
  _globals['_RSVPLSPSSTATE']._serialized_start=198511
  _globals['_RSVPLSPSSTATE']._serialized_end=198620
  _globals['_RSVPIPV4LSPSTATE']._serialized_start=198623
  _globals['_RSVPIPV4LSPSTATE']._serialized_end=198849
  _globals['_RSVPLSPSTATE']._serialized_start=198852
  _globals['_RSVPLSPSTATE']._serialized_end=199416
  _globals['_RSVPLSPSTATE_SESSIONSTATUS']._serialized_start=199146
  _globals['_RSVPLSPSTATE_SESSIONSTATUS']._serialized_end=199204
  _globals['_RSVPLSPSTATE_SESSIONSTATUS_ENUM']._serialized_start=20321
  _globals['_RSVPLSPSTATE_SESSIONSTATUS_ENUM']._serialized_end=20362
  _globals['_RSVPLSPSTATE_LASTFLAPREASON']._serialized_start=199206
  _globals['_RSVPLSPSTATE_LASTFLAPREASON']._serialized_end=199295
  _globals['_RSVPLSPSTATE_LASTFLAPREASON_ENUM']._serialized_start=199224
  _globals['_RSVPLSPSTATE_LASTFLAPREASON_ENUM']._serialized_end=199295
  _globals['_RSVPLSPIPV4RRO']._serialized_start=199418
  _globals['_RSVPLSPIPV4RRO']._serialized_end=199516
  _globals['_RSVPLSPIPV4ERO']._serialized_start=199519
  _globals['_RSVPLSPIPV4ERO']._serialized_end=199761
  _globals['_RSVPLSPIPV4ERO_TYPE']._serialized_start=199626
  _globals['_RSVPLSPIPV4ERO_TYPE']._serialized_end=199733
  _globals['_RSVPLSPIPV4ERO_TYPE_ENUM']._serialized_start=199634
  _globals['_RSVPLSPIPV4ERO_TYPE_ENUM']._serialized_end=199733
  _globals['_DHCPV4INTERFACESTATEREQUEST']._serialized_start=199763
  _globals['_DHCPV4INTERFACESTATEREQUEST']._serialized_end=199819
  _globals['_DHCPV4INTERFACESTATE']._serialized_start=199822
  _globals['_DHCPV4INTERFACESTATE']._serialized_end=200158
  _globals['_DHCPV4LEASESTATEREQUEST']._serialized_start=200160
  _globals['_DHCPV4LEASESTATEREQUEST']._serialized_end=200212
  _globals['_DHCPV4LEASESSTATE']._serialized_start=200214
  _globals['_DHCPV4LEASESSTATE']._serialized_end=200324
  _globals['_DHCPV4LEASESTATE']._serialized_start=200327
  _globals['_DHCPV4LEASESTATE']._serialized_end=200665
  _globals['_DHCPV6INTERFACESTATEREQUEST']._serialized_start=200667
  _globals['_DHCPV6INTERFACESTATEREQUEST']._serialized_end=200723
  _globals['_DHCPV6INTERFACESTATE']._serialized_start=200726
  _globals['_DHCPV6INTERFACESTATE']._serialized_end=200896
  _globals['_DHCPV6INTERFACEIAPD']._serialized_start=200899
  _globals['_DHCPV6INTERFACEIAPD']._serialized_end=201040
  _globals['_DHCPV6INTERFACEIA']._serialized_start=201042
  _globals['_DHCPV6INTERFACEIA']._serialized_end=201169
  _globals['_DHCPV6LEASESTATEREQUEST']._serialized_start=201171
  _globals['_DHCPV6LEASESTATEREQUEST']._serialized_end=201223
  _globals['_DHCPV6LEASESSTATE']._serialized_start=201225
  _globals['_DHCPV6LEASESSTATE']._serialized_end=201341
  _globals['_DHCPV6SERVERLEASESTATE']._serialized_start=201344
  _globals['_DHCPV6SERVERLEASESTATE']._serialized_end=201692
  _globals['_OSPFV2LSASSTATEREQUEST']._serialized_start=201694
  _globals['_OSPFV2LSASSTATEREQUEST']._serialized_end=201740
  _globals['_OSPFV2LSASTATE']._serialized_start=201743
  _globals['_OSPFV2LSASTATE']._serialized_end=202133
  _globals['_OSPFV2ROUTERLSA']._serialized_start=202135
  _globals['_OSPFV2ROUTERLSA']._serialized_end=202222
  _globals['_OSPFV2NETWORKLSA']._serialized_start=202225
  _globals['_OSPFV2NETWORKLSA']._serialized_end=202354
  _globals['_OSPFV2NETWORKSUMMARYLSA']._serialized_start=202357
  _globals['_OSPFV2NETWORKSUMMARYLSA']._serialized_end=202496
  _globals['_OSPFV2SUMMARYASLSA']._serialized_start=202499
  _globals['_OSPFV2SUMMARYASLSA']._serialized_end=202633
  _globals['_OSPFV2EXTERNALASLSA']._serialized_start=202636
  _globals['_OSPFV2EXTERNALASLSA']._serialized_end=202813
  _globals['_OSPFV2NSSALSA']._serialized_start=202816
  _globals['_OSPFV2NSSALSA']._serialized_end=203043
  _globals['_OSPFV2OPAQUELSA']._serialized_start=203046
  _globals['_OSPFV2OPAQUELSA']._serialized_end=203227
  _globals['_OSPFV2OPAQUELSA_TYPE']._serialized_start=203154
  _globals['_OSPFV2OPAQUELSA_TYPE']._serialized_end=203218
  _globals['_OSPFV2OPAQUELSA_TYPE_ENUM']._serialized_start=203162
  _globals['_OSPFV2OPAQUELSA_TYPE_ENUM']._serialized_end=203218
  _globals['_OSPFV2LSAHEADER']._serialized_start=203230
  _globals['_OSPFV2LSAHEADER']._serialized_end=203459
  _globals['_OSPFV2LINK']._serialized_start=203462
  _globals['_OSPFV2LINK']._serialized_end=203702
  _globals['_OSPFV2LINK_TYPE']._serialized_start=203579
  _globals['_OSPFV2LINK_TYPE']._serialized_end=203666
  _globals['_OSPFV2LINK_TYPE_ENUM']._serialized_start=203587
  _globals['_OSPFV2LINK_TYPE_ENUM']._serialized_end=203666
  _globals['_OSPFV3LSASSTATEREQUEST']._serialized_start=203704
  _globals['_OSPFV3LSASSTATEREQUEST']._serialized_end=203750
  _globals['_OSPFV3LSASTATE']._serialized_start=203753
  _globals['_OSPFV3LSASTATE']._serialized_end=204218
  _globals['_OSPFV3ROUTERLSA']._serialized_start=204221
  _globals['_OSPFV3ROUTERLSA']._serialized_end=204364
  _globals['_OSPFV3NETWORKLSA']._serialized_start=204366
  _globals['_OSPFV3NETWORKLSA']._serialized_end=204451
  _globals['_OSPFV3INTERAREAPREFIXLSA']._serialized_start=204454
  _globals['_OSPFV3INTERAREAPREFIXLSA']._serialized_end=204644
  _globals['_OSPFV3INTERAREAROUTERLSA']._serialized_start=204647
  _globals['_OSPFV3INTERAREAROUTERLSA']._serialized_end=204805
  _globals['_OSPFV3EXTERNALASLSA']._serialized_start=204808
  _globals['_OSPFV3EXTERNALASLSA']._serialized_end=205143
  _globals['_OSPFV3NSSALSA']._serialized_start=205146
  _globals['_OSPFV3NSSALSA']._serialized_end=205419
  _globals['_OSPFV3LINKLSA']._serialized_start=205422
  _globals['_OSPFV3LINKLSA']._serialized_end=205625
  _globals['_OSPFV3INTRAAREAPREFIXLSA']._serialized_start=205628
  _globals['_OSPFV3INTRAAREAPREFIXLSA']._serialized_end=205818
  _globals['_OSPFV3LSAHEADER']._serialized_start=205821
  _globals['_OSPFV3LSAHEADER']._serialized_end=206008
  _globals['_OSPFV3LINK']._serialized_start=206011
  _globals['_OSPFV3LINK']._serialized_end=206199
  _globals['_OSPFV3LINK_TYPE']._serialized_start=203579
  _globals['_OSPFV3LINK_TYPE']._serialized_end=203666
  _globals['_OSPFV3LINK_TYPE_ENUM']._serialized_start=203587
  _globals['_OSPFV3LINK_TYPE_ENUM']._serialized_end=203666
  _globals['_ISISIIHSSTATEREQUEST']._serialized_start=206201
  _globals['_ISISIIHSSTATEREQUEST']._serialized_end=206250
  _globals['_ISISIIHSSTATE']._serialized_start=206252
  _globals['_ISISIIHSSTATE']._serialized_end=206379
  _globals['_ISISLOCALIIHADJACENCYSTATES']._serialized_start=206382
  _globals['_ISISLOCALIIHADJACENCYSTATES']._serialized_end=206611
  _globals['_ISISLOCALIIHSTATE']._serialized_start=206614
  _globals['_ISISLOCALIIHSTATE']._serialized_end=206890
  _globals['_ISISLOCALIIHSTATE_LEVELTYPE']._serialized_start=16409
  _globals['_ISISLOCALIIHSTATE_LEVELTYPE']._serialized_end=16486
  _globals['_ISISLOCALIIHSTATE_LEVELTYPE_ENUM']._serialized_start=16422
  _globals['_ISISLOCALIIHSTATE_LEVELTYPE_ENUM']._serialized_end=16486
  _globals['_ISISNEIGHBORIIHSTATE']._serialized_start=206893
  _globals['_ISISNEIGHBORIIHSTATE']._serialized_end=207218
  _globals['_ISISNEIGHBORIIHSTATE_LEVELTYPE']._serialized_start=16409
  _globals['_ISISNEIGHBORIIHSTATE_LEVELTYPE']._serialized_end=16486
  _globals['_ISISNEIGHBORIIHSTATE_LEVELTYPE_ENUM']._serialized_start=16422
  _globals['_ISISNEIGHBORIIHSTATE_LEVELTYPE_ENUM']._serialized_end=16486
  _globals['_ISISIIHLOCALRESTARTSTATUS']._serialized_start=207221
  _globals['_ISISIIHLOCALRESTARTSTATUS']._serialized_end=207465
  _globals['_ISISIIHLOCALRESTARTSTATUS_STATE']._serialized_start=207380
  _globals['_ISISIIHLOCALRESTARTSTATUS_STATE']._serialized_end=207455
  _globals['_ISISIIHLOCALRESTARTSTATUS_STATE_ENUM']._serialized_start=207389
  _globals['_ISISIIHLOCALRESTARTSTATUS_STATE_ENUM']._serialized_end=207455
  _globals['_ISISIIHNEIGHBORRESTARTSTATUS']._serialized_start=207468
  _globals['_ISISIIHNEIGHBORRESTARTSTATUS']._serialized_end=207721
  _globals['_ISISIIHNEIGHBORRESTARTSTATUS_STATE']._serialized_start=207380
  _globals['_ISISIIHNEIGHBORRESTARTSTATUS_STATE']._serialized_end=207455
  _globals['_ISISIIHNEIGHBORRESTARTSTATUS_STATE_ENUM']._serialized_start=207389
  _globals['_ISISIIHNEIGHBORRESTARTSTATUS_STATE_ENUM']._serialized_end=207455
  _globals['_ISISIIHLOCALGRLASTATTEMPTSTATUS']._serialized_start=207724
  _globals['_ISISIIHLOCALGRLASTATTEMPTSTATUS']._serialized_end=208048
  _globals['_ISISIIHLOCALGRLASTATTEMPTSTATUS_CHOICE']._serialized_start=207944
  _globals['_ISISIIHLOCALGRLASTATTEMPTSTATUS_CHOICE']._serialized_end=208037
  _globals['_ISISIIHLOCALGRLASTATTEMPTSTATUS_CHOICE_ENUM']._serialized_start=207954
  _globals['_ISISIIHLOCALGRLASTATTEMPTSTATUS_CHOICE_ENUM']._serialized_end=208037
  _globals['_ISISIIHLOCALGRLASTATTEMPTFAILED']._serialized_start=208050
  _globals['_ISISIIHLOCALGRLASTATTEMPTFAILED']._serialized_end=208115
  _globals['_ISISIIHLOCALGRLASTATTEMPTSUCCEEDED']._serialized_start=208118
  _globals['_ISISIIHLOCALGRLASTATTEMPTSUCCEEDED']._serialized_end=208272
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSTATUS']._serialized_start=208275
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSTATUS']._serialized_end=208611
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSTATUS_CHOICE']._serialized_start=207944
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSTATUS_CHOICE']._serialized_end=208037
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSTATUS_CHOICE_ENUM']._serialized_start=207954
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSTATUS_CHOICE_ENUM']._serialized_end=208037
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTFAILED']._serialized_start=208613
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTFAILED']._serialized_end=208681
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSUCCEEDED']._serialized_start=208683
  _globals['_ISISIIHNEIGHBORGRLASTATTEMPTSUCCEEDED']._serialized_end=208788
  _globals['_ISISIIHNEIGHBORTLVS']._serialized_start=208790
  _globals['_ISISIIHNEIGHBORTLVS']._serialized_end=208856
  _globals['_ISISIIHRESTARTTLV']._serialized_start=208859
  _globals['_ISISIIHRESTARTTLV']._serialized_end=209031
  _globals['_ISISIIHRESTARTFLAGS']._serialized_start=209034
  _globals['_ISISIIHRESTARTFLAGS']._serialized_end=209215
  _globals['_CAPTUREREQUEST']._serialized_start=209217
  _globals['_CAPTUREREQUEST']._serialized_end=209316
  _globals['_CAPTUREREQUESTPACKETS']._serialized_start=209319
  _globals['_CAPTUREREQUESTPACKETS']._serialized_end=209517
  _globals['_CAPTUREREQUESTPACKETS_CHOICE']._serialized_start=209453
  _globals['_CAPTUREREQUESTPACKETS_CHOICE']._serialized_end=209506
  _globals['_CAPTUREREQUESTPACKETS_CHOICE_ENUM']._serialized_start=209463
  _globals['_CAPTUREREQUESTPACKETS_CHOICE_ENUM']._serialized_end=209506
  _globals['_CAPTUREREQUESTCAPTURESLICE']._serialized_start=209520
  _globals['_CAPTUREREQUESTCAPTURESLICE']._serialized_end=209730
  _globals['_CAPTUREREQUESTCAPTURESLICE_CHOICE']._serialized_start=209673
  _globals['_CAPTUREREQUESTCAPTURESLICE_CHOICE']._serialized_end=209719
  _globals['_CAPTUREREQUESTCAPTURESLICE_CHOICE_ENUM']._serialized_start=209683
  _globals['_CAPTUREREQUESTCAPTURESLICE_CHOICE_ENUM']._serialized_end=209719
  _globals['_CAPTUREREQUESTCAPTURESLICEINITIAL']._serialized_start=209732
  _globals['_CAPTUREREQUESTCAPTURESLICEINITIAL']._serialized_end=209827
  _globals['_PATTERNFLOWETHERNETDSTCOUNTER']._serialized_start=209829
  _globals['_PATTERNFLOWETHERNETDSTCOUNTER']._serialized_end=209948
  _globals['_PATTERNFLOWETHERNETDSTMETRICTAG']._serialized_start=209950
  _globals['_PATTERNFLOWETHERNETDSTMETRICTAG']._serialized_end=210075
  _globals['_PATTERNFLOWETHERNETDST']._serialized_start=210078
  _globals['_PATTERNFLOWETHERNETDST']._serialized_end=210516
  _globals['_PATTERNFLOWETHERNETDST_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWETHERNETDST_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWETHERNETDST_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWETHERNETDST_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWETHERNETSRCCOUNTER']._serialized_start=210518
  _globals['_PATTERNFLOWETHERNETSRCCOUNTER']._serialized_end=210637
  _globals['_PATTERNFLOWETHERNETSRCMETRICTAG']._serialized_start=210639
  _globals['_PATTERNFLOWETHERNETSRCMETRICTAG']._serialized_end=210764
  _globals['_PATTERNFLOWETHERNETSRC']._serialized_start=210767
  _globals['_PATTERNFLOWETHERNETSRC']._serialized_end=211167
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETETHERTYPECOUNTER']._serialized_start=211169
  _globals['_PATTERNFLOWETHERNETETHERTYPECOUNTER']._serialized_end=211294
  _globals['_PATTERNFLOWETHERNETETHERTYPEMETRICTAG']._serialized_start=211297
  _globals['_PATTERNFLOWETHERNETETHERTYPEMETRICTAG']._serialized_end=211428
  _globals['_PATTERNFLOWETHERNETETHERTYPE']._serialized_start=211431
  _globals['_PATTERNFLOWETHERNETETHERTYPE']._serialized_end=211899
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWETHERNETPFCQUEUECOUNTER']._serialized_start=211901
  _globals['_PATTERNFLOWETHERNETPFCQUEUECOUNTER']._serialized_end=212025
  _globals['_PATTERNFLOWETHERNETPFCQUEUEMETRICTAG']._serialized_start=212028
  _globals['_PATTERNFLOWETHERNETPFCQUEUEMETRICTAG']._serialized_end=212158
  _globals['_PATTERNFLOWETHERNETPFCQUEUE']._serialized_start=212161
  _globals['_PATTERNFLOWETHERNETPFCQUEUE']._serialized_end=212586
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVLANPRIORITYCOUNTER']._serialized_start=212588
  _globals['_PATTERNFLOWVLANPRIORITYCOUNTER']._serialized_end=212708
  _globals['_PATTERNFLOWVLANPRIORITYMETRICTAG']._serialized_start=212710
  _globals['_PATTERNFLOWVLANPRIORITYMETRICTAG']._serialized_end=212836
  _globals['_PATTERNFLOWVLANPRIORITY']._serialized_start=212839
  _globals['_PATTERNFLOWVLANPRIORITY']._serialized_end=213244
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVLANCFICOUNTER']._serialized_start=213246
  _globals['_PATTERNFLOWVLANCFICOUNTER']._serialized_end=213361
  _globals['_PATTERNFLOWVLANCFIMETRICTAG']._serialized_start=213363
  _globals['_PATTERNFLOWVLANCFIMETRICTAG']._serialized_end=213484
  _globals['_PATTERNFLOWVLANCFI']._serialized_start=213487
  _globals['_PATTERNFLOWVLANCFI']._serialized_end=213867
  _globals['_PATTERNFLOWVLANCFI_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVLANCFI_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVLANCFI_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVLANCFI_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVLANIDCOUNTER']._serialized_start=213869
  _globals['_PATTERNFLOWVLANIDCOUNTER']._serialized_end=213983
  _globals['_PATTERNFLOWVLANIDMETRICTAG']._serialized_start=213985
  _globals['_PATTERNFLOWVLANIDMETRICTAG']._serialized_end=214105
  _globals['_PATTERNFLOWVLANID']._serialized_start=214108
  _globals['_PATTERNFLOWVLANID']._serialized_end=214483
  _globals['_PATTERNFLOWVLANID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVLANID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVLANID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVLANID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVLANTPIDCOUNTER']._serialized_start=214485
  _globals['_PATTERNFLOWVLANTPIDCOUNTER']._serialized_end=214601
  _globals['_PATTERNFLOWVLANTPIDMETRICTAG']._serialized_start=214603
  _globals['_PATTERNFLOWVLANTPIDMETRICTAG']._serialized_end=214725
  _globals['_PATTERNFLOWVLANTPID']._serialized_start=214728
  _globals['_PATTERNFLOWVLANTPID']._serialized_end=215113
  _globals['_PATTERNFLOWVLANTPID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVLANTPID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVLANTPID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVLANTPID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVXLANFLAGSCOUNTER']._serialized_start=215115
  _globals['_PATTERNFLOWVXLANFLAGSCOUNTER']._serialized_end=215233
  _globals['_PATTERNFLOWVXLANFLAGSMETRICTAG']._serialized_start=215235
  _globals['_PATTERNFLOWVXLANFLAGSMETRICTAG']._serialized_end=215359
  _globals['_PATTERNFLOWVXLANFLAGS']._serialized_start=215362
  _globals['_PATTERNFLOWVXLANFLAGS']._serialized_end=215757
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVXLANRESERVED0COUNTER']._serialized_start=215759
  _globals['_PATTERNFLOWVXLANRESERVED0COUNTER']._serialized_end=215881
  _globals['_PATTERNFLOWVXLANRESERVED0METRICTAG']._serialized_start=215884
  _globals['_PATTERNFLOWVXLANRESERVED0METRICTAG']._serialized_end=216012
  _globals['_PATTERNFLOWVXLANRESERVED0']._serialized_start=216015
  _globals['_PATTERNFLOWVXLANRESERVED0']._serialized_end=216430
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWVXLANVNICOUNTER']._serialized_start=216432
  _globals['_PATTERNFLOWVXLANVNICOUNTER']._serialized_end=216548
  _globals['_PATTERNFLOWVXLANVNIMETRICTAG']._serialized_start=216550
  _globals['_PATTERNFLOWVXLANVNIMETRICTAG']._serialized_end=216672
  _globals['_PATTERNFLOWVXLANVNI']._serialized_start=216675
  _globals['_PATTERNFLOWVXLANVNI']._serialized_end=217098
  _globals['_PATTERNFLOWVXLANVNI_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWVXLANVNI_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWVXLANVNI_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWVXLANVNI_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWVXLANRESERVED1COUNTER']._serialized_start=217100
  _globals['_PATTERNFLOWVXLANRESERVED1COUNTER']._serialized_end=217222
  _globals['_PATTERNFLOWVXLANRESERVED1METRICTAG']._serialized_start=217225
  _globals['_PATTERNFLOWVXLANRESERVED1METRICTAG']._serialized_end=217353
  _globals['_PATTERNFLOWVXLANRESERVED1']._serialized_start=217356
  _globals['_PATTERNFLOWVXLANRESERVED1']._serialized_end=217771
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4VERSIONCOUNTER']._serialized_start=217773
  _globals['_PATTERNFLOWIPV4VERSIONCOUNTER']._serialized_end=217892
  _globals['_PATTERNFLOWIPV4VERSIONMETRICTAG']._serialized_start=217894
  _globals['_PATTERNFLOWIPV4VERSIONMETRICTAG']._serialized_end=218019
  _globals['_PATTERNFLOWIPV4VERSION']._serialized_start=218022
  _globals['_PATTERNFLOWIPV4VERSION']._serialized_end=218422
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4HEADERLENGTHCOUNTER']._serialized_start=218424
  _globals['_PATTERNFLOWIPV4HEADERLENGTHCOUNTER']._serialized_end=218548
  _globals['_PATTERNFLOWIPV4HEADERLENGTHMETRICTAG']._serialized_start=218551
  _globals['_PATTERNFLOWIPV4HEADERLENGTHMETRICTAG']._serialized_end=218681
  _globals['_PATTERNFLOWIPV4HEADERLENGTH']._serialized_start=218684
  _globals['_PATTERNFLOWIPV4HEADERLENGTH']._serialized_end=219147
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWIPV4TOTALLENGTHCOUNTER']._serialized_start=219149
  _globals['_PATTERNFLOWIPV4TOTALLENGTHCOUNTER']._serialized_end=219272
  _globals['_PATTERNFLOWIPV4TOTALLENGTHMETRICTAG']._serialized_start=219275
  _globals['_PATTERNFLOWIPV4TOTALLENGTHMETRICTAG']._serialized_end=219404
  _globals['_PATTERNFLOWIPV4TOTALLENGTH']._serialized_start=219407
  _globals['_PATTERNFLOWIPV4TOTALLENGTH']._serialized_end=219865
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER']._serialized_start=219867
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER']._serialized_end=219993
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG']._serialized_start=219996
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG']._serialized_end=220128
  _globals['_PATTERNFLOWIPV4IDENTIFICATION']._serialized_start=220131
  _globals['_PATTERNFLOWIPV4IDENTIFICATION']._serialized_end=220566
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4RESERVEDCOUNTER']._serialized_start=220568
  _globals['_PATTERNFLOWIPV4RESERVEDCOUNTER']._serialized_end=220688
  _globals['_PATTERNFLOWIPV4RESERVEDMETRICTAG']._serialized_start=220690
  _globals['_PATTERNFLOWIPV4RESERVEDMETRICTAG']._serialized_end=220816
  _globals['_PATTERNFLOWIPV4RESERVED']._serialized_start=220819
  _globals['_PATTERNFLOWIPV4RESERVED']._serialized_end=221224
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER']._serialized_start=221226
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER']._serialized_end=221350
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG']._serialized_start=221353
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG']._serialized_end=221483
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT']._serialized_start=221486
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT']._serialized_end=221911
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER']._serialized_start=221913
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER']._serialized_end=222038
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG']._serialized_start=222041
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG']._serialized_end=222172
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS']._serialized_start=222175
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS']._serialized_end=222605
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER']._serialized_start=222607
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER']._serialized_end=222733
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG']._serialized_start=222736
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG']._serialized_end=222868
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET']._serialized_start=222871
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET']._serialized_end=223306
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TIMETOLIVECOUNTER']._serialized_start=223308
  _globals['_PATTERNFLOWIPV4TIMETOLIVECOUNTER']._serialized_end=223430
  _globals['_PATTERNFLOWIPV4TIMETOLIVEMETRICTAG']._serialized_start=223433
  _globals['_PATTERNFLOWIPV4TIMETOLIVEMETRICTAG']._serialized_end=223561
  _globals['_PATTERNFLOWIPV4TIMETOLIVE']._serialized_start=223564
  _globals['_PATTERNFLOWIPV4TIMETOLIVE']._serialized_end=223979
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4PROTOCOLCOUNTER']._serialized_start=223981
  _globals['_PATTERNFLOWIPV4PROTOCOLCOUNTER']._serialized_end=224101
  _globals['_PATTERNFLOWIPV4PROTOCOLMETRICTAG']._serialized_start=224103
  _globals['_PATTERNFLOWIPV4PROTOCOLMETRICTAG']._serialized_end=224229
  _globals['_PATTERNFLOWIPV4PROTOCOL']._serialized_start=224232
  _globals['_PATTERNFLOWIPV4PROTOCOL']._serialized_end=224675
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM']._serialized_start=224678
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM']._serialized_end=225029
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWIPV4SRCCOUNTER']._serialized_start=225031
  _globals['_PATTERNFLOWIPV4SRCCOUNTER']._serialized_end=225146
  _globals['_PATTERNFLOWIPV4SRCMETRICTAG']._serialized_start=225148
  _globals['_PATTERNFLOWIPV4SRCMETRICTAG']._serialized_end=225269
  _globals['_PATTERNFLOWIPV4SRCRANDOM']._serialized_start=225272
  _globals['_PATTERNFLOWIPV4SRCRANDOM']._serialized_end=225408
  _globals['_PATTERNFLOWIPV4SRC']._serialized_start=225411
  _globals['_PATTERNFLOWIPV4SRC']._serialized_end=225893
  _globals['_PATTERNFLOWIPV4SRC_CHOICE']._serialized_start=225764
  _globals['_PATTERNFLOWIPV4SRC_CHOICE']._serialized_end=225872
  _globals['_PATTERNFLOWIPV4SRC_CHOICE_ENUM']._serialized_start=225774
  _globals['_PATTERNFLOWIPV4SRC_CHOICE_ENUM']._serialized_end=225872
  _globals['_PATTERNFLOWIPV4DSTCOUNTER']._serialized_start=225895
  _globals['_PATTERNFLOWIPV4DSTCOUNTER']._serialized_end=226010
  _globals['_PATTERNFLOWIPV4DSTMETRICTAG']._serialized_start=226012
  _globals['_PATTERNFLOWIPV4DSTMETRICTAG']._serialized_end=226133
  _globals['_PATTERNFLOWIPV4DSTRANDOM']._serialized_start=226136
  _globals['_PATTERNFLOWIPV4DSTRANDOM']._serialized_end=226272
  _globals['_PATTERNFLOWIPV4DST']._serialized_start=226275
  _globals['_PATTERNFLOWIPV4DST']._serialized_end=226757
  _globals['_PATTERNFLOWIPV4DST_CHOICE']._serialized_start=225764
  _globals['_PATTERNFLOWIPV4DST_CHOICE']._serialized_end=225872
  _globals['_PATTERNFLOWIPV4DST_CHOICE_ENUM']._serialized_start=225774
  _globals['_PATTERNFLOWIPV4DST_CHOICE_ENUM']._serialized_end=225872
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAGCOUNTER']._serialized_start=226760
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAGCOUNTER']._serialized_end=226899
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG']._serialized_start=226902
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG']._serialized_end=227323
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASSCOUNTER']._serialized_start=227326
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASSCOUNTER']._serialized_end=227466
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS']._serialized_start=227469
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS']._serialized_end=227894
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBERCOUNTER']._serialized_start=227897
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBERCOUNTER']._serialized_end=228038
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER']._serialized_start=228041
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER']._serialized_end=228470
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4PRIORITYRAWCOUNTER']._serialized_start=228472
  _globals['_PATTERNFLOWIPV4PRIORITYRAWCOUNTER']._serialized_end=228595
  _globals['_PATTERNFLOWIPV4PRIORITYRAWMETRICTAG']._serialized_start=228598
  _globals['_PATTERNFLOWIPV4PRIORITYRAWMETRICTAG']._serialized_end=228727
  _globals['_PATTERNFLOWIPV4PRIORITYRAW']._serialized_start=228730
  _globals['_PATTERNFLOWIPV4PRIORITYRAW']._serialized_end=229150
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4DSCPPHBCOUNTER']._serialized_start=229152
  _globals['_PATTERNFLOWIPV4DSCPPHBCOUNTER']._serialized_end=229271
  _globals['_PATTERNFLOWIPV4DSCPPHBMETRICTAG']._serialized_start=229273
  _globals['_PATTERNFLOWIPV4DSCPPHBMETRICTAG']._serialized_end=229398
  _globals['_PATTERNFLOWIPV4DSCPPHB']._serialized_start=229401
  _globals['_PATTERNFLOWIPV4DSCPPHB']._serialized_end=229801
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4DSCPECNCOUNTER']._serialized_start=229803
  _globals['_PATTERNFLOWIPV4DSCPECNCOUNTER']._serialized_end=229922
  _globals['_PATTERNFLOWIPV4DSCPECNMETRICTAG']._serialized_start=229924
  _globals['_PATTERNFLOWIPV4DSCPECNMETRICTAG']._serialized_end=230049
  _globals['_PATTERNFLOWIPV4DSCPECN']._serialized_start=230052
  _globals['_PATTERNFLOWIPV4DSCPECN']._serialized_end=230452
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER']._serialized_start=230454
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER']._serialized_end=230579
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG']._serialized_start=230582
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG']._serialized_end=230713
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE']._serialized_start=230716
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE']._serialized_end=231146
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSDELAYCOUNTER']._serialized_start=231148
  _globals['_PATTERNFLOWIPV4TOSDELAYCOUNTER']._serialized_end=231268
  _globals['_PATTERNFLOWIPV4TOSDELAYMETRICTAG']._serialized_start=231270
  _globals['_PATTERNFLOWIPV4TOSDELAYMETRICTAG']._serialized_end=231396
  _globals['_PATTERNFLOWIPV4TOSDELAY']._serialized_start=231399
  _globals['_PATTERNFLOWIPV4TOSDELAY']._serialized_end=231804
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER']._serialized_start=231806
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER']._serialized_end=231931
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG']._serialized_start=231934
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG']._serialized_end=232065
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT']._serialized_start=232068
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT']._serialized_end=232498
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER']._serialized_start=232500
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER']._serialized_end=232626
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG']._serialized_start=232629
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG']._serialized_end=232761
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY']._serialized_start=232764
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY']._serialized_end=233199
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSMONETARYCOUNTER']._serialized_start=233201
  _globals['_PATTERNFLOWIPV4TOSMONETARYCOUNTER']._serialized_end=233324
  _globals['_PATTERNFLOWIPV4TOSMONETARYMETRICTAG']._serialized_start=233327
  _globals['_PATTERNFLOWIPV4TOSMONETARYMETRICTAG']._serialized_end=233456
  _globals['_PATTERNFLOWIPV4TOSMONETARY']._serialized_start=233459
  _globals['_PATTERNFLOWIPV4TOSMONETARY']._serialized_end=233879
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSUNUSEDCOUNTER']._serialized_start=233881
  _globals['_PATTERNFLOWIPV4TOSUNUSEDCOUNTER']._serialized_end=234002
  _globals['_PATTERNFLOWIPV4TOSUNUSEDMETRICTAG']._serialized_start=234004
  _globals['_PATTERNFLOWIPV4TOSUNUSEDMETRICTAG']._serialized_end=234131
  _globals['_PATTERNFLOWIPV4TOSUNUSED']._serialized_start=234134
  _globals['_PATTERNFLOWIPV4TOSUNUSED']._serialized_end=234544
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6VERSIONCOUNTER']._serialized_start=234546
  _globals['_PATTERNFLOWIPV6VERSIONCOUNTER']._serialized_end=234665
  _globals['_PATTERNFLOWIPV6VERSIONMETRICTAG']._serialized_start=234667
  _globals['_PATTERNFLOWIPV6VERSIONMETRICTAG']._serialized_end=234792
  _globals['_PATTERNFLOWIPV6VERSION']._serialized_start=234795
  _globals['_PATTERNFLOWIPV6VERSION']._serialized_end=235195
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER']._serialized_start=235197
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER']._serialized_end=235321
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG']._serialized_start=235324
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG']._serialized_end=235454
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS']._serialized_start=235457
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS']._serialized_end=235882
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6FLOWLABELCOUNTER']._serialized_start=235884
  _globals['_PATTERNFLOWIPV6FLOWLABELCOUNTER']._serialized_end=236005
  _globals['_PATTERNFLOWIPV6FLOWLABELMETRICTAG']._serialized_start=236007
  _globals['_PATTERNFLOWIPV6FLOWLABELMETRICTAG']._serialized_end=236134
  _globals['_PATTERNFLOWIPV6FLOWLABELRANDOM']._serialized_start=236137
  _globals['_PATTERNFLOWIPV6FLOWLABELRANDOM']._serialized_end=236279
  _globals['_PATTERNFLOWIPV6FLOWLABEL']._serialized_start=236282
  _globals['_PATTERNFLOWIPV6FLOWLABEL']._serialized_end=236757
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE']._serialized_start=236638
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE']._serialized_end=236736
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM']._serialized_start=236648
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM']._serialized_end=236736
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER']._serialized_start=236759
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER']._serialized_end=236884
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG']._serialized_start=236887
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG']._serialized_end=237018
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH']._serialized_start=237021
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH']._serialized_end=237489
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWIPV6NEXTHEADERCOUNTER']._serialized_start=237491
  _globals['_PATTERNFLOWIPV6NEXTHEADERCOUNTER']._serialized_end=237613
  _globals['_PATTERNFLOWIPV6NEXTHEADERMETRICTAG']._serialized_start=237616
  _globals['_PATTERNFLOWIPV6NEXTHEADERMETRICTAG']._serialized_end=237744
  _globals['_PATTERNFLOWIPV6NEXTHEADER']._serialized_start=237747
  _globals['_PATTERNFLOWIPV6NEXTHEADER']._serialized_end=238200
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWIPV6HOPLIMITCOUNTER']._serialized_start=238202
  _globals['_PATTERNFLOWIPV6HOPLIMITCOUNTER']._serialized_end=238322
  _globals['_PATTERNFLOWIPV6HOPLIMITMETRICTAG']._serialized_start=238324
  _globals['_PATTERNFLOWIPV6HOPLIMITMETRICTAG']._serialized_end=238450
  _globals['_PATTERNFLOWIPV6HOPLIMIT']._serialized_start=238453
  _globals['_PATTERNFLOWIPV6HOPLIMIT']._serialized_end=238858
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIPV6SRCCOUNTER']._serialized_start=238860
  _globals['_PATTERNFLOWIPV6SRCCOUNTER']._serialized_end=238975
  _globals['_PATTERNFLOWIPV6SRCMETRICTAG']._serialized_start=238977
  _globals['_PATTERNFLOWIPV6SRCMETRICTAG']._serialized_end=239098
  _globals['_PATTERNFLOWIPV6SRC']._serialized_start=239101
  _globals['_PATTERNFLOWIPV6SRC']._serialized_end=239524
  _globals['_PATTERNFLOWIPV6SRC_CHOICE']._serialized_start=239407
  _globals['_PATTERNFLOWIPV6SRC_CHOICE']._serialized_end=239503
  _globals['_PATTERNFLOWIPV6SRC_CHOICE_ENUM']._serialized_start=225774
  _globals['_PATTERNFLOWIPV6SRC_CHOICE_ENUM']._serialized_end=225860
  _globals['_PATTERNFLOWIPV6DSTCOUNTER']._serialized_start=239526
  _globals['_PATTERNFLOWIPV6DSTCOUNTER']._serialized_end=239641
  _globals['_PATTERNFLOWIPV6DSTMETRICTAG']._serialized_start=239643
  _globals['_PATTERNFLOWIPV6DSTMETRICTAG']._serialized_end=239764
  _globals['_PATTERNFLOWIPV6DST']._serialized_start=239767
  _globals['_PATTERNFLOWIPV6DST']._serialized_end=240190
  _globals['_PATTERNFLOWIPV6DST_CHOICE']._serialized_start=239407
  _globals['_PATTERNFLOWIPV6DST_CHOICE']._serialized_end=239503
  _globals['_PATTERNFLOWIPV6DST_CHOICE_ENUM']._serialized_start=225774
  _globals['_PATTERNFLOWIPV6DST_CHOICE_ENUM']._serialized_end=225860
  _globals['_PATTERNFLOWPFCPAUSEDSTCOUNTER']._serialized_start=240192
  _globals['_PATTERNFLOWPFCPAUSEDSTCOUNTER']._serialized_end=240311
  _globals['_PATTERNFLOWPFCPAUSEDSTMETRICTAG']._serialized_start=240313
  _globals['_PATTERNFLOWPFCPAUSEDSTMETRICTAG']._serialized_end=240438
  _globals['_PATTERNFLOWPFCPAUSEDST']._serialized_start=240441
  _globals['_PATTERNFLOWPFCPAUSEDST']._serialized_end=240841
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSESRCCOUNTER']._serialized_start=240843
  _globals['_PATTERNFLOWPFCPAUSESRCCOUNTER']._serialized_end=240962
  _globals['_PATTERNFLOWPFCPAUSESRCMETRICTAG']._serialized_start=240964
  _globals['_PATTERNFLOWPFCPAUSESRCMETRICTAG']._serialized_end=241089
  _globals['_PATTERNFLOWPFCPAUSESRC']._serialized_start=241092
  _globals['_PATTERNFLOWPFCPAUSESRC']._serialized_end=241492
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER']._serialized_start=241494
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER']._serialized_end=241619
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG']._serialized_start=241622
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG']._serialized_end=241753
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE']._serialized_start=241756
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE']._serialized_end=242186
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER']._serialized_start=242189
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER']._serialized_end=242318
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG']._serialized_start=242321
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG']._serialized_end=242456
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE']._serialized_start=242459
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE']._serialized_end=242909
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER']._serialized_start=242912
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER']._serialized_end=243045
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG']._serialized_start=243048
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG']._serialized_end=243187
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR']._serialized_start=243190
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR']._serialized_end=243660
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER']._serialized_start=243662
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER']._serialized_end=243789
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG']._serialized_start=243792
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG']._serialized_end=243925
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0']._serialized_start=243928
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0']._serialized_end=244368
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER']._serialized_start=244370
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER']._serialized_end=244497
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG']._serialized_start=244500
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG']._serialized_end=244633
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1']._serialized_start=244636
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1']._serialized_end=245076
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER']._serialized_start=245078
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER']._serialized_end=245205
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG']._serialized_start=245208
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG']._serialized_end=245341
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2']._serialized_start=245344
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2']._serialized_end=245784
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER']._serialized_start=245786
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER']._serialized_end=245913
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG']._serialized_start=245916
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG']._serialized_end=246049
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3']._serialized_start=246052
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3']._serialized_end=246492
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER']._serialized_start=246494
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER']._serialized_end=246621
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG']._serialized_start=246624
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG']._serialized_end=246757
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4']._serialized_start=246760
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4']._serialized_end=247200
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER']._serialized_start=247202
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER']._serialized_end=247329
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG']._serialized_start=247332
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG']._serialized_end=247465
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5']._serialized_start=247468
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5']._serialized_end=247908
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER']._serialized_start=247910
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER']._serialized_end=248037
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG']._serialized_start=248040
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG']._serialized_end=248173
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6']._serialized_start=248176
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6']._serialized_end=248616
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER']._serialized_start=248618
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER']._serialized_end=248745
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG']._serialized_start=248748
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG']._serialized_end=248881
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7']._serialized_start=248884
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7']._serialized_end=249324
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSEDSTCOUNTER']._serialized_start=249326
  _globals['_PATTERNFLOWETHERNETPAUSEDSTCOUNTER']._serialized_end=249450
  _globals['_PATTERNFLOWETHERNETPAUSEDSTMETRICTAG']._serialized_start=249453
  _globals['_PATTERNFLOWETHERNETPAUSEDSTMETRICTAG']._serialized_end=249583
  _globals['_PATTERNFLOWETHERNETPAUSEDST']._serialized_start=249586
  _globals['_PATTERNFLOWETHERNETPAUSEDST']._serialized_end=250011
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSESRCCOUNTER']._serialized_start=250013
  _globals['_PATTERNFLOWETHERNETPAUSESRCCOUNTER']._serialized_end=250137
  _globals['_PATTERNFLOWETHERNETPAUSESRCMETRICTAG']._serialized_start=250140
  _globals['_PATTERNFLOWETHERNETPAUSESRCMETRICTAG']._serialized_end=250270
  _globals['_PATTERNFLOWETHERNETPAUSESRC']._serialized_start=250273
  _globals['_PATTERNFLOWETHERNETPAUSESRC']._serialized_end=250698
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER']._serialized_start=250701
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER']._serialized_end=250831
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG']._serialized_start=250834
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG']._serialized_end=250970
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE']._serialized_start=250973
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE']._serialized_end=251428
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER']._serialized_start=251431
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER']._serialized_end=251565
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG']._serialized_start=251568
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG']._serialized_end=251708
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE']._serialized_start=251711
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE']._serialized_end=252186
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSETIMECOUNTER']._serialized_start=252188
  _globals['_PATTERNFLOWETHERNETPAUSETIMECOUNTER']._serialized_end=252313
  _globals['_PATTERNFLOWETHERNETPAUSETIMEMETRICTAG']._serialized_start=252316
  _globals['_PATTERNFLOWETHERNETPAUSETIMEMETRICTAG']._serialized_end=252447
  _globals['_PATTERNFLOWETHERNETPAUSETIME']._serialized_start=252450
  _globals['_PATTERNFLOWETHERNETPAUSETIME']._serialized_end=252880
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPSRCPORTCOUNTER']._serialized_start=252882
  _globals['_PATTERNFLOWTCPSRCPORTCOUNTER']._serialized_end=253000
  _globals['_PATTERNFLOWTCPSRCPORTMETRICTAG']._serialized_start=253002
  _globals['_PATTERNFLOWTCPSRCPORTMETRICTAG']._serialized_end=253126
  _globals['_PATTERNFLOWTCPSRCPORTRANDOM']._serialized_start=253129
  _globals['_PATTERNFLOWTCPSRCPORTRANDOM']._serialized_end=253268
  _globals['_PATTERNFLOWTCPSRCPORT']._serialized_start=253271
  _globals['_PATTERNFLOWTCPSRCPORT']._serialized_end=253728
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE']._serialized_start=236638
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE']._serialized_end=236736
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM']._serialized_start=236648
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM']._serialized_end=236736
  _globals['_PATTERNFLOWTCPDSTPORTCOUNTER']._serialized_start=253730
  _globals['_PATTERNFLOWTCPDSTPORTCOUNTER']._serialized_end=253848
  _globals['_PATTERNFLOWTCPDSTPORTMETRICTAG']._serialized_start=253850
  _globals['_PATTERNFLOWTCPDSTPORTMETRICTAG']._serialized_end=253974
  _globals['_PATTERNFLOWTCPDSTPORTRANDOM']._serialized_start=253977
  _globals['_PATTERNFLOWTCPDSTPORTRANDOM']._serialized_end=254116
  _globals['_PATTERNFLOWTCPDSTPORT']._serialized_start=254119
  _globals['_PATTERNFLOWTCPDSTPORT']._serialized_end=254576
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE']._serialized_start=236638
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE']._serialized_end=236736
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM']._serialized_start=236648
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM']._serialized_end=236736
  _globals['_PATTERNFLOWTCPSEQNUMCOUNTER']._serialized_start=254578
  _globals['_PATTERNFLOWTCPSEQNUMCOUNTER']._serialized_end=254695
  _globals['_PATTERNFLOWTCPSEQNUMMETRICTAG']._serialized_start=254697
  _globals['_PATTERNFLOWTCPSEQNUMMETRICTAG']._serialized_end=254820
  _globals['_PATTERNFLOWTCPSEQNUM']._serialized_start=254823
  _globals['_PATTERNFLOWTCPSEQNUM']._serialized_end=255213
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPACKNUMCOUNTER']._serialized_start=255215
  _globals['_PATTERNFLOWTCPACKNUMCOUNTER']._serialized_end=255332
  _globals['_PATTERNFLOWTCPACKNUMMETRICTAG']._serialized_start=255334
  _globals['_PATTERNFLOWTCPACKNUMMETRICTAG']._serialized_end=255457
  _globals['_PATTERNFLOWTCPACKNUM']._serialized_start=255460
  _globals['_PATTERNFLOWTCPACKNUM']._serialized_end=255850
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPDATAOFFSETCOUNTER']._serialized_start=255852
  _globals['_PATTERNFLOWTCPDATAOFFSETCOUNTER']._serialized_end=255973
  _globals['_PATTERNFLOWTCPDATAOFFSETMETRICTAG']._serialized_start=255975
  _globals['_PATTERNFLOWTCPDATAOFFSETMETRICTAG']._serialized_end=256102
  _globals['_PATTERNFLOWTCPDATAOFFSET']._serialized_start=256105
  _globals['_PATTERNFLOWTCPDATAOFFSET']._serialized_end=256515
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPECNNSCOUNTER']._serialized_start=256517
  _globals['_PATTERNFLOWTCPECNNSCOUNTER']._serialized_end=256633
  _globals['_PATTERNFLOWTCPECNNSMETRICTAG']._serialized_start=256635
  _globals['_PATTERNFLOWTCPECNNSMETRICTAG']._serialized_end=256757
  _globals['_PATTERNFLOWTCPECNNS']._serialized_start=256760
  _globals['_PATTERNFLOWTCPECNNS']._serialized_end=257145
  _globals['_PATTERNFLOWTCPECNNS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPECNNS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPECNNS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPECNNS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPECNCWRCOUNTER']._serialized_start=257147
  _globals['_PATTERNFLOWTCPECNCWRCOUNTER']._serialized_end=257264
  _globals['_PATTERNFLOWTCPECNCWRMETRICTAG']._serialized_start=257266
  _globals['_PATTERNFLOWTCPECNCWRMETRICTAG']._serialized_end=257389
  _globals['_PATTERNFLOWTCPECNCWR']._serialized_start=257392
  _globals['_PATTERNFLOWTCPECNCWR']._serialized_end=257782
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPECNECHOCOUNTER']._serialized_start=257784
  _globals['_PATTERNFLOWTCPECNECHOCOUNTER']._serialized_end=257902
  _globals['_PATTERNFLOWTCPECNECHOMETRICTAG']._serialized_start=257904
  _globals['_PATTERNFLOWTCPECNECHOMETRICTAG']._serialized_end=258028
  _globals['_PATTERNFLOWTCPECNECHO']._serialized_start=258031
  _globals['_PATTERNFLOWTCPECNECHO']._serialized_end=258426
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLURGCOUNTER']._serialized_start=258428
  _globals['_PATTERNFLOWTCPCTLURGCOUNTER']._serialized_end=258545
  _globals['_PATTERNFLOWTCPCTLURGMETRICTAG']._serialized_start=258547
  _globals['_PATTERNFLOWTCPCTLURGMETRICTAG']._serialized_end=258670
  _globals['_PATTERNFLOWTCPCTLURG']._serialized_start=258673
  _globals['_PATTERNFLOWTCPCTLURG']._serialized_end=259063
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLACKCOUNTER']._serialized_start=259065
  _globals['_PATTERNFLOWTCPCTLACKCOUNTER']._serialized_end=259182
  _globals['_PATTERNFLOWTCPCTLACKMETRICTAG']._serialized_start=259184
  _globals['_PATTERNFLOWTCPCTLACKMETRICTAG']._serialized_end=259307
  _globals['_PATTERNFLOWTCPCTLACK']._serialized_start=259310
  _globals['_PATTERNFLOWTCPCTLACK']._serialized_end=259700
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLPSHCOUNTER']._serialized_start=259702
  _globals['_PATTERNFLOWTCPCTLPSHCOUNTER']._serialized_end=259819
  _globals['_PATTERNFLOWTCPCTLPSHMETRICTAG']._serialized_start=259821
  _globals['_PATTERNFLOWTCPCTLPSHMETRICTAG']._serialized_end=259944
  _globals['_PATTERNFLOWTCPCTLPSH']._serialized_start=259947
  _globals['_PATTERNFLOWTCPCTLPSH']._serialized_end=260337
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLRSTCOUNTER']._serialized_start=260339
  _globals['_PATTERNFLOWTCPCTLRSTCOUNTER']._serialized_end=260456
  _globals['_PATTERNFLOWTCPCTLRSTMETRICTAG']._serialized_start=260458
  _globals['_PATTERNFLOWTCPCTLRSTMETRICTAG']._serialized_end=260581
  _globals['_PATTERNFLOWTCPCTLRST']._serialized_start=260584
  _globals['_PATTERNFLOWTCPCTLRST']._serialized_end=260974
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLSYNCOUNTER']._serialized_start=260976
  _globals['_PATTERNFLOWTCPCTLSYNCOUNTER']._serialized_end=261093
  _globals['_PATTERNFLOWTCPCTLSYNMETRICTAG']._serialized_start=261095
  _globals['_PATTERNFLOWTCPCTLSYNMETRICTAG']._serialized_end=261218
  _globals['_PATTERNFLOWTCPCTLSYN']._serialized_start=261221
  _globals['_PATTERNFLOWTCPCTLSYN']._serialized_end=261611
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLFINCOUNTER']._serialized_start=261613
  _globals['_PATTERNFLOWTCPCTLFINCOUNTER']._serialized_end=261730
  _globals['_PATTERNFLOWTCPCTLFINMETRICTAG']._serialized_start=261732
  _globals['_PATTERNFLOWTCPCTLFINMETRICTAG']._serialized_end=261855
  _globals['_PATTERNFLOWTCPCTLFIN']._serialized_start=261858
  _globals['_PATTERNFLOWTCPCTLFIN']._serialized_end=262248
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPWINDOWCOUNTER']._serialized_start=262250
  _globals['_PATTERNFLOWTCPWINDOWCOUNTER']._serialized_end=262367
  _globals['_PATTERNFLOWTCPWINDOWMETRICTAG']._serialized_start=262369
  _globals['_PATTERNFLOWTCPWINDOWMETRICTAG']._serialized_end=262492
  _globals['_PATTERNFLOWTCPWINDOW']._serialized_start=262495
  _globals['_PATTERNFLOWTCPWINDOW']._serialized_end=262885
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWTCPCHECKSUM']._serialized_start=262888
  _globals['_PATTERNFLOWTCPCHECKSUM']._serialized_end=263218
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWUDPSRCPORTCOUNTER']._serialized_start=263220
  _globals['_PATTERNFLOWUDPSRCPORTCOUNTER']._serialized_end=263338
  _globals['_PATTERNFLOWUDPSRCPORTMETRICTAG']._serialized_start=263340
  _globals['_PATTERNFLOWUDPSRCPORTMETRICTAG']._serialized_end=263464
  _globals['_PATTERNFLOWUDPSRCPORTRANDOM']._serialized_start=263467
  _globals['_PATTERNFLOWUDPSRCPORTRANDOM']._serialized_end=263606
  _globals['_PATTERNFLOWUDPSRCPORT']._serialized_start=263609
  _globals['_PATTERNFLOWUDPSRCPORT']._serialized_end=264066
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE']._serialized_start=236638
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE']._serialized_end=236736
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM']._serialized_start=236648
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM']._serialized_end=236736
  _globals['_PATTERNFLOWUDPDSTPORTCOUNTER']._serialized_start=264068
  _globals['_PATTERNFLOWUDPDSTPORTCOUNTER']._serialized_end=264186
  _globals['_PATTERNFLOWUDPDSTPORTMETRICTAG']._serialized_start=264188
  _globals['_PATTERNFLOWUDPDSTPORTMETRICTAG']._serialized_end=264312
  _globals['_PATTERNFLOWUDPDSTPORTRANDOM']._serialized_start=264315
  _globals['_PATTERNFLOWUDPDSTPORTRANDOM']._serialized_end=264454
  _globals['_PATTERNFLOWUDPDSTPORT']._serialized_start=264457
  _globals['_PATTERNFLOWUDPDSTPORT']._serialized_end=264914
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE']._serialized_start=236638
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE']._serialized_end=236736
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM']._serialized_start=236648
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM']._serialized_end=236736
  _globals['_PATTERNFLOWUDPLENGTHCOUNTER']._serialized_start=264916
  _globals['_PATTERNFLOWUDPLENGTHCOUNTER']._serialized_end=265033
  _globals['_PATTERNFLOWUDPLENGTHMETRICTAG']._serialized_start=265035
  _globals['_PATTERNFLOWUDPLENGTHMETRICTAG']._serialized_end=265158
  _globals['_PATTERNFLOWUDPLENGTH']._serialized_start=265161
  _globals['_PATTERNFLOWUDPLENGTH']._serialized_end=265551
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWUDPCHECKSUM']._serialized_start=265554
  _globals['_PATTERNFLOWUDPCHECKSUM']._serialized_end=265884
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER']._serialized_start=265886
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER']._serialized_end=266012
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG']._serialized_start=266015
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG']._serialized_end=266147
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT']._serialized_start=266150
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT']._serialized_end=266585
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGRERESERVED0COUNTER']._serialized_start=266587
  _globals['_PATTERNFLOWGRERESERVED0COUNTER']._serialized_end=266707
  _globals['_PATTERNFLOWGRERESERVED0METRICTAG']._serialized_start=266709
  _globals['_PATTERNFLOWGRERESERVED0METRICTAG']._serialized_end=266835
  _globals['_PATTERNFLOWGRERESERVED0']._serialized_start=266838
  _globals['_PATTERNFLOWGRERESERVED0']._serialized_end=267243
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGREVERSIONCOUNTER']._serialized_start=267245
  _globals['_PATTERNFLOWGREVERSIONCOUNTER']._serialized_end=267363
  _globals['_PATTERNFLOWGREVERSIONMETRICTAG']._serialized_start=267365
  _globals['_PATTERNFLOWGREVERSIONMETRICTAG']._serialized_end=267489
  _globals['_PATTERNFLOWGREVERSION']._serialized_start=267492
  _globals['_PATTERNFLOWGREVERSION']._serialized_end=267887
  _globals['_PATTERNFLOWGREVERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGREVERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGREVERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGREVERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGREPROTOCOLCOUNTER']._serialized_start=267889
  _globals['_PATTERNFLOWGREPROTOCOLCOUNTER']._serialized_end=268008
  _globals['_PATTERNFLOWGREPROTOCOLMETRICTAG']._serialized_start=268010
  _globals['_PATTERNFLOWGREPROTOCOLMETRICTAG']._serialized_end=268135
  _globals['_PATTERNFLOWGREPROTOCOL']._serialized_start=268138
  _globals['_PATTERNFLOWGREPROTOCOL']._serialized_end=268576
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE']._serialized_start=239407
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE']._serialized_end=239503
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM']._serialized_start=225774
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM']._serialized_end=225860
  _globals['_PATTERNFLOWGRECHECKSUM']._serialized_start=268579
  _globals['_PATTERNFLOWGRECHECKSUM']._serialized_end=268909
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWGRERESERVED1COUNTER']._serialized_start=268911
  _globals['_PATTERNFLOWGRERESERVED1COUNTER']._serialized_end=269031
  _globals['_PATTERNFLOWGRERESERVED1METRICTAG']._serialized_start=269033
  _globals['_PATTERNFLOWGRERESERVED1METRICTAG']._serialized_end=269159
  _globals['_PATTERNFLOWGRERESERVED1']._serialized_start=269162
  _globals['_PATTERNFLOWGRERESERVED1']._serialized_end=269567
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1VERSIONCOUNTER']._serialized_start=269569
  _globals['_PATTERNFLOWGTPV1VERSIONCOUNTER']._serialized_end=269689
  _globals['_PATTERNFLOWGTPV1VERSIONMETRICTAG']._serialized_start=269691
  _globals['_PATTERNFLOWGTPV1VERSIONMETRICTAG']._serialized_end=269817
  _globals['_PATTERNFLOWGTPV1VERSION']._serialized_start=269820
  _globals['_PATTERNFLOWGTPV1VERSION']._serialized_end=270225
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER']._serialized_start=270227
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER']._serialized_end=270352
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG']._serialized_start=270355
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG']._serialized_end=270486
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE']._serialized_start=270489
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE']._serialized_end=270919
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1RESERVEDCOUNTER']._serialized_start=270921
  _globals['_PATTERNFLOWGTPV1RESERVEDCOUNTER']._serialized_end=271042
  _globals['_PATTERNFLOWGTPV1RESERVEDMETRICTAG']._serialized_start=271044
  _globals['_PATTERNFLOWGTPV1RESERVEDMETRICTAG']._serialized_end=271171
  _globals['_PATTERNFLOWGTPV1RESERVED']._serialized_start=271174
  _globals['_PATTERNFLOWGTPV1RESERVED']._serialized_end=271584
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1EFLAGCOUNTER']._serialized_start=271586
  _globals['_PATTERNFLOWGTPV1EFLAGCOUNTER']._serialized_end=271704
  _globals['_PATTERNFLOWGTPV1EFLAGMETRICTAG']._serialized_start=271706
  _globals['_PATTERNFLOWGTPV1EFLAGMETRICTAG']._serialized_end=271830
  _globals['_PATTERNFLOWGTPV1EFLAG']._serialized_start=271833
  _globals['_PATTERNFLOWGTPV1EFLAG']._serialized_end=272228
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1SFLAGCOUNTER']._serialized_start=272230
  _globals['_PATTERNFLOWGTPV1SFLAGCOUNTER']._serialized_end=272348
  _globals['_PATTERNFLOWGTPV1SFLAGMETRICTAG']._serialized_start=272350
  _globals['_PATTERNFLOWGTPV1SFLAGMETRICTAG']._serialized_end=272474
  _globals['_PATTERNFLOWGTPV1SFLAG']._serialized_start=272477
  _globals['_PATTERNFLOWGTPV1SFLAG']._serialized_end=272872
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1PNFLAGCOUNTER']._serialized_start=272874
  _globals['_PATTERNFLOWGTPV1PNFLAGCOUNTER']._serialized_end=272993
  _globals['_PATTERNFLOWGTPV1PNFLAGMETRICTAG']._serialized_start=272995
  _globals['_PATTERNFLOWGTPV1PNFLAGMETRICTAG']._serialized_end=273120
  _globals['_PATTERNFLOWGTPV1PNFLAG']._serialized_start=273123
  _globals['_PATTERNFLOWGTPV1PNFLAG']._serialized_end=273523
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1MESSAGETYPECOUNTER']._serialized_start=273525
  _globals['_PATTERNFLOWGTPV1MESSAGETYPECOUNTER']._serialized_end=273649
  _globals['_PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG']._serialized_start=273652
  _globals['_PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG']._serialized_end=273782
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE']._serialized_start=273785
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE']._serialized_end=274210
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER']._serialized_start=274212
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER']._serialized_end=274338
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG']._serialized_start=274341
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG']._serialized_end=274473
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH']._serialized_start=274476
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH']._serialized_end=274911
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1TEIDCOUNTER']._serialized_start=274913
  _globals['_PATTERNFLOWGTPV1TEIDCOUNTER']._serialized_end=275030
  _globals['_PATTERNFLOWGTPV1TEIDMETRICTAG']._serialized_start=275032
  _globals['_PATTERNFLOWGTPV1TEIDMETRICTAG']._serialized_end=275155
  _globals['_PATTERNFLOWGTPV1TEID']._serialized_start=275158
  _globals['_PATTERNFLOWGTPV1TEID']._serialized_end=275548
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER']._serialized_start=275550
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER']._serialized_end=275676
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG']._serialized_start=275679
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG']._serialized_end=275811
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER']._serialized_start=275814
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER']._serialized_end=276249
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER']._serialized_start=276251
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER']._serialized_end=276374
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG']._serialized_start=276377
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG']._serialized_end=276506
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER']._serialized_start=276509
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER']._serialized_end=276929
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER']._serialized_start=276932
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER']._serialized_end=277068
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG']._serialized_start=277071
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG']._serialized_end=277213
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE']._serialized_start=277216
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE']._serialized_end=277701
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER']._serialized_start=277704
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER']._serialized_end=277839
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG']._serialized_start=277842
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG']._serialized_end=277983
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH']._serialized_start=277986
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH']._serialized_end=278466
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER']._serialized_start=278469
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER']._serialized_end=278597
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG']._serialized_start=278600
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG']._serialized_end=278734
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS']._serialized_start=278737
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS']._serialized_end=279182
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER']._serialized_start=279185
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER']._serialized_end=279324
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG']._serialized_start=279327
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG']._serialized_end=279472
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER']._serialized_start=279475
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER']._serialized_end=279975
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2VERSIONCOUNTER']._serialized_start=279977
  _globals['_PATTERNFLOWGTPV2VERSIONCOUNTER']._serialized_end=280097
  _globals['_PATTERNFLOWGTPV2VERSIONMETRICTAG']._serialized_start=280099
  _globals['_PATTERNFLOWGTPV2VERSIONMETRICTAG']._serialized_end=280225
  _globals['_PATTERNFLOWGTPV2VERSION']._serialized_start=280228
  _globals['_PATTERNFLOWGTPV2VERSION']._serialized_end=280633
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER']._serialized_start=280636
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER']._serialized_end=280765
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG']._serialized_start=280768
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG']._serialized_end=280903
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG']._serialized_start=280906
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG']._serialized_end=281356
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2TEIDFLAGCOUNTER']._serialized_start=281358
  _globals['_PATTERNFLOWGTPV2TEIDFLAGCOUNTER']._serialized_end=281479
  _globals['_PATTERNFLOWGTPV2TEIDFLAGMETRICTAG']._serialized_start=281481
  _globals['_PATTERNFLOWGTPV2TEIDFLAGMETRICTAG']._serialized_end=281608
  _globals['_PATTERNFLOWGTPV2TEIDFLAG']._serialized_start=281611
  _globals['_PATTERNFLOWGTPV2TEIDFLAG']._serialized_end=282021
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2SPARE1COUNTER']._serialized_start=282023
  _globals['_PATTERNFLOWGTPV2SPARE1COUNTER']._serialized_end=282142
  _globals['_PATTERNFLOWGTPV2SPARE1METRICTAG']._serialized_start=282144
  _globals['_PATTERNFLOWGTPV2SPARE1METRICTAG']._serialized_end=282269
  _globals['_PATTERNFLOWGTPV2SPARE1']._serialized_start=282272
  _globals['_PATTERNFLOWGTPV2SPARE1']._serialized_end=282672
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2MESSAGETYPECOUNTER']._serialized_start=282674
  _globals['_PATTERNFLOWGTPV2MESSAGETYPECOUNTER']._serialized_end=282798
  _globals['_PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG']._serialized_start=282801
  _globals['_PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG']._serialized_end=282931
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE']._serialized_start=282934
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE']._serialized_end=283359
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER']._serialized_start=283361
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER']._serialized_end=283487
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG']._serialized_start=283490
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG']._serialized_end=283622
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH']._serialized_start=283625
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH']._serialized_end=284060
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2TEIDCOUNTER']._serialized_start=284062
  _globals['_PATTERNFLOWGTPV2TEIDCOUNTER']._serialized_end=284179
  _globals['_PATTERNFLOWGTPV2TEIDMETRICTAG']._serialized_start=284181
  _globals['_PATTERNFLOWGTPV2TEIDMETRICTAG']._serialized_end=284304
  _globals['_PATTERNFLOWGTPV2TEID']._serialized_start=284307
  _globals['_PATTERNFLOWGTPV2TEID']._serialized_end=284697
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER']._serialized_start=284699
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER']._serialized_end=284826
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG']._serialized_start=284829
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG']._serialized_end=284962
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER']._serialized_start=284965
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER']._serialized_end=285405
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2SPARE2COUNTER']._serialized_start=285407
  _globals['_PATTERNFLOWGTPV2SPARE2COUNTER']._serialized_end=285526
  _globals['_PATTERNFLOWGTPV2SPARE2METRICTAG']._serialized_start=285528
  _globals['_PATTERNFLOWGTPV2SPARE2METRICTAG']._serialized_end=285653
  _globals['_PATTERNFLOWGTPV2SPARE2']._serialized_start=285656
  _globals['_PATTERNFLOWGTPV2SPARE2']._serialized_end=286056
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPHARDWARETYPECOUNTER']._serialized_start=286058
  _globals['_PATTERNFLOWARPHARDWARETYPECOUNTER']._serialized_end=286181
  _globals['_PATTERNFLOWARPHARDWARETYPEMETRICTAG']._serialized_start=286184
  _globals['_PATTERNFLOWARPHARDWARETYPEMETRICTAG']._serialized_end=286313
  _globals['_PATTERNFLOWARPHARDWARETYPE']._serialized_start=286316
  _globals['_PATTERNFLOWARPHARDWARETYPE']._serialized_end=286736
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPPROTOCOLTYPECOUNTER']._serialized_start=286738
  _globals['_PATTERNFLOWARPPROTOCOLTYPECOUNTER']._serialized_end=286861
  _globals['_PATTERNFLOWARPPROTOCOLTYPEMETRICTAG']._serialized_start=286864
  _globals['_PATTERNFLOWARPPROTOCOLTYPEMETRICTAG']._serialized_end=286993
  _globals['_PATTERNFLOWARPPROTOCOLTYPE']._serialized_start=286996
  _globals['_PATTERNFLOWARPPROTOCOLTYPE']._serialized_end=287416
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPHARDWARELENGTHCOUNTER']._serialized_start=287418
  _globals['_PATTERNFLOWARPHARDWARELENGTHCOUNTER']._serialized_end=287543
  _globals['_PATTERNFLOWARPHARDWARELENGTHMETRICTAG']._serialized_start=287546
  _globals['_PATTERNFLOWARPHARDWARELENGTHMETRICTAG']._serialized_end=287677
  _globals['_PATTERNFLOWARPHARDWARELENGTH']._serialized_start=287680
  _globals['_PATTERNFLOWARPHARDWARELENGTH']._serialized_end=288110
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER']._serialized_start=288112
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER']._serialized_end=288237
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG']._serialized_start=288240
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG']._serialized_end=288371
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH']._serialized_start=288374
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH']._serialized_end=288804
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPOPERATIONCOUNTER']._serialized_start=288806
  _globals['_PATTERNFLOWARPOPERATIONCOUNTER']._serialized_end=288926
  _globals['_PATTERNFLOWARPOPERATIONMETRICTAG']._serialized_start=288928
  _globals['_PATTERNFLOWARPOPERATIONMETRICTAG']._serialized_end=289054
  _globals['_PATTERNFLOWARPOPERATION']._serialized_start=289057
  _globals['_PATTERNFLOWARPOPERATION']._serialized_end=289462
  _globals['_PATTERNFLOWARPOPERATION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPOPERATION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPOPERATION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPOPERATION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER']._serialized_start=289465
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER']._serialized_end=289594
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG']._serialized_start=289597
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG']._serialized_end=289732
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR']._serialized_start=289735
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR']._serialized_end=290185
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER']._serialized_start=290188
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER']._serialized_end=290317
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG']._serialized_start=290320
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG']._serialized_end=290455
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR']._serialized_start=290458
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR']._serialized_end=290908
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER']._serialized_start=290911
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER']._serialized_end=291040
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG']._serialized_start=291043
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG']._serialized_end=291178
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR']._serialized_start=291181
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR']._serialized_end=291631
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER']._serialized_start=291634
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER']._serialized_end=291763
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG']._serialized_start=291766
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG']._serialized_end=291901
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR']._serialized_start=291904
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR']._serialized_end=292354
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOTYPECOUNTER']._serialized_start=292356
  _globals['_PATTERNFLOWICMPECHOTYPECOUNTER']._serialized_end=292476
  _globals['_PATTERNFLOWICMPECHOTYPEMETRICTAG']._serialized_start=292478
  _globals['_PATTERNFLOWICMPECHOTYPEMETRICTAG']._serialized_end=292604
  _globals['_PATTERNFLOWICMPECHOTYPE']._serialized_start=292607
  _globals['_PATTERNFLOWICMPECHOTYPE']._serialized_end=293012
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOCODECOUNTER']._serialized_start=293014
  _globals['_PATTERNFLOWICMPECHOCODECOUNTER']._serialized_end=293134
  _globals['_PATTERNFLOWICMPECHOCODEMETRICTAG']._serialized_start=293136
  _globals['_PATTERNFLOWICMPECHOCODEMETRICTAG']._serialized_end=293262
  _globals['_PATTERNFLOWICMPECHOCODE']._serialized_start=293265
  _globals['_PATTERNFLOWICMPECHOCODE']._serialized_end=293670
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOCHECKSUM']._serialized_start=293673
  _globals['_PATTERNFLOWICMPECHOCHECKSUM']._serialized_end=294018
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER']._serialized_start=294020
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER']._serialized_end=294146
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG']._serialized_start=294149
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG']._serialized_end=294281
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER']._serialized_start=294284
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER']._serialized_end=294719
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER']._serialized_start=294722
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER']._serialized_end=294852
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG']._serialized_start=294855
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG']._serialized_end=294991
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER']._serialized_start=294994
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER']._serialized_end=295449
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM']._serialized_start=295452
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM']._serialized_end=295803
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER']._serialized_start=295806
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER']._serialized_end=295938
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG']._serialized_start=295941
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG']._serialized_end=296079
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER']._serialized_start=296082
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER']._serialized_end=296547
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER']._serialized_start=296550
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER']._serialized_end=296686
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG']._serialized_start=296689
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG']._serialized_end=296831
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER']._serialized_start=296834
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER']._serialized_end=297319
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOTYPECOUNTER']._serialized_start=297321
  _globals['_PATTERNFLOWICMPV6ECHOTYPECOUNTER']._serialized_end=297443
  _globals['_PATTERNFLOWICMPV6ECHOTYPEMETRICTAG']._serialized_start=297446
  _globals['_PATTERNFLOWICMPV6ECHOTYPEMETRICTAG']._serialized_end=297574
  _globals['_PATTERNFLOWICMPV6ECHOTYPE']._serialized_start=297577
  _globals['_PATTERNFLOWICMPV6ECHOTYPE']._serialized_end=297992
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOCODECOUNTER']._serialized_start=297994
  _globals['_PATTERNFLOWICMPV6ECHOCODECOUNTER']._serialized_end=298116
  _globals['_PATTERNFLOWICMPV6ECHOCODEMETRICTAG']._serialized_start=298119
  _globals['_PATTERNFLOWICMPV6ECHOCODEMETRICTAG']._serialized_end=298247
  _globals['_PATTERNFLOWICMPV6ECHOCODE']._serialized_start=298250
  _globals['_PATTERNFLOWICMPV6ECHOCODE']._serialized_end=298665
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER']._serialized_start=298668
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER']._serialized_end=298796
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG']._serialized_start=298799
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG']._serialized_end=298933
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER']._serialized_start=298936
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER']._serialized_end=299381
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER']._serialized_start=299384
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER']._serialized_end=299516
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG']._serialized_start=299519
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG']._serialized_end=299657
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER']._serialized_start=299660
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER']._serialized_end=300125
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM']._serialized_start=300128
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM']._serialized_end=300479
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM']._serialized_start=300482
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM']._serialized_end=300839
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWPPPADDRESSCOUNTER']._serialized_start=300841
  _globals['_PATTERNFLOWPPPADDRESSCOUNTER']._serialized_end=300959
  _globals['_PATTERNFLOWPPPADDRESSMETRICTAG']._serialized_start=300961
  _globals['_PATTERNFLOWPPPADDRESSMETRICTAG']._serialized_end=301085
  _globals['_PATTERNFLOWPPPADDRESS']._serialized_start=301088
  _globals['_PATTERNFLOWPPPADDRESS']._serialized_end=301483
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPPPCONTROLCOUNTER']._serialized_start=301485
  _globals['_PATTERNFLOWPPPCONTROLCOUNTER']._serialized_end=301603
  _globals['_PATTERNFLOWPPPCONTROLMETRICTAG']._serialized_start=301605
  _globals['_PATTERNFLOWPPPCONTROLMETRICTAG']._serialized_end=301729
  _globals['_PATTERNFLOWPPPCONTROL']._serialized_start=301732
  _globals['_PATTERNFLOWPPPCONTROL']._serialized_end=302127
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWPPPPROTOCOLTYPECOUNTER']._serialized_start=302129
  _globals['_PATTERNFLOWPPPPROTOCOLTYPECOUNTER']._serialized_end=302252
  _globals['_PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG']._serialized_start=302255
  _globals['_PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG']._serialized_end=302384
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE']._serialized_start=302387
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE']._serialized_end=302845
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWIGMPV1VERSIONCOUNTER']._serialized_start=302847
  _globals['_PATTERNFLOWIGMPV1VERSIONCOUNTER']._serialized_end=302968
  _globals['_PATTERNFLOWIGMPV1VERSIONMETRICTAG']._serialized_start=302970
  _globals['_PATTERNFLOWIGMPV1VERSIONMETRICTAG']._serialized_end=303097
  _globals['_PATTERNFLOWIGMPV1VERSION']._serialized_start=303100
  _globals['_PATTERNFLOWIGMPV1VERSION']._serialized_end=303510
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1TYPECOUNTER']._serialized_start=303512
  _globals['_PATTERNFLOWIGMPV1TYPECOUNTER']._serialized_end=303630
  _globals['_PATTERNFLOWIGMPV1TYPEMETRICTAG']._serialized_start=303632
  _globals['_PATTERNFLOWIGMPV1TYPEMETRICTAG']._serialized_end=303756
  _globals['_PATTERNFLOWIGMPV1TYPE']._serialized_start=303759
  _globals['_PATTERNFLOWIGMPV1TYPE']._serialized_end=304154
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1UNUSEDCOUNTER']._serialized_start=304156
  _globals['_PATTERNFLOWIGMPV1UNUSEDCOUNTER']._serialized_end=304276
  _globals['_PATTERNFLOWIGMPV1UNUSEDMETRICTAG']._serialized_start=304278
  _globals['_PATTERNFLOWIGMPV1UNUSEDMETRICTAG']._serialized_end=304404
  _globals['_PATTERNFLOWIGMPV1UNUSED']._serialized_start=304407
  _globals['_PATTERNFLOWIGMPV1UNUSED']._serialized_end=304812
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1CHECKSUM']._serialized_start=304815
  _globals['_PATTERNFLOWIGMPV1CHECKSUM']._serialized_end=305154
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER']._serialized_start=305156
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER']._serialized_end=305282
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG']._serialized_start=305285
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG']._serialized_end=305417
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS']._serialized_start=305420
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS']._serialized_end=305855
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWMPLSLABELCOUNTER']._serialized_start=305857
  _globals['_PATTERNFLOWMPLSLABELCOUNTER']._serialized_end=305974
  _globals['_PATTERNFLOWMPLSLABELMETRICTAG']._serialized_start=305976
  _globals['_PATTERNFLOWMPLSLABELMETRICTAG']._serialized_end=306099
  _globals['_PATTERNFLOWMPLSLABEL']._serialized_start=306102
  _globals['_PATTERNFLOWMPLSLABEL']._serialized_end=306530
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSCOUNTER']._serialized_start=306532
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSCOUNTER']._serialized_end=306656
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG']._serialized_start=306659
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG']._serialized_end=306789
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS']._serialized_start=306792
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS']._serialized_end=307217
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER']._serialized_start=307219
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER']._serialized_end=307344
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG']._serialized_start=307347
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG']._serialized_end=307478
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK']._serialized_start=307481
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK']._serialized_end=307949
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE']._serialized_start=210390
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE']._serialized_end=210486
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM']._serialized_end=210486
  _globals['_PATTERNFLOWMPLSTIMETOLIVECOUNTER']._serialized_start=307951
  _globals['_PATTERNFLOWMPLSTIMETOLIVECOUNTER']._serialized_end=308073
  _globals['_PATTERNFLOWMPLSTIMETOLIVEMETRICTAG']._serialized_start=308076
  _globals['_PATTERNFLOWMPLSTIMETOLIVEMETRICTAG']._serialized_end=308204
  _globals['_PATTERNFLOWMPLSTIMETOLIVE']._serialized_start=308207
  _globals['_PATTERNFLOWMPLSTIMETOLIVE']._serialized_end=308622
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVERSIONCOUNTER']._serialized_start=308624
  _globals['_PATTERNFLOWSNMPV2CVERSIONCOUNTER']._serialized_end=308746
  _globals['_PATTERNFLOWSNMPV2CVERSION']._serialized_start=308749
  _globals['_PATTERNFLOWSNMPV2CVERSION']._serialized_end=309102
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTIDCOUNTER']._serialized_start=309104
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTIDCOUNTER']._serialized_end=309231
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID']._serialized_start=309234
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID']._serialized_end=309607
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEXCOUNTER']._serialized_start=309610
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEXCOUNTER']._serialized_end=309738
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX']._serialized_start=309741
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX']._serialized_end=310118
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTIDCOUNTER']._serialized_start=310121
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTIDCOUNTER']._serialized_end=310252
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID']._serialized_start=310255
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID']._serialized_end=310644
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS']._serialized_start=310647
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS']._serialized_end=310878
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE']._serialized_start=310801
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE']._serialized_end=310857
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE_ENUM']._serialized_end=210446
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONSCOUNTER']._serialized_start=310881
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONSCOUNTER']._serialized_end=311017
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS']._serialized_start=311020
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS']._serialized_end=311429
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUECOUNTER']._serialized_start=311432
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUECOUNTER']._serialized_end=311579
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE']._serialized_start=311582
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE']._serialized_end=312035
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUECOUNTER']._serialized_start=312038
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUECOUNTER']._serialized_end=312187
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE']._serialized_start=312190
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE']._serialized_end=312651
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUECOUNTER']._serialized_start=312654
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUECOUNTER']._serialized_end=312801
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE']._serialized_start=312804
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE']._serialized_end=313257
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUECOUNTER']._serialized_start=313260
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUECOUNTER']._serialized_end=313409
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE']._serialized_start=313412
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE']._serialized_end=313873
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUECOUNTER']._serialized_start=313876
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUECOUNTER']._serialized_end=314026
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE']._serialized_start=314029
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE']._serialized_end=314494
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUECOUNTER']._serialized_start=314497
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUECOUNTER']._serialized_end=314652
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE']._serialized_start=314655
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE']._serialized_end=315140
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTIDCOUNTER']._serialized_start=315143
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTIDCOUNTER']._serialized_end=315273
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID']._serialized_start=315276
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID']._serialized_end=315661
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM']._serialized_start=315664
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM']._serialized_end=316009
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE']._serialized_start=224876
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE']._serialized_end=224936
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE_ENUM']._serialized_start=224886
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE_ENUM']._serialized_end=224936
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED']._serialized_start=224938
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED']._serialized_end=224993
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED_ENUM']._serialized_start=224951
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED_ENUM']._serialized_end=224993
  _globals['_PATTERNFLOWRSVPTIMETOLIVECOUNTER']._serialized_start=316011
  _globals['_PATTERNFLOWRSVPTIMETOLIVECOUNTER']._serialized_end=316133
  _globals['_PATTERNFLOWRSVPTIMETOLIVE']._serialized_start=316136
  _globals['_PATTERNFLOWRSVPTIMETOLIVE']._serialized_end=316489
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPRESERVEDCOUNTER']._serialized_start=316491
  _globals['_PATTERNFLOWRSVPRESERVEDCOUNTER']._serialized_end=316611
  _globals['_PATTERNFLOWRSVPRESERVED']._serialized_start=316614
  _globals['_PATTERNFLOWRSVPRESERVED']._serialized_end=316959
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESSCOUNTER']._serialized_start=316962
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESSCOUNTER']._serialized_end=317123
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS']._serialized_start=317126
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS']._serialized_end=317635
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVEDCOUNTER']._serialized_start=317638
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVEDCOUNTER']._serialized_end=317782
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED']._serialized_start=317785
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED']._serialized_end=318226
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELIDCOUNTER']._serialized_start=318229
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELIDCOUNTER']._serialized_end=318373
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID']._serialized_start=318376
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID']._serialized_end=318817
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGERCOUNTER']._serialized_start=318820
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGERCOUNTER']._serialized_end=318963
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER']._serialized_start=318966
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER']._serialized_end=319403
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4COUNTER']._serialized_start=319406
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4COUNTER']._serialized_end=319546
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4']._serialized_start=319549
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4']._serialized_end=319974
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESSCOUNTER']._serialized_start=319977
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESSCOUNTER']._serialized_end=320115
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS']._serialized_start=320118
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS']._serialized_end=320535
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLECOUNTER']._serialized_start=320538
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLECOUNTER']._serialized_end=320687
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE']._serialized_start=320690
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE']._serialized_end=321151
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODRCOUNTER']._serialized_start=321154
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODRCOUNTER']._serialized_end=321299
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR']._serialized_start=321302
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR']._serialized_end=321747
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBITCOUNTER']._serialized_start=321750
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBITCOUNTER']._serialized_end=321898
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT']._serialized_start=321901
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT']._serialized_end=322358
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESSCOUNTER']._serialized_start=322361
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESSCOUNTER']._serialized_end=322516
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS']._serialized_start=322519
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS']._serialized_end=323004
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBITCOUNTER']._serialized_start=323007
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBITCOUNTER']._serialized_end=323153
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT']._serialized_start=323156
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT']._serialized_end=323605
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVEDCOUNTER']._serialized_start=323608
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVEDCOUNTER']._serialized_end=323761
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED']._serialized_start=323764
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED']._serialized_end=324241
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PIDCOUNTER']._serialized_start=324244
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PIDCOUNTER']._serialized_end=324394
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID']._serialized_start=324397
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID']._serialized_end=324862
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESSCOUNTER']._serialized_start=324865
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESSCOUNTER']._serialized_end=325031
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS']._serialized_start=325034
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS']._serialized_end=325563
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVEDCOUNTER']._serialized_start=325566
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVEDCOUNTER']._serialized_end=325717
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED']._serialized_start=325720
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED']._serialized_end=326189
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPIDCOUNTER']._serialized_start=326192
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPIDCOUNTER']._serialized_end=326340
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID']._serialized_start=326343
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID']._serialized_end=326800
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSIONCOUNTER']._serialized_start=326803
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSIONCOUNTER']._serialized_end=326944
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION']._serialized_start=326947
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION']._serialized_end=327376
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1COUNTER']._serialized_start=327379
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1COUNTER']._serialized_end=327522
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1']._serialized_start=327525
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1']._serialized_end=327962
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTHCOUNTER']._serialized_start=327965
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTHCOUNTER']._serialized_end=328112
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH']._serialized_start=328115
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH']._serialized_end=328568
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADERCOUNTER']._serialized_start=328571
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADERCOUNTER']._serialized_end=328718
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER']._serialized_start=328721
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER']._serialized_end=329174
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBITCOUNTER']._serialized_start=329177
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBITCOUNTER']._serialized_end=329318
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT']._serialized_start=329321
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT']._serialized_end=329750
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2COUNTER']._serialized_start=329753
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2COUNTER']._serialized_end=329896
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2']._serialized_start=329899
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2']._serialized_end=330336
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATACOUNTER']._serialized_start=330339
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATACOUNTER']._serialized_end=330492
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA']._serialized_start=330495
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA']._serialized_end=330972
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPECCOUNTER']._serialized_start=330975
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPECCOUNTER']._serialized_end=331136
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC']._serialized_start=331139
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC']._serialized_end=331648
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAGCOUNTER']._serialized_start=331651
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAGCOUNTER']._serialized_end=331801
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG']._serialized_start=331804
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG']._serialized_end=332269
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTHCOUNTER']._serialized_start=332272
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTHCOUNTER']._serialized_end=332424
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH']._serialized_start=332427
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH']._serialized_end=332900
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNITCOUNTER']._serialized_start=332903
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNITCOUNTER']._serialized_end=333055
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT']._serialized_start=333058
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT']._serialized_end=333531
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZECOUNTER']._serialized_start=333534
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZECOUNTER']._serialized_end=333685
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE']._serialized_start=333688
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE']._serialized_end=334157
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESSCOUNTER']._serialized_start=334160
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESSCOUNTER']._serialized_end=334314
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS']._serialized_start=334317
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS']._serialized_end=334798
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTHCOUNTER']._serialized_start=334801
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTHCOUNTER']._serialized_end=334956
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH']._serialized_start=334959
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH']._serialized_end=335444
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS']._serialized_start=335447
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS']._serialized_end=335694
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE']._serialized_start=310801
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE']._serialized_end=310857
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE_ENUM']._serialized_end=210446
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE']._serialized_start=335697
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE']._serialized_end=335944
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE']._serialized_start=310801
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE']._serialized_end=310857
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE_ENUM']._serialized_start=210400
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE_ENUM']._serialized_end=210446
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPECOUNTER']._serialized_start=335947
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPECOUNTER']._serialized_end=336080
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE']._serialized_start=336083
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE']._serialized_end=336480
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPVERSIONCOUNTER']._serialized_start=336482
  _globals['_PATTERNFLOWLACPVERSIONCOUNTER']._serialized_end=336601
  _globals['_PATTERNFLOWLACPVERSION']._serialized_start=336604
  _globals['_PATTERNFLOWLACPVERSION']._serialized_end=336945
  _globals['_PATTERNFLOWLACPVERSION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPVERSION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPVERSION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPVERSION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORTYPECOUNTER']._serialized_start=336947
  _globals['_PATTERNFLOWLACPDUACTORTYPECOUNTER']._serialized_end=337070
  _globals['_PATTERNFLOWLACPDUACTORTYPE']._serialized_start=337073
  _globals['_PATTERNFLOWLACPDUACTORTYPE']._serialized_end=337430
  _globals['_PATTERNFLOWLACPDUACTORTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORLENGTHCOUNTER']._serialized_start=337432
  _globals['_PATTERNFLOWLACPDUACTORLENGTHCOUNTER']._serialized_end=337557
  _globals['_PATTERNFLOWLACPDUACTORLENGTH']._serialized_start=337560
  _globals['_PATTERNFLOWLACPDUACTORLENGTH']._serialized_end=337925
  _globals['_PATTERNFLOWLACPDUACTORLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITYCOUNTER']._serialized_start=337928
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITYCOUNTER']._serialized_end=338061
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITY']._serialized_start=338064
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITY']._serialized_end=338461
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMPRIORITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMIDCOUNTER']._serialized_start=338463
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMIDCOUNTER']._serialized_end=338590
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMID']._serialized_start=338593
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMID']._serialized_end=338966
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSYSTEMID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORKEYCOUNTER']._serialized_start=338968
  _globals['_PATTERNFLOWLACPDUACTORKEYCOUNTER']._serialized_end=339090
  _globals['_PATTERNFLOWLACPDUACTORKEY']._serialized_start=339093
  _globals['_PATTERNFLOWLACPDUACTORKEY']._serialized_end=339446
  _globals['_PATTERNFLOWLACPDUACTORKEY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORKEY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORKEY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORKEY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITYCOUNTER']._serialized_start=339449
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITYCOUNTER']._serialized_end=339580
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITY']._serialized_start=339583
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITY']._serialized_end=339972
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORPORTPRIORITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBERCOUNTER']._serialized_start=339975
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBERCOUNTER']._serialized_end=340104
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBER']._serialized_start=340107
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBER']._serialized_end=340488
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORPORTNUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORRESERVEDCOUNTER']._serialized_start=340490
  _globals['_PATTERNFLOWLACPDUACTORRESERVEDCOUNTER']._serialized_end=340617
  _globals['_PATTERNFLOWLACPDUACTORRESERVED']._serialized_start=340620
  _globals['_PATTERNFLOWLACPDUACTORRESERVED']._serialized_end=340993
  _globals['_PATTERNFLOWLACPDUACTORRESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORRESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORRESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORRESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERTYPECOUNTER']._serialized_start=340995
  _globals['_PATTERNFLOWLACPDUPARTNERTYPECOUNTER']._serialized_end=341120
  _globals['_PATTERNFLOWLACPDUPARTNERTYPE']._serialized_start=341123
  _globals['_PATTERNFLOWLACPDUPARTNERTYPE']._serialized_end=341488
  _globals['_PATTERNFLOWLACPDUPARTNERTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTHCOUNTER']._serialized_start=341490
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTHCOUNTER']._serialized_end=341617
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTH']._serialized_start=341620
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTH']._serialized_end=341993
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITYCOUNTER']._serialized_start=341996
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITYCOUNTER']._serialized_end=342131
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITY']._serialized_start=342134
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITY']._serialized_end=342539
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMPRIORITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMIDCOUNTER']._serialized_start=342542
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMIDCOUNTER']._serialized_end=342671
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMID']._serialized_start=342674
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMID']._serialized_end=343055
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMID_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMID_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMID_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSYSTEMID_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERKEYCOUNTER']._serialized_start=343057
  _globals['_PATTERNFLOWLACPDUPARTNERKEYCOUNTER']._serialized_end=343181
  _globals['_PATTERNFLOWLACPDUPARTNERKEY']._serialized_start=343184
  _globals['_PATTERNFLOWLACPDUPARTNERKEY']._serialized_end=343545
  _globals['_PATTERNFLOWLACPDUPARTNERKEY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERKEY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERKEY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERKEY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITYCOUNTER']._serialized_start=343548
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITYCOUNTER']._serialized_end=343681
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITY']._serialized_start=343684
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITY']._serialized_end=344081
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERPORTPRIORITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBERCOUNTER']._serialized_start=344084
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBERCOUNTER']._serialized_end=344215
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBER']._serialized_start=344218
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBER']._serialized_end=344607
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBER_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBER_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBER_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERPORTNUMBER_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVEDCOUNTER']._serialized_start=344610
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVEDCOUNTER']._serialized_end=344739
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVED']._serialized_start=344742
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVED']._serialized_end=345123
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERRESERVED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPECOUNTER']._serialized_start=345125
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPECOUNTER']._serialized_end=345252
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPE']._serialized_start=345255
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPE']._serialized_end=345628
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUCOLLECTORTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTHCOUNTER']._serialized_start=345631
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTHCOUNTER']._serialized_end=345760
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTH']._serialized_start=345763
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTH']._serialized_end=346144
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUCOLLECTORLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAYCOUNTER']._serialized_start=346147
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAYCOUNTER']._serialized_end=346278
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAY']._serialized_start=346281
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAY']._serialized_end=346670
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUCOLLECTORMAXDELAY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPECOUNTER']._serialized_start=346673
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPECOUNTER']._serialized_end=346801
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPE']._serialized_start=346804
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPE']._serialized_end=347181
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPE_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPE_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPE_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUTERMINATORTYPE_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTHCOUNTER']._serialized_start=347184
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTHCOUNTER']._serialized_end=347314
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTH']._serialized_start=347317
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTH']._serialized_end=347702
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTH_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTH_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTH_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUTERMINATORLENGTH_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITYCOUNTER']._serialized_start=347705
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITYCOUNTER']._serialized_end=347837
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITY']._serialized_start=347840
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITY']._serialized_end=348233
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATEACTIVITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUTCOUNTER']._serialized_start=348236
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUTCOUNTER']._serialized_end=348367
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUT']._serialized_start=348370
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUT']._serialized_end=348759
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATETIMEOUT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATIONCOUNTER']._serialized_start=348762
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATIONCOUNTER']._serialized_end=348897
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATION']._serialized_start=348900
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATION']._serialized_end=349305
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATEAGGREGATION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATIONCOUNTER']._serialized_start=349308
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATIONCOUNTER']._serialized_end=349447
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATION']._serialized_start=349450
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATION']._serialized_end=349871
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATESYNCHRONIZATION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTINGCOUNTER']._serialized_start=349874
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTINGCOUNTER']._serialized_end=350008
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTING']._serialized_start=350011
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTING']._serialized_end=350412
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTING_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTING_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTING_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATECOLLECTING_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTINGCOUNTER']._serialized_start=350415
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTINGCOUNTER']._serialized_end=350551
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTING']._serialized_start=350554
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTING']._serialized_end=350963
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTING_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTING_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTING_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATEDISTRIBUTING_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTEDCOUNTER']._serialized_start=350966
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTEDCOUNTER']._serialized_end=351099
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTED']._serialized_start=351102
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTED']._serialized_end=351499
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATEDEFAULTED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIREDCOUNTER']._serialized_start=351502
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIREDCOUNTER']._serialized_end=351633
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIRED']._serialized_start=351636
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIRED']._serialized_end=352025
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIRED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIRED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIRED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUACTORSTATEEXPIRED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITYCOUNTER']._serialized_start=352028
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITYCOUNTER']._serialized_end=352162
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITY']._serialized_start=352165
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITY']._serialized_end=352566
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITY_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITY_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITY_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEACTIVITY_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUTCOUNTER']._serialized_start=352569
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUTCOUNTER']._serialized_end=352702
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUT']._serialized_start=352705
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUT']._serialized_end=353102
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUT_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUT_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUT_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATETIMEOUT_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATIONCOUNTER']._serialized_start=353105
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATIONCOUNTER']._serialized_end=353242
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATION']._serialized_start=353245
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATION']._serialized_end=353658
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEAGGREGATION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATIONCOUNTER']._serialized_start=353661
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATIONCOUNTER']._serialized_end=353802
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATION']._serialized_start=353805
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATION']._serialized_end=354234
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATION_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATION_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATION_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATESYNCHRONIZATION_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTINGCOUNTER']._serialized_start=354237
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTINGCOUNTER']._serialized_end=354373
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTING']._serialized_start=354376
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTING']._serialized_end=354785
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTING_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTING_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTING_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATECOLLECTING_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTINGCOUNTER']._serialized_start=354788
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTINGCOUNTER']._serialized_end=354926
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTING']._serialized_start=354929
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTING']._serialized_end=355346
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTING_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTING_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTING_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDISTRIBUTING_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTEDCOUNTER']._serialized_start=355349
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTEDCOUNTER']._serialized_end=355484
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTED']._serialized_start=355487
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTED']._serialized_end=355892
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEDEFAULTED_CHOICE_ENUM']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIREDCOUNTER']._serialized_start=355895
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIREDCOUNTER']._serialized_end=356028
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIRED']._serialized_start=356031
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIRED']._serialized_end=356428
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIRED_CHOICE']._serialized_start=211060
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIRED_CHOICE']._serialized_end=211146
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIRED_CHOICE_ENUM']._serialized_start=211070
  _globals['_PATTERNFLOWLACPDUPARTNERSTATEEXPIRED_CHOICE_ENUM']._serialized_end=211146
  _globals['_VERSION']._serialized_start=356431
  _globals['_VERSION']._serialized_end=356576
  _globals['_SUCCESS']._serialized_start=356578
  _globals['_SUCCESS']._serialized_end=356618
  _globals['_FAILURE']._serialized_start=356620
  _globals['_FAILURE']._serialized_end=356656
  _globals['_DATA']._serialized_start=356658
  _globals['_DATA']._serialized_end=356699
  _globals['_SETCONFIGREQUEST']._serialized_start=356701
  _globals['_SETCONFIGREQUEST']._serialized_end=356748
  _globals['_UPDATECONFIGREQUEST']._serialized_start=356750
  _globals['_UPDATECONFIGREQUEST']._serialized_end=356813
  _globals['_SETCONFIGRESPONSE']._serialized_start=356815
  _globals['_SETCONFIGRESPONSE']._serialized_end=356865
  _globals['_GETCONFIGRESPONSE']._serialized_start=356867
  _globals['_GETCONFIGRESPONSE']._serialized_end=356915
  _globals['_UPDATECONFIGRESPONSE']._serialized_start=356917
  _globals['_UPDATECONFIGRESPONSE']._serialized_end=356970
  _globals['_APPENDCONFIGREQUEST']._serialized_start=356972
  _globals['_APPENDCONFIGREQUEST']._serialized_end=357035
  _globals['_APPENDCONFIGRESPONSE']._serialized_start=357037
  _globals['_APPENDCONFIGRESPONSE']._serialized_end=357090
  _globals['_DELETECONFIGREQUEST']._serialized_start=357092
  _globals['_DELETECONFIGREQUEST']._serialized_end=357155
  _globals['_DELETECONFIGRESPONSE']._serialized_start=357157
  _globals['_DELETECONFIGRESPONSE']._serialized_end=357210
  _globals['_SETCONTROLSTATEREQUEST']._serialized_start=357212
  _globals['_SETCONTROLSTATEREQUEST']._serialized_end=357278
  _globals['_SETCONTROLSTATERESPONSE']._serialized_start=357280
  _globals['_SETCONTROLSTATERESPONSE']._serialized_end=357336
  _globals['_SETCONTROLACTIONREQUEST']._serialized_start=357338
  _globals['_SETCONTROLACTIONREQUEST']._serialized_end=357407
  _globals['_SETCONTROLACTIONRESPONSE']._serialized_start=357409
  _globals['_SETCONTROLACTIONRESPONSE']._serialized_end=357496
  _globals['_GETMETRICSREQUEST']._serialized_start=357498
  _globals['_GETMETRICSREQUEST']._serialized_end=357563
  _globals['_GETMETRICSRESPONSE']._serialized_start=357565
  _globals['_GETMETRICSRESPONSE']._serialized_end=357633
  _globals['_GETSTATESREQUEST']._serialized_start=357635
  _globals['_GETSTATESREQUEST']._serialized_end=357697
  _globals['_GETSTATESRESPONSE']._serialized_start=357699
  _globals['_GETSTATESRESPONSE']._serialized_end=357764
  _globals['_GETCAPTUREREQUEST']._serialized_start=357766
  _globals['_GETCAPTUREREQUEST']._serialized_end=357831
  _globals['_GETCAPTURERESPONSE']._serialized_start=357833
  _globals['_GETCAPTURERESPONSE']._serialized_end=357877
  _globals['_GETVERSIONRESPONSE']._serialized_start=357879
  _globals['_GETVERSIONRESPONSE']._serialized_end=357930
  _globals['_OPENAPI']._serialized_start=357933
  _globals['_OPENAPI']._serialized_end=359097
# @@protoc_insertion_point(module_scope)
